if exists ( Select * From sysobjects where id=object_id('dbo.A_Admin_UserGroup_User_Get'))
	Drop procedure dbo.A_Admin_UserGroup_User_Get
GO

Create Procedure [dbo].[A_Admin_UserGroup_User_Get]
	@iduser uniqueidentifier
As
Begin
	Select 	u.Id, 
		u.Name, 
		u.Info, 
		u.ParentGroupId, 
		u.Login, 
		u.Password, 
		u.Type, 
		isnull ( IsOperator, 0 ) as IsOperator,
		isnull ( up.IdRole, '00000000-0000-0000-0000-000000000000' ) as RoleId,
		isnull ( up.CallerId, '' ) as CallerId,
		isnull ( u.IsDeleted, 0 ) as IsDeleted,
		u.DeleteDT,
		g.Name as GroupName,
		g.Info as GroupInfo
		
	From A_Users u
		left join A_UserParams up on u.Id = up.IdUser
		left join A_Groups g on u.ParentGroupId = g.Id
	
	Where u.Id = @iduser
End
GO


If exists ( Select * From sysobjects where id = object_id ( 'dbo.A_Admin_UserGroup_User_Save' ))
	Drop procedure dbo.A_Admin_UserGroup_User_Save
GO

Create procedure [dbo].[A_Admin_UserGroup_User_Save]
	@id		uniqueidentifier,
	@name		nvarchar ( 200 ),
	@info		nvarchar ( 1000 ),
	@parentgroupid	uniqueidentifier,
	@login		nvarchar ( 50 ),
	@password	nvarchar ( 50 ),	
	@type		int,
	@isoperator	bit,
	@roleid		uniqueidentifier = null,
	@callerid	nvarchar ( 20 ) = '',
	@isdeleted	bit = 0,
	@deletedt	datetime = NULL
as
begin

	Declare @deletedtN DateTime
	Select @deletedtN = case when (( @isdeleted is null ) or ( @isdeleted = 0 )) then NULL else @deletedt end

	Update A_Users
	Set 	
		Name 		= @name,
		Info 		= @info,
		ParentGroupId 	= @parentgroupid,
		Login		= @login,
		Password 	= @password,
		Type		= @type,
		IsDeleted	= @isdeleted,
		DeleteDT	= @deletedtN
	Where 
		Id 		= @id
	
	if ( @@rowcount = 0 )
	begin
		Insert 
		Into A_Users 
			( Id, Name, Info, ParentGroupId, Login, Password, Type, Enabled, IsDeleted, DeleteDT )
		Values
			( @id, @name, @info, @parentgroupid, @login, @password, @type, 1, @isdeleted, @deletedt )
	end

	Update A_UserParams
	Set	IdRole = @roleid,
		CallerId = @callerid,
		IsOperator = @isoperator
	Where IdUser = @id

	if ( @@rowcount = 0 )
		Insert 
		Into A_UserParams ( IdUser, IdRole, IsOperator, CallerId, IsRedirect, IsCC, IsLunch  )
		Values	( @id, @roleid, @isoperator, @callerid, 0, 0, 0 )



	if ( @isoperator = 0 )
	  begin
		Delete 
		From C_GroupOperators
		Where IDoperator = @id
	  end


	exec A_Admin_UserGroup_Group_SiftEmpty


	--      
	If Exists ( Select * FROM Master..sysdatabases where name like 'oktell_cc_temp' )
	If Exists ( Select * FROM oktell_cc_temp..sysobjects where id = Object_Id ( 'oktell_cc_temp.dbo.A_Cube_CC_Cat_OperatorInfo' ) )
		Update oktell_cc_temp.dbo.A_Cube_CC_Cat_OperatorInfo
		Set Name = @name
		Where Id = @id

end
GO


If exists ( Select * From sysobjects where id = object_id ( 'dbo.A_Admin_UserGroup_User_GetControlled' ))
	Drop procedure dbo.A_Admin_UserGroup_User_GetControlled
GO

Create Procedure [dbo].[A_Admin_UserGroup_User_GetControlled]
	@iduser uniqueidentifier = null
As
Begin

    if ( @iduser is null )
	Select UserA, UserB
	From A_UserControls
	Order By UserA
   
    else
	Select UserA, UserB
	From A_UserControls
	Where UserA = @iduser

End
GO


If exists ( Select * From sysobjects where id = object_id ( 'dbo.A_Admin_UserGroup_User_GetControlling' ))
	Drop procedure dbo.A_Admin_UserGroup_User_GetControlling
GO

Create Procedure [dbo].[A_Admin_UserGroup_User_GetControlling]
	@iduser uniqueidentifier = null
As
Begin

    if ( @iduser is null )
	Select UserA, UserB
	From A_UserControls
	Order By UserB
    
    else
	Select UserA, UserB
	From A_UserControls
	Where UserB = @iduser
End
GO


If exists ( Select * From sysobjects where id = object_id ( 'dbo.A_Admin_UserGroup_User_GetControlledLines' ))
	Drop procedure dbo.A_Admin_UserGroup_User_GetControlledLines
GO


Create Procedure [dbo].[A_Admin_UserGroup_User_GetControlledLines]
	@iduser uniqueidentifier = null
As
Begin

    if ( @iduser is null )
	Select UserA, IdLine
	From A_UserControlLines
	Order By UserA
    
    else
	Select UserA, IdLine
	From A_UserControlLines
	Where UserA = @iduser
 	
End
GO



if exists ( Select * from sysobjects where id = object_id ( 'dbo.A_UserRoles_Load_Roles' ))
	Drop procedure dbo.A_UserRoles_Load_Roles
GO

Create Procedure dbo.A_UserRoles_Load_Roles
	@onlyforuserid uniqueidentifier = null,
	@onlyforroleid uniqueidentifier = null,
	@skipdominant bit = 0
As
Begin

    if ( @onlyforuserid is null )

	Select Id, Name, BaseRole, Domination, UserCount 
	From dbo.A_UserRoles_Roles a
	    left join
	    (
		Select IdRole, UserCount = Count ( * )
		From A_UserRoles_RolesOfUsers
		Group By IdRole ) b On a.Id = b.IdRole
	Where (( @skipdominant = 0 ) or ( Domination != 1 ))
		And ((@onlyforroleid is null) or ( a.Id = @onlyforroleid ))
	Order by Name

    else begin

	Declare @roles table (id uniqueidentifier)
	Insert into @roles (id)
		Select IdRole
		From A_UserRoles_RolesOfUsers
		Where IdUser = @onlyforuserid

	Select a.Id, a.Name, a.BaseRole, a.Domination, b.UserCount 
	From dbo.A_UserRoles_Roles a
		inner join @roles r on a.Id = r.id
	    	left join (
			Select IdRole, UserCount = Count ( * )
			From A_UserRoles_RolesOfUsers
			Group By IdRole ) b On a.Id = b.IdRole
	Where (( @skipdominant = 0 ) or ( a.Domination != 1 ))
		And ((@onlyforroleid is null) or ( a.Id = @onlyforroleid ))
	Order by Name

    end

End
GO



if exists ( Select * from sysobjects where id = object_id ( 'dbo.A_UserRoles_Load_RightsOfRoles' ))
	Drop procedure dbo.A_UserRoles_Load_RightsOfRoles
GO

Create Procedure dbo.A_UserRoles_Load_RightsOfRoles
	@onlyforuserid uniqueidentifier = null,
	@onlyforroleid uniqueidentifier = null,
	@skipdominant bit = 0
As
Begin
	if ( @onlyforuserid is null )
		Select a.IdRole, b.Code, a.Value 
		From dbo.A_UserRoles_RightsOfRoles a
			inner join A_UserRoles_Roles roles on roles.Id = a.IdRole
			left join A_UserRoles_Rights b On a.IdRight = b.id
		Where ((@skipdominant = 0) or (roles.Domination = 0))
			And ((@onlyforroleid is null) or ( roles.Id = @onlyforroleid ))

	else begin

		Declare @roles table (id uniqueidentifier)
		Insert into @roles (id)
			Select IdRole
			From A_UserRoles_RolesOfUsers
			Where IdUser = @onlyforuserid

		Select a.IdRole, b.Code, a.Value 
		From dbo.A_UserRoles_RightsOfRoles a
			inner join @roles r on r.id = a.IdRole
			inner join A_UserRoles_Roles roles on roles.Id = a.IdRole
			left join A_UserRoles_Rights b On a.IdRight = b.id
		Where ((@skipdominant = 0) or (roles.Domination = 0))
			And ((@onlyforroleid is null) or ( roles.Id = @onlyforroleid ))
		
	end

End
GO



if exists ( Select * from sysobjects where id = object_id ( 'dbo.A_UserRoles_Load_RolesOfUsers' ))
	Drop procedure dbo.A_UserRoles_Load_RolesOfUsers
GO

Create Procedure dbo.A_UserRoles_Load_RolesOfUsers
	@onlyforuserid uniqueidentifier = null,
	@onlyforroleid uniqueidentifier = null,
	@skipdominant bit = 0
As
Begin
	if ( @onlyforuserid is null )
		Select IdUser, IdRole, b.Domination 
		From dbo.A_UserRoles_RolesOfUsers a
			left join A_UserRoles_Roles b On a.IdRole = b.Id
		Where ( b.Domination is not null )
			And ((@skipdominant = 0) or (b.Domination = 0))
			And ((@onlyforroleid is null) or ( b.Id = @onlyforroleid ))

	else begin

		Declare @roles table (id uniqueidentifier)
		Insert into @roles (id)
			Select IdRole
			From A_UserRoles_RolesOfUsers
			Where IdUser = @onlyforuserid

		Select a.IdUser, a.IdRole, b.Domination 
		From dbo.A_UserRoles_RolesOfUsers a
			inner join @roles r on r.Id = a.IdRole
			left join A_UserRoles_Roles b On a.IdRole = b.Id
		Where (b.Domination is not null)
			And ((@skipdominant = 0) or (b.Domination = 0))
			And ((@onlyforroleid is null) or ( b.Id = @onlyforroleid ))
	end

End
GO