/*!
 * jQuery JavaScript Library v1.8.3
 * http://jquery.com/
 *
 * Includes Sizzle.js
 * http://sizzlejs.com/
 *
 * Copyright 2012 jQuery Foundation and other contributors
 * Released under the MIT license
 * http://jquery.org/license
 *
 * Date: Tue Nov 13 2012 08:20:33 GMT-0500 (Eastern Standard Time)
 */
(function( window, undefined ) {
	var
	// A central reference to the root jQuery(document)
		rootjQuery,

	// The deferred used on DOM ready
		readyList,

	// Use the correct document accordingly with window argument (sandbox)
		document = window.document,
		location = window.location,
		navigator = window.navigator,

	// Map over jQuery in case of overwrite
		_jQuery = window.jQuery,

	// Map over the $ in case of overwrite
		_$ = window.$,

	// Save a reference to some core methods
		core_push = Array.prototype.push,
		core_slice = Array.prototype.slice,
		core_indexOf = Array.prototype.indexOf,
		core_toString = Object.prototype.toString,
		core_hasOwn = Object.prototype.hasOwnProperty,
		core_trim = String.prototype.trim,

	// Define a local copy of jQuery
		jQuery = function( selector, context ) {
			// The jQuery object is actually just the init constructor 'enhanced'
			return new jQuery.fn.init( selector, context, rootjQuery );
		},

	// Used for matching numbers
		core_pnum = /[\-+]?(?:\d*\.|)\d+(?:[eE][\-+]?\d+|)/.source,

	// Used for detecting and trimming whitespace
		core_rnotwhite = /\S/,
		core_rspace = /\s+/,

	// Make sure we trim BOM and NBSP (here's looking at you, Safari 5.0 and IE)
		rtrim = /^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g,

	// A simple way to check for HTML strings
	// Prioritize #id over <tag> to avoid XSS via location.hash (#9521)
		rquickExpr = /^(?:[^#<]*(<[\w\W]+>)[^>]*$|#([\w\-]*)$)/,

	// Match a standalone tag
		rsingleTag = /^<(\w+)\s*\/?>(?:<\/\1>|)$/,

	// JSON RegExp
		rvalidchars = /^[\],:{}\s]*$/,
		rvalidbraces = /(?:^|:|,)(?:\s*\[)+/g,
		rvalidescape = /\\(?:["\\\/bfnrt]|u[\da-fA-F]{4})/g,
		rvalidtokens = /"[^"\\\r\n]*"|true|false|null|-?(?:\d\d*\.|)\d+(?:[eE][\-+]?\d+|)/g,

	// Matches dashed string for camelizing
		rmsPrefix = /^-ms-/,
		rdashAlpha = /-([\da-z])/gi,

	// Used by jQuery.camelCase as callback to replace()
		fcamelCase = function( all, letter ) {
			return ( letter + "" ).toUpperCase();
		},

	// The ready event handler and self cleanup method
		DOMContentLoaded = function() {
			if ( document.addEventListener ) {
				document.removeEventListener( "DOMContentLoaded", DOMContentLoaded, false );
				jQuery.ready();
			} else if ( document.readyState === "complete" ) {
				// we're here because readyState === "complete" in oldIE
				// which is good enough for us to call the dom ready!
				document.detachEvent( "onreadystatechange", DOMContentLoaded );
				jQuery.ready();
			}
		},

	// [[Class]] -> type pairs
		class2type = {};

	jQuery.fn = jQuery.prototype = {
		constructor: jQuery,
		init: function( selector, context, rootjQuery ) {
			var match, elem, ret, doc;

			// Handle $(""), $(null), $(undefined), $(false)
			if ( !selector ) {
				return this;
			}

			// Handle $(DOMElement)
			if ( selector.nodeType ) {
				this.context = this[0] = selector;
				this.length = 1;
				return this;
			}

			// Handle HTML strings
			if ( typeof selector === "string" ) {
				if ( selector.charAt(0) === "<" && selector.charAt( selector.length - 1 ) === ">" && selector.length >= 3 ) {
					// Assume that strings that start and end with <> are HTML and skip the regex check
					match = [ null, selector, null ];

				} else {
					match = rquickExpr.exec( selector );
				}

				// Match html or make sure no context is specified for #id
				if ( match && (match[1] || !context) ) {

					// HANDLE: $(html) -> $(array)
					if ( match[1] ) {
						context = context instanceof jQuery ? context[0] : context;
						doc = ( context && context.nodeType ? context.ownerDocument || context : document );

						// scripts is true for back-compat
						selector = jQuery.parseHTML( match[1], doc, true );
						if ( rsingleTag.test( match[1] ) && jQuery.isPlainObject( context ) ) {
							this.attr.call( selector, context, true );
						}

						return jQuery.merge( this, selector );

						// HANDLE: $(#id)
					} else {
						elem = document.getElementById( match[2] );

						// Check parentNode to catch when Blackberry 4.6 returns
						// nodes that are no longer in the document #6963
						if ( elem && elem.parentNode ) {
							// Handle the case where IE and Opera return items
							// by name instead of ID
							if ( elem.id !== match[2] ) {
								return rootjQuery.find( selector );
							}

							// Otherwise, we inject the element directly into the jQuery object
							this.length = 1;
							this[0] = elem;
						}

						this.context = document;
						this.selector = selector;
						return this;
					}

					// HANDLE: $(expr, $(...))
				} else if ( !context || context.jquery ) {
					return ( context || rootjQuery ).find( selector );

					// HANDLE: $(expr, context)
					// (which is just equivalent to: $(context).find(expr)
				} else {
					return this.constructor( context ).find( selector );
				}

				// HANDLE: $(function)
				// Shortcut for document ready
			} else if ( jQuery.isFunction( selector ) ) {
				return rootjQuery.ready( selector );
			}

			if ( selector.selector !== undefined ) {
				this.selector = selector.selector;
				this.context = selector.context;
			}

			return jQuery.makeArray( selector, this );
		},

		// Start with an empty selector
		selector: "",

		// The current version of jQuery being used
		jquery: "1.8.3",

		// The default length of a jQuery object is 0
		length: 0,

		// The number of elements contained in the matched element set
		size: function() {
			return this.length;
		},

		toArray: function() {
			return core_slice.call( this );
		},

		// Get the Nth element in the matched element set OR
		// Get the whole matched element set as a clean array
		get: function( num ) {
			return num == null ?

				// Return a 'clean' array
				this.toArray() :

				// Return just the object
				( num < 0 ? this[ this.length + num ] : this[ num ] );
		},

		// Take an array of elements and push it onto the stack
		// (returning the new matched element set)
		pushStack: function( elems, name, selector ) {

			// Build a new jQuery matched element set
			var ret = jQuery.merge( this.constructor(), elems );

			// Add the old object onto the stack (as a reference)
			ret.prevObject = this;

			ret.context = this.context;

			if ( name === "find" ) {
				ret.selector = this.selector + ( this.selector ? " " : "" ) + selector;
			} else if ( name ) {
				ret.selector = this.selector + "." + name + "(" + selector + ")";
			}

			// Return the newly-formed element set
			return ret;
		},

		// Execute a callback for every element in the matched set.
		// (You can seed the arguments with an array of args, but this is
		// only used internally.)
		each: function( callback, args ) {
			return jQuery.each( this, callback, args );
		},

		ready: function( fn ) {
			// Add the callback
			jQuery.ready.promise().done( fn );

			return this;
		},

		eq: function( i ) {
			i = +i;
			return i === -1 ?
				this.slice( i ) :
				this.slice( i, i + 1 );
		},

		first: function() {
			return this.eq( 0 );
		},

		last: function() {
			return this.eq( -1 );
		},

		slice: function() {
			return this.pushStack( core_slice.apply( this, arguments ),
				"slice", core_slice.call(arguments).join(",") );
		},

		map: function( callback ) {
			return this.pushStack( jQuery.map(this, function( elem, i ) {
				return callback.call( elem, i, elem );
			}));
		},

		end: function() {
			return this.prevObject || this.constructor(null);
		},

		// For internal use only.
		// Behaves like an Array's method, not like a jQuery method.
		push: core_push,
		sort: [].sort,
		splice: [].splice
	};

// Give the init function the jQuery prototype for later instantiation
	jQuery.fn.init.prototype = jQuery.fn;

	jQuery.extend = jQuery.fn.extend = function() {
		var options, name, src, copy, copyIsArray, clone,
			target = arguments[0] || {},
			i = 1,
			length = arguments.length,
			deep = false;

		// Handle a deep copy situation
		if ( typeof target === "boolean" ) {
			deep = target;
			target = arguments[1] || {};
			// skip the boolean and the target
			i = 2;
		}

		// Handle case when target is a string or something (possible in deep copy)
		if ( typeof target !== "object" && !jQuery.isFunction(target) ) {
			target = {};
		}

		// extend jQuery itself if only one argument is passed
		if ( length === i ) {
			target = this;
			--i;
		}

		for ( ; i < length; i++ ) {
			// Only deal with non-null/undefined values
			if ( (options = arguments[ i ]) != null ) {
				// Extend the base object
				for ( name in options ) {
					src = target[ name ];
					copy = options[ name ];

					// Prevent never-ending loop
					if ( target === copy ) {
						continue;
					}

					// Recurse if we're merging plain objects or arrays
					if ( deep && copy && ( jQuery.isPlainObject(copy) || (copyIsArray = jQuery.isArray(copy)) ) ) {
						if ( copyIsArray ) {
							copyIsArray = false;
							clone = src && jQuery.isArray(src) ? src : [];

						} else {
							clone = src && jQuery.isPlainObject(src) ? src : {};
						}

						// Never move original objects, clone them
						target[ name ] = jQuery.extend( deep, clone, copy );

						// Don't bring in undefined values
					} else if ( copy !== undefined ) {
						target[ name ] = copy;
					}
				}
			}
		}

		// Return the modified object
		return target;
	};

	jQuery.extend({
		noConflict: function( deep ) {
			if ( window.$ === jQuery ) {
				window.$ = _$;
			}

			if ( deep && window.jQuery === jQuery ) {
				window.jQuery = _jQuery;
			}

			return jQuery;
		},

		// Is the DOM ready to be used? Set to true once it occurs.
		isReady: false,

		// A counter to track how many items to wait for before
		// the ready event fires. See #6781
		readyWait: 1,

		// Hold (or release) the ready event
		holdReady: function( hold ) {
			if ( hold ) {
				jQuery.readyWait++;
			} else {
				jQuery.ready( true );
			}
		},

		// Handle when the DOM is ready
		ready: function( wait ) {

			// Abort if there are pending holds or we're already ready
			if ( wait === true ? --jQuery.readyWait : jQuery.isReady ) {
				return;
			}

			// Make sure body exists, at least, in case IE gets a little overzealous (ticket #5443).
			if ( !document.body ) {
				return setTimeout( jQuery.ready, 1 );
			}

			// Remember that the DOM is ready
			jQuery.isReady = true;

			// If a normal DOM Ready event fired, decrement, and wait if need be
			if ( wait !== true && --jQuery.readyWait > 0 ) {
				return;
			}

			// If there are functions bound, to execute
			readyList.resolveWith( document, [ jQuery ] );

			// Trigger any bound ready events
			if ( jQuery.fn.trigger ) {
				jQuery( document ).trigger("ready").off("ready");
			}
		},

		// See test/unit/core.js for details concerning isFunction.
		// Since version 1.3, DOM methods and functions like alert
		// aren't supported. They return false on IE (#2968).
		isFunction: function( obj ) {
			return jQuery.type(obj) === "function";
		},

		isArray: Array.isArray || function( obj ) {
			return jQuery.type(obj) === "array";
		},

		isWindow: function( obj ) {
			return obj != null && obj == obj.window;
		},

		isNumeric: function( obj ) {
			return !isNaN( parseFloat(obj) ) && isFinite( obj );
		},

		type: function( obj ) {
			return obj == null ?
				String( obj ) :
				class2type[ core_toString.call(obj) ] || "object";
		},

		isPlainObject: function( obj ) {
			// Must be an Object.
			// Because of IE, we also have to check the presence of the constructor property.
			// Make sure that DOM nodes and window objects don't pass through, as well
			if ( !obj || jQuery.type(obj) !== "object" || obj.nodeType || jQuery.isWindow( obj ) ) {
				return false;
			}

			try {
				// Not own constructor property must be Object
				if ( obj.constructor &&
					!core_hasOwn.call(obj, "constructor") &&
					!core_hasOwn.call(obj.constructor.prototype, "isPrototypeOf") ) {
					return false;
				}
			} catch ( e ) {
				// IE8,9 Will throw exceptions on certain host objects #9897
				return false;
			}

			// Own properties are enumerated firstly, so to speed up,
			// if last one is own, then all properties are own.

			var key;
			for ( key in obj ) {}

			return key === undefined || core_hasOwn.call( obj, key );
		},

		isEmptyObject: function( obj ) {
			var name;
			for ( name in obj ) {
				return false;
			}
			return true;
		},

		error: function( msg ) {
			throw new Error( msg );
		},

		// data: string of html
		// context (optional): If specified, the fragment will be created in this context, defaults to document
		// scripts (optional): If true, will include scripts passed in the html string
		parseHTML: function( data, context, scripts ) {
			var parsed;
			if ( !data || typeof data !== "string" ) {
				return null;
			}
			if ( typeof context === "boolean" ) {
				scripts = context;
				context = 0;
			}
			context = context || document;

			// Single tag
			if ( (parsed = rsingleTag.exec( data )) ) {
				return [ context.createElement( parsed[1] ) ];
			}

			parsed = jQuery.buildFragment( [ data ], context, scripts ? null : [] );
			return jQuery.merge( [],
				(parsed.cacheable ? jQuery.clone( parsed.fragment ) : parsed.fragment).childNodes );
		},

		parseJSON: function( data ) {
			if ( !data || typeof data !== "string") {
				return null;
			}

			// Make sure leading/trailing whitespace is removed (IE can't handle it)
			data = jQuery.trim( data );

			// Attempt to parse using the native JSON parser first
			if ( window.JSON && window.JSON.parse ) {
				return window.JSON.parse( data );
			}

			// Make sure the incoming data is actual JSON
			// Logic borrowed from http://json.org/json2.js
			if ( rvalidchars.test( data.replace( rvalidescape, "@" )
				.replace( rvalidtokens, "]" )
				.replace( rvalidbraces, "")) ) {

				return ( new Function( "return " + data ) )();

			}
			jQuery.error( "Invalid JSON: " + data );
		},

		// Cross-browser xml parsing
		parseXML: function( data ) {
			var xml, tmp;
			if ( !data || typeof data !== "string" ) {
				return null;
			}
			try {
				if ( window.DOMParser ) { // Standard
					tmp = new DOMParser();
					xml = tmp.parseFromString( data , "text/xml" );
				} else { // IE
					xml = new ActiveXObject( "Microsoft.XMLDOM" );
					xml.async = "false";
					xml.loadXML( data );
				}
			} catch( e ) {
				xml = undefined;
			}
			if ( !xml || !xml.documentElement || xml.getElementsByTagName( "parsererror" ).length ) {
				jQuery.error( "Invalid XML: " + data );
			}
			return xml;
		},

		noop: function() {},

		// Evaluates a script in a global context
		// Workarounds based on findings by Jim Driscoll
		// http://weblogs.java.net/blog/driscoll/archive/2009/09/08/eval-javascript-global-context
		globalEval: function( data ) {
			if ( data && core_rnotwhite.test( data ) ) {
				// We use execScript on Internet Explorer
				// We use an anonymous function so that context is window
				// rather than jQuery in Firefox
				( window.execScript || function( data ) {
					window[ "eval" ].call( window, data );
				} )( data );
			}
		},

		// Convert dashed to camelCase; used by the css and data modules
		// Microsoft forgot to hump their vendor prefix (#9572)
		camelCase: function( string ) {
			return string.replace( rmsPrefix, "ms-" ).replace( rdashAlpha, fcamelCase );
		},

		nodeName: function( elem, name ) {
			return elem.nodeName && elem.nodeName.toLowerCase() === name.toLowerCase();
		},

		// args is for internal usage only
		each: function( obj, callback, args ) {
			var name,
				i = 0,
				length = obj.length,
				isObj = length === undefined || jQuery.isFunction( obj );

			if ( args ) {
				if ( isObj ) {
					for ( name in obj ) {
						if ( callback.apply( obj[ name ], args ) === false ) {
							break;
						}
					}
				} else {
					for ( ; i < length; ) {
						if ( callback.apply( obj[ i++ ], args ) === false ) {
							break;
						}
					}
				}

				// A special, fast, case for the most common use of each
			} else {
				if ( isObj ) {
					for ( name in obj ) {
						if ( callback.call( obj[ name ], name, obj[ name ] ) === false ) {
							break;
						}
					}
				} else {
					for ( ; i < length; ) {
						if ( callback.call( obj[ i ], i, obj[ i++ ] ) === false ) {
							break;
						}
					}
				}
			}

			return obj;
		},

		// Use native String.trim function wherever possible
		trim: core_trim && !core_trim.call("\uFEFF\xA0") ?
			function( text ) {
				return text == null ?
					"" :
					core_trim.call( text );
			} :

			// Otherwise use our own trimming functionality
			function( text ) {
				return text == null ?
					"" :
					( text + "" ).replace( rtrim, "" );
			},

		// results is for internal usage only
		makeArray: function( arr, results ) {
			var type,
				ret = results || [];

			if ( arr != null ) {
				// The window, strings (and functions) also have 'length'
				// Tweaked logic slightly to handle Blackberry 4.7 RegExp issues #6930
				type = jQuery.type( arr );

				if ( arr.length == null || type === "string" || type === "function" || type === "regexp" || jQuery.isWindow( arr ) ) {
					core_push.call( ret, arr );
				} else {
					jQuery.merge( ret, arr );
				}
			}

			return ret;
		},

		inArray: function( elem, arr, i ) {
			var len;

			if ( arr ) {
				if ( core_indexOf ) {
					return core_indexOf.call( arr, elem, i );
				}

				len = arr.length;
				i = i ? i < 0 ? Math.max( 0, len + i ) : i : 0;

				for ( ; i < len; i++ ) {
					// Skip accessing in sparse arrays
					if ( i in arr && arr[ i ] === elem ) {
						return i;
					}
				}
			}

			return -1;
		},

		merge: function( first, second ) {
			var l = second.length,
				i = first.length,
				j = 0;

			if ( typeof l === "number" ) {
				for ( ; j < l; j++ ) {
					first[ i++ ] = second[ j ];
				}

			} else {
				while ( second[j] !== undefined ) {
					first[ i++ ] = second[ j++ ];
				}
			}

			first.length = i;

			return first;
		},

		grep: function( elems, callback, inv ) {
			var retVal,
				ret = [],
				i = 0,
				length = elems.length;
			inv = !!inv;

			// Go through the array, only saving the items
			// that pass the validator function
			for ( ; i < length; i++ ) {
				retVal = !!callback( elems[ i ], i );
				if ( inv !== retVal ) {
					ret.push( elems[ i ] );
				}
			}

			return ret;
		},

		// arg is for internal usage only
		map: function( elems, callback, arg ) {
			var value, key,
				ret = [],
				i = 0,
				length = elems.length,
			// jquery objects are treated as arrays
				isArray = elems instanceof jQuery || length !== undefined && typeof length === "number" && ( ( length > 0 && elems[ 0 ] && elems[ length -1 ] ) || length === 0 || jQuery.isArray( elems ) ) ;

			// Go through the array, translating each of the items to their
			if ( isArray ) {
				for ( ; i < length; i++ ) {
					value = callback( elems[ i ], i, arg );

					if ( value != null ) {
						ret[ ret.length ] = value;
					}
				}

				// Go through every key on the object,
			} else {
				for ( key in elems ) {
					value = callback( elems[ key ], key, arg );

					if ( value != null ) {
						ret[ ret.length ] = value;
					}
				}
			}

			// Flatten any nested arrays
			return ret.concat.apply( [], ret );
		},

		// A global GUID counter for objects
		guid: 1,

		// Bind a function to a context, optionally partially applying any
		// arguments.
		proxy: function( fn, context ) {
			var tmp, args, proxy;

			if ( typeof context === "string" ) {
				tmp = fn[ context ];
				context = fn;
				fn = tmp;
			}

			// Quick check to determine if target is callable, in the spec
			// this throws a TypeError, but we will just return undefined.
			if ( !jQuery.isFunction( fn ) ) {
				return undefined;
			}

			// Simulated bind
			args = core_slice.call( arguments, 2 );
			proxy = function() {
				return fn.apply( context, args.concat( core_slice.call( arguments ) ) );
			};

			// Set the guid of unique handler to the same of original handler, so it can be removed
			proxy.guid = fn.guid = fn.guid || jQuery.guid++;

			return proxy;
		},

		// Multifunctional method to get and set values of a collection
		// The value/s can optionally be executed if it's a function
		access: function( elems, fn, key, value, chainable, emptyGet, pass ) {
			var exec,
				bulk = key == null,
				i = 0,
				length = elems.length;

			// Sets many values
			if ( key && typeof key === "object" ) {
				for ( i in key ) {
					jQuery.access( elems, fn, i, key[i], 1, emptyGet, value );
				}
				chainable = 1;

				// Sets one value
			} else if ( value !== undefined ) {
				// Optionally, function values get executed if exec is true
				exec = pass === undefined && jQuery.isFunction( value );

				if ( bulk ) {
					// Bulk operations only iterate when executing function values
					if ( exec ) {
						exec = fn;
						fn = function( elem, key, value ) {
							return exec.call( jQuery( elem ), value );
						};

						// Otherwise they run against the entire set
					} else {
						fn.call( elems, value );
						fn = null;
					}
				}

				if ( fn ) {
					for (; i < length; i++ ) {
						fn( elems[i], key, exec ? value.call( elems[i], i, fn( elems[i], key ) ) : value, pass );
					}
				}

				chainable = 1;
			}

			return chainable ?
				elems :

				// Gets
				bulk ?
					fn.call( elems ) :
					length ? fn( elems[0], key ) : emptyGet;
		},

		now: function() {
			return ( new Date() ).getTime();
		}
	});

	jQuery.ready.promise = function( obj ) {
		if ( !readyList ) {

			readyList = jQuery.Deferred();

			// Catch cases where $(document).ready() is called after the browser event has already occurred.
			// we once tried to use readyState "interactive" here, but it caused issues like the one
			// discovered by ChrisS here: http://bugs.jquery.com/ticket/12282#comment:15
			if ( document.readyState === "complete" ) {
				// Handle it asynchronously to allow scripts the opportunity to delay ready
				setTimeout( jQuery.ready, 1 );

				// Standards-based browsers support DOMContentLoaded
			} else if ( document.addEventListener ) {
				// Use the handy event callback
				document.addEventListener( "DOMContentLoaded", DOMContentLoaded, false );

				// A fallback to window.onload, that will always work
				window.addEventListener( "load", jQuery.ready, false );

				// If IE event model is used
			} else {
				// Ensure firing before onload, maybe late but safe also for iframes
				document.attachEvent( "onreadystatechange", DOMContentLoaded );

				// A fallback to window.onload, that will always work
				window.attachEvent( "onload", jQuery.ready );

				// If IE and not a frame
				// continually check to see if the document is ready
				var top = false;

				try {
					top = window.frameElement == null && document.documentElement;
				} catch(e) {}

				if ( top && top.doScroll ) {
					(function doScrollCheck() {
						if ( !jQuery.isReady ) {

							try {
								// Use the trick by Diego Perini
								// http://javascript.nwbox.com/IEContentLoaded/
								top.doScroll("left");
							} catch(e) {
								return setTimeout( doScrollCheck, 50 );
							}

							// and execute any waiting functions
							jQuery.ready();
						}
					})();
				}
			}
		}
		return readyList.promise( obj );
	};

// Populate the class2type map
	jQuery.each("Boolean Number String Function Array Date RegExp Object".split(" "), function(i, name) {
		class2type[ "[object " + name + "]" ] = name.toLowerCase();
	});

// All jQuery objects should point back to these
	rootjQuery = jQuery(document);
// String to Object options format cache
	var optionsCache = {};

// Convert String-formatted options into Object-formatted ones and store in cache
	function createOptions( options ) {
		var object = optionsCache[ options ] = {};
		jQuery.each( options.split( core_rspace ), function( _, flag ) {
			object[ flag ] = true;
		});
		return object;
	}

	/*
	 * Create a callback list using the following parameters:
	 *
	 *	options: an optional list of space-separated options that will change how
	 *			the callback list behaves or a more traditional option object
	 *
	 * By default a callback list will act like an event callback list and can be
	 * "fired" multiple times.
	 *
	 * Possible options:
	 *
	 *	once:			will ensure the callback list can only be fired once (like a Deferred)
	 *
	 *	memory:			will keep track of previous values and will call any callback added
	 *					after the list has been fired right away with the latest "memorized"
	 *					values (like a Deferred)
	 *
	 *	unique:			will ensure a callback can only be added once (no duplicate in the list)
	 *
	 *	stopOnFalse:	interrupt callings when a callback returns false
	 *
	 */
	jQuery.Callbacks = function( options ) {

		// Convert options from String-formatted to Object-formatted if needed
		// (we check in cache first)
		options = typeof options === "string" ?
			( optionsCache[ options ] || createOptions( options ) ) :
			jQuery.extend( {}, options );

		var // Last fire value (for non-forgettable lists)
			memory,
		// Flag to know if list was already fired
			fired,
		// Flag to know if list is currently firing
			firing,
		// First callback to fire (used internally by add and fireWith)
			firingStart,
		// End of the loop when firing
			firingLength,
		// Index of currently firing callback (modified by remove if needed)
			firingIndex,
		// Actual callback list
			list = [],
		// Stack of fire calls for repeatable lists
			stack = !options.once && [],
		// Fire callbacks
			fire = function( data ) {
				memory = options.memory && data;
				fired = true;
				firingIndex = firingStart || 0;
				firingStart = 0;
				firingLength = list.length;
				firing = true;
				for ( ; list && firingIndex < firingLength; firingIndex++ ) {
					if ( list[ firingIndex ].apply( data[ 0 ], data[ 1 ] ) === false && options.stopOnFalse ) {
						memory = false; // To prevent further calls using add
						break;
					}
				}
				firing = false;
				if ( list ) {
					if ( stack ) {
						if ( stack.length ) {
							fire( stack.shift() );
						}
					} else if ( memory ) {
						list = [];
					} else {
						self.disable();
					}
				}
			},
		// Actual Callbacks object
			self = {
				// Add a callback or a collection of callbacks to the list
				add: function() {
					if ( list ) {
						// First, we save the current length
						var start = list.length;
						(function add( args ) {
							jQuery.each( args, function( _, arg ) {
								var type = jQuery.type( arg );
								if ( type === "function" ) {
									if ( !options.unique || !self.has( arg ) ) {
										list.push( arg );
									}
								} else if ( arg && arg.length && type !== "string" ) {
									// Inspect recursively
									add( arg );
								}
							});
						})( arguments );
						// Do we need to add the callbacks to the
						// current firing batch?
						if ( firing ) {
							firingLength = list.length;
							// With memory, if we're not firing then
							// we should call right away
						} else if ( memory ) {
							firingStart = start;
							fire( memory );
						}
					}
					return this;
				},
				// Remove a callback from the list
				remove: function() {
					if ( list ) {
						jQuery.each( arguments, function( _, arg ) {
							var index;
							while( ( index = jQuery.inArray( arg, list, index ) ) > -1 ) {
								list.splice( index, 1 );
								// Handle firing indexes
								if ( firing ) {
									if ( index <= firingLength ) {
										firingLength--;
									}
									if ( index <= firingIndex ) {
										firingIndex--;
									}
								}
							}
						});
					}
					return this;
				},
				// Control if a given callback is in the list
				has: function( fn ) {
					return jQuery.inArray( fn, list ) > -1;
				},
				// Remove all callbacks from the list
				empty: function() {
					list = [];
					return this;
				},
				// Have the list do nothing anymore
				disable: function() {
					list = stack = memory = undefined;
					return this;
				},
				// Is it disabled?
				disabled: function() {
					return !list;
				},
				// Lock the list in its current state
				lock: function() {
					stack = undefined;
					if ( !memory ) {
						self.disable();
					}
					return this;
				},
				// Is it locked?
				locked: function() {
					return !stack;
				},
				// Call all callbacks with the given context and arguments
				fireWith: function( context, args ) {
					args = args || [];
					args = [ context, args.slice ? args.slice() : args ];
					if ( list && ( !fired || stack ) ) {
						if ( firing ) {
							stack.push( args );
						} else {
							fire( args );
						}
					}
					return this;
				},
				// Call all the callbacks with the given arguments
				fire: function() {
					self.fireWith( this, arguments );
					return this;
				},
				// To know if the callbacks have already been called at least once
				fired: function() {
					return !!fired;
				}
			};

		return self;
	};
	jQuery.extend({

		Deferred: function( func ) {
			var tuples = [
					// action, add listener, listener list, final state
					[ "resolve", "done", jQuery.Callbacks("once memory"), "resolved" ],
					[ "reject", "fail", jQuery.Callbacks("once memory"), "rejected" ],
					[ "notify", "progress", jQuery.Callbacks("memory") ]
				],
				state = "pending",
				promise = {
					state: function() {
						return state;
					},
					always: function() {
						deferred.done( arguments ).fail( arguments );
						return this;
					},
					then: function( /* fnDone, fnFail, fnProgress */ ) {
						var fns = arguments;
						return jQuery.Deferred(function( newDefer ) {
							jQuery.each( tuples, function( i, tuple ) {
								var action = tuple[ 0 ],
									fn = fns[ i ];
								// deferred[ done | fail | progress ] for forwarding actions to newDefer
								deferred[ tuple[1] ]( jQuery.isFunction( fn ) ?
									function() {
										var returned = fn.apply( this, arguments );
										if ( returned && jQuery.isFunction( returned.promise ) ) {
											returned.promise()
												.done( newDefer.resolve )
												.fail( newDefer.reject )
												.progress( newDefer.notify );
										} else {
											newDefer[ action + "With" ]( this === deferred ? newDefer : this, [ returned ] );
										}
									} :
									newDefer[ action ]
								);
							});
							fns = null;
						}).promise();
					},
					// Get a promise for this deferred
					// If obj is provided, the promise aspect is added to the object
					promise: function( obj ) {
						return obj != null ? jQuery.extend( obj, promise ) : promise;
					}
				},
				deferred = {};

			// Keep pipe for back-compat
			promise.pipe = promise.then;

			// Add list-specific methods
			jQuery.each( tuples, function( i, tuple ) {
				var list = tuple[ 2 ],
					stateString = tuple[ 3 ];

				// promise[ done | fail | progress ] = list.add
				promise[ tuple[1] ] = list.add;

				// Handle state
				if ( stateString ) {
					list.add(function() {
						// state = [ resolved | rejected ]
						state = stateString;

						// [ reject_list | resolve_list ].disable; progress_list.lock
					}, tuples[ i ^ 1 ][ 2 ].disable, tuples[ 2 ][ 2 ].lock );
				}

				// deferred[ resolve | reject | notify ] = list.fire
				deferred[ tuple[0] ] = list.fire;
				deferred[ tuple[0] + "With" ] = list.fireWith;
			});

			// Make the deferred a promise
			promise.promise( deferred );

			// Call given func if any
			if ( func ) {
				func.call( deferred, deferred );
			}

			// All done!
			return deferred;
		},

		// Deferred helper
		when: function( subordinate /* , ..., subordinateN */ ) {
			var i = 0,
				resolveValues = core_slice.call( arguments ),
				length = resolveValues.length,

			// the count of uncompleted subordinates
				remaining = length !== 1 || ( subordinate && jQuery.isFunction( subordinate.promise ) ) ? length : 0,

			// the master Deferred. If resolveValues consist of only a single Deferred, just use that.
				deferred = remaining === 1 ? subordinate : jQuery.Deferred(),

			// Update function for both resolve and progress values
				updateFunc = function( i, contexts, values ) {
					return function( value ) {
						contexts[ i ] = this;
						values[ i ] = arguments.length > 1 ? core_slice.call( arguments ) : value;
						if( values === progressValues ) {
							deferred.notifyWith( contexts, values );
						} else if ( !( --remaining ) ) {
							deferred.resolveWith( contexts, values );
						}
					};
				},

				progressValues, progressContexts, resolveContexts;

			// add listeners to Deferred subordinates; treat others as resolved
			if ( length > 1 ) {
				progressValues = new Array( length );
				progressContexts = new Array( length );
				resolveContexts = new Array( length );
				for ( ; i < length; i++ ) {
					if ( resolveValues[ i ] && jQuery.isFunction( resolveValues[ i ].promise ) ) {
						resolveValues[ i ].promise()
							.done( updateFunc( i, resolveContexts, resolveValues ) )
							.fail( deferred.reject )
							.progress( updateFunc( i, progressContexts, progressValues ) );
					} else {
						--remaining;
					}
				}
			}

			// if we're not waiting on anything, resolve the master
			if ( !remaining ) {
				deferred.resolveWith( resolveContexts, resolveValues );
			}

			return deferred.promise();
		}
	});
	jQuery.support = (function() {

		var support,
			all,
			a,
			select,
			opt,
			input,
			fragment,
			eventName,
			i,
			isSupported,
			clickFn,
			div = document.createElement("div");

		// Setup
		div.setAttribute( "className", "t" );
		div.innerHTML = "  <link/><table></table><a href='/a'>a</a><input type='checkbox'/>";

		// Support tests won't run in some limited or non-browser environments
		all = div.getElementsByTagName("*");
		a = div.getElementsByTagName("a")[ 0 ];
		if ( !all || !a || !all.length ) {
			return {};
		}

		// First batch of tests
		select = document.createElement("select");
		opt = select.appendChild( document.createElement("option") );
		input = div.getElementsByTagName("input")[ 0 ];

		a.style.cssText = "top:1px;float:left;opacity:.5";
		support = {
			// IE strips leading whitespace when .innerHTML is used
			leadingWhitespace: ( div.firstChild.nodeType === 3 ),

			// Make sure that tbody elements aren't automatically inserted
			// IE will insert them into empty tables
			tbody: !div.getElementsByTagName("tbody").length,

			// Make sure that link elements get serialized correctly by innerHTML
			// This requires a wrapper element in IE
			htmlSerialize: !!div.getElementsByTagName("link").length,

			// Get the style information from getAttribute
			// (IE uses .cssText instead)
			style: /top/.test( a.getAttribute("style") ),

			// Make sure that URLs aren't manipulated
			// (IE normalizes it by default)
			hrefNormalized: ( a.getAttribute("href") === "/a" ),

			// Make sure that element opacity exists
			// (IE uses filter instead)
			// Use a regex to work around a WebKit issue. See #5145
			opacity: /^0.5/.test( a.style.opacity ),

			// Verify style float existence
			// (IE uses styleFloat instead of cssFloat)
			cssFloat: !!a.style.cssFloat,

			// Make sure that if no value is specified for a checkbox
			// that it defaults to "on".
			// (WebKit defaults to "" instead)
			checkOn: ( input.value === "on" ),

			// Make sure that a selected-by-default option has a working selected property.
			// (WebKit defaults to false instead of true, IE too, if it's in an optgroup)
			optSelected: opt.selected,

			// Test setAttribute on camelCase class. If it works, we need attrFixes when doing get/setAttribute (ie6/7)
			getSetAttribute: div.className !== "t",

			// Tests for enctype support on a form (#6743)
			enctype: !!document.createElement("form").enctype,

			// Makes sure cloning an html5 element does not cause problems
			// Where outerHTML is undefined, this still works
			html5Clone: document.createElement("nav").cloneNode( true ).outerHTML !== "<:nav></:nav>",

			// jQuery.support.boxModel DEPRECATED in 1.8 since we don't support Quirks Mode
			boxModel: ( document.compatMode === "CSS1Compat" ),

			// Will be defined later
			submitBubbles: true,
			changeBubbles: true,
			focusinBubbles: false,
			deleteExpando: true,
			noCloneEvent: true,
			inlineBlockNeedsLayout: false,
			shrinkWrapBlocks: false,
			reliableMarginRight: true,
			boxSizingReliable: true,
			pixelPosition: false
		};

		// Make sure checked status is properly cloned
		input.checked = true;
		support.noCloneChecked = input.cloneNode( true ).checked;

		// Make sure that the options inside disabled selects aren't marked as disabled
		// (WebKit marks them as disabled)
		select.disabled = true;
		support.optDisabled = !opt.disabled;

		// Test to see if it's possible to delete an expando from an element
		// Fails in Internet Explorer
		try {
			delete div.test;
		} catch( e ) {
			support.deleteExpando = false;
		}

		if ( !div.addEventListener && div.attachEvent && div.fireEvent ) {
			div.attachEvent( "onclick", clickFn = function() {
				// Cloning a node shouldn't copy over any
				// bound event handlers (IE does this)
				support.noCloneEvent = false;
			});
			div.cloneNode( true ).fireEvent("onclick");
			div.detachEvent( "onclick", clickFn );
		}

		// Check if a radio maintains its value
		// after being appended to the DOM
		input = document.createElement("input");
		input.value = "t";
		input.setAttribute( "type", "radio" );
		support.radioValue = input.value === "t";

		input.setAttribute( "checked", "checked" );

		// #11217 - WebKit loses check when the name is after the checked attribute
		input.setAttribute( "name", "t" );

		div.appendChild( input );
		fragment = document.createDocumentFragment();
		fragment.appendChild( div.lastChild );

		// WebKit doesn't clone checked state correctly in fragments
		support.checkClone = fragment.cloneNode( true ).cloneNode( true ).lastChild.checked;

		// Check if a disconnected checkbox will retain its checked
		// value of true after appended to the DOM (IE6/7)
		support.appendChecked = input.checked;

		fragment.removeChild( input );
		fragment.appendChild( div );

		// Technique from Juriy Zaytsev
		// http://perfectionkills.com/detecting-event-support-without-browser-sniffing/
		// We only care about the case where non-standard event systems
		// are used, namely in IE. Short-circuiting here helps us to
		// avoid an eval call (in setAttribute) which can cause CSP
		// to go haywire. See: https://developer.mozilla.org/en/Security/CSP
		if ( div.attachEvent ) {
			for ( i in {
				submit: true,
				change: true,
				focusin: true
			}) {
				eventName = "on" + i;
				isSupported = ( eventName in div );
				if ( !isSupported ) {
					div.setAttribute( eventName, "return;" );
					isSupported = ( typeof div[ eventName ] === "function" );
				}
				support[ i + "Bubbles" ] = isSupported;
			}
		}

		// Run tests that need a body at doc ready
		jQuery(function() {
			var container, div, tds, marginDiv,
				divReset = "padding:0;margin:0;border:0;display:block;overflow:hidden;",
				body = document.getElementsByTagName("body")[0];

			if ( !body ) {
				// Return for frameset docs that don't have a body
				return;
			}

			container = document.createElement("div");
			container.style.cssText = "visibility:hidden;border:0;width:0;height:0;position:static;top:0;margin-top:1px";
			body.insertBefore( container, body.firstChild );

			// Construct the test element
			div = document.createElement("div");
			container.appendChild( div );

			// Check if table cells still have offsetWidth/Height when they are set
			// to display:none and there are still other visible table cells in a
			// table row; if so, offsetWidth/Height are not reliable for use when
			// determining if an element has been hidden directly using
			// display:none (it is still safe to use offsets if a parent element is
			// hidden; don safety goggles and see bug #4512 for more information).
			// (only IE 8 fails this test)
			div.innerHTML = "<table><tr><td></td><td>t</td></tr></table>";
			tds = div.getElementsByTagName("td");
			tds[ 0 ].style.cssText = "padding:0;margin:0;border:0;display:none";
			isSupported = ( tds[ 0 ].offsetHeight === 0 );

			tds[ 0 ].style.display = "";
			tds[ 1 ].style.display = "none";

			// Check if empty table cells still have offsetWidth/Height
			// (IE <= 8 fail this test)
			support.reliableHiddenOffsets = isSupported && ( tds[ 0 ].offsetHeight === 0 );

			// Check box-sizing and margin behavior
			div.innerHTML = "";
			div.style.cssText = "box-sizing:border-box;-moz-box-sizing:border-box;-webkit-box-sizing:border-box;padding:1px;border:1px;display:block;width:4px;margin-top:1%;position:absolute;top:1%;";
			support.boxSizing = ( div.offsetWidth === 4 );
			support.doesNotIncludeMarginInBodyOffset = ( body.offsetTop !== 1 );

			// NOTE: To any future maintainer, we've window.getComputedStyle
			// because jsdom on node.js will break without it.
			if ( window.getComputedStyle ) {
				support.pixelPosition = ( window.getComputedStyle( div, null ) || {} ).top !== "1%";
				support.boxSizingReliable = ( window.getComputedStyle( div, null ) || { width: "4px" } ).width === "4px";

				// Check if div with explicit width and no margin-right incorrectly
				// gets computed margin-right based on width of container. For more
				// info see bug #3333
				// Fails in WebKit before Feb 2011 nightlies
				// WebKit Bug 13343 - getComputedStyle returns wrong value for margin-right
				marginDiv = document.createElement("div");
				marginDiv.style.cssText = div.style.cssText = divReset;
				marginDiv.style.marginRight = marginDiv.style.width = "0";
				div.style.width = "1px";
				div.appendChild( marginDiv );
				support.reliableMarginRight =
					!parseFloat( ( window.getComputedStyle( marginDiv, null ) || {} ).marginRight );
			}

			if ( typeof div.style.zoom !== "undefined" ) {
				// Check if natively block-level elements act like inline-block
				// elements when setting their display to 'inline' and giving
				// them layout
				// (IE < 8 does this)
				div.innerHTML = "";
				div.style.cssText = divReset + "width:1px;padding:1px;display:inline;zoom:1";
				support.inlineBlockNeedsLayout = ( div.offsetWidth === 3 );

				// Check if elements with layout shrink-wrap their children
				// (IE 6 does this)
				div.style.display = "block";
				div.style.overflow = "visible";
				div.innerHTML = "<div></div>";
				div.firstChild.style.width = "5px";
				support.shrinkWrapBlocks = ( div.offsetWidth !== 3 );

				container.style.zoom = 1;
			}

			// Null elements to avoid leaks in IE
			body.removeChild( container );
			container = div = tds = marginDiv = null;
		});

		// Null elements to avoid leaks in IE
		fragment.removeChild( div );
		all = a = select = opt = input = fragment = div = null;

		return support;
	})();
	var rbrace = /(?:\{[\s\S]*\}|\[[\s\S]*\])$/,
		rmultiDash = /([A-Z])/g;

	jQuery.extend({
		cache: {},

		deletedIds: [],

		// Remove at next major release (1.9/2.0)
		uuid: 0,

		// Unique for each copy of jQuery on the page
		// Non-digits removed to match rinlinejQuery
		expando: "jQuery" + ( jQuery.fn.jquery + Math.random() ).replace( /\D/g, "" ),

		// The following elements throw uncatchable exceptions if you
		// attempt to add expando properties to them.
		noData: {
			"embed": true,
			// Ban all objects except for Flash (which handle expandos)
			"object": "clsid:D27CDB6E-AE6D-11cf-96B8-444553540000",
			"applet": true
		},

		hasData: function( elem ) {
			elem = elem.nodeType ? jQuery.cache[ elem[jQuery.expando] ] : elem[ jQuery.expando ];
			return !!elem && !isEmptyDataObject( elem );
		},

		data: function( elem, name, data, pvt /* Internal Use Only */ ) {
			if ( !jQuery.acceptData( elem ) ) {
				return;
			}

			var thisCache, ret,
				internalKey = jQuery.expando,
				getByName = typeof name === "string",

			// We have to handle DOM nodes and JS objects differently because IE6-7
			// can't GC object references properly across the DOM-JS boundary
				isNode = elem.nodeType,

			// Only DOM nodes need the global jQuery cache; JS object data is
			// attached directly to the object so GC can occur automatically
				cache = isNode ? jQuery.cache : elem,

			// Only defining an ID for JS objects if its cache already exists allows
			// the code to shortcut on the same path as a DOM node with no cache
				id = isNode ? elem[ internalKey ] : elem[ internalKey ] && internalKey;

			// Avoid doing any more work than we need to when trying to get data on an
			// object that has no data at all
			if ( (!id || !cache[id] || (!pvt && !cache[id].data)) && getByName && data === undefined ) {
				return;
			}

			if ( !id ) {
				// Only DOM nodes need a new unique ID for each element since their data
				// ends up in the global cache
				if ( isNode ) {
					elem[ internalKey ] = id = jQuery.deletedIds.pop() || jQuery.guid++;
				} else {
					id = internalKey;
				}
			}

			if ( !cache[ id ] ) {
				cache[ id ] = {};

				// Avoids exposing jQuery metadata on plain JS objects when the object
				// is serialized using JSON.stringify
				if ( !isNode ) {
					cache[ id ].toJSON = jQuery.noop;
				}
			}

			// An object can be passed to jQuery.data instead of a key/value pair; this gets
			// shallow copied over onto the existing cache
			if ( typeof name === "object" || typeof name === "function" ) {
				if ( pvt ) {
					cache[ id ] = jQuery.extend( cache[ id ], name );
				} else {
					cache[ id ].data = jQuery.extend( cache[ id ].data, name );
				}
			}

			thisCache = cache[ id ];

			// jQuery data() is stored in a separate object inside the object's internal data
			// cache in order to avoid key collisions between internal data and user-defined
			// data.
			if ( !pvt ) {
				if ( !thisCache.data ) {
					thisCache.data = {};
				}

				thisCache = thisCache.data;
			}

			if ( data !== undefined ) {
				thisCache[ jQuery.camelCase( name ) ] = data;
			}

			// Check for both converted-to-camel and non-converted data property names
			// If a data property was specified
			if ( getByName ) {

				// First Try to find as-is property data
				ret = thisCache[ name ];

				// Test for null|undefined property data
				if ( ret == null ) {

					// Try to find the camelCased property
					ret = thisCache[ jQuery.camelCase( name ) ];
				}
			} else {
				ret = thisCache;
			}

			return ret;
		},

		removeData: function( elem, name, pvt /* Internal Use Only */ ) {
			if ( !jQuery.acceptData( elem ) ) {
				return;
			}

			var thisCache, i, l,

				isNode = elem.nodeType,

			// See jQuery.data for more information
				cache = isNode ? jQuery.cache : elem,
				id = isNode ? elem[ jQuery.expando ] : jQuery.expando;

			// If there is already no cache entry for this object, there is no
			// purpose in continuing
			if ( !cache[ id ] ) {
				return;
			}

			if ( name ) {

				thisCache = pvt ? cache[ id ] : cache[ id ].data;

				if ( thisCache ) {

					// Support array or space separated string names for data keys
					if ( !jQuery.isArray( name ) ) {

						// try the string as a key before any manipulation
						if ( name in thisCache ) {
							name = [ name ];
						} else {

							// split the camel cased version by spaces unless a key with the spaces exists
							name = jQuery.camelCase( name );
							if ( name in thisCache ) {
								name = [ name ];
							} else {
								name = name.split(" ");
							}
						}
					}

					for ( i = 0, l = name.length; i < l; i++ ) {
						delete thisCache[ name[i] ];
					}

					// If there is no data left in the cache, we want to continue
					// and let the cache object itself get destroyed
					if ( !( pvt ? isEmptyDataObject : jQuery.isEmptyObject )( thisCache ) ) {
						return;
					}
				}
			}

			// See jQuery.data for more information
			if ( !pvt ) {
				delete cache[ id ].data;

				// Don't destroy the parent cache unless the internal data object
				// had been the only thing left in it
				if ( !isEmptyDataObject( cache[ id ] ) ) {
					return;
				}
			}

			// Destroy the cache
			if ( isNode ) {
				jQuery.cleanData( [ elem ], true );

				// Use delete when supported for expandos or `cache` is not a window per isWindow (#10080)
			} else if ( jQuery.support.deleteExpando || cache != cache.window ) {
				delete cache[ id ];

				// When all else fails, null
			} else {
				cache[ id ] = null;
			}
		},

		// For internal use only.
		_data: function( elem, name, data ) {
			return jQuery.data( elem, name, data, true );
		},

		// A method for determining if a DOM node can handle the data expando
		acceptData: function( elem ) {
			var noData = elem.nodeName && jQuery.noData[ elem.nodeName.toLowerCase() ];

			// nodes accept data unless otherwise specified; rejection can be conditional
			return !noData || noData !== true && elem.getAttribute("classid") === noData;
		}
	});

	jQuery.fn.extend({
		data: function( key, value ) {
			var parts, part, attr, name, l,
				elem = this[0],
				i = 0,
				data = null;

			// Gets all values
			if ( key === undefined ) {
				if ( this.length ) {
					data = jQuery.data( elem );

					if ( elem.nodeType === 1 && !jQuery._data( elem, "parsedAttrs" ) ) {
						attr = elem.attributes;
						for ( l = attr.length; i < l; i++ ) {
							name = attr[i].name;

							if ( !name.indexOf( "data-" ) ) {
								name = jQuery.camelCase( name.substring(5) );

								dataAttr( elem, name, data[ name ] );
							}
						}
						jQuery._data( elem, "parsedAttrs", true );
					}
				}

				return data;
			}

			// Sets multiple values
			if ( typeof key === "object" ) {
				return this.each(function() {
					jQuery.data( this, key );
				});
			}

			parts = key.split( ".", 2 );
			parts[1] = parts[1] ? "." + parts[1] : "";
			part = parts[1] + "!";

			return jQuery.access( this, function( value ) {

				if ( value === undefined ) {
					data = this.triggerHandler( "getData" + part, [ parts[0] ] );

					// Try to fetch any internally stored data first
					if ( data === undefined && elem ) {
						data = jQuery.data( elem, key );
						data = dataAttr( elem, key, data );
					}

					return data === undefined && parts[1] ?
						this.data( parts[0] ) :
						data;
				}

				parts[1] = value;
				this.each(function() {
					var self = jQuery( this );

					self.triggerHandler( "setData" + part, parts );
					jQuery.data( this, key, value );
					self.triggerHandler( "changeData" + part, parts );
				});
			}, null, value, arguments.length > 1, null, false );
		},

		removeData: function( key ) {
			return this.each(function() {
				jQuery.removeData( this, key );
			});
		}
	});

	function dataAttr( elem, key, data ) {
		// If nothing was found internally, try to fetch any
		// data from the HTML5 data-* attribute
		if ( data === undefined && elem.nodeType === 1 ) {

			var name = "data-" + key.replace( rmultiDash, "-$1" ).toLowerCase();

			data = elem.getAttribute( name );

			if ( typeof data === "string" ) {
				try {
					data = data === "true" ? true :
						data === "false" ? false :
							data === "null" ? null :
								// Only convert to a number if it doesn't change the string
								+data + "" === data ? +data :
									rbrace.test( data ) ? jQuery.parseJSON( data ) :
										data;
				} catch( e ) {}

				// Make sure we set the data so it isn't changed later
				jQuery.data( elem, key, data );

			} else {
				data = undefined;
			}
		}

		return data;
	}

// checks a cache object for emptiness
	function isEmptyDataObject( obj ) {
		var name;
		for ( name in obj ) {

			// if the public data object is empty, the private is still empty
			if ( name === "data" && jQuery.isEmptyObject( obj[name] ) ) {
				continue;
			}
			if ( name !== "toJSON" ) {
				return false;
			}
		}

		return true;
	}
	jQuery.extend({
		queue: function( elem, type, data ) {
			var queue;

			if ( elem ) {
				type = ( type || "fx" ) + "queue";
				queue = jQuery._data( elem, type );

				// Speed up dequeue by getting out quickly if this is just a lookup
				if ( data ) {
					if ( !queue || jQuery.isArray(data) ) {
						queue = jQuery._data( elem, type, jQuery.makeArray(data) );
					} else {
						queue.push( data );
					}
				}
				return queue || [];
			}
		},

		dequeue: function( elem, type ) {
			type = type || "fx";

			var queue = jQuery.queue( elem, type ),
				startLength = queue.length,
				fn = queue.shift(),
				hooks = jQuery._queueHooks( elem, type ),
				next = function() {
					jQuery.dequeue( elem, type );
				};

			// If the fx queue is dequeued, always remove the progress sentinel
			if ( fn === "inprogress" ) {
				fn = queue.shift();
				startLength--;
			}

			if ( fn ) {

				// Add a progress sentinel to prevent the fx queue from being
				// automatically dequeued
				if ( type === "fx" ) {
					queue.unshift( "inprogress" );
				}

				// clear up the last queue stop function
				delete hooks.stop;
				fn.call( elem, next, hooks );
			}

			if ( !startLength && hooks ) {
				hooks.empty.fire();
			}
		},

		// not intended for public consumption - generates a queueHooks object, or returns the current one
		_queueHooks: function( elem, type ) {
			var key = type + "queueHooks";
			return jQuery._data( elem, key ) || jQuery._data( elem, key, {
				empty: jQuery.Callbacks("once memory").add(function() {
					jQuery.removeData( elem, type + "queue", true );
					jQuery.removeData( elem, key, true );
				})
			});
		}
	});

	jQuery.fn.extend({
		queue: function( type, data ) {
			var setter = 2;

			if ( typeof type !== "string" ) {
				data = type;
				type = "fx";
				setter--;
			}

			if ( arguments.length < setter ) {
				return jQuery.queue( this[0], type );
			}

			return data === undefined ?
				this :
				this.each(function() {
					var queue = jQuery.queue( this, type, data );

					// ensure a hooks for this queue
					jQuery._queueHooks( this, type );

					if ( type === "fx" && queue[0] !== "inprogress" ) {
						jQuery.dequeue( this, type );
					}
				});
		},
		dequeue: function( type ) {
			return this.each(function() {
				jQuery.dequeue( this, type );
			});
		},
		// Based off of the plugin by Clint Helfers, with permission.
		// http://blindsignals.com/index.php/2009/07/jquery-delay/
		delay: function( time, type ) {
			time = jQuery.fx ? jQuery.fx.speeds[ time ] || time : time;
			type = type || "fx";

			return this.queue( type, function( next, hooks ) {
				var timeout = setTimeout( next, time );
				hooks.stop = function() {
					clearTimeout( timeout );
				};
			});
		},
		clearQueue: function( type ) {
			return this.queue( type || "fx", [] );
		},
		// Get a promise resolved when queues of a certain type
		// are emptied (fx is the type by default)
		promise: function( type, obj ) {
			var tmp,
				count = 1,
				defer = jQuery.Deferred(),
				elements = this,
				i = this.length,
				resolve = function() {
					if ( !( --count ) ) {
						defer.resolveWith( elements, [ elements ] );
					}
				};

			if ( typeof type !== "string" ) {
				obj = type;
				type = undefined;
			}
			type = type || "fx";

			while( i-- ) {
				tmp = jQuery._data( elements[ i ], type + "queueHooks" );
				if ( tmp && tmp.empty ) {
					count++;
					tmp.empty.add( resolve );
				}
			}
			resolve();
			return defer.promise( obj );
		}
	});
	var nodeHook, boolHook, fixSpecified,
		rclass = /[\t\r\n]/g,
		rreturn = /\r/g,
		rtype = /^(?:button|input)$/i,
		rfocusable = /^(?:button|input|object|select|textarea)$/i,
		rclickable = /^a(?:rea|)$/i,
		rboolean = /^(?:autofocus|autoplay|async|checked|controls|defer|disabled|hidden|loop|multiple|open|readonly|required|scoped|selected)$/i,
		getSetAttribute = jQuery.support.getSetAttribute;

	jQuery.fn.extend({
		attr: function( name, value ) {
			return jQuery.access( this, jQuery.attr, name, value, arguments.length > 1 );
		},

		removeAttr: function( name ) {
			return this.each(function() {
				jQuery.removeAttr( this, name );
			});
		},

		prop: function( name, value ) {
			return jQuery.access( this, jQuery.prop, name, value, arguments.length > 1 );
		},

		removeProp: function( name ) {
			name = jQuery.propFix[ name ] || name;
			return this.each(function() {
				// try/catch handles cases where IE balks (such as removing a property on window)
				try {
					this[ name ] = undefined;
					delete this[ name ];
				} catch( e ) {}
			});
		},

		addClass: function( value ) {
			var classNames, i, l, elem,
				setClass, c, cl;

			if ( jQuery.isFunction( value ) ) {
				return this.each(function( j ) {
					jQuery( this ).addClass( value.call(this, j, this.className) );
				});
			}

			if ( value && typeof value === "string" ) {
				classNames = value.split( core_rspace );

				for ( i = 0, l = this.length; i < l; i++ ) {
					elem = this[ i ];

					if ( elem.nodeType === 1 ) {
						if ( !elem.className && classNames.length === 1 ) {
							elem.className = value;

						} else {
							setClass = " " + elem.className + " ";

							for ( c = 0, cl = classNames.length; c < cl; c++ ) {
								if ( setClass.indexOf( " " + classNames[ c ] + " " ) < 0 ) {
									setClass += classNames[ c ] + " ";
								}
							}
							elem.className = jQuery.trim( setClass );
						}
					}
				}
			}

			return this;
		},

		removeClass: function( value ) {
			var removes, className, elem, c, cl, i, l;

			if ( jQuery.isFunction( value ) ) {
				return this.each(function( j ) {
					jQuery( this ).removeClass( value.call(this, j, this.className) );
				});
			}
			if ( (value && typeof value === "string") || value === undefined ) {
				removes = ( value || "" ).split( core_rspace );

				for ( i = 0, l = this.length; i < l; i++ ) {
					elem = this[ i ];
					if ( elem.nodeType === 1 && elem.className ) {

						className = (" " + elem.className + " ").replace( rclass, " " );

						// loop over each item in the removal list
						for ( c = 0, cl = removes.length; c < cl; c++ ) {
							// Remove until there is nothing to remove,
							while ( className.indexOf(" " + removes[ c ] + " ") >= 0 ) {
								className = className.replace( " " + removes[ c ] + " " , " " );
							}
						}
						elem.className = value ? jQuery.trim( className ) : "";
					}
				}
			}

			return this;
		},

		toggleClass: function( value, stateVal ) {
			var type = typeof value,
				isBool = typeof stateVal === "boolean";

			if ( jQuery.isFunction( value ) ) {
				return this.each(function( i ) {
					jQuery( this ).toggleClass( value.call(this, i, this.className, stateVal), stateVal );
				});
			}

			return this.each(function() {
				if ( type === "string" ) {
					// toggle individual class names
					var className,
						i = 0,
						self = jQuery( this ),
						state = stateVal,
						classNames = value.split( core_rspace );

					while ( (className = classNames[ i++ ]) ) {
						// check each className given, space separated list
						state = isBool ? state : !self.hasClass( className );
						self[ state ? "addClass" : "removeClass" ]( className );
					}

				} else if ( type === "undefined" || type === "boolean" ) {
					if ( this.className ) {
						// store className if set
						jQuery._data( this, "__className__", this.className );
					}

					// toggle whole className
					this.className = this.className || value === false ? "" : jQuery._data( this, "__className__" ) || "";
				}
			});
		},

		hasClass: function( selector ) {
			var className = " " + selector + " ",
				i = 0,
				l = this.length;
			for ( ; i < l; i++ ) {
				if ( this[i].nodeType === 1 && (" " + this[i].className + " ").replace(rclass, " ").indexOf( className ) >= 0 ) {
					return true;
				}
			}

			return false;
		},

		val: function( value ) {
			var hooks, ret, isFunction,
				elem = this[0];

			if ( !arguments.length ) {
				if ( elem ) {
					hooks = jQuery.valHooks[ elem.type ] || jQuery.valHooks[ elem.nodeName.toLowerCase() ];

					if ( hooks && "get" in hooks && (ret = hooks.get( elem, "value" )) !== undefined ) {
						return ret;
					}

					ret = elem.value;

					return typeof ret === "string" ?
						// handle most common string cases
						ret.replace(rreturn, "") :
						// handle cases where value is null/undef or number
						ret == null ? "" : ret;
				}

				return;
			}

			isFunction = jQuery.isFunction( value );

			return this.each(function( i ) {
				var val,
					self = jQuery(this);

				if ( this.nodeType !== 1 ) {
					return;
				}

				if ( isFunction ) {
					val = value.call( this, i, self.val() );
				} else {
					val = value;
				}

				// Treat null/undefined as ""; convert numbers to string
				if ( val == null ) {
					val = "";
				} else if ( typeof val === "number" ) {
					val += "";
				} else if ( jQuery.isArray( val ) ) {
					val = jQuery.map(val, function ( value ) {
						return value == null ? "" : value + "";
					});
				}

				hooks = jQuery.valHooks[ this.type ] || jQuery.valHooks[ this.nodeName.toLowerCase() ];

				// If set returns undefined, fall back to normal setting
				if ( !hooks || !("set" in hooks) || hooks.set( this, val, "value" ) === undefined ) {
					this.value = val;
				}
			});
		}
	});

	jQuery.extend({
		valHooks: {
			option: {
				get: function( elem ) {
					// attributes.value is undefined in Blackberry 4.7 but
					// uses .value. See #6932
					var val = elem.attributes.value;
					return !val || val.specified ? elem.value : elem.text;
				}
			},
			select: {
				get: function( elem ) {
					var value, option,
						options = elem.options,
						index = elem.selectedIndex,
						one = elem.type === "select-one" || index < 0,
						values = one ? null : [],
						max = one ? index + 1 : options.length,
						i = index < 0 ?
							max :
							one ? index : 0;

					// Loop through all the selected options
					for ( ; i < max; i++ ) {
						option = options[ i ];

						// oldIE doesn't update selected after form reset (#2551)
						if ( ( option.selected || i === index ) &&
							// Don't return options that are disabled or in a disabled optgroup
							( jQuery.support.optDisabled ? !option.disabled : option.getAttribute("disabled") === null ) &&
							( !option.parentNode.disabled || !jQuery.nodeName( option.parentNode, "optgroup" ) ) ) {

							// Get the specific value for the option
							value = jQuery( option ).val();

							// We don't need an array for one selects
							if ( one ) {
								return value;
							}

							// Multi-Selects return an array
							values.push( value );
						}
					}

					return values;
				},

				set: function( elem, value ) {
					var values = jQuery.makeArray( value );

					jQuery(elem).find("option").each(function() {
						this.selected = jQuery.inArray( jQuery(this).val(), values ) >= 0;
					});

					if ( !values.length ) {
						elem.selectedIndex = -1;
					}
					return values;
				}
			}
		},

		// Unused in 1.8, left in so attrFn-stabbers won't die; remove in 1.9
		attrFn: {},

		attr: function( elem, name, value, pass ) {
			var ret, hooks, notxml,
				nType = elem.nodeType;

			// don't get/set attributes on text, comment and attribute nodes
			if ( !elem || nType === 3 || nType === 8 || nType === 2 ) {
				return;
			}

			if ( pass && jQuery.isFunction( jQuery.fn[ name ] ) ) {
				return jQuery( elem )[ name ]( value );
			}

			// Fallback to prop when attributes are not supported
			if ( typeof elem.getAttribute === "undefined" ) {
				return jQuery.prop( elem, name, value );
			}

			notxml = nType !== 1 || !jQuery.isXMLDoc( elem );

			// All attributes are lowercase
			// Grab necessary hook if one is defined
			if ( notxml ) {
				name = name.toLowerCase();
				hooks = jQuery.attrHooks[ name ] || ( rboolean.test( name ) ? boolHook : nodeHook );
			}

			if ( value !== undefined ) {

				if ( value === null ) {
					jQuery.removeAttr( elem, name );
					return;

				} else if ( hooks && "set" in hooks && notxml && (ret = hooks.set( elem, value, name )) !== undefined ) {
					return ret;

				} else {
					elem.setAttribute( name, value + "" );
					return value;
				}

			} else if ( hooks && "get" in hooks && notxml && (ret = hooks.get( elem, name )) !== null ) {
				return ret;

			} else {

				ret = elem.getAttribute( name );

				// Non-existent attributes return null, we normalize to undefined
				return ret === null ?
					undefined :
					ret;
			}
		},

		removeAttr: function( elem, value ) {
			var propName, attrNames, name, isBool,
				i = 0;

			if ( value && elem.nodeType === 1 ) {

				attrNames = value.split( core_rspace );

				for ( ; i < attrNames.length; i++ ) {
					name = attrNames[ i ];

					if ( name ) {
						propName = jQuery.propFix[ name ] || name;
						isBool = rboolean.test( name );

						// See #9699 for explanation of this approach (setting first, then removal)
						// Do not do this for boolean attributes (see #10870)
						if ( !isBool ) {
							jQuery.attr( elem, name, "" );
						}
						elem.removeAttribute( getSetAttribute ? name : propName );

						// Set corresponding property to false for boolean attributes
						if ( isBool && propName in elem ) {
							elem[ propName ] = false;
						}
					}
				}
			}
		},

		attrHooks: {
			type: {
				set: function( elem, value ) {
					// We can't allow the type property to be changed (since it causes problems in IE)
					if ( rtype.test( elem.nodeName ) && elem.parentNode ) {
						jQuery.error( "type property can't be changed" );
					} else if ( !jQuery.support.radioValue && value === "radio" && jQuery.nodeName(elem, "input") ) {
						// Setting the type on a radio button after the value resets the value in IE6-9
						// Reset value to it's default in case type is set after value
						// This is for element creation
						var val = elem.value;
						elem.setAttribute( "type", value );
						if ( val ) {
							elem.value = val;
						}
						return value;
					}
				}
			},
			// Use the value property for back compat
			// Use the nodeHook for button elements in IE6/7 (#1954)
			value: {
				get: function( elem, name ) {
					if ( nodeHook && jQuery.nodeName( elem, "button" ) ) {
						return nodeHook.get( elem, name );
					}
					return name in elem ?
						elem.value :
						null;
				},
				set: function( elem, value, name ) {
					if ( nodeHook && jQuery.nodeName( elem, "button" ) ) {
						return nodeHook.set( elem, value, name );
					}
					// Does not return so that setAttribute is also used
					elem.value = value;
				}
			}
		},

		propFix: {
			tabindex: "tabIndex",
			readonly: "readOnly",
			"for": "htmlFor",
			"class": "className",
			maxlength: "maxLength",
			cellspacing: "cellSpacing",
			cellpadding: "cellPadding",
			rowspan: "rowSpan",
			colspan: "colSpan",
			usemap: "useMap",
			frameborder: "frameBorder",
			contenteditable: "contentEditable"
		},

		prop: function( elem, name, value ) {
			var ret, hooks, notxml,
				nType = elem.nodeType;

			// don't get/set properties on text, comment and attribute nodes
			if ( !elem || nType === 3 || nType === 8 || nType === 2 ) {
				return;
			}

			notxml = nType !== 1 || !jQuery.isXMLDoc( elem );

			if ( notxml ) {
				// Fix name and attach hooks
				name = jQuery.propFix[ name ] || name;
				hooks = jQuery.propHooks[ name ];
			}

			if ( value !== undefined ) {
				if ( hooks && "set" in hooks && (ret = hooks.set( elem, value, name )) !== undefined ) {
					return ret;

				} else {
					return ( elem[ name ] = value );
				}

			} else {
				if ( hooks && "get" in hooks && (ret = hooks.get( elem, name )) !== null ) {
					return ret;

				} else {
					return elem[ name ];
				}
			}
		},

		propHooks: {
			tabIndex: {
				get: function( elem ) {
					// elem.tabIndex doesn't always return the correct value when it hasn't been explicitly set
					// http://fluidproject.org/blog/2008/01/09/getting-setting-and-removing-tabindex-values-with-javascript/
					var attributeNode = elem.getAttributeNode("tabindex");

					return attributeNode && attributeNode.specified ?
						parseInt( attributeNode.value, 10 ) :
						rfocusable.test( elem.nodeName ) || rclickable.test( elem.nodeName ) && elem.href ?
							0 :
							undefined;
				}
			}
		}
	});

// Hook for boolean attributes
	boolHook = {
		get: function( elem, name ) {
			// Align boolean attributes with corresponding properties
			// Fall back to attribute presence where some booleans are not supported
			var attrNode,
				property = jQuery.prop( elem, name );
			return property === true || typeof property !== "boolean" && ( attrNode = elem.getAttributeNode(name) ) && attrNode.nodeValue !== false ?
				name.toLowerCase() :
				undefined;
		},
		set: function( elem, value, name ) {
			var propName;
			if ( value === false ) {
				// Remove boolean attributes when set to false
				jQuery.removeAttr( elem, name );
			} else {
				// value is true since we know at this point it's type boolean and not false
				// Set boolean attributes to the same name and set the DOM property
				propName = jQuery.propFix[ name ] || name;
				if ( propName in elem ) {
					// Only set the IDL specifically if it already exists on the element
					elem[ propName ] = true;
				}

				elem.setAttribute( name, name.toLowerCase() );
			}
			return name;
		}
	};

// IE6/7 do not support getting/setting some attributes with get/setAttribute
	if ( !getSetAttribute ) {

		fixSpecified = {
			name: true,
			id: true,
			coords: true
		};

		// Use this for any attribute in IE6/7
		// This fixes almost every IE6/7 issue
		nodeHook = jQuery.valHooks.button = {
			get: function( elem, name ) {
				var ret;
				ret = elem.getAttributeNode( name );
				return ret && ( fixSpecified[ name ] ? ret.value !== "" : ret.specified ) ?
					ret.value :
					undefined;
			},
			set: function( elem, value, name ) {
				// Set the existing or create a new attribute node
				var ret = elem.getAttributeNode( name );
				if ( !ret ) {
					ret = document.createAttribute( name );
					elem.setAttributeNode( ret );
				}
				return ( ret.value = value + "" );
			}
		};

		// Set width and height to auto instead of 0 on empty string( Bug #8150 )
		// This is for removals
		jQuery.each([ "width", "height" ], function( i, name ) {
			jQuery.attrHooks[ name ] = jQuery.extend( jQuery.attrHooks[ name ], {
				set: function( elem, value ) {
					if ( value === "" ) {
						elem.setAttribute( name, "auto" );
						return value;
					}
				}
			});
		});

		// Set contenteditable to false on removals(#10429)
		// Setting to empty string throws an error as an invalid value
		jQuery.attrHooks.contenteditable = {
			get: nodeHook.get,
			set: function( elem, value, name ) {
				if ( value === "" ) {
					value = "false";
				}
				nodeHook.set( elem, value, name );
			}
		};
	}


// Some attributes require a special call on IE
	if ( !jQuery.support.hrefNormalized ) {
		jQuery.each([ "href", "src", "width", "height" ], function( i, name ) {
			jQuery.attrHooks[ name ] = jQuery.extend( jQuery.attrHooks[ name ], {
				get: function( elem ) {
					var ret = elem.getAttribute( name, 2 );
					return ret === null ? undefined : ret;
				}
			});
		});
	}

	if ( !jQuery.support.style ) {
		jQuery.attrHooks.style = {
			get: function( elem ) {
				// Return undefined in the case of empty string
				// Normalize to lowercase since IE uppercases css property names
				return elem.style.cssText.toLowerCase() || undefined;
			},
			set: function( elem, value ) {
				return ( elem.style.cssText = value + "" );
			}
		};
	}

// Safari mis-reports the default selected property of an option
// Accessing the parent's selectedIndex property fixes it
	if ( !jQuery.support.optSelected ) {
		jQuery.propHooks.selected = jQuery.extend( jQuery.propHooks.selected, {
			get: function( elem ) {
				var parent = elem.parentNode;

				if ( parent ) {
					parent.selectedIndex;

					// Make sure that it also works with optgroups, see #5701
					if ( parent.parentNode ) {
						parent.parentNode.selectedIndex;
					}
				}
				return null;
			}
		});
	}

// IE6/7 call enctype encoding
	if ( !jQuery.support.enctype ) {
		jQuery.propFix.enctype = "encoding";
	}

// Radios and checkboxes getter/setter
	if ( !jQuery.support.checkOn ) {
		jQuery.each([ "radio", "checkbox" ], function() {
			jQuery.valHooks[ this ] = {
				get: function( elem ) {
					// Handle the case where in Webkit "" is returned instead of "on" if a value isn't specified
					return elem.getAttribute("value") === null ? "on" : elem.value;
				}
			};
		});
	}
	jQuery.each([ "radio", "checkbox" ], function() {
		jQuery.valHooks[ this ] = jQuery.extend( jQuery.valHooks[ this ], {
			set: function( elem, value ) {
				if ( jQuery.isArray( value ) ) {
					return ( elem.checked = jQuery.inArray( jQuery(elem).val(), value ) >= 0 );
				}
			}
		});
	});
	var rformElems = /^(?:textarea|input|select)$/i,
		rtypenamespace = /^([^\.]*|)(?:\.(.+)|)$/,
		rhoverHack = /(?:^|\s)hover(\.\S+|)\b/,
		rkeyEvent = /^key/,
		rmouseEvent = /^(?:mouse|contextmenu)|click/,
		rfocusMorph = /^(?:focusinfocus|focusoutblur)$/,
		hoverHack = function( events ) {
			return jQuery.event.special.hover ? events : events.replace( rhoverHack, "mouseenter$1 mouseleave$1" );
		};

	/*
	 * Helper functions for managing events -- not part of the public interface.
	 * Props to Dean Edwards' addEvent library for many of the ideas.
	 */
	jQuery.event = {

		add: function( elem, types, handler, data, selector ) {

			var elemData, eventHandle, events,
				t, tns, type, namespaces, handleObj,
				handleObjIn, handlers, special;

			// Don't attach events to noData or text/comment nodes (allow plain objects tho)
			if ( elem.nodeType === 3 || elem.nodeType === 8 || !types || !handler || !(elemData = jQuery._data( elem )) ) {
				return;
			}

			// Caller can pass in an object of custom data in lieu of the handler
			if ( handler.handler ) {
				handleObjIn = handler;
				handler = handleObjIn.handler;
				selector = handleObjIn.selector;
			}

			// Make sure that the handler has a unique ID, used to find/remove it later
			if ( !handler.guid ) {
				handler.guid = jQuery.guid++;
			}

			// Init the element's event structure and main handler, if this is the first
			events = elemData.events;
			if ( !events ) {
				elemData.events = events = {};
			}
			eventHandle = elemData.handle;
			if ( !eventHandle ) {
				elemData.handle = eventHandle = function( e ) {
					// Discard the second event of a jQuery.event.trigger() and
					// when an event is called after a page has unloaded
					return typeof jQuery !== "undefined" && (!e || jQuery.event.triggered !== e.type) ?
						jQuery.event.dispatch.apply( eventHandle.elem, arguments ) :
						undefined;
				};
				// Add elem as a property of the handle fn to prevent a memory leak with IE non-native events
				eventHandle.elem = elem;
			}

			// Handle multiple events separated by a space
			// jQuery(...).bind("mouseover mouseout", fn);
			types = jQuery.trim( hoverHack(types) ).split( " " );
			for ( t = 0; t < types.length; t++ ) {

				tns = rtypenamespace.exec( types[t] ) || [];
				type = tns[1];
				namespaces = ( tns[2] || "" ).split( "." ).sort();

				// If event changes its type, use the special event handlers for the changed type
				special = jQuery.event.special[ type ] || {};

				// If selector defined, determine special event api type, otherwise given type
				type = ( selector ? special.delegateType : special.bindType ) || type;

				// Update special based on newly reset type
				special = jQuery.event.special[ type ] || {};

				// handleObj is passed to all event handlers
				handleObj = jQuery.extend({
					type: type,
					origType: tns[1],
					data: data,
					handler: handler,
					guid: handler.guid,
					selector: selector,
					needsContext: selector && jQuery.expr.match.needsContext.test( selector ),
					namespace: namespaces.join(".")
				}, handleObjIn );

				// Init the event handler queue if we're the first
				handlers = events[ type ];
				if ( !handlers ) {
					handlers = events[ type ] = [];
					handlers.delegateCount = 0;

					// Only use addEventListener/attachEvent if the special events handler returns false
					if ( !special.setup || special.setup.call( elem, data, namespaces, eventHandle ) === false ) {
						// Bind the global event handler to the element
						if ( elem.addEventListener ) {
							elem.addEventListener( type, eventHandle, false );

						} else if ( elem.attachEvent ) {
							elem.attachEvent( "on" + type, eventHandle );
						}
					}
				}

				if ( special.add ) {
					special.add.call( elem, handleObj );

					if ( !handleObj.handler.guid ) {
						handleObj.handler.guid = handler.guid;
					}
				}

				// Add to the element's handler list, delegates in front
				if ( selector ) {
					handlers.splice( handlers.delegateCount++, 0, handleObj );
				} else {
					handlers.push( handleObj );
				}

				// Keep track of which events have ever been used, for event optimization
				jQuery.event.global[ type ] = true;
			}

			// Nullify elem to prevent memory leaks in IE
			elem = null;
		},

		global: {},

		// Detach an event or set of events from an element
		remove: function( elem, types, handler, selector, mappedTypes ) {

			var t, tns, type, origType, namespaces, origCount,
				j, events, special, eventType, handleObj,
				elemData = jQuery.hasData( elem ) && jQuery._data( elem );

			if ( !elemData || !(events = elemData.events) ) {
				return;
			}

			// Once for each type.namespace in types; type may be omitted
			types = jQuery.trim( hoverHack( types || "" ) ).split(" ");
			for ( t = 0; t < types.length; t++ ) {
				tns = rtypenamespace.exec( types[t] ) || [];
				type = origType = tns[1];
				namespaces = tns[2];

				// Unbind all events (on this namespace, if provided) for the element
				if ( !type ) {
					for ( type in events ) {
						jQuery.event.remove( elem, type + types[ t ], handler, selector, true );
					}
					continue;
				}

				special = jQuery.event.special[ type ] || {};
				type = ( selector? special.delegateType : special.bindType ) || type;
				eventType = events[ type ] || [];
				origCount = eventType.length;
				namespaces = namespaces ? new RegExp("(^|\\.)" + namespaces.split(".").sort().join("\\.(?:.*\\.|)") + "(\\.|$)") : null;

				// Remove matching events
				for ( j = 0; j < eventType.length; j++ ) {
					handleObj = eventType[ j ];

					if ( ( mappedTypes || origType === handleObj.origType ) &&
						( !handler || handler.guid === handleObj.guid ) &&
						( !namespaces || namespaces.test( handleObj.namespace ) ) &&
						( !selector || selector === handleObj.selector || selector === "**" && handleObj.selector ) ) {
						eventType.splice( j--, 1 );

						if ( handleObj.selector ) {
							eventType.delegateCount--;
						}
						if ( special.remove ) {
							special.remove.call( elem, handleObj );
						}
					}
				}

				// Remove generic event handler if we removed something and no more handlers exist
				// (avoids potential for endless recursion during removal of special event handlers)
				if ( eventType.length === 0 && origCount !== eventType.length ) {
					if ( !special.teardown || special.teardown.call( elem, namespaces, elemData.handle ) === false ) {
						jQuery.removeEvent( elem, type, elemData.handle );
					}

					delete events[ type ];
				}
			}

			// Remove the expando if it's no longer used
			if ( jQuery.isEmptyObject( events ) ) {
				delete elemData.handle;

				// removeData also checks for emptiness and clears the expando if empty
				// so use it instead of delete
				jQuery.removeData( elem, "events", true );
			}
		},

		// Events that are safe to short-circuit if no handlers are attached.
		// Native DOM events should not be added, they may have inline handlers.
		customEvent: {
			"getData": true,
			"setData": true,
			"changeData": true
		},

		trigger: function( event, data, elem, onlyHandlers ) {
			// Don't do events on text and comment nodes
			if ( elem && (elem.nodeType === 3 || elem.nodeType === 8) ) {
				return;
			}

			// Event object or event type
			var cache, exclusive, i, cur, old, ontype, special, handle, eventPath, bubbleType,
				type = event.type || event,
				namespaces = [];

			// focus/blur morphs to focusin/out; ensure we're not firing them right now
			if ( rfocusMorph.test( type + jQuery.event.triggered ) ) {
				return;
			}

			if ( type.indexOf( "!" ) >= 0 ) {
				// Exclusive events trigger only for the exact event (no namespaces)
				type = type.slice(0, -1);
				exclusive = true;
			}

			if ( type.indexOf( "." ) >= 0 ) {
				// Namespaced trigger; create a regexp to match event type in handle()
				namespaces = type.split(".");
				type = namespaces.shift();
				namespaces.sort();
			}

			if ( (!elem || jQuery.event.customEvent[ type ]) && !jQuery.event.global[ type ] ) {
				// No jQuery handlers for this event type, and it can't have inline handlers
				return;
			}

			// Caller can pass in an Event, Object, or just an event type string
			event = typeof event === "object" ?
				// jQuery.Event object
				event[ jQuery.expando ] ? event :
					// Object literal
					new jQuery.Event( type, event ) :
				// Just the event type (string)
				new jQuery.Event( type );

			event.type = type;
			event.isTrigger = true;
			event.exclusive = exclusive;
			event.namespace = namespaces.join( "." );
			event.namespace_re = event.namespace? new RegExp("(^|\\.)" + namespaces.join("\\.(?:.*\\.|)") + "(\\.|$)") : null;
			ontype = type.indexOf( ":" ) < 0 ? "on" + type : "";

			// Handle a global trigger
			if ( !elem ) {

				// TODO: Stop taunting the data cache; remove global events and always attach to document
				cache = jQuery.cache;
				for ( i in cache ) {
					if ( cache[ i ].events && cache[ i ].events[ type ] ) {
						jQuery.event.trigger( event, data, cache[ i ].handle.elem, true );
					}
				}
				return;
			}

			// Clean up the event in case it is being reused
			event.result = undefined;
			if ( !event.target ) {
				event.target = elem;
			}

			// Clone any incoming data and prepend the event, creating the handler arg list
			data = data != null ? jQuery.makeArray( data ) : [];
			data.unshift( event );

			// Allow special events to draw outside the lines
			special = jQuery.event.special[ type ] || {};
			if ( special.trigger && special.trigger.apply( elem, data ) === false ) {
				return;
			}

			// Determine event propagation path in advance, per W3C events spec (#9951)
			// Bubble up to document, then to window; watch for a global ownerDocument var (#9724)
			eventPath = [[ elem, special.bindType || type ]];
			if ( !onlyHandlers && !special.noBubble && !jQuery.isWindow( elem ) ) {

				bubbleType = special.delegateType || type;
				cur = rfocusMorph.test( bubbleType + type ) ? elem : elem.parentNode;
				for ( old = elem; cur; cur = cur.parentNode ) {
					eventPath.push([ cur, bubbleType ]);
					old = cur;
				}

				// Only add window if we got to document (e.g., not plain obj or detached DOM)
				if ( old === (elem.ownerDocument || document) ) {
					eventPath.push([ old.defaultView || old.parentWindow || window, bubbleType ]);
				}
			}

			// Fire handlers on the event path
			for ( i = 0; i < eventPath.length && !event.isPropagationStopped(); i++ ) {

				cur = eventPath[i][0];
				event.type = eventPath[i][1];

				handle = ( jQuery._data( cur, "events" ) || {} )[ event.type ] && jQuery._data( cur, "handle" );
				if ( handle ) {
					handle.apply( cur, data );
				}
				// Note that this is a bare JS function and not a jQuery handler
				handle = ontype && cur[ ontype ];
				if ( handle && jQuery.acceptData( cur ) && handle.apply && handle.apply( cur, data ) === false ) {
					event.preventDefault();
				}
			}
			event.type = type;

			// If nobody prevented the default action, do it now
			if ( !onlyHandlers && !event.isDefaultPrevented() ) {

				if ( (!special._default || special._default.apply( elem.ownerDocument, data ) === false) &&
					!(type === "click" && jQuery.nodeName( elem, "a" )) && jQuery.acceptData( elem ) ) {

					// Call a native DOM method on the target with the same name name as the event.
					// Can't use an .isFunction() check here because IE6/7 fails that test.
					// Don't do default actions on window, that's where global variables be (#6170)
					// IE<9 dies on focus/blur to hidden element (#1486)
					if ( ontype && elem[ type ] && ((type !== "focus" && type !== "blur") || event.target.offsetWidth !== 0) && !jQuery.isWindow( elem ) ) {

						// Don't re-trigger an onFOO event when we call its FOO() method
						old = elem[ ontype ];

						if ( old ) {
							elem[ ontype ] = null;
						}

						// Prevent re-triggering of the same event, since we already bubbled it above
						jQuery.event.triggered = type;
						elem[ type ]();
						jQuery.event.triggered = undefined;

						if ( old ) {
							elem[ ontype ] = old;
						}
					}
				}
			}

			return event.result;
		},

		dispatch: function( event ) {

			// Make a writable jQuery.Event from the native event object
			event = jQuery.event.fix( event || window.event );

			var i, j, cur, ret, selMatch, matched, matches, handleObj, sel, related,
				handlers = ( (jQuery._data( this, "events" ) || {} )[ event.type ] || []),
				delegateCount = handlers.delegateCount,
				args = core_slice.call( arguments ),
				run_all = !event.exclusive && !event.namespace,
				special = jQuery.event.special[ event.type ] || {},
				handlerQueue = [];

			// Use the fix-ed jQuery.Event rather than the (read-only) native event
			args[0] = event;
			event.delegateTarget = this;

			// Call the preDispatch hook for the mapped type, and let it bail if desired
			if ( special.preDispatch && special.preDispatch.call( this, event ) === false ) {
				return;
			}

			// Determine handlers that should run if there are delegated events
			// Avoid non-left-click bubbling in Firefox (#3861)
			if ( delegateCount && !(event.button && event.type === "click") ) {

				for ( cur = event.target; cur != this; cur = cur.parentNode || this ) {

					// Don't process clicks (ONLY) on disabled elements (#6911, #8165, #11382, #11764)
					if ( cur.disabled !== true || event.type !== "click" ) {
						selMatch = {};
						matches = [];
						for ( i = 0; i < delegateCount; i++ ) {
							handleObj = handlers[ i ];
							sel = handleObj.selector;

							if ( selMatch[ sel ] === undefined ) {
								selMatch[ sel ] = handleObj.needsContext ?
									jQuery( sel, this ).index( cur ) >= 0 :
									jQuery.find( sel, this, null, [ cur ] ).length;
							}
							if ( selMatch[ sel ] ) {
								matches.push( handleObj );
							}
						}
						if ( matches.length ) {
							handlerQueue.push({ elem: cur, matches: matches });
						}
					}
				}
			}

			// Add the remaining (directly-bound) handlers
			if ( handlers.length > delegateCount ) {
				handlerQueue.push({ elem: this, matches: handlers.slice( delegateCount ) });
			}

			// Run delegates first; they may want to stop propagation beneath us
			for ( i = 0; i < handlerQueue.length && !event.isPropagationStopped(); i++ ) {
				matched = handlerQueue[ i ];
				event.currentTarget = matched.elem;

				for ( j = 0; j < matched.matches.length && !event.isImmediatePropagationStopped(); j++ ) {
					handleObj = matched.matches[ j ];

					// Triggered event must either 1) be non-exclusive and have no namespace, or
					// 2) have namespace(s) a subset or equal to those in the bound event (both can have no namespace).
					if ( run_all || (!event.namespace && !handleObj.namespace) || event.namespace_re && event.namespace_re.test( handleObj.namespace ) ) {

						event.data = handleObj.data;
						event.handleObj = handleObj;

						ret = ( (jQuery.event.special[ handleObj.origType ] || {}).handle || handleObj.handler )
							.apply( matched.elem, args );

						if ( ret !== undefined ) {
							event.result = ret;
							if ( ret === false ) {
								event.preventDefault();
								event.stopPropagation();
							}
						}
					}
				}
			}

			// Call the postDispatch hook for the mapped type
			if ( special.postDispatch ) {
				special.postDispatch.call( this, event );
			}

			return event.result;
		},

		// Includes some event props shared by KeyEvent and MouseEvent
		// *** attrChange attrName relatedNode srcElement  are not normalized, non-W3C, deprecated, will be removed in 1.8 ***
		props: "attrChange attrName relatedNode srcElement altKey bubbles cancelable ctrlKey currentTarget eventPhase metaKey relatedTarget shiftKey target timeStamp view which".split(" "),

		fixHooks: {},

		keyHooks: {
			props: "char charCode key keyCode".split(" "),
			filter: function( event, original ) {

				// Add which for key events
				if ( event.which == null ) {
					event.which = original.charCode != null ? original.charCode : original.keyCode;
				}

				return event;
			}
		},

		mouseHooks: {
			props: "button buttons clientX clientY fromElement offsetX offsetY pageX pageY screenX screenY toElement".split(" "),
			filter: function( event, original ) {
				var eventDoc, doc, body,
					button = original.button,
					fromElement = original.fromElement;

				// Calculate pageX/Y if missing and clientX/Y available
				if ( event.pageX == null && original.clientX != null ) {
					eventDoc = event.target.ownerDocument || document;
					doc = eventDoc.documentElement;
					body = eventDoc.body;

					event.pageX = original.clientX + ( doc && doc.scrollLeft || body && body.scrollLeft || 0 ) - ( doc && doc.clientLeft || body && body.clientLeft || 0 );
					event.pageY = original.clientY + ( doc && doc.scrollTop  || body && body.scrollTop  || 0 ) - ( doc && doc.clientTop  || body && body.clientTop  || 0 );
				}

				// Add relatedTarget, if necessary
				if ( !event.relatedTarget && fromElement ) {
					event.relatedTarget = fromElement === event.target ? original.toElement : fromElement;
				}

				// Add which for click: 1 === left; 2 === middle; 3 === right
				// Note: button is not normalized, so don't use it
				if ( !event.which && button !== undefined ) {
					event.which = ( button & 1 ? 1 : ( button & 2 ? 3 : ( button & 4 ? 2 : 0 ) ) );
				}

				return event;
			}
		},

		fix: function( event ) {
			if ( event[ jQuery.expando ] ) {
				return event;
			}

			// Create a writable copy of the event object and normalize some properties
			var i, prop,
				originalEvent = event,
				fixHook = jQuery.event.fixHooks[ event.type ] || {},
				copy = fixHook.props ? this.props.concat( fixHook.props ) : this.props;

			event = jQuery.Event( originalEvent );

			for ( i = copy.length; i; ) {
				prop = copy[ --i ];
				event[ prop ] = originalEvent[ prop ];
			}

			// Fix target property, if necessary (#1925, IE 6/7/8 & Safari2)
			if ( !event.target ) {
				event.target = originalEvent.srcElement || document;
			}

			// Target should not be a text node (#504, Safari)
			if ( event.target.nodeType === 3 ) {
				event.target = event.target.parentNode;
			}

			// For mouse/key events, metaKey==false if it's undefined (#3368, #11328; IE6/7/8)
			event.metaKey = !!event.metaKey;

			return fixHook.filter? fixHook.filter( event, originalEvent ) : event;
		},

		special: {
			load: {
				// Prevent triggered image.load events from bubbling to window.load
				noBubble: true
			},

			focus: {
				delegateType: "focusin"
			},
			blur: {
				delegateType: "focusout"
			},

			beforeunload: {
				setup: function( data, namespaces, eventHandle ) {
					// We only want to do this special case on windows
					if ( jQuery.isWindow( this ) ) {
						this.onbeforeunload = eventHandle;
					}
				},

				teardown: function( namespaces, eventHandle ) {
					if ( this.onbeforeunload === eventHandle ) {
						this.onbeforeunload = null;
					}
				}
			}
		},

		simulate: function( type, elem, event, bubble ) {
			// Piggyback on a donor event to simulate a different one.
			// Fake originalEvent to avoid donor's stopPropagation, but if the
			// simulated event prevents default then we do the same on the donor.
			var e = jQuery.extend(
				new jQuery.Event(),
				event,
				{ type: type,
					isSimulated: true,
					originalEvent: {}
				}
			);
			if ( bubble ) {
				jQuery.event.trigger( e, null, elem );
			} else {
				jQuery.event.dispatch.call( elem, e );
			}
			if ( e.isDefaultPrevented() ) {
				event.preventDefault();
			}
		}
	};

// Some plugins are using, but it's undocumented/deprecated and will be removed.
// The 1.7 special event interface should provide all the hooks needed now.
	jQuery.event.handle = jQuery.event.dispatch;

	jQuery.removeEvent = document.removeEventListener ?
		function( elem, type, handle ) {
			if ( elem.removeEventListener ) {
				elem.removeEventListener( type, handle, false );
			}
		} :
		function( elem, type, handle ) {
			var name = "on" + type;

			if ( elem.detachEvent ) {

				// #8545, #7054, preventing memory leaks for custom events in IE6-8
				// detachEvent needed property on element, by name of that event, to properly expose it to GC
				if ( typeof elem[ name ] === "undefined" ) {
					elem[ name ] = null;
				}

				elem.detachEvent( name, handle );
			}
		};

	jQuery.Event = function( src, props ) {
		// Allow instantiation without the 'new' keyword
		if ( !(this instanceof jQuery.Event) ) {
			return new jQuery.Event( src, props );
		}

		// Event object
		if ( src && src.type ) {
			this.originalEvent = src;
			this.type = src.type;

			// Events bubbling up the document may have been marked as prevented
			// by a handler lower down the tree; reflect the correct value.
			this.isDefaultPrevented = ( src.defaultPrevented || src.returnValue === false ||
				src.getPreventDefault && src.getPreventDefault() ) ? returnTrue : returnFalse;

			// Event type
		} else {
			this.type = src;
		}

		// Put explicitly provided properties onto the event object
		if ( props ) {
			jQuery.extend( this, props );
		}

		// Create a timestamp if incoming event doesn't have one
		this.timeStamp = src && src.timeStamp || jQuery.now();

		// Mark it as fixed
		this[ jQuery.expando ] = true;
	};

	function returnFalse() {
		return false;
	}
	function returnTrue() {
		return true;
	}

// jQuery.Event is based on DOM3 Events as specified by the ECMAScript Language Binding
// http://www.w3.org/TR/2003/WD-DOM-Level-3-Events-20030331/ecma-script-binding.html
	jQuery.Event.prototype = {
		preventDefault: function() {
			this.isDefaultPrevented = returnTrue;

			var e = this.originalEvent;
			if ( !e ) {
				return;
			}

			// if preventDefault exists run it on the original event
			if ( e.preventDefault ) {
				e.preventDefault();

				// otherwise set the returnValue property of the original event to false (IE)
			} else {
				e.returnValue = false;
			}
		},
		stopPropagation: function() {
			this.isPropagationStopped = returnTrue;

			var e = this.originalEvent;
			if ( !e ) {
				return;
			}
			// if stopPropagation exists run it on the original event
			if ( e.stopPropagation ) {
				e.stopPropagation();
			}
			// otherwise set the cancelBubble property of the original event to true (IE)
			e.cancelBubble = true;
		},
		stopImmediatePropagation: function() {
			this.isImmediatePropagationStopped = returnTrue;
			this.stopPropagation();
		},
		isDefaultPrevented: returnFalse,
		isPropagationStopped: returnFalse,
		isImmediatePropagationStopped: returnFalse
	};

// Create mouseenter/leave events using mouseover/out and event-time checks
	jQuery.each({
		mouseenter: "mouseover",
		mouseleave: "mouseout"
	}, function( orig, fix ) {
		jQuery.event.special[ orig ] = {
			delegateType: fix,
			bindType: fix,

			handle: function( event ) {
				var ret,
					target = this,
					related = event.relatedTarget,
					handleObj = event.handleObj,
					selector = handleObj.selector;

				// For mousenter/leave call the handler if related is outside the target.
				// NB: No relatedTarget if the mouse left/entered the browser window
				if ( !related || (related !== target && !jQuery.contains( target, related )) ) {
					event.type = handleObj.origType;
					ret = handleObj.handler.apply( this, arguments );
					event.type = fix;
				}
				return ret;
			}
		};
	});

// IE submit delegation
	if ( !jQuery.support.submitBubbles ) {

		jQuery.event.special.submit = {
			setup: function() {
				// Only need this for delegated form submit events
				if ( jQuery.nodeName( this, "form" ) ) {
					return false;
				}

				// Lazy-add a submit handler when a descendant form may potentially be submitted
				jQuery.event.add( this, "click._submit keypress._submit", function( e ) {
					// Node name check avoids a VML-related crash in IE (#9807)
					var elem = e.target,
						form = jQuery.nodeName( elem, "input" ) || jQuery.nodeName( elem, "button" ) ? elem.form : undefined;
					if ( form && !jQuery._data( form, "_submit_attached" ) ) {
						jQuery.event.add( form, "submit._submit", function( event ) {
							event._submit_bubble = true;
						});
						jQuery._data( form, "_submit_attached", true );
					}
				});
				// return undefined since we don't need an event listener
			},

			postDispatch: function( event ) {
				// If form was submitted by the user, bubble the event up the tree
				if ( event._submit_bubble ) {
					delete event._submit_bubble;
					if ( this.parentNode && !event.isTrigger ) {
						jQuery.event.simulate( "submit", this.parentNode, event, true );
					}
				}
			},

			teardown: function() {
				// Only need this for delegated form submit events
				if ( jQuery.nodeName( this, "form" ) ) {
					return false;
				}

				// Remove delegated handlers; cleanData eventually reaps submit handlers attached above
				jQuery.event.remove( this, "._submit" );
			}
		};
	}

// IE change delegation and checkbox/radio fix
	if ( !jQuery.support.changeBubbles ) {

		jQuery.event.special.change = {

			setup: function() {

				if ( rformElems.test( this.nodeName ) ) {
					// IE doesn't fire change on a check/radio until blur; trigger it on click
					// after a propertychange. Eat the blur-change in special.change.handle.
					// This still fires onchange a second time for check/radio after blur.
					if ( this.type === "checkbox" || this.type === "radio" ) {
						jQuery.event.add( this, "propertychange._change", function( event ) {
							if ( event.originalEvent.propertyName === "checked" ) {
								this._just_changed = true;
							}
						});
						jQuery.event.add( this, "click._change", function( event ) {
							if ( this._just_changed && !event.isTrigger ) {
								this._just_changed = false;
							}
							// Allow triggered, simulated change events (#11500)
							jQuery.event.simulate( "change", this, event, true );
						});
					}
					return false;
				}
				// Delegated event; lazy-add a change handler on descendant inputs
				jQuery.event.add( this, "beforeactivate._change", function( e ) {
					var elem = e.target;

					if ( rformElems.test( elem.nodeName ) && !jQuery._data( elem, "_change_attached" ) ) {
						jQuery.event.add( elem, "change._change", function( event ) {
							if ( this.parentNode && !event.isSimulated && !event.isTrigger ) {
								jQuery.event.simulate( "change", this.parentNode, event, true );
							}
						});
						jQuery._data( elem, "_change_attached", true );
					}
				});
			},

			handle: function( event ) {
				var elem = event.target;

				// Swallow native change events from checkbox/radio, we already triggered them above
				if ( this !== elem || event.isSimulated || event.isTrigger || (elem.type !== "radio" && elem.type !== "checkbox") ) {
					return event.handleObj.handler.apply( this, arguments );
				}
			},

			teardown: function() {
				jQuery.event.remove( this, "._change" );

				return !rformElems.test( this.nodeName );
			}
		};
	}

// Create "bubbling" focus and blur events
	if ( !jQuery.support.focusinBubbles ) {
		jQuery.each({ focus: "focusin", blur: "focusout" }, function( orig, fix ) {

			// Attach a single capturing handler while someone wants focusin/focusout
			var attaches = 0,
				handler = function( event ) {
					jQuery.event.simulate( fix, event.target, jQuery.event.fix( event ), true );
				};

			jQuery.event.special[ fix ] = {
				setup: function() {
					if ( attaches++ === 0 ) {
						document.addEventListener( orig, handler, true );
					}
				},
				teardown: function() {
					if ( --attaches === 0 ) {
						document.removeEventListener( orig, handler, true );
					}
				}
			};
		});
	}

	jQuery.fn.extend({

		on: function( types, selector, data, fn, /*INTERNAL*/ one ) {
			var origFn, type;

			// Types can be a map of types/handlers
			if ( typeof types === "object" ) {
				// ( types-Object, selector, data )
				if ( typeof selector !== "string" ) { // && selector != null
					// ( types-Object, data )
					data = data || selector;
					selector = undefined;
				}
				for ( type in types ) {
					this.on( type, selector, data, types[ type ], one );
				}
				return this;
			}

			if ( data == null && fn == null ) {
				// ( types, fn )
				fn = selector;
				data = selector = undefined;
			} else if ( fn == null ) {
				if ( typeof selector === "string" ) {
					// ( types, selector, fn )
					fn = data;
					data = undefined;
				} else {
					// ( types, data, fn )
					fn = data;
					data = selector;
					selector = undefined;
				}
			}
			if ( fn === false ) {
				fn = returnFalse;
			} else if ( !fn ) {
				return this;
			}

			if ( one === 1 ) {
				origFn = fn;
				fn = function( event ) {
					// Can use an empty set, since event contains the info
					jQuery().off( event );
					return origFn.apply( this, arguments );
				};
				// Use same guid so caller can remove using origFn
				fn.guid = origFn.guid || ( origFn.guid = jQuery.guid++ );
			}
			return this.each( function() {
				jQuery.event.add( this, types, fn, data, selector );
			});
		},
		one: function( types, selector, data, fn ) {
			return this.on( types, selector, data, fn, 1 );
		},
		off: function( types, selector, fn ) {
			var handleObj, type;
			if ( types && types.preventDefault && types.handleObj ) {
				// ( event )  dispatched jQuery.Event
				handleObj = types.handleObj;
				jQuery( types.delegateTarget ).off(
					handleObj.namespace ? handleObj.origType + "." + handleObj.namespace : handleObj.origType,
					handleObj.selector,
					handleObj.handler
				);
				return this;
			}
			if ( typeof types === "object" ) {
				// ( types-object [, selector] )
				for ( type in types ) {
					this.off( type, selector, types[ type ] );
				}
				return this;
			}
			if ( selector === false || typeof selector === "function" ) {
				// ( types [, fn] )
				fn = selector;
				selector = undefined;
			}
			if ( fn === false ) {
				fn = returnFalse;
			}
			return this.each(function() {
				jQuery.event.remove( this, types, fn, selector );
			});
		},

		bind: function( types, data, fn ) {
			return this.on( types, null, data, fn );
		},
		unbind: function( types, fn ) {
			return this.off( types, null, fn );
		},

		live: function( types, data, fn ) {
			jQuery( this.context ).on( types, this.selector, data, fn );
			return this;
		},
		die: function( types, fn ) {
			jQuery( this.context ).off( types, this.selector || "**", fn );
			return this;
		},

		delegate: function( selector, types, data, fn ) {
			return this.on( types, selector, data, fn );
		},
		undelegate: function( selector, types, fn ) {
			// ( namespace ) or ( selector, types [, fn] )
			return arguments.length === 1 ? this.off( selector, "**" ) : this.off( types, selector || "**", fn );
		},

		trigger: function( type, data ) {
			return this.each(function() {
				jQuery.event.trigger( type, data, this );
			});
		},
		triggerHandler: function( type, data ) {
			if ( this[0] ) {
				return jQuery.event.trigger( type, data, this[0], true );
			}
		},

		toggle: function( fn ) {
			// Save reference to arguments for access in closure
			var args = arguments,
				guid = fn.guid || jQuery.guid++,
				i = 0,
				toggler = function( event ) {
					// Figure out which function to execute
					var lastToggle = ( jQuery._data( this, "lastToggle" + fn.guid ) || 0 ) % i;
					jQuery._data( this, "lastToggle" + fn.guid, lastToggle + 1 );

					// Make sure that clicks stop
					event.preventDefault();

					// and execute the function
					return args[ lastToggle ].apply( this, arguments ) || false;
				};

			// link all the functions, so any of them can unbind this click handler
			toggler.guid = guid;
			while ( i < args.length ) {
				args[ i++ ].guid = guid;
			}

			return this.click( toggler );
		},

		hover: function( fnOver, fnOut ) {
			return this.mouseenter( fnOver ).mouseleave( fnOut || fnOver );
		}
	});

	jQuery.each( ("blur focus focusin focusout load resize scroll unload click dblclick " +
		"mousedown mouseup mousemove mouseover mouseout mouseenter mouseleave " +
		"change select submit keydown keypress keyup error contextmenu").split(" "), function( i, name ) {

		// Handle event binding
		jQuery.fn[ name ] = function( data, fn ) {
			if ( fn == null ) {
				fn = data;
				data = null;
			}

			return arguments.length > 0 ?
				this.on( name, null, data, fn ) :
				this.trigger( name );
		};

		if ( rkeyEvent.test( name ) ) {
			jQuery.event.fixHooks[ name ] = jQuery.event.keyHooks;
		}

		if ( rmouseEvent.test( name ) ) {
			jQuery.event.fixHooks[ name ] = jQuery.event.mouseHooks;
		}
	});
	/*!
	 * Sizzle CSS Selector Engine
	 * Copyright 2012 jQuery Foundation and other contributors
	 * Released under the MIT license
	 * http://sizzlejs.com/
	 */
	(function( window, undefined ) {

		var cachedruns,
			assertGetIdNotName,
			Expr,
			getText,
			isXML,
			contains,
			compile,
			sortOrder,
			hasDuplicate,
			outermostContext,

			baseHasDuplicate = true,
			strundefined = "undefined",

			expando = ( "sizcache" + Math.random() ).replace( ".", "" ),

			Token = String,
			document = window.document,
			docElem = document.documentElement,
			dirruns = 0,
			done = 0,
			pop = [].pop,
			push = [].push,
			slice = [].slice,
		// Use a stripped-down indexOf if a native one is unavailable
			indexOf = [].indexOf || function( elem ) {
				var i = 0,
					len = this.length;
				for ( ; i < len; i++ ) {
					if ( this[i] === elem ) {
						return i;
					}
				}
				return -1;
			},

		// Augment a function for special use by Sizzle
			markFunction = function( fn, value ) {
				fn[ expando ] = value == null || value;
				return fn;
			},

			createCache = function() {
				var cache = {},
					keys = [];

				return markFunction(function( key, value ) {
					// Only keep the most recent entries
					if ( keys.push( key ) > Expr.cacheLength ) {
						delete cache[ keys.shift() ];
					}

					// Retrieve with (key + " ") to avoid collision with native Object.prototype properties (see Issue #157)
					return (cache[ key + " " ] = value);
				}, cache );
			},

			classCache = createCache(),
			tokenCache = createCache(),
			compilerCache = createCache(),

		// Regex

		// Whitespace characters http://www.w3.org/TR/css3-selectors/#whitespace
			whitespace = "[\\x20\\t\\r\\n\\f]",
		// http://www.w3.org/TR/css3-syntax/#characters
			characterEncoding = "(?:\\\\.|[-\\w]|[^\\x00-\\xa0])+",

		// Loosely modeled on CSS identifier characters
		// An unquoted value should be a CSS identifier (http://www.w3.org/TR/css3-selectors/#attribute-selectors)
		// Proper syntax: http://www.w3.org/TR/CSS21/syndata.html#value-def-identifier
			identifier = characterEncoding.replace( "w", "w#" ),

		// Acceptable operators http://www.w3.org/TR/selectors/#attribute-selectors
			operators = "([*^$|!~]?=)",
			attributes = "\\[" + whitespace + "*(" + characterEncoding + ")" + whitespace +
				"*(?:" + operators + whitespace + "*(?:(['\"])((?:\\\\.|[^\\\\])*?)\\3|(" + identifier + ")|)|)" + whitespace + "*\\]",

		// Prefer arguments not in parens/brackets,
		//   then attribute selectors and non-pseudos (denoted by :),
		//   then anything else
		// These preferences are here to reduce the number of selectors
		//   needing tokenize in the PSEUDO preFilter
			pseudos = ":(" + characterEncoding + ")(?:\\((?:(['\"])((?:\\\\.|[^\\\\])*?)\\2|([^()[\\]]*|(?:(?:" + attributes + ")|[^:]|\\\\.)*|.*))\\)|)",

		// For matchExpr.POS and matchExpr.needsContext
			pos = ":(even|odd|eq|gt|lt|nth|first|last)(?:\\(" + whitespace +
				"*((?:-\\d)?\\d*)" + whitespace + "*\\)|)(?=[^-]|$)",

		// Leading and non-escaped trailing whitespace, capturing some non-whitespace characters preceding the latter
			rtrim = new RegExp( "^" + whitespace + "+|((?:^|[^\\\\])(?:\\\\.)*)" + whitespace + "+$", "g" ),

			rcomma = new RegExp( "^" + whitespace + "*," + whitespace + "*" ),
			rcombinators = new RegExp( "^" + whitespace + "*([\\x20\\t\\r\\n\\f>+~])" + whitespace + "*" ),
			rpseudo = new RegExp( pseudos ),

		// Easily-parseable/retrievable ID or TAG or CLASS selectors
			rquickExpr = /^(?:#([\w\-]+)|(\w+)|\.([\w\-]+))$/,

			rnot = /^:not/,
			rsibling = /[\x20\t\r\n\f]*[+~]/,
			rendsWithNot = /:not\($/,

			rheader = /h\d/i,
			rinputs = /input|select|textarea|button/i,

			rbackslash = /\\(?!\\)/g,

			matchExpr = {
				"ID": new RegExp( "^#(" + characterEncoding + ")" ),
				"CLASS": new RegExp( "^\\.(" + characterEncoding + ")" ),
				"NAME": new RegExp( "^\\[name=['\"]?(" + characterEncoding + ")['\"]?\\]" ),
				"TAG": new RegExp( "^(" + characterEncoding.replace( "w", "w*" ) + ")" ),
				"ATTR": new RegExp( "^" + attributes ),
				"PSEUDO": new RegExp( "^" + pseudos ),
				"POS": new RegExp( pos, "i" ),
				"CHILD": new RegExp( "^:(only|nth|first|last)-child(?:\\(" + whitespace +
					"*(even|odd|(([+-]|)(\\d*)n|)" + whitespace + "*(?:([+-]|)" + whitespace +
					"*(\\d+)|))" + whitespace + "*\\)|)", "i" ),
				// For use in libraries implementing .is()
				"needsContext": new RegExp( "^" + whitespace + "*[>+~]|" + pos, "i" )
			},

		// Support

		// Used for testing something on an element
			assert = function( fn ) {
				var div = document.createElement("div");

				try {
					return fn( div );
				} catch (e) {
					return false;
				} finally {
					// release memory in IE
					div = null;
				}
			},

		// Check if getElementsByTagName("*") returns only elements
			assertTagNameNoComments = assert(function( div ) {
				div.appendChild( document.createComment("") );
				return !div.getElementsByTagName("*").length;
			}),

		// Check if getAttribute returns normalized href attributes
			assertHrefNotNormalized = assert(function( div ) {
				div.innerHTML = "<a href='#'></a>";
				return div.firstChild && typeof div.firstChild.getAttribute !== strundefined &&
					div.firstChild.getAttribute("href") === "#";
			}),

		// Check if attributes should be retrieved by attribute nodes
			assertAttributes = assert(function( div ) {
				div.innerHTML = "<select></select>";
				var type = typeof div.lastChild.getAttribute("multiple");
				// IE8 returns a string for some attributes even when not present
				return type !== "boolean" && type !== "string";
			}),

		// Check if getElementsByClassName can be trusted
			assertUsableClassName = assert(function( div ) {
				// Opera can't find a second classname (in 9.6)
				div.innerHTML = "<div class='hidden e'></div><div class='hidden'></div>";
				if ( !div.getElementsByClassName || !div.getElementsByClassName("e").length ) {
					return false;
				}

				// Safari 3.2 caches class attributes and doesn't catch changes
				div.lastChild.className = "e";
				return div.getElementsByClassName("e").length === 2;
			}),

		// Check if getElementById returns elements by name
		// Check if getElementsByName privileges form controls or returns elements by ID
			assertUsableName = assert(function( div ) {
				// Inject content
				div.id = expando + 0;
				div.innerHTML = "<a name='" + expando + "'></a><div name='" + expando + "'></div>";
				docElem.insertBefore( div, docElem.firstChild );

				// Test
				var pass = document.getElementsByName &&
					// buggy browsers will return fewer than the correct 2
					document.getElementsByName( expando ).length === 2 +
						// buggy browsers will return more than the correct 0
						document.getElementsByName( expando + 0 ).length;
				assertGetIdNotName = !document.getElementById( expando );

				// Cleanup
				docElem.removeChild( div );

				return pass;
			});

// If slice is not available, provide a backup
		try {
			slice.call( docElem.childNodes, 0 )[0].nodeType;
		} catch ( e ) {
			slice = function( i ) {
				var elem,
					results = [];
				for ( ; (elem = this[i]); i++ ) {
					results.push( elem );
				}
				return results;
			};
		}

		function Sizzle( selector, context, results, seed ) {
			results = results || [];
			context = context || document;
			var match, elem, xml, m,
				nodeType = context.nodeType;

			if ( !selector || typeof selector !== "string" ) {
				return results;
			}

			if ( nodeType !== 1 && nodeType !== 9 ) {
				return [];
			}

			xml = isXML( context );

			if ( !xml && !seed ) {
				if ( (match = rquickExpr.exec( selector )) ) {
					// Speed-up: Sizzle("#ID")
					if ( (m = match[1]) ) {
						if ( nodeType === 9 ) {
							elem = context.getElementById( m );
							// Check parentNode to catch when Blackberry 4.6 returns
							// nodes that are no longer in the document #6963
							if ( elem && elem.parentNode ) {
								// Handle the case where IE, Opera, and Webkit return items
								// by name instead of ID
								if ( elem.id === m ) {
									results.push( elem );
									return results;
								}
							} else {
								return results;
							}
						} else {
							// Context is not a document
							if ( context.ownerDocument && (elem = context.ownerDocument.getElementById( m )) &&
								contains( context, elem ) && elem.id === m ) {
								results.push( elem );
								return results;
							}
						}

						// Speed-up: Sizzle("TAG")
					} else if ( match[2] ) {
						push.apply( results, slice.call(context.getElementsByTagName( selector ), 0) );
						return results;

						// Speed-up: Sizzle(".CLASS")
					} else if ( (m = match[3]) && assertUsableClassName && context.getElementsByClassName ) {
						push.apply( results, slice.call(context.getElementsByClassName( m ), 0) );
						return results;
					}
				}
			}

			// All others
			return select( selector.replace( rtrim, "$1" ), context, results, seed, xml );
		}

		Sizzle.matches = function( expr, elements ) {
			return Sizzle( expr, null, null, elements );
		};

		Sizzle.matchesSelector = function( elem, expr ) {
			return Sizzle( expr, null, null, [ elem ] ).length > 0;
		};

// Returns a function to use in pseudos for input types
		function createInputPseudo( type ) {
			return function( elem ) {
				var name = elem.nodeName.toLowerCase();
				return name === "input" && elem.type === type;
			};
		}

// Returns a function to use in pseudos for buttons
		function createButtonPseudo( type ) {
			return function( elem ) {
				var name = elem.nodeName.toLowerCase();
				return (name === "input" || name === "button") && elem.type === type;
			};
		}

// Returns a function to use in pseudos for positionals
		function createPositionalPseudo( fn ) {
			return markFunction(function( argument ) {
				argument = +argument;
				return markFunction(function( seed, matches ) {
					var j,
						matchIndexes = fn( [], seed.length, argument ),
						i = matchIndexes.length;

					// Match elements found at the specified indexes
					while ( i-- ) {
						if ( seed[ (j = matchIndexes[i]) ] ) {
							seed[j] = !(matches[j] = seed[j]);
						}
					}
				});
			});
		}

		/**
		 * Utility function for retrieving the text value of an array of DOM nodes
		 * @param {Array|Element} elem
		 */
		getText = Sizzle.getText = function( elem ) {
			var node,
				ret = "",
				i = 0,
				nodeType = elem.nodeType;

			if ( nodeType ) {
				if ( nodeType === 1 || nodeType === 9 || nodeType === 11 ) {
					// Use textContent for elements
					// innerText usage removed for consistency of new lines (see #11153)
					if ( typeof elem.textContent === "string" ) {
						return elem.textContent;
					} else {
						// Traverse its children
						for ( elem = elem.firstChild; elem; elem = elem.nextSibling ) {
							ret += getText( elem );
						}
					}
				} else if ( nodeType === 3 || nodeType === 4 ) {
					return elem.nodeValue;
				}
				// Do not include comment or processing instruction nodes
			} else {

				// If no nodeType, this is expected to be an array
				for ( ; (node = elem[i]); i++ ) {
					// Do not traverse comment nodes
					ret += getText( node );
				}
			}
			return ret;
		};

		isXML = Sizzle.isXML = function( elem ) {
			// documentElement is verified for cases where it doesn't yet exist
			// (such as loading iframes in IE - #4833)
			var documentElement = elem && (elem.ownerDocument || elem).documentElement;
			return documentElement ? documentElement.nodeName !== "HTML" : false;
		};

// Element contains another
		contains = Sizzle.contains = docElem.contains ?
			function( a, b ) {
				var adown = a.nodeType === 9 ? a.documentElement : a,
					bup = b && b.parentNode;
				return a === bup || !!( bup && bup.nodeType === 1 && adown.contains && adown.contains(bup) );
			} :
			docElem.compareDocumentPosition ?
				function( a, b ) {
					return b && !!( a.compareDocumentPosition( b ) & 16 );
				} :
				function( a, b ) {
					while ( (b = b.parentNode) ) {
						if ( b === a ) {
							return true;
						}
					}
					return false;
				};

		Sizzle.attr = function( elem, name ) {
			var val,
				xml = isXML( elem );

			if ( !xml ) {
				name = name.toLowerCase();
			}
			if ( (val = Expr.attrHandle[ name ]) ) {
				return val( elem );
			}
			if ( xml || assertAttributes ) {
				return elem.getAttribute( name );
			}
			val = elem.getAttributeNode( name );
			return val ?
				typeof elem[ name ] === "boolean" ?
					elem[ name ] ? name : null :
					val.specified ? val.value : null :
				null;
		};

		Expr = Sizzle.selectors = {

			// Can be adjusted by the user
			cacheLength: 50,

			createPseudo: markFunction,

			match: matchExpr,

			// IE6/7 return a modified href
			attrHandle: assertHrefNotNormalized ?
			{} :
			{
				"href": function( elem ) {
					return elem.getAttribute( "href", 2 );
				},
				"type": function( elem ) {
					return elem.getAttribute("type");
				}
			},

			find: {
				"ID": assertGetIdNotName ?
					function( id, context, xml ) {
						if ( typeof context.getElementById !== strundefined && !xml ) {
							var m = context.getElementById( id );
							// Check parentNode to catch when Blackberry 4.6 returns
							// nodes that are no longer in the document #6963
							return m && m.parentNode ? [m] : [];
						}
					} :
					function( id, context, xml ) {
						if ( typeof context.getElementById !== strundefined && !xml ) {
							var m = context.getElementById( id );

							return m ?
								m.id === id || typeof m.getAttributeNode !== strundefined && m.getAttributeNode("id").value === id ?
									[m] :
									undefined :
								[];
						}
					},

				"TAG": assertTagNameNoComments ?
					function( tag, context ) {
						if ( typeof context.getElementsByTagName !== strundefined ) {
							return context.getElementsByTagName( tag );
						}
					} :
					function( tag, context ) {
						var results = context.getElementsByTagName( tag );

						// Filter out possible comments
						if ( tag === "*" ) {
							var elem,
								tmp = [],
								i = 0;

							for ( ; (elem = results[i]); i++ ) {
								if ( elem.nodeType === 1 ) {
									tmp.push( elem );
								}
							}

							return tmp;
						}
						return results;
					},

				"NAME": assertUsableName && function( tag, context ) {
					if ( typeof context.getElementsByName !== strundefined ) {
						return context.getElementsByName( name );
					}
				},

				"CLASS": assertUsableClassName && function( className, context, xml ) {
					if ( typeof context.getElementsByClassName !== strundefined && !xml ) {
						return context.getElementsByClassName( className );
					}
				}
			},

			relative: {
				">": { dir: "parentNode", first: true },
				" ": { dir: "parentNode" },
				"+": { dir: "previousSibling", first: true },
				"~": { dir: "previousSibling" }
			},

			preFilter: {
				"ATTR": function( match ) {
					match[1] = match[1].replace( rbackslash, "" );

					// Move the given value to match[3] whether quoted or unquoted
					match[3] = ( match[4] || match[5] || "" ).replace( rbackslash, "" );

					if ( match[2] === "~=" ) {
						match[3] = " " + match[3] + " ";
					}

					return match.slice( 0, 4 );
				},

				"CHILD": function( match ) {
					/* matches from matchExpr["CHILD"]
					 1 type (only|nth|...)
					 2 argument (even|odd|\d*|\d*n([+-]\d+)?|...)
					 3 xn-component of xn+y argument ([+-]?\d*n|)
					 4 sign of xn-component
					 5 x of xn-component
					 6 sign of y-component
					 7 y of y-component
					 */
					match[1] = match[1].toLowerCase();

					if ( match[1] === "nth" ) {
						// nth-child requires argument
						if ( !match[2] ) {
							Sizzle.error( match[0] );
						}

						// numeric x and y parameters for Expr.filter.CHILD
						// remember that false/true cast respectively to 0/1
						match[3] = +( match[3] ? match[4] + (match[5] || 1) : 2 * ( match[2] === "even" || match[2] === "odd" ) );
						match[4] = +( ( match[6] + match[7] ) || match[2] === "odd" );

						// other types prohibit arguments
					} else if ( match[2] ) {
						Sizzle.error( match[0] );
					}

					return match;
				},

				"PSEUDO": function( match ) {
					var unquoted, excess;
					if ( matchExpr["CHILD"].test( match[0] ) ) {
						return null;
					}

					if ( match[3] ) {
						match[2] = match[3];
					} else if ( (unquoted = match[4]) ) {
						// Only check arguments that contain a pseudo
						if ( rpseudo.test(unquoted) &&
							// Get excess from tokenize (recursively)
							(excess = tokenize( unquoted, true )) &&
							// advance to the next closing parenthesis
							(excess = unquoted.indexOf( ")", unquoted.length - excess ) - unquoted.length) ) {

							// excess is a negative index
							unquoted = unquoted.slice( 0, excess );
							match[0] = match[0].slice( 0, excess );
						}
						match[2] = unquoted;
					}

					// Return only captures needed by the pseudo filter method (type and argument)
					return match.slice( 0, 3 );
				}
			},

			filter: {
				"ID": assertGetIdNotName ?
					function( id ) {
						id = id.replace( rbackslash, "" );
						return function( elem ) {
							return elem.getAttribute("id") === id;
						};
					} :
					function( id ) {
						id = id.replace( rbackslash, "" );
						return function( elem ) {
							var node = typeof elem.getAttributeNode !== strundefined && elem.getAttributeNode("id");
							return node && node.value === id;
						};
					},

				"TAG": function( nodeName ) {
					if ( nodeName === "*" ) {
						return function() { return true; };
					}
					nodeName = nodeName.replace( rbackslash, "" ).toLowerCase();

					return function( elem ) {
						return elem.nodeName && elem.nodeName.toLowerCase() === nodeName;
					};
				},

				"CLASS": function( className ) {
					var pattern = classCache[ expando ][ className + " " ];

					return pattern ||
						(pattern = new RegExp( "(^|" + whitespace + ")" + className + "(" + whitespace + "|$)" )) &&
							classCache( className, function( elem ) {
								return pattern.test( elem.className || (typeof elem.getAttribute !== strundefined && elem.getAttribute("class")) || "" );
							});
				},

				"ATTR": function( name, operator, check ) {
					return function( elem, context ) {
						var result = Sizzle.attr( elem, name );

						if ( result == null ) {
							return operator === "!=";
						}
						if ( !operator ) {
							return true;
						}

						result += "";

						return operator === "=" ? result === check :
							operator === "!=" ? result !== check :
								operator === "^=" ? check && result.indexOf( check ) === 0 :
									operator === "*=" ? check && result.indexOf( check ) > -1 :
										operator === "$=" ? check && result.substr( result.length - check.length ) === check :
											operator === "~=" ? ( " " + result + " " ).indexOf( check ) > -1 :
												operator === "|=" ? result === check || result.substr( 0, check.length + 1 ) === check + "-" :
													false;
					};
				},

				"CHILD": function( type, argument, first, last ) {

					if ( type === "nth" ) {
						return function( elem ) {
							var node, diff,
								parent = elem.parentNode;

							if ( first === 1 && last === 0 ) {
								return true;
							}

							if ( parent ) {
								diff = 0;
								for ( node = parent.firstChild; node; node = node.nextSibling ) {
									if ( node.nodeType === 1 ) {
										diff++;
										if ( elem === node ) {
											break;
										}
									}
								}
							}

							// Incorporate the offset (or cast to NaN), then check against cycle size
							diff -= last;
							return diff === first || ( diff % first === 0 && diff / first >= 0 );
						};
					}

					return function( elem ) {
						var node = elem;

						switch ( type ) {
							case "only":
							case "first":
								while ( (node = node.previousSibling) ) {
									if ( node.nodeType === 1 ) {
										return false;
									}
								}

								if ( type === "first" ) {
									return true;
								}

								node = elem;

							/* falls through */
							case "last":
								while ( (node = node.nextSibling) ) {
									if ( node.nodeType === 1 ) {
										return false;
									}
								}

								return true;
						}
					};
				},

				"PSEUDO": function( pseudo, argument ) {
					// pseudo-class names are case-insensitive
					// http://www.w3.org/TR/selectors/#pseudo-classes
					// Prioritize by case sensitivity in case custom pseudos are added with uppercase letters
					// Remember that setFilters inherits from pseudos
					var args,
						fn = Expr.pseudos[ pseudo ] || Expr.setFilters[ pseudo.toLowerCase() ] ||
							Sizzle.error( "unsupported pseudo: " + pseudo );

					// The user may use createPseudo to indicate that
					// arguments are needed to create the filter function
					// just as Sizzle does
					if ( fn[ expando ] ) {
						return fn( argument );
					}

					// But maintain support for old signatures
					if ( fn.length > 1 ) {
						args = [ pseudo, pseudo, "", argument ];
						return Expr.setFilters.hasOwnProperty( pseudo.toLowerCase() ) ?
							markFunction(function( seed, matches ) {
								var idx,
									matched = fn( seed, argument ),
									i = matched.length;
								while ( i-- ) {
									idx = indexOf.call( seed, matched[i] );
									seed[ idx ] = !( matches[ idx ] = matched[i] );
								}
							}) :
							function( elem ) {
								return fn( elem, 0, args );
							};
					}

					return fn;
				}
			},

			pseudos: {
				"not": markFunction(function( selector ) {
					// Trim the selector passed to compile
					// to avoid treating leading and trailing
					// spaces as combinators
					var input = [],
						results = [],
						matcher = compile( selector.replace( rtrim, "$1" ) );

					return matcher[ expando ] ?
						markFunction(function( seed, matches, context, xml ) {
							var elem,
								unmatched = matcher( seed, null, xml, [] ),
								i = seed.length;

							// Match elements unmatched by `matcher`
							while ( i-- ) {
								if ( (elem = unmatched[i]) ) {
									seed[i] = !(matches[i] = elem);
								}
							}
						}) :
						function( elem, context, xml ) {
							input[0] = elem;
							matcher( input, null, xml, results );
							return !results.pop();
						};
				}),

				"has": markFunction(function( selector ) {
					return function( elem ) {
						return Sizzle( selector, elem ).length > 0;
					};
				}),

				"contains": markFunction(function( text ) {
					return function( elem ) {
						return ( elem.textContent || elem.innerText || getText( elem ) ).indexOf( text ) > -1;
					};
				}),

				"enabled": function( elem ) {
					return elem.disabled === false;
				},

				"disabled": function( elem ) {
					return elem.disabled === true;
				},

				"checked": function( elem ) {
					// In CSS3, :checked should return both checked and selected elements
					// http://www.w3.org/TR/2011/REC-css3-selectors-20110929/#checked
					var nodeName = elem.nodeName.toLowerCase();
					return (nodeName === "input" && !!elem.checked) || (nodeName === "option" && !!elem.selected);
				},

				"selected": function( elem ) {
					// Accessing this property makes selected-by-default
					// options in Safari work properly
					if ( elem.parentNode ) {
						elem.parentNode.selectedIndex;
					}

					return elem.selected === true;
				},

				"parent": function( elem ) {
					return !Expr.pseudos["empty"]( elem );
				},

				"empty": function( elem ) {
					// http://www.w3.org/TR/selectors/#empty-pseudo
					// :empty is only affected by element nodes and content nodes(including text(3), cdata(4)),
					//   not comment, processing instructions, or others
					// Thanks to Diego Perini for the nodeName shortcut
					//   Greater than "@" means alpha characters (specifically not starting with "#" or "?")
					var nodeType;
					elem = elem.firstChild;
					while ( elem ) {
						if ( elem.nodeName > "@" || (nodeType = elem.nodeType) === 3 || nodeType === 4 ) {
							return false;
						}
						elem = elem.nextSibling;
					}
					return true;
				},

				"header": function( elem ) {
					return rheader.test( elem.nodeName );
				},

				"text": function( elem ) {
					var type, attr;
					// IE6 and 7 will map elem.type to 'text' for new HTML5 types (search, etc)
					// use getAttribute instead to test this case
					return elem.nodeName.toLowerCase() === "input" &&
						(type = elem.type) === "text" &&
						( (attr = elem.getAttribute("type")) == null || attr.toLowerCase() === type );
				},

				// Input types
				"radio": createInputPseudo("radio"),
				"checkbox": createInputPseudo("checkbox"),
				"file": createInputPseudo("file"),
				"password": createInputPseudo("password"),
				"image": createInputPseudo("image"),

				"submit": createButtonPseudo("submit"),
				"reset": createButtonPseudo("reset"),

				"button": function( elem ) {
					var name = elem.nodeName.toLowerCase();
					return name === "input" && elem.type === "button" || name === "button";
				},

				"input": function( elem ) {
					return rinputs.test( elem.nodeName );
				},

				"focus": function( elem ) {
					var doc = elem.ownerDocument;
					return elem === doc.activeElement && (!doc.hasFocus || doc.hasFocus()) && !!(elem.type || elem.href || ~elem.tabIndex);
				},

				"active": function( elem ) {
					return elem === elem.ownerDocument.activeElement;
				},

				// Positional types
				"first": createPositionalPseudo(function() {
					return [ 0 ];
				}),

				"last": createPositionalPseudo(function( matchIndexes, length ) {
					return [ length - 1 ];
				}),

				"eq": createPositionalPseudo(function( matchIndexes, length, argument ) {
					return [ argument < 0 ? argument + length : argument ];
				}),

				"even": createPositionalPseudo(function( matchIndexes, length ) {
					for ( var i = 0; i < length; i += 2 ) {
						matchIndexes.push( i );
					}
					return matchIndexes;
				}),

				"odd": createPositionalPseudo(function( matchIndexes, length ) {
					for ( var i = 1; i < length; i += 2 ) {
						matchIndexes.push( i );
					}
					return matchIndexes;
				}),

				"lt": createPositionalPseudo(function( matchIndexes, length, argument ) {
					for ( var i = argument < 0 ? argument + length : argument; --i >= 0; ) {
						matchIndexes.push( i );
					}
					return matchIndexes;
				}),

				"gt": createPositionalPseudo(function( matchIndexes, length, argument ) {
					for ( var i = argument < 0 ? argument + length : argument; ++i < length; ) {
						matchIndexes.push( i );
					}
					return matchIndexes;
				})
			}
		};

		function siblingCheck( a, b, ret ) {
			if ( a === b ) {
				return ret;
			}

			var cur = a.nextSibling;

			while ( cur ) {
				if ( cur === b ) {
					return -1;
				}

				cur = cur.nextSibling;
			}

			return 1;
		}

		sortOrder = docElem.compareDocumentPosition ?
			function( a, b ) {
				if ( a === b ) {
					hasDuplicate = true;
					return 0;
				}

				return ( !a.compareDocumentPosition || !b.compareDocumentPosition ?
					a.compareDocumentPosition :
					a.compareDocumentPosition(b) & 4
					) ? -1 : 1;
			} :
			function( a, b ) {
				// The nodes are identical, we can exit early
				if ( a === b ) {
					hasDuplicate = true;
					return 0;

					// Fallback to using sourceIndex (in IE) if it's available on both nodes
				} else if ( a.sourceIndex && b.sourceIndex ) {
					return a.sourceIndex - b.sourceIndex;
				}

				var al, bl,
					ap = [],
					bp = [],
					aup = a.parentNode,
					bup = b.parentNode,
					cur = aup;

				// If the nodes are siblings (or identical) we can do a quick check
				if ( aup === bup ) {
					return siblingCheck( a, b );

					// If no parents were found then the nodes are disconnected
				} else if ( !aup ) {
					return -1;

				} else if ( !bup ) {
					return 1;
				}

				// Otherwise they're somewhere else in the tree so we need
				// to build up a full list of the parentNodes for comparison
				while ( cur ) {
					ap.unshift( cur );
					cur = cur.parentNode;
				}

				cur = bup;

				while ( cur ) {
					bp.unshift( cur );
					cur = cur.parentNode;
				}

				al = ap.length;
				bl = bp.length;

				// Start walking down the tree looking for a discrepancy
				for ( var i = 0; i < al && i < bl; i++ ) {
					if ( ap[i] !== bp[i] ) {
						return siblingCheck( ap[i], bp[i] );
					}
				}

				// We ended someplace up the tree so do a sibling check
				return i === al ?
					siblingCheck( a, bp[i], -1 ) :
					siblingCheck( ap[i], b, 1 );
			};

// Always assume the presence of duplicates if sort doesn't
// pass them to our comparison function (as in Google Chrome).
		[0, 0].sort( sortOrder );
		baseHasDuplicate = !hasDuplicate;

// Document sorting and removing duplicates
		Sizzle.uniqueSort = function( results ) {
			var elem,
				duplicates = [],
				i = 1,
				j = 0;

			hasDuplicate = baseHasDuplicate;
			results.sort( sortOrder );

			if ( hasDuplicate ) {
				for ( ; (elem = results[i]); i++ ) {
					if ( elem === results[ i - 1 ] ) {
						j = duplicates.push( i );
					}
				}
				while ( j-- ) {
					results.splice( duplicates[ j ], 1 );
				}
			}

			return results;
		};

		Sizzle.error = function( msg ) {
			throw new Error( "Syntax error, unrecognized expression: " + msg );
		};

		function tokenize( selector, parseOnly ) {
			var matched, match, tokens, type,
				soFar, groups, preFilters,
				cached = tokenCache[ expando ][ selector + " " ];

			if ( cached ) {
				return parseOnly ? 0 : cached.slice( 0 );
			}

			soFar = selector;
			groups = [];
			preFilters = Expr.preFilter;

			while ( soFar ) {

				// Comma and first run
				if ( !matched || (match = rcomma.exec( soFar )) ) {
					if ( match ) {
						// Don't consume trailing commas as valid
						soFar = soFar.slice( match[0].length ) || soFar;
					}
					groups.push( tokens = [] );
				}

				matched = false;

				// Combinators
				if ( (match = rcombinators.exec( soFar )) ) {
					tokens.push( matched = new Token( match.shift() ) );
					soFar = soFar.slice( matched.length );

					// Cast descendant combinators to space
					matched.type = match[0].replace( rtrim, " " );
				}

				// Filters
				for ( type in Expr.filter ) {
					if ( (match = matchExpr[ type ].exec( soFar )) && (!preFilters[ type ] ||
						(match = preFilters[ type ]( match ))) ) {

						tokens.push( matched = new Token( match.shift() ) );
						soFar = soFar.slice( matched.length );
						matched.type = type;
						matched.matches = match;
					}
				}

				if ( !matched ) {
					break;
				}
			}

			// Return the length of the invalid excess
			// if we're just parsing
			// Otherwise, throw an error or return tokens
			return parseOnly ?
				soFar.length :
				soFar ?
					Sizzle.error( selector ) :
					// Cache the tokens
					tokenCache( selector, groups ).slice( 0 );
		}

		function addCombinator( matcher, combinator, base ) {
			var dir = combinator.dir,
				checkNonElements = base && combinator.dir === "parentNode",
				doneName = done++;

			return combinator.first ?
				// Check against closest ancestor/preceding element
				function( elem, context, xml ) {
					while ( (elem = elem[ dir ]) ) {
						if ( checkNonElements || elem.nodeType === 1  ) {
							return matcher( elem, context, xml );
						}
					}
				} :

				// Check against all ancestor/preceding elements
				function( elem, context, xml ) {
					// We can't set arbitrary data on XML nodes, so they don't benefit from dir caching
					if ( !xml ) {
						var cache,
							dirkey = dirruns + " " + doneName + " ",
							cachedkey = dirkey + cachedruns;
						while ( (elem = elem[ dir ]) ) {
							if ( checkNonElements || elem.nodeType === 1 ) {
								if ( (cache = elem[ expando ]) === cachedkey ) {
									return elem.sizset;
								} else if ( typeof cache === "string" && cache.indexOf(dirkey) === 0 ) {
									if ( elem.sizset ) {
										return elem;
									}
								} else {
									elem[ expando ] = cachedkey;
									if ( matcher( elem, context, xml ) ) {
										elem.sizset = true;
										return elem;
									}
									elem.sizset = false;
								}
							}
						}
					} else {
						while ( (elem = elem[ dir ]) ) {
							if ( checkNonElements || elem.nodeType === 1 ) {
								if ( matcher( elem, context, xml ) ) {
									return elem;
								}
							}
						}
					}
				};
		}

		function elementMatcher( matchers ) {
			return matchers.length > 1 ?
				function( elem, context, xml ) {
					var i = matchers.length;
					while ( i-- ) {
						if ( !matchers[i]( elem, context, xml ) ) {
							return false;
						}
					}
					return true;
				} :
				matchers[0];
		}

		function condense( unmatched, map, filter, context, xml ) {
			var elem,
				newUnmatched = [],
				i = 0,
				len = unmatched.length,
				mapped = map != null;

			for ( ; i < len; i++ ) {
				if ( (elem = unmatched[i]) ) {
					if ( !filter || filter( elem, context, xml ) ) {
						newUnmatched.push( elem );
						if ( mapped ) {
							map.push( i );
						}
					}
				}
			}

			return newUnmatched;
		}

		function setMatcher( preFilter, selector, matcher, postFilter, postFinder, postSelector ) {
			if ( postFilter && !postFilter[ expando ] ) {
				postFilter = setMatcher( postFilter );
			}
			if ( postFinder && !postFinder[ expando ] ) {
				postFinder = setMatcher( postFinder, postSelector );
			}
			return markFunction(function( seed, results, context, xml ) {
				var temp, i, elem,
					preMap = [],
					postMap = [],
					preexisting = results.length,

				// Get initial elements from seed or context
					elems = seed || multipleContexts( selector || "*", context.nodeType ? [ context ] : context, [] ),

				// Prefilter to get matcher input, preserving a map for seed-results synchronization
					matcherIn = preFilter && ( seed || !selector ) ?
						condense( elems, preMap, preFilter, context, xml ) :
						elems,

					matcherOut = matcher ?
						// If we have a postFinder, or filtered seed, or non-seed postFilter or preexisting results,
						postFinder || ( seed ? preFilter : preexisting || postFilter ) ?

							// ...intermediate processing is necessary
							[] :

							// ...otherwise use results directly
							results :
						matcherIn;

				// Find primary matches
				if ( matcher ) {
					matcher( matcherIn, matcherOut, context, xml );
				}

				// Apply postFilter
				if ( postFilter ) {
					temp = condense( matcherOut, postMap );
					postFilter( temp, [], context, xml );

					// Un-match failing elements by moving them back to matcherIn
					i = temp.length;
					while ( i-- ) {
						if ( (elem = temp[i]) ) {
							matcherOut[ postMap[i] ] = !(matcherIn[ postMap[i] ] = elem);
						}
					}
				}

				if ( seed ) {
					if ( postFinder || preFilter ) {
						if ( postFinder ) {
							// Get the final matcherOut by condensing this intermediate into postFinder contexts
							temp = [];
							i = matcherOut.length;
							while ( i-- ) {
								if ( (elem = matcherOut[i]) ) {
									// Restore matcherIn since elem is not yet a final match
									temp.push( (matcherIn[i] = elem) );
								}
							}
							postFinder( null, (matcherOut = []), temp, xml );
						}

						// Move matched elements from seed to results to keep them synchronized
						i = matcherOut.length;
						while ( i-- ) {
							if ( (elem = matcherOut[i]) &&
								(temp = postFinder ? indexOf.call( seed, elem ) : preMap[i]) > -1 ) {

								seed[temp] = !(results[temp] = elem);
							}
						}
					}

					// Add elements to results, through postFinder if defined
				} else {
					matcherOut = condense(
						matcherOut === results ?
							matcherOut.splice( preexisting, matcherOut.length ) :
							matcherOut
					);
					if ( postFinder ) {
						postFinder( null, results, matcherOut, xml );
					} else {
						push.apply( results, matcherOut );
					}
				}
			});
		}

		function matcherFromTokens( tokens ) {
			var checkContext, matcher, j,
				len = tokens.length,
				leadingRelative = Expr.relative[ tokens[0].type ],
				implicitRelative = leadingRelative || Expr.relative[" "],
				i = leadingRelative ? 1 : 0,

			// The foundational matcher ensures that elements are reachable from top-level context(s)
				matchContext = addCombinator( function( elem ) {
					return elem === checkContext;
				}, implicitRelative, true ),
				matchAnyContext = addCombinator( function( elem ) {
					return indexOf.call( checkContext, elem ) > -1;
				}, implicitRelative, true ),
				matchers = [ function( elem, context, xml ) {
					return ( !leadingRelative && ( xml || context !== outermostContext ) ) || (
						(checkContext = context).nodeType ?
							matchContext( elem, context, xml ) :
							matchAnyContext( elem, context, xml ) );
				} ];

			for ( ; i < len; i++ ) {
				if ( (matcher = Expr.relative[ tokens[i].type ]) ) {
					matchers = [ addCombinator( elementMatcher( matchers ), matcher ) ];
				} else {
					matcher = Expr.filter[ tokens[i].type ].apply( null, tokens[i].matches );

					// Return special upon seeing a positional matcher
					if ( matcher[ expando ] ) {
						// Find the next relative operator (if any) for proper handling
						j = ++i;
						for ( ; j < len; j++ ) {
							if ( Expr.relative[ tokens[j].type ] ) {
								break;
							}
						}
						return setMatcher(
							i > 1 && elementMatcher( matchers ),
							i > 1 && tokens.slice( 0, i - 1 ).join("").replace( rtrim, "$1" ),
							matcher,
							i < j && matcherFromTokens( tokens.slice( i, j ) ),
							j < len && matcherFromTokens( (tokens = tokens.slice( j )) ),
							j < len && tokens.join("")
						);
					}
					matchers.push( matcher );
				}
			}

			return elementMatcher( matchers );
		}

		function matcherFromGroupMatchers( elementMatchers, setMatchers ) {
			var bySet = setMatchers.length > 0,
				byElement = elementMatchers.length > 0,
				superMatcher = function( seed, context, xml, results, expandContext ) {
					var elem, j, matcher,
						setMatched = [],
						matchedCount = 0,
						i = "0",
						unmatched = seed && [],
						outermost = expandContext != null,
						contextBackup = outermostContext,
					// We must always have either seed elements or context
						elems = seed || byElement && Expr.find["TAG"]( "*", expandContext && context.parentNode || context ),
					// Nested matchers should use non-integer dirruns
						dirrunsUnique = (dirruns += contextBackup == null ? 1 : Math.E);

					if ( outermost ) {
						outermostContext = context !== document && context;
						cachedruns = superMatcher.el;
					}

					// Add elements passing elementMatchers directly to results
					for ( ; (elem = elems[i]) != null; i++ ) {
						if ( byElement && elem ) {
							for ( j = 0; (matcher = elementMatchers[j]); j++ ) {
								if ( matcher( elem, context, xml ) ) {
									results.push( elem );
									break;
								}
							}
							if ( outermost ) {
								dirruns = dirrunsUnique;
								cachedruns = ++superMatcher.el;
							}
						}

						// Track unmatched elements for set filters
						if ( bySet ) {
							// They will have gone through all possible matchers
							if ( (elem = !matcher && elem) ) {
								matchedCount--;
							}

							// Lengthen the array for every element, matched or not
							if ( seed ) {
								unmatched.push( elem );
							}
						}
					}

					// Apply set filters to unmatched elements
					matchedCount += i;
					if ( bySet && i !== matchedCount ) {
						for ( j = 0; (matcher = setMatchers[j]); j++ ) {
							matcher( unmatched, setMatched, context, xml );
						}

						if ( seed ) {
							// Reintegrate element matches to eliminate the need for sorting
							if ( matchedCount > 0 ) {
								while ( i-- ) {
									if ( !(unmatched[i] || setMatched[i]) ) {
										setMatched[i] = pop.call( results );
									}
								}
							}

							// Discard index placeholder values to get only actual matches
							setMatched = condense( setMatched );
						}

						// Add matches to results
						push.apply( results, setMatched );

						// Seedless set matches succeeding multiple successful matchers stipulate sorting
						if ( outermost && !seed && setMatched.length > 0 &&
							( matchedCount + setMatchers.length ) > 1 ) {

							Sizzle.uniqueSort( results );
						}
					}

					// Override manipulation of globals by nested matchers
					if ( outermost ) {
						dirruns = dirrunsUnique;
						outermostContext = contextBackup;
					}

					return unmatched;
				};

			superMatcher.el = 0;
			return bySet ?
				markFunction( superMatcher ) :
				superMatcher;
		}

		compile = Sizzle.compile = function( selector, group /* Internal Use Only */ ) {
			var i,
				setMatchers = [],
				elementMatchers = [],
				cached = compilerCache[ expando ][ selector + " " ];

			if ( !cached ) {
				// Generate a function of recursive functions that can be used to check each element
				if ( !group ) {
					group = tokenize( selector );
				}
				i = group.length;
				while ( i-- ) {
					cached = matcherFromTokens( group[i] );
					if ( cached[ expando ] ) {
						setMatchers.push( cached );
					} else {
						elementMatchers.push( cached );
					}
				}

				// Cache the compiled function
				cached = compilerCache( selector, matcherFromGroupMatchers( elementMatchers, setMatchers ) );
			}
			return cached;
		};

		function multipleContexts( selector, contexts, results ) {
			var i = 0,
				len = contexts.length;
			for ( ; i < len; i++ ) {
				Sizzle( selector, contexts[i], results );
			}
			return results;
		}

		function select( selector, context, results, seed, xml ) {
			var i, tokens, token, type, find,
				match = tokenize( selector ),
				j = match.length;

			if ( !seed ) {
				// Try to minimize operations if there is only one group
				if ( match.length === 1 ) {

					// Take a shortcut and set the context if the root selector is an ID
					tokens = match[0] = match[0].slice( 0 );
					if ( tokens.length > 2 && (token = tokens[0]).type === "ID" &&
						context.nodeType === 9 && !xml &&
						Expr.relative[ tokens[1].type ] ) {

						context = Expr.find["ID"]( token.matches[0].replace( rbackslash, "" ), context, xml )[0];
						if ( !context ) {
							return results;
						}

						selector = selector.slice( tokens.shift().length );
					}

					// Fetch a seed set for right-to-left matching
					for ( i = matchExpr["POS"].test( selector ) ? -1 : tokens.length - 1; i >= 0; i-- ) {
						token = tokens[i];

						// Abort if we hit a combinator
						if ( Expr.relative[ (type = token.type) ] ) {
							break;
						}
						if ( (find = Expr.find[ type ]) ) {
							// Search, expanding context for leading sibling combinators
							if ( (seed = find(
								token.matches[0].replace( rbackslash, "" ),
								rsibling.test( tokens[0].type ) && context.parentNode || context,
								xml
							)) ) {

								// If seed is empty or no tokens remain, we can return early
								tokens.splice( i, 1 );
								selector = seed.length && tokens.join("");
								if ( !selector ) {
									push.apply( results, slice.call( seed, 0 ) );
									return results;
								}

								break;
							}
						}
					}
				}
			}

			// Compile and execute a filtering function
			// Provide `match` to avoid retokenization if we modified the selector above
			compile( selector, match )(
				seed,
				context,
				xml,
				results,
				rsibling.test( selector )
			);
			return results;
		}

		if ( document.querySelectorAll ) {
			(function() {
				var disconnectedMatch,
					oldSelect = select,
					rescape = /'|\\/g,
					rattributeQuotes = /\=[\x20\t\r\n\f]*([^'"\]]*)[\x20\t\r\n\f]*\]/g,

				// qSa(:focus) reports false when true (Chrome 21), no need to also add to buggyMatches since matches checks buggyQSA
				// A support test would require too much code (would include document ready)
					rbuggyQSA = [ ":focus" ],

				// matchesSelector(:active) reports false when true (IE9/Opera 11.5)
				// A support test would require too much code (would include document ready)
				// just skip matchesSelector for :active
					rbuggyMatches = [ ":active" ],
					matches = docElem.matchesSelector ||
						docElem.mozMatchesSelector ||
						docElem.webkitMatchesSelector ||
						docElem.oMatchesSelector ||
						docElem.msMatchesSelector;

				// Build QSA regex
				// Regex strategy adopted from Diego Perini
				assert(function( div ) {
					// Select is set to empty string on purpose
					// This is to test IE's treatment of not explictly
					// setting a boolean content attribute,
					// since its presence should be enough
					// http://bugs.jquery.com/ticket/12359
					div.innerHTML = "<select><option selected=''></option></select>";

					// IE8 - Some boolean attributes are not treated correctly
					if ( !div.querySelectorAll("[selected]").length ) {
						rbuggyQSA.push( "\\[" + whitespace + "*(?:checked|disabled|ismap|multiple|readonly|selected|value)" );
					}

					// Webkit/Opera - :checked should return selected option elements
					// http://www.w3.org/TR/2011/REC-css3-selectors-20110929/#checked
					// IE8 throws error here (do not put tests after this one)
					if ( !div.querySelectorAll(":checked").length ) {
						rbuggyQSA.push(":checked");
					}
				});

				assert(function( div ) {

					// Opera 10-12/IE9 - ^= $= *= and empty values
					// Should not select anything
					div.innerHTML = "<p test=''></p>";
					if ( div.querySelectorAll("[test^='']").length ) {
						rbuggyQSA.push( "[*^$]=" + whitespace + "*(?:\"\"|'')" );
					}

					// FF 3.5 - :enabled/:disabled and hidden elements (hidden elements are still enabled)
					// IE8 throws error here (do not put tests after this one)
					div.innerHTML = "<input type='hidden'/>";
					if ( !div.querySelectorAll(":enabled").length ) {
						rbuggyQSA.push(":enabled", ":disabled");
					}
				});

				// rbuggyQSA always contains :focus, so no need for a length check
				rbuggyQSA = /* rbuggyQSA.length && */ new RegExp( rbuggyQSA.join("|") );

				select = function( selector, context, results, seed, xml ) {
					// Only use querySelectorAll when not filtering,
					// when this is not xml,
					// and when no QSA bugs apply
					if ( !seed && !xml && !rbuggyQSA.test( selector ) ) {
						var groups, i,
							old = true,
							nid = expando,
							newContext = context,
							newSelector = context.nodeType === 9 && selector;

						// qSA works strangely on Element-rooted queries
						// We can work around this by specifying an extra ID on the root
						// and working up from there (Thanks to Andrew Dupont for the technique)
						// IE 8 doesn't work on object elements
						if ( context.nodeType === 1 && context.nodeName.toLowerCase() !== "object" ) {
							groups = tokenize( selector );

							if ( (old = context.getAttribute("id")) ) {
								nid = old.replace( rescape, "\\$&" );
							} else {
								context.setAttribute( "id", nid );
							}
							nid = "[id='" + nid + "'] ";

							i = groups.length;
							while ( i-- ) {
								groups[i] = nid + groups[i].join("");
							}
							newContext = rsibling.test( selector ) && context.parentNode || context;
							newSelector = groups.join(",");
						}

						if ( newSelector ) {
							try {
								push.apply( results, slice.call( newContext.querySelectorAll(
									newSelector
								), 0 ) );
								return results;
							} catch(qsaError) {
							} finally {
								if ( !old ) {
									context.removeAttribute("id");
								}
							}
						}
					}

					return oldSelect( selector, context, results, seed, xml );
				};

				if ( matches ) {
					assert(function( div ) {
						// Check to see if it's possible to do matchesSelector
						// on a disconnected node (IE 9)
						disconnectedMatch = matches.call( div, "div" );

						// This should fail with an exception
						// Gecko does not error, returns false instead
						try {
							matches.call( div, "[test!='']:sizzle" );
							rbuggyMatches.push( "!=", pseudos );
						} catch ( e ) {}
					});

					// rbuggyMatches always contains :active and :focus, so no need for a length check
					rbuggyMatches = /* rbuggyMatches.length && */ new RegExp( rbuggyMatches.join("|") );

					Sizzle.matchesSelector = function( elem, expr ) {
						// Make sure that attribute selectors are quoted
						expr = expr.replace( rattributeQuotes, "='$1']" );

						// rbuggyMatches always contains :active, so no need for an existence check
						if ( !isXML( elem ) && !rbuggyMatches.test( expr ) && !rbuggyQSA.test( expr ) ) {
							try {
								var ret = matches.call( elem, expr );

								// IE 9's matchesSelector returns false on disconnected nodes
								if ( ret || disconnectedMatch ||
									// As well, disconnected nodes are said to be in a document
									// fragment in IE 9
									elem.document && elem.document.nodeType !== 11 ) {
									return ret;
								}
							} catch(e) {}
						}

						return Sizzle( expr, null, null, [ elem ] ).length > 0;
					};
				}
			})();
		}

// Deprecated
		Expr.pseudos["nth"] = Expr.pseudos["eq"];

// Back-compat
		function setFilters() {}
		Expr.filters = setFilters.prototype = Expr.pseudos;
		Expr.setFilters = new setFilters();

// Override sizzle attribute retrieval
		Sizzle.attr = jQuery.attr;
		jQuery.find = Sizzle;
		jQuery.expr = Sizzle.selectors;
		jQuery.expr[":"] = jQuery.expr.pseudos;
		jQuery.unique = Sizzle.uniqueSort;
		jQuery.text = Sizzle.getText;
		jQuery.isXMLDoc = Sizzle.isXML;
		jQuery.contains = Sizzle.contains;


	})( window );
	var runtil = /Until$/,
		rparentsprev = /^(?:parents|prev(?:Until|All))/,
		isSimple = /^.[^:#\[\.,]*$/,
		rneedsContext = jQuery.expr.match.needsContext,
	// methods guaranteed to produce a unique set when starting from a unique set
		guaranteedUnique = {
			children: true,
			contents: true,
			next: true,
			prev: true
		};

	jQuery.fn.extend({
		find: function( selector ) {
			var i, l, length, n, r, ret,
				self = this;

			if ( typeof selector !== "string" ) {
				return jQuery( selector ).filter(function() {
					for ( i = 0, l = self.length; i < l; i++ ) {
						if ( jQuery.contains( self[ i ], this ) ) {
							return true;
						}
					}
				});
			}

			ret = this.pushStack( "", "find", selector );

			for ( i = 0, l = this.length; i < l; i++ ) {
				length = ret.length;
				jQuery.find( selector, this[i], ret );

				if ( i > 0 ) {
					// Make sure that the results are unique
					for ( n = length; n < ret.length; n++ ) {
						for ( r = 0; r < length; r++ ) {
							if ( ret[r] === ret[n] ) {
								ret.splice(n--, 1);
								break;
							}
						}
					}
				}
			}

			return ret;
		},

		has: function( target ) {
			var i,
				targets = jQuery( target, this ),
				len = targets.length;

			return this.filter(function() {
				for ( i = 0; i < len; i++ ) {
					if ( jQuery.contains( this, targets[i] ) ) {
						return true;
					}
				}
			});
		},

		not: function( selector ) {
			return this.pushStack( winnow(this, selector, false), "not", selector);
		},

		filter: function( selector ) {
			return this.pushStack( winnow(this, selector, true), "filter", selector );
		},

		is: function( selector ) {
			return !!selector && (
				typeof selector === "string" ?
					// If this is a positional/relative selector, check membership in the returned set
					// so $("p:first").is("p:last") won't return true for a doc with two "p".
					rneedsContext.test( selector ) ?
						jQuery( selector, this.context ).index( this[0] ) >= 0 :
						jQuery.filter( selector, this ).length > 0 :
					this.filter( selector ).length > 0 );
		},

		closest: function( selectors, context ) {
			var cur,
				i = 0,
				l = this.length,
				ret = [],
				pos = rneedsContext.test( selectors ) || typeof selectors !== "string" ?
					jQuery( selectors, context || this.context ) :
					0;

			for ( ; i < l; i++ ) {
				cur = this[i];

				while ( cur && cur.ownerDocument && cur !== context && cur.nodeType !== 11 ) {
					if ( pos ? pos.index(cur) > -1 : jQuery.find.matchesSelector(cur, selectors) ) {
						ret.push( cur );
						break;
					}
					cur = cur.parentNode;
				}
			}

			ret = ret.length > 1 ? jQuery.unique( ret ) : ret;

			return this.pushStack( ret, "closest", selectors );
		},

		// Determine the position of an element within
		// the matched set of elements
		index: function( elem ) {

			// No argument, return index in parent
			if ( !elem ) {
				return ( this[0] && this[0].parentNode ) ? this.prevAll().length : -1;
			}

			// index in selector
			if ( typeof elem === "string" ) {
				return jQuery.inArray( this[0], jQuery( elem ) );
			}

			// Locate the position of the desired element
			return jQuery.inArray(
				// If it receives a jQuery object, the first element is used
				elem.jquery ? elem[0] : elem, this );
		},

		add: function( selector, context ) {
			var set = typeof selector === "string" ?
					jQuery( selector, context ) :
					jQuery.makeArray( selector && selector.nodeType ? [ selector ] : selector ),
				all = jQuery.merge( this.get(), set );

			return this.pushStack( isDisconnected( set[0] ) || isDisconnected( all[0] ) ?
				all :
				jQuery.unique( all ) );
		},

		addBack: function( selector ) {
			return this.add( selector == null ?
				this.prevObject : this.prevObject.filter(selector)
			);
		}
	});

	jQuery.fn.andSelf = jQuery.fn.addBack;

// A painfully simple check to see if an element is disconnected
// from a document (should be improved, where feasible).
	function isDisconnected( node ) {
		return !node || !node.parentNode || node.parentNode.nodeType === 11;
	}

	function sibling( cur, dir ) {
		do {
			cur = cur[ dir ];
		} while ( cur && cur.nodeType !== 1 );

		return cur;
	}

	jQuery.each({
		parent: function( elem ) {
			var parent = elem.parentNode;
			return parent && parent.nodeType !== 11 ? parent : null;
		},
		parents: function( elem ) {
			return jQuery.dir( elem, "parentNode" );
		},
		parentsUntil: function( elem, i, until ) {
			return jQuery.dir( elem, "parentNode", until );
		},
		next: function( elem ) {
			return sibling( elem, "nextSibling" );
		},
		prev: function( elem ) {
			return sibling( elem, "previousSibling" );
		},
		nextAll: function( elem ) {
			return jQuery.dir( elem, "nextSibling" );
		},
		prevAll: function( elem ) {
			return jQuery.dir( elem, "previousSibling" );
		},
		nextUntil: function( elem, i, until ) {
			return jQuery.dir( elem, "nextSibling", until );
		},
		prevUntil: function( elem, i, until ) {
			return jQuery.dir( elem, "previousSibling", until );
		},
		siblings: function( elem ) {
			return jQuery.sibling( ( elem.parentNode || {} ).firstChild, elem );
		},
		children: function( elem ) {
			return jQuery.sibling( elem.firstChild );
		},
		contents: function( elem ) {
			return jQuery.nodeName( elem, "iframe" ) ?
				elem.contentDocument || elem.contentWindow.document :
				jQuery.merge( [], elem.childNodes );
		}
	}, function( name, fn ) {
		jQuery.fn[ name ] = function( until, selector ) {
			var ret = jQuery.map( this, fn, until );

			if ( !runtil.test( name ) ) {
				selector = until;
			}

			if ( selector && typeof selector === "string" ) {
				ret = jQuery.filter( selector, ret );
			}

			ret = this.length > 1 && !guaranteedUnique[ name ] ? jQuery.unique( ret ) : ret;

			if ( this.length > 1 && rparentsprev.test( name ) ) {
				ret = ret.reverse();
			}

			return this.pushStack( ret, name, core_slice.call( arguments ).join(",") );
		};
	});

	jQuery.extend({
		filter: function( expr, elems, not ) {
			if ( not ) {
				expr = ":not(" + expr + ")";
			}

			return elems.length === 1 ?
				jQuery.find.matchesSelector(elems[0], expr) ? [ elems[0] ] : [] :
				jQuery.find.matches(expr, elems);
		},

		dir: function( elem, dir, until ) {
			var matched = [],
				cur = elem[ dir ];

			while ( cur && cur.nodeType !== 9 && (until === undefined || cur.nodeType !== 1 || !jQuery( cur ).is( until )) ) {
				if ( cur.nodeType === 1 ) {
					matched.push( cur );
				}
				cur = cur[dir];
			}
			return matched;
		},

		sibling: function( n, elem ) {
			var r = [];

			for ( ; n; n = n.nextSibling ) {
				if ( n.nodeType === 1 && n !== elem ) {
					r.push( n );
				}
			}

			return r;
		}
	});

// Implement the identical functionality for filter and not
	function winnow( elements, qualifier, keep ) {

		// Can't pass null or undefined to indexOf in Firefox 4
		// Set to 0 to skip string check
		qualifier = qualifier || 0;

		if ( jQuery.isFunction( qualifier ) ) {
			return jQuery.grep(elements, function( elem, i ) {
				var retVal = !!qualifier.call( elem, i, elem );
				return retVal === keep;
			});

		} else if ( qualifier.nodeType ) {
			return jQuery.grep(elements, function( elem, i ) {
				return ( elem === qualifier ) === keep;
			});

		} else if ( typeof qualifier === "string" ) {
			var filtered = jQuery.grep(elements, function( elem ) {
				return elem.nodeType === 1;
			});

			if ( isSimple.test( qualifier ) ) {
				return jQuery.filter(qualifier, filtered, !keep);
			} else {
				qualifier = jQuery.filter( qualifier, filtered );
			}
		}

		return jQuery.grep(elements, function( elem, i ) {
			return ( jQuery.inArray( elem, qualifier ) >= 0 ) === keep;
		});
	}
	function createSafeFragment( document ) {
		var list = nodeNames.split( "|" ),
			safeFrag = document.createDocumentFragment();

		if ( safeFrag.createElement ) {
			while ( list.length ) {
				safeFrag.createElement(
					list.pop()
				);
			}
		}
		return safeFrag;
	}

	var nodeNames = "abbr|article|aside|audio|bdi|canvas|data|datalist|details|figcaption|figure|footer|" +
			"header|hgroup|mark|meter|nav|output|progress|section|summary|time|video",
		rinlinejQuery = / jQuery\d+="(?:null|\d+)"/g,
		rleadingWhitespace = /^\s+/,
		rxhtmlTag = /<(?!area|br|col|embed|hr|img|input|link|meta|param)(([\w:]+)[^>]*)\/>/gi,
		rtagName = /<([\w:]+)/,
		rtbody = /<tbody/i,
		rhtml = /<|&#?\w+;/,
		rnoInnerhtml = /<(?:script|style|link)/i,
		rnocache = /<(?:script|object|embed|option|style)/i,
		rnoshimcache = new RegExp("<(?:" + nodeNames + ")[\\s/>]", "i"),
		rcheckableType = /^(?:checkbox|radio)$/,
	// checked="checked" or checked
		rchecked = /checked\s*(?:[^=]|=\s*.checked.)/i,
		rscriptType = /\/(java|ecma)script/i,
		rcleanScript = /^\s*<!(?:\[CDATA\[|\-\-)|[\]\-]{2}>\s*$/g,
		wrapMap = {
			option: [ 1, "<select multiple='multiple'>", "</select>" ],
			legend: [ 1, "<fieldset>", "</fieldset>" ],
			thead: [ 1, "<table>", "</table>" ],
			tr: [ 2, "<table><tbody>", "</tbody></table>" ],
			td: [ 3, "<table><tbody><tr>", "</tr></tbody></table>" ],
			col: [ 2, "<table><tbody></tbody><colgroup>", "</colgroup></table>" ],
			area: [ 1, "<map>", "</map>" ],
			_default: [ 0, "", "" ]
		},
		safeFragment = createSafeFragment( document ),
		fragmentDiv = safeFragment.appendChild( document.createElement("div") );

	wrapMap.optgroup = wrapMap.option;
	wrapMap.tbody = wrapMap.tfoot = wrapMap.colgroup = wrapMap.caption = wrapMap.thead;
	wrapMap.th = wrapMap.td;

// IE6-8 can't serialize link, script, style, or any html5 (NoScope) tags,
// unless wrapped in a div with non-breaking characters in front of it.
	if ( !jQuery.support.htmlSerialize ) {
		wrapMap._default = [ 1, "X<div>", "</div>" ];
	}

	jQuery.fn.extend({
		text: function( value ) {
			return jQuery.access( this, function( value ) {
				return value === undefined ?
					jQuery.text( this ) :
					this.empty().append( ( this[0] && this[0].ownerDocument || document ).createTextNode( value ) );
			}, null, value, arguments.length );
		},

		wrapAll: function( html ) {
			if ( jQuery.isFunction( html ) ) {
				return this.each(function(i) {
					jQuery(this).wrapAll( html.call(this, i) );
				});
			}

			if ( this[0] ) {
				// The elements to wrap the target around
				var wrap = jQuery( html, this[0].ownerDocument ).eq(0).clone(true);

				if ( this[0].parentNode ) {
					wrap.insertBefore( this[0] );
				}

				wrap.map(function() {
					var elem = this;

					while ( elem.firstChild && elem.firstChild.nodeType === 1 ) {
						elem = elem.firstChild;
					}

					return elem;
				}).append( this );
			}

			return this;
		},

		wrapInner: function( html ) {
			if ( jQuery.isFunction( html ) ) {
				return this.each(function(i) {
					jQuery(this).wrapInner( html.call(this, i) );
				});
			}

			return this.each(function() {
				var self = jQuery( this ),
					contents = self.contents();

				if ( contents.length ) {
					contents.wrapAll( html );

				} else {
					self.append( html );
				}
			});
		},

		wrap: function( html ) {
			var isFunction = jQuery.isFunction( html );

			return this.each(function(i) {
				jQuery( this ).wrapAll( isFunction ? html.call(this, i) : html );
			});
		},

		unwrap: function() {
			return this.parent().each(function() {
				if ( !jQuery.nodeName( this, "body" ) ) {
					jQuery( this ).replaceWith( this.childNodes );
				}
			}).end();
		},

		append: function() {
			return this.domManip(arguments, true, function( elem ) {
				if ( this.nodeType === 1 || this.nodeType === 11 ) {
					this.appendChild( elem );
				}
			});
		},

		prepend: function() {
			return this.domManip(arguments, true, function( elem ) {
				if ( this.nodeType === 1 || this.nodeType === 11 ) {
					this.insertBefore( elem, this.firstChild );
				}
			});
		},

		before: function() {
			if ( !isDisconnected( this[0] ) ) {
				return this.domManip(arguments, false, function( elem ) {
					this.parentNode.insertBefore( elem, this );
				});
			}

			if ( arguments.length ) {
				var set = jQuery.clean( arguments );
				return this.pushStack( jQuery.merge( set, this ), "before", this.selector );
			}
		},

		after: function() {
			if ( !isDisconnected( this[0] ) ) {
				return this.domManip(arguments, false, function( elem ) {
					this.parentNode.insertBefore( elem, this.nextSibling );
				});
			}

			if ( arguments.length ) {
				var set = jQuery.clean( arguments );
				return this.pushStack( jQuery.merge( this, set ), "after", this.selector );
			}
		},

		// keepData is for internal use only--do not document
		remove: function( selector, keepData ) {
			var elem,
				i = 0;

			for ( ; (elem = this[i]) != null; i++ ) {
				if ( !selector || jQuery.filter( selector, [ elem ] ).length ) {
					if ( !keepData && elem.nodeType === 1 ) {
						jQuery.cleanData( elem.getElementsByTagName("*") );
						jQuery.cleanData( [ elem ] );
					}

					if ( elem.parentNode ) {
						elem.parentNode.removeChild( elem );
					}
				}
			}

			return this;
		},

		empty: function() {
			var elem,
				i = 0;

			for ( ; (elem = this[i]) != null; i++ ) {
				// Remove element nodes and prevent memory leaks
				if ( elem.nodeType === 1 ) {
					jQuery.cleanData( elem.getElementsByTagName("*") );
				}

				// Remove any remaining nodes
				while ( elem.firstChild ) {
					elem.removeChild( elem.firstChild );
				}
			}

			return this;
		},

		clone: function( dataAndEvents, deepDataAndEvents ) {
			dataAndEvents = dataAndEvents == null ? false : dataAndEvents;
			deepDataAndEvents = deepDataAndEvents == null ? dataAndEvents : deepDataAndEvents;

			return this.map( function () {
				return jQuery.clone( this, dataAndEvents, deepDataAndEvents );
			});
		},

		html: function( value ) {
			return jQuery.access( this, function( value ) {
				var elem = this[0] || {},
					i = 0,
					l = this.length;

				if ( value === undefined ) {
					return elem.nodeType === 1 ?
						elem.innerHTML.replace( rinlinejQuery, "" ) :
						undefined;
				}

				// See if we can take a shortcut and just use innerHTML
				if ( typeof value === "string" && !rnoInnerhtml.test( value ) &&
					( jQuery.support.htmlSerialize || !rnoshimcache.test( value )  ) &&
					( jQuery.support.leadingWhitespace || !rleadingWhitespace.test( value ) ) &&
					!wrapMap[ ( rtagName.exec( value ) || ["", ""] )[1].toLowerCase() ] ) {

					value = value.replace( rxhtmlTag, "<$1></$2>" );

					try {
						for (; i < l; i++ ) {
							// Remove element nodes and prevent memory leaks
							elem = this[i] || {};
							if ( elem.nodeType === 1 ) {
								jQuery.cleanData( elem.getElementsByTagName( "*" ) );
								elem.innerHTML = value;
							}
						}

						elem = 0;

						// If using innerHTML throws an exception, use the fallback method
					} catch(e) {}
				}

				if ( elem ) {
					this.empty().append( value );
				}
			}, null, value, arguments.length );
		},

		replaceWith: function( value ) {
			if ( !isDisconnected( this[0] ) ) {
				// Make sure that the elements are removed from the DOM before they are inserted
				// this can help fix replacing a parent with child elements
				if ( jQuery.isFunction( value ) ) {
					return this.each(function(i) {
						var self = jQuery(this), old = self.html();
						self.replaceWith( value.call( this, i, old ) );
					});
				}

				if ( typeof value !== "string" ) {
					value = jQuery( value ).detach();
				}

				return this.each(function() {
					var next = this.nextSibling,
						parent = this.parentNode;

					jQuery( this ).remove();

					if ( next ) {
						jQuery(next).before( value );
					} else {
						jQuery(parent).append( value );
					}
				});
			}

			return this.length ?
				this.pushStack( jQuery(jQuery.isFunction(value) ? value() : value), "replaceWith", value ) :
				this;
		},

		detach: function( selector ) {
			return this.remove( selector, true );
		},

		domManip: function( args, table, callback ) {

			// Flatten any nested arrays
			args = [].concat.apply( [], args );

			var results, first, fragment, iNoClone,
				i = 0,
				value = args[0],
				scripts = [],
				l = this.length;

			// We can't cloneNode fragments that contain checked, in WebKit
			if ( !jQuery.support.checkClone && l > 1 && typeof value === "string" && rchecked.test( value ) ) {
				return this.each(function() {
					jQuery(this).domManip( args, table, callback );
				});
			}

			if ( jQuery.isFunction(value) ) {
				return this.each(function(i) {
					var self = jQuery(this);
					args[0] = value.call( this, i, table ? self.html() : undefined );
					self.domManip( args, table, callback );
				});
			}

			if ( this[0] ) {
				results = jQuery.buildFragment( args, this, scripts );
				fragment = results.fragment;
				first = fragment.firstChild;

				if ( fragment.childNodes.length === 1 ) {
					fragment = first;
				}

				if ( first ) {
					table = table && jQuery.nodeName( first, "tr" );

					// Use the original fragment for the last item instead of the first because it can end up
					// being emptied incorrectly in certain situations (#8070).
					// Fragments from the fragment cache must always be cloned and never used in place.
					for ( iNoClone = results.cacheable || l - 1; i < l; i++ ) {
						callback.call(
							table && jQuery.nodeName( this[i], "table" ) ?
								findOrAppend( this[i], "tbody" ) :
								this[i],
							i === iNoClone ?
								fragment :
								jQuery.clone( fragment, true, true )
						);
					}
				}

				// Fix #11809: Avoid leaking memory
				fragment = first = null;

				if ( scripts.length ) {
					jQuery.each( scripts, function( i, elem ) {
						if ( elem.src ) {
							if ( jQuery.ajax ) {
								jQuery.ajax({
									url: elem.src,
									type: "GET",
									dataType: "script",
									async: false,
									global: false,
									"throws": true
								});
							} else {
								jQuery.error("no ajax");
							}
						} else {
							jQuery.globalEval( ( elem.text || elem.textContent || elem.innerHTML || "" ).replace( rcleanScript, "" ) );
						}

						if ( elem.parentNode ) {
							elem.parentNode.removeChild( elem );
						}
					});
				}
			}

			return this;
		}
	});

	function findOrAppend( elem, tag ) {
		return elem.getElementsByTagName( tag )[0] || elem.appendChild( elem.ownerDocument.createElement( tag ) );
	}

	function cloneCopyEvent( src, dest ) {

		if ( dest.nodeType !== 1 || !jQuery.hasData( src ) ) {
			return;
		}

		var type, i, l,
			oldData = jQuery._data( src ),
			curData = jQuery._data( dest, oldData ),
			events = oldData.events;

		if ( events ) {
			delete curData.handle;
			curData.events = {};

			for ( type in events ) {
				for ( i = 0, l = events[ type ].length; i < l; i++ ) {
					jQuery.event.add( dest, type, events[ type ][ i ] );
				}
			}
		}

		// make the cloned public data object a copy from the original
		if ( curData.data ) {
			curData.data = jQuery.extend( {}, curData.data );
		}
	}

	function cloneFixAttributes( src, dest ) {
		var nodeName;

		// We do not need to do anything for non-Elements
		if ( dest.nodeType !== 1 ) {
			return;
		}

		// clearAttributes removes the attributes, which we don't want,
		// but also removes the attachEvent events, which we *do* want
		if ( dest.clearAttributes ) {
			dest.clearAttributes();
		}

		// mergeAttributes, in contrast, only merges back on the
		// original attributes, not the events
		if ( dest.mergeAttributes ) {
			dest.mergeAttributes( src );
		}

		nodeName = dest.nodeName.toLowerCase();

		if ( nodeName === "object" ) {
			// IE6-10 improperly clones children of object elements using classid.
			// IE10 throws NoModificationAllowedError if parent is null, #12132.
			if ( dest.parentNode ) {
				dest.outerHTML = src.outerHTML;
			}

			// This path appears unavoidable for IE9. When cloning an object
			// element in IE9, the outerHTML strategy above is not sufficient.
			// If the src has innerHTML and the destination does not,
			// copy the src.innerHTML into the dest.innerHTML. #10324
			if ( jQuery.support.html5Clone && (src.innerHTML && !jQuery.trim(dest.innerHTML)) ) {
				dest.innerHTML = src.innerHTML;
			}

		} else if ( nodeName === "input" && rcheckableType.test( src.type ) ) {
			// IE6-8 fails to persist the checked state of a cloned checkbox
			// or radio button. Worse, IE6-7 fail to give the cloned element
			// a checked appearance if the defaultChecked value isn't also set

			dest.defaultChecked = dest.checked = src.checked;

			// IE6-7 get confused and end up setting the value of a cloned
			// checkbox/radio button to an empty string instead of "on"
			if ( dest.value !== src.value ) {
				dest.value = src.value;
			}

			// IE6-8 fails to return the selected option to the default selected
			// state when cloning options
		} else if ( nodeName === "option" ) {
			dest.selected = src.defaultSelected;

			// IE6-8 fails to set the defaultValue to the correct value when
			// cloning other types of input fields
		} else if ( nodeName === "input" || nodeName === "textarea" ) {
			dest.defaultValue = src.defaultValue;

			// IE blanks contents when cloning scripts
		} else if ( nodeName === "script" && dest.text !== src.text ) {
			dest.text = src.text;
		}

		// Event data gets referenced instead of copied if the expando
		// gets copied too
		dest.removeAttribute( jQuery.expando );
	}

	jQuery.buildFragment = function( args, context, scripts ) {
		var fragment, cacheable, cachehit,
			first = args[ 0 ];

		// Set context from what may come in as undefined or a jQuery collection or a node
		// Updated to fix #12266 where accessing context[0] could throw an exception in IE9/10 &
		// also doubles as fix for #8950 where plain objects caused createDocumentFragment exception
		context = context || document;
		context = !context.nodeType && context[0] || context;
		context = context.ownerDocument || context;

		// Only cache "small" (1/2 KB) HTML strings that are associated with the main document
		// Cloning options loses the selected state, so don't cache them
		// IE 6 doesn't like it when you put <object> or <embed> elements in a fragment
		// Also, WebKit does not clone 'checked' attributes on cloneNode, so don't cache
		// Lastly, IE6,7,8 will not correctly reuse cached fragments that were created from unknown elems #10501
		if ( args.length === 1 && typeof first === "string" && first.length < 512 && context === document &&
			first.charAt(0) === "<" && !rnocache.test( first ) &&
			(jQuery.support.checkClone || !rchecked.test( first )) &&
			(jQuery.support.html5Clone || !rnoshimcache.test( first )) ) {

			// Mark cacheable and look for a hit
			cacheable = true;
			fragment = jQuery.fragments[ first ];
			cachehit = fragment !== undefined;
		}

		if ( !fragment ) {
			fragment = context.createDocumentFragment();
			jQuery.clean( args, context, fragment, scripts );

			// Update the cache, but only store false
			// unless this is a second parsing of the same content
			if ( cacheable ) {
				jQuery.fragments[ first ] = cachehit && fragment;
			}
		}

		return { fragment: fragment, cacheable: cacheable };
	};

	jQuery.fragments = {};

	jQuery.each({
		appendTo: "append",
		prependTo: "prepend",
		insertBefore: "before",
		insertAfter: "after",
		replaceAll: "replaceWith"
	}, function( name, original ) {
		jQuery.fn[ name ] = function( selector ) {
			var elems,
				i = 0,
				ret = [],
				insert = jQuery( selector ),
				l = insert.length,
				parent = this.length === 1 && this[0].parentNode;

			if ( (parent == null || parent && parent.nodeType === 11 && parent.childNodes.length === 1) && l === 1 ) {
				insert[ original ]( this[0] );
				return this;
			} else {
				for ( ; i < l; i++ ) {
					elems = ( i > 0 ? this.clone(true) : this ).get();
					jQuery( insert[i] )[ original ]( elems );
					ret = ret.concat( elems );
				}

				return this.pushStack( ret, name, insert.selector );
			}
		};
	});

	function getAll( elem ) {
		if ( typeof elem.getElementsByTagName !== "undefined" ) {
			return elem.getElementsByTagName( "*" );

		} else if ( typeof elem.querySelectorAll !== "undefined" ) {
			return elem.querySelectorAll( "*" );

		} else {
			return [];
		}
	}

// Used in clean, fixes the defaultChecked property
	function fixDefaultChecked( elem ) {
		if ( rcheckableType.test( elem.type ) ) {
			elem.defaultChecked = elem.checked;
		}
	}

	jQuery.extend({
		clone: function( elem, dataAndEvents, deepDataAndEvents ) {
			var srcElements,
				destElements,
				i,
				clone;

			if ( jQuery.support.html5Clone || jQuery.isXMLDoc(elem) || !rnoshimcache.test( "<" + elem.nodeName + ">" ) ) {
				clone = elem.cloneNode( true );

				// IE<=8 does not properly clone detached, unknown element nodes
			} else {
				fragmentDiv.innerHTML = elem.outerHTML;
				fragmentDiv.removeChild( clone = fragmentDiv.firstChild );
			}

			if ( (!jQuery.support.noCloneEvent || !jQuery.support.noCloneChecked) &&
				(elem.nodeType === 1 || elem.nodeType === 11) && !jQuery.isXMLDoc(elem) ) {
				// IE copies events bound via attachEvent when using cloneNode.
				// Calling detachEvent on the clone will also remove the events
				// from the original. In order to get around this, we use some
				// proprietary methods to clear the events. Thanks to MooTools
				// guys for this hotness.

				cloneFixAttributes( elem, clone );

				// Using Sizzle here is crazy slow, so we use getElementsByTagName instead
				srcElements = getAll( elem );
				destElements = getAll( clone );

				// Weird iteration because IE will replace the length property
				// with an element if you are cloning the body and one of the
				// elements on the page has a name or id of "length"
				for ( i = 0; srcElements[i]; ++i ) {
					// Ensure that the destination node is not null; Fixes #9587
					if ( destElements[i] ) {
						cloneFixAttributes( srcElements[i], destElements[i] );
					}
				}
			}

			// Copy the events from the original to the clone
			if ( dataAndEvents ) {
				cloneCopyEvent( elem, clone );

				if ( deepDataAndEvents ) {
					srcElements = getAll( elem );
					destElements = getAll( clone );

					for ( i = 0; srcElements[i]; ++i ) {
						cloneCopyEvent( srcElements[i], destElements[i] );
					}
				}
			}

			srcElements = destElements = null;

			// Return the cloned set
			return clone;
		},

		clean: function( elems, context, fragment, scripts ) {
			var i, j, elem, tag, wrap, depth, div, hasBody, tbody, len, handleScript, jsTags,
				safe = context === document && safeFragment,
				ret = [];

			// Ensure that context is a document
			if ( !context || typeof context.createDocumentFragment === "undefined" ) {
				context = document;
			}

			// Use the already-created safe fragment if context permits
			for ( i = 0; (elem = elems[i]) != null; i++ ) {
				if ( typeof elem === "number" ) {
					elem += "";
				}

				if ( !elem ) {
					continue;
				}

				// Convert html string into DOM nodes
				if ( typeof elem === "string" ) {
					if ( !rhtml.test( elem ) ) {
						elem = context.createTextNode( elem );
					} else {
						// Ensure a safe container in which to render the html
						safe = safe || createSafeFragment( context );
						div = context.createElement("div");
						safe.appendChild( div );

						// Fix "XHTML"-style tags in all browsers
						elem = elem.replace(rxhtmlTag, "<$1></$2>");

						// Go to html and back, then peel off extra wrappers
						tag = ( rtagName.exec( elem ) || ["", ""] )[1].toLowerCase();
						wrap = wrapMap[ tag ] || wrapMap._default;
						depth = wrap[0];
						div.innerHTML = wrap[1] + elem + wrap[2];

						// Move to the right depth
						while ( depth-- ) {
							div = div.lastChild;
						}

						// Remove IE's autoinserted <tbody> from table fragments
						if ( !jQuery.support.tbody ) {

							// String was a <table>, *may* have spurious <tbody>
							hasBody = rtbody.test(elem);
							tbody = tag === "table" && !hasBody ?
								div.firstChild && div.firstChild.childNodes :

								// String was a bare <thead> or <tfoot>
								wrap[1] === "<table>" && !hasBody ?
									div.childNodes :
									[];

							for ( j = tbody.length - 1; j >= 0 ; --j ) {
								if ( jQuery.nodeName( tbody[ j ], "tbody" ) && !tbody[ j ].childNodes.length ) {
									tbody[ j ].parentNode.removeChild( tbody[ j ] );
								}
							}
						}

						// IE completely kills leading whitespace when innerHTML is used
						if ( !jQuery.support.leadingWhitespace && rleadingWhitespace.test( elem ) ) {
							div.insertBefore( context.createTextNode( rleadingWhitespace.exec(elem)[0] ), div.firstChild );
						}

						elem = div.childNodes;

						// Take out of fragment container (we need a fresh div each time)
						div.parentNode.removeChild( div );
					}
				}

				if ( elem.nodeType ) {
					ret.push( elem );
				} else {
					jQuery.merge( ret, elem );
				}
			}

			// Fix #11356: Clear elements from safeFragment
			if ( div ) {
				elem = div = safe = null;
			}

			// Reset defaultChecked for any radios and checkboxes
			// about to be appended to the DOM in IE 6/7 (#8060)
			if ( !jQuery.support.appendChecked ) {
				for ( i = 0; (elem = ret[i]) != null; i++ ) {
					if ( jQuery.nodeName( elem, "input" ) ) {
						fixDefaultChecked( elem );
					} else if ( typeof elem.getElementsByTagName !== "undefined" ) {
						jQuery.grep( elem.getElementsByTagName("input"), fixDefaultChecked );
					}
				}
			}

			// Append elements to a provided document fragment
			if ( fragment ) {
				// Special handling of each script element
				handleScript = function( elem ) {
					// Check if we consider it executable
					if ( !elem.type || rscriptType.test( elem.type ) ) {
						// Detach the script and store it in the scripts array (if provided) or the fragment
						// Return truthy to indicate that it has been handled
						return scripts ?
							scripts.push( elem.parentNode ? elem.parentNode.removeChild( elem ) : elem ) :
							fragment.appendChild( elem );
					}
				};

				for ( i = 0; (elem = ret[i]) != null; i++ ) {
					// Check if we're done after handling an executable script
					if ( !( jQuery.nodeName( elem, "script" ) && handleScript( elem ) ) ) {
						// Append to fragment and handle embedded scripts
						fragment.appendChild( elem );
						if ( typeof elem.getElementsByTagName !== "undefined" ) {
							// handleScript alters the DOM, so use jQuery.merge to ensure snapshot iteration
							jsTags = jQuery.grep( jQuery.merge( [], elem.getElementsByTagName("script") ), handleScript );

							// Splice the scripts into ret after their former ancestor and advance our index beyond them
							ret.splice.apply( ret, [i + 1, 0].concat( jsTags ) );
							i += jsTags.length;
						}
					}
				}
			}

			return ret;
		},

		cleanData: function( elems, /* internal */ acceptData ) {
			var data, id, elem, type,
				i = 0,
				internalKey = jQuery.expando,
				cache = jQuery.cache,
				deleteExpando = jQuery.support.deleteExpando,
				special = jQuery.event.special;

			for ( ; (elem = elems[i]) != null; i++ ) {

				if ( acceptData || jQuery.acceptData( elem ) ) {

					id = elem[ internalKey ];
					data = id && cache[ id ];

					if ( data ) {
						if ( data.events ) {
							for ( type in data.events ) {
								if ( special[ type ] ) {
									jQuery.event.remove( elem, type );

									// This is a shortcut to avoid jQuery.event.remove's overhead
								} else {
									jQuery.removeEvent( elem, type, data.handle );
								}
							}
						}

						// Remove cache only if it was not already removed by jQuery.event.remove
						if ( cache[ id ] ) {

							delete cache[ id ];

							// IE does not allow us to delete expando properties from nodes,
							// nor does it have a removeAttribute function on Document nodes;
							// we must handle all of these cases
							if ( deleteExpando ) {
								delete elem[ internalKey ];

							} else if ( elem.removeAttribute ) {
								elem.removeAttribute( internalKey );

							} else {
								elem[ internalKey ] = null;
							}

							jQuery.deletedIds.push( id );
						}
					}
				}
			}
		}
	});
// Limit scope pollution from any deprecated API
	(function() {

		var matched, browser;

// Use of jQuery.browser is frowned upon.
// More details: http://api.jquery.com/jQuery.browser
// jQuery.uaMatch maintained for back-compat
		jQuery.uaMatch = function( ua ) {
			ua = ua.toLowerCase();

			var match = /(chrome)[ \/]([\w.]+)/.exec( ua ) ||
				/(webkit)[ \/]([\w.]+)/.exec( ua ) ||
				/(opera)(?:.*version|)[ \/]([\w.]+)/.exec( ua ) ||
				/(msie) ([\w.]+)/.exec( ua ) ||
				ua.indexOf("compatible") < 0 && /(mozilla)(?:.*? rv:([\w.]+)|)/.exec( ua ) ||
				[];

			return {
				browser: match[ 1 ] || "",
				version: match[ 2 ] || "0"
			};
		};

		matched = jQuery.uaMatch( navigator.userAgent );
		browser = {};

		if ( matched.browser ) {
			browser[ matched.browser ] = true;
			browser.version = matched.version;
		}

// Chrome is Webkit, but Webkit is also Safari.
		if ( browser.chrome ) {
			browser.webkit = true;
		} else if ( browser.webkit ) {
			browser.safari = true;
		}

		jQuery.browser = browser;

		jQuery.sub = function() {
			function jQuerySub( selector, context ) {
				return new jQuerySub.fn.init( selector, context );
			}
			jQuery.extend( true, jQuerySub, this );
			jQuerySub.superclass = this;
			jQuerySub.fn = jQuerySub.prototype = this();
			jQuerySub.fn.constructor = jQuerySub;
			jQuerySub.sub = this.sub;
			jQuerySub.fn.init = function init( selector, context ) {
				if ( context && context instanceof jQuery && !(context instanceof jQuerySub) ) {
					context = jQuerySub( context );
				}

				return jQuery.fn.init.call( this, selector, context, rootjQuerySub );
			};
			jQuerySub.fn.init.prototype = jQuerySub.fn;
			var rootjQuerySub = jQuerySub(document);
			return jQuerySub;
		};

	})();
	var curCSS, iframe, iframeDoc,
		ralpha = /alpha\([^)]*\)/i,
		ropacity = /opacity=([^)]*)/,
		rposition = /^(top|right|bottom|left)$/,
	// swappable if display is none or starts with table except "table", "table-cell", or "table-caption"
	// see here for display values: https://developer.mozilla.org/en-US/docs/CSS/display
		rdisplayswap = /^(none|table(?!-c[ea]).+)/,
		rmargin = /^margin/,
		rnumsplit = new RegExp( "^(" + core_pnum + ")(.*)$", "i" ),
		rnumnonpx = new RegExp( "^(" + core_pnum + ")(?!px)[a-z%]+$", "i" ),
		rrelNum = new RegExp( "^([-+])=(" + core_pnum + ")", "i" ),
		elemdisplay = { BODY: "block" },

		cssShow = { position: "absolute", visibility: "hidden", display: "block" },
		cssNormalTransform = {
			letterSpacing: 0,
			fontWeight: 400
		},

		cssExpand = [ "Top", "Right", "Bottom", "Left" ],
		cssPrefixes = [ "Webkit", "O", "Moz", "ms" ],

		eventsToggle = jQuery.fn.toggle;

// return a css property mapped to a potentially vendor prefixed property
	function vendorPropName( style, name ) {

		// shortcut for names that are not vendor prefixed
		if ( name in style ) {
			return name;
		}

		// check for vendor prefixed names
		var capName = name.charAt(0).toUpperCase() + name.slice(1),
			origName = name,
			i = cssPrefixes.length;

		while ( i-- ) {
			name = cssPrefixes[ i ] + capName;
			if ( name in style ) {
				return name;
			}
		}

		return origName;
	}

	function isHidden( elem, el ) {
		elem = el || elem;
		return jQuery.css( elem, "display" ) === "none" || !jQuery.contains( elem.ownerDocument, elem );
	}

	function showHide( elements, show ) {
		var elem, display,
			values = [],
			index = 0,
			length = elements.length;

		for ( ; index < length; index++ ) {
			elem = elements[ index ];
			if ( !elem.style ) {
				continue;
			}
			values[ index ] = jQuery._data( elem, "olddisplay" );
			if ( show ) {
				// Reset the inline display of this element to learn if it is
				// being hidden by cascaded rules or not
				if ( !values[ index ] && elem.style.display === "none" ) {
					elem.style.display = "";
				}

				// Set elements which have been overridden with display: none
				// in a stylesheet to whatever the default browser style is
				// for such an element
				if ( elem.style.display === "" && isHidden( elem ) ) {
					values[ index ] = jQuery._data( elem, "olddisplay", css_defaultDisplay(elem.nodeName) );
				}
			} else {
				display = curCSS( elem, "display" );

				if ( !values[ index ] && display !== "none" ) {
					jQuery._data( elem, "olddisplay", display );
				}
			}
		}

		// Set the display of most of the elements in a second loop
		// to avoid the constant reflow
		for ( index = 0; index < length; index++ ) {
			elem = elements[ index ];
			if ( !elem.style ) {
				continue;
			}
			if ( !show || elem.style.display === "none" || elem.style.display === "" ) {
				elem.style.display = show ? values[ index ] || "" : "none";
			}
		}

		return elements;
	}

	jQuery.fn.extend({
		css: function( name, value ) {
			return jQuery.access( this, function( elem, name, value ) {
				return value !== undefined ?
					jQuery.style( elem, name, value ) :
					jQuery.css( elem, name );
			}, name, value, arguments.length > 1 );
		},
		show: function() {
			return showHide( this, true );
		},
		hide: function() {
			return showHide( this );
		},
		toggle: function( state, fn2 ) {
			var bool = typeof state === "boolean";

			if ( jQuery.isFunction( state ) && jQuery.isFunction( fn2 ) ) {
				return eventsToggle.apply( this, arguments );
			}

			return this.each(function() {
				if ( bool ? state : isHidden( this ) ) {
					jQuery( this ).show();
				} else {
					jQuery( this ).hide();
				}
			});
		}
	});

	jQuery.extend({
		// Add in style property hooks for overriding the default
		// behavior of getting and setting a style property
		cssHooks: {
			opacity: {
				get: function( elem, computed ) {
					if ( computed ) {
						// We should always get a number back from opacity
						var ret = curCSS( elem, "opacity" );
						return ret === "" ? "1" : ret;

					}
				}
			}
		},

		// Exclude the following css properties to add px
		cssNumber: {
			"fillOpacity": true,
			"fontWeight": true,
			"lineHeight": true,
			"opacity": true,
			"orphans": true,
			"widows": true,
			"zIndex": true,
			"zoom": true
		},

		// Add in properties whose names you wish to fix before
		// setting or getting the value
		cssProps: {
			// normalize float css property
			"float": jQuery.support.cssFloat ? "cssFloat" : "styleFloat"
		},

		// Get and set the style property on a DOM Node
		style: function( elem, name, value, extra ) {
			// Don't set styles on text and comment nodes
			if ( !elem || elem.nodeType === 3 || elem.nodeType === 8 || !elem.style ) {
				return;
			}

			// Make sure that we're working with the right name
			var ret, type, hooks,
				origName = jQuery.camelCase( name ),
				style = elem.style;

			name = jQuery.cssProps[ origName ] || ( jQuery.cssProps[ origName ] = vendorPropName( style, origName ) );

			// gets hook for the prefixed version
			// followed by the unprefixed version
			hooks = jQuery.cssHooks[ name ] || jQuery.cssHooks[ origName ];

			// Check if we're setting a value
			if ( value !== undefined ) {
				type = typeof value;

				// convert relative number strings (+= or -=) to relative numbers. #7345
				if ( type === "string" && (ret = rrelNum.exec( value )) ) {
					value = ( ret[1] + 1 ) * ret[2] + parseFloat( jQuery.css( elem, name ) );
					// Fixes bug #9237
					type = "number";
				}

				// Make sure that NaN and null values aren't set. See: #7116
				if ( value == null || type === "number" && isNaN( value ) ) {
					return;
				}

				// If a number was passed in, add 'px' to the (except for certain CSS properties)
				if ( type === "number" && !jQuery.cssNumber[ origName ] ) {
					value += "px";
				}

				// If a hook was provided, use that value, otherwise just set the specified value
				if ( !hooks || !("set" in hooks) || (value = hooks.set( elem, value, extra )) !== undefined ) {
					// Wrapped to prevent IE from throwing errors when 'invalid' values are provided
					// Fixes bug #5509
					try {
						style[ name ] = value;
					} catch(e) {}
				}

			} else {
				// If a hook was provided get the non-computed value from there
				if ( hooks && "get" in hooks && (ret = hooks.get( elem, false, extra )) !== undefined ) {
					return ret;
				}

				// Otherwise just get the value from the style object
				return style[ name ];
			}
		},

		css: function( elem, name, numeric, extra ) {
			var val, num, hooks,
				origName = jQuery.camelCase( name );

			// Make sure that we're working with the right name
			name = jQuery.cssProps[ origName ] || ( jQuery.cssProps[ origName ] = vendorPropName( elem.style, origName ) );

			// gets hook for the prefixed version
			// followed by the unprefixed version
			hooks = jQuery.cssHooks[ name ] || jQuery.cssHooks[ origName ];

			// If a hook was provided get the computed value from there
			if ( hooks && "get" in hooks ) {
				val = hooks.get( elem, true, extra );
			}

			// Otherwise, if a way to get the computed value exists, use that
			if ( val === undefined ) {
				val = curCSS( elem, name );
			}

			//convert "normal" to computed value
			if ( val === "normal" && name in cssNormalTransform ) {
				val = cssNormalTransform[ name ];
			}

			// Return, converting to number if forced or a qualifier was provided and val looks numeric
			if ( numeric || extra !== undefined ) {
				num = parseFloat( val );
				return numeric || jQuery.isNumeric( num ) ? num || 0 : val;
			}
			return val;
		},

		// A method for quickly swapping in/out CSS properties to get correct calculations
		swap: function( elem, options, callback ) {
			var ret, name,
				old = {};

			// Remember the old values, and insert the new ones
			for ( name in options ) {
				old[ name ] = elem.style[ name ];
				elem.style[ name ] = options[ name ];
			}

			ret = callback.call( elem );

			// Revert the old values
			for ( name in options ) {
				elem.style[ name ] = old[ name ];
			}

			return ret;
		}
	});

// NOTE: To any future maintainer, we've window.getComputedStyle
// because jsdom on node.js will break without it.
	if ( window.getComputedStyle ) {
		curCSS = function( elem, name ) {
			var ret, width, minWidth, maxWidth,
				computed = window.getComputedStyle( elem, null ),
				style = elem.style;

			if ( computed ) {

				// getPropertyValue is only needed for .css('filter') in IE9, see #12537
				ret = computed.getPropertyValue( name ) || computed[ name ];

				if ( ret === "" && !jQuery.contains( elem.ownerDocument, elem ) ) {
					ret = jQuery.style( elem, name );
				}

				// A tribute to the "awesome hack by Dean Edwards"
				// Chrome < 17 and Safari 5.0 uses "computed value" instead of "used value" for margin-right
				// Safari 5.1.7 (at least) returns percentage for a larger set of values, but width seems to be reliably pixels
				// this is against the CSSOM draft spec: http://dev.w3.org/csswg/cssom/#resolved-values
				if ( rnumnonpx.test( ret ) && rmargin.test( name ) ) {
					width = style.width;
					minWidth = style.minWidth;
					maxWidth = style.maxWidth;

					style.minWidth = style.maxWidth = style.width = ret;
					ret = computed.width;

					style.width = width;
					style.minWidth = minWidth;
					style.maxWidth = maxWidth;
				}
			}

			return ret;
		};
	} else if ( document.documentElement.currentStyle ) {
		curCSS = function( elem, name ) {
			var left, rsLeft,
				ret = elem.currentStyle && elem.currentStyle[ name ],
				style = elem.style;

			// Avoid setting ret to empty string here
			// so we don't default to auto
			if ( ret == null && style && style[ name ] ) {
				ret = style[ name ];
			}

			// From the awesome hack by Dean Edwards
			// http://erik.eae.net/archives/2007/07/27/18.54.15/#comment-102291

			// If we're not dealing with a regular pixel number
			// but a number that has a weird ending, we need to convert it to pixels
			// but not position css attributes, as those are proportional to the parent element instead
			// and we can't measure the parent instead because it might trigger a "stacking dolls" problem
			if ( rnumnonpx.test( ret ) && !rposition.test( name ) ) {

				// Remember the original values
				left = style.left;
				rsLeft = elem.runtimeStyle && elem.runtimeStyle.left;

				// Put in the new values to get a computed value out
				if ( rsLeft ) {
					elem.runtimeStyle.left = elem.currentStyle.left;
				}
				style.left = name === "fontSize" ? "1em" : ret;
				ret = style.pixelLeft + "px";

				// Revert the changed values
				style.left = left;
				if ( rsLeft ) {
					elem.runtimeStyle.left = rsLeft;
				}
			}

			return ret === "" ? "auto" : ret;
		};
	}

	function setPositiveNumber( elem, value, subtract ) {
		var matches = rnumsplit.exec( value );
		return matches ?
			Math.max( 0, matches[ 1 ] - ( subtract || 0 ) ) + ( matches[ 2 ] || "px" ) :
			value;
	}

	function augmentWidthOrHeight( elem, name, extra, isBorderBox ) {
		var i = extra === ( isBorderBox ? "border" : "content" ) ?
				// If we already have the right measurement, avoid augmentation
				4 :
				// Otherwise initialize for horizontal or vertical properties
				name === "width" ? 1 : 0,

			val = 0;

		for ( ; i < 4; i += 2 ) {
			// both box models exclude margin, so add it if we want it
			if ( extra === "margin" ) {
				// we use jQuery.css instead of curCSS here
				// because of the reliableMarginRight CSS hook!
				val += jQuery.css( elem, extra + cssExpand[ i ], true );
			}

			// From this point on we use curCSS for maximum performance (relevant in animations)
			if ( isBorderBox ) {
				// border-box includes padding, so remove it if we want content
				if ( extra === "content" ) {
					val -= parseFloat( curCSS( elem, "padding" + cssExpand[ i ] ) ) || 0;
				}

				// at this point, extra isn't border nor margin, so remove border
				if ( extra !== "margin" ) {
					val -= parseFloat( curCSS( elem, "border" + cssExpand[ i ] + "Width" ) ) || 0;
				}
			} else {
				// at this point, extra isn't content, so add padding
				val += parseFloat( curCSS( elem, "padding" + cssExpand[ i ] ) ) || 0;

				// at this point, extra isn't content nor padding, so add border
				if ( extra !== "padding" ) {
					val += parseFloat( curCSS( elem, "border" + cssExpand[ i ] + "Width" ) ) || 0;
				}
			}
		}

		return val;
	}

	function getWidthOrHeight( elem, name, extra ) {

		// Start with offset property, which is equivalent to the border-box value
		var val = name === "width" ? elem.offsetWidth : elem.offsetHeight,
			valueIsBorderBox = true,
			isBorderBox = jQuery.support.boxSizing && jQuery.css( elem, "boxSizing" ) === "border-box";

		// some non-html elements return undefined for offsetWidth, so check for null/undefined
		// svg - https://bugzilla.mozilla.org/show_bug.cgi?id=649285
		// MathML - https://bugzilla.mozilla.org/show_bug.cgi?id=491668
		if ( val <= 0 || val == null ) {
			// Fall back to computed then uncomputed css if necessary
			val = curCSS( elem, name );
			if ( val < 0 || val == null ) {
				val = elem.style[ name ];
			}

			// Computed unit is not pixels. Stop here and return.
			if ( rnumnonpx.test(val) ) {
				return val;
			}

			// we need the check for style in case a browser which returns unreliable values
			// for getComputedStyle silently falls back to the reliable elem.style
			valueIsBorderBox = isBorderBox && ( jQuery.support.boxSizingReliable || val === elem.style[ name ] );

			// Normalize "", auto, and prepare for extra
			val = parseFloat( val ) || 0;
		}

		// use the active box-sizing model to add/subtract irrelevant styles
		return ( val +
			augmentWidthOrHeight(
				elem,
				name,
				extra || ( isBorderBox ? "border" : "content" ),
				valueIsBorderBox
			)
			) + "px";
	}


// Try to determine the default display value of an element
	function css_defaultDisplay( nodeName ) {
		if ( elemdisplay[ nodeName ] ) {
			return elemdisplay[ nodeName ];
		}

		var elem = jQuery( "<" + nodeName + ">" ).appendTo( document.body ),
			display = elem.css("display");
		elem.remove();

		// If the simple way fails,
		// get element's real default display by attaching it to a temp iframe
		if ( display === "none" || display === "" ) {
			// Use the already-created iframe if possible
			iframe = document.body.appendChild(
				iframe || jQuery.extend( document.createElement("iframe"), {
					frameBorder: 0,
					width: 0,
					height: 0
				})
			);

			// Create a cacheable copy of the iframe document on first call.
			// IE and Opera will allow us to reuse the iframeDoc without re-writing the fake HTML
			// document to it; WebKit & Firefox won't allow reusing the iframe document.
			if ( !iframeDoc || !iframe.createElement ) {
				iframeDoc = ( iframe.contentWindow || iframe.contentDocument ).document;
				iframeDoc.write("<!doctype html><html><body>");
				iframeDoc.close();
			}

			elem = iframeDoc.body.appendChild( iframeDoc.createElement(nodeName) );

			display = curCSS( elem, "display" );
			document.body.removeChild( iframe );
		}

		// Store the correct default display
		elemdisplay[ nodeName ] = display;

		return display;
	}

	jQuery.each([ "height", "width" ], function( i, name ) {
		jQuery.cssHooks[ name ] = {
			get: function( elem, computed, extra ) {
				if ( computed ) {
					// certain elements can have dimension info if we invisibly show them
					// however, it must have a current display style that would benefit from this
					if ( elem.offsetWidth === 0 && rdisplayswap.test( curCSS( elem, "display" ) ) ) {
						return jQuery.swap( elem, cssShow, function() {
							return getWidthOrHeight( elem, name, extra );
						});
					} else {
						return getWidthOrHeight( elem, name, extra );
					}
				}
			},

			set: function( elem, value, extra ) {
				return setPositiveNumber( elem, value, extra ?
					augmentWidthOrHeight(
						elem,
						name,
						extra,
						jQuery.support.boxSizing && jQuery.css( elem, "boxSizing" ) === "border-box"
					) : 0
				);
			}
		};
	});

	if ( !jQuery.support.opacity ) {
		jQuery.cssHooks.opacity = {
			get: function( elem, computed ) {
				// IE uses filters for opacity
				return ropacity.test( (computed && elem.currentStyle ? elem.currentStyle.filter : elem.style.filter) || "" ) ?
					( 0.01 * parseFloat( RegExp.$1 ) ) + "" :
					computed ? "1" : "";
			},

			set: function( elem, value ) {
				var style = elem.style,
					currentStyle = elem.currentStyle,
					opacity = jQuery.isNumeric( value ) ? "alpha(opacity=" + value * 100 + ")" : "",
					filter = currentStyle && currentStyle.filter || style.filter || "";

				// IE has trouble with opacity if it does not have layout
				// Force it by setting the zoom level
				style.zoom = 1;

				// if setting opacity to 1, and no other filters exist - attempt to remove filter attribute #6652
				if ( value >= 1 && jQuery.trim( filter.replace( ralpha, "" ) ) === "" &&
					style.removeAttribute ) {

					// Setting style.filter to null, "" & " " still leave "filter:" in the cssText
					// if "filter:" is present at all, clearType is disabled, we want to avoid this
					// style.removeAttribute is IE Only, but so apparently is this code path...
					style.removeAttribute( "filter" );

					// if there there is no filter style applied in a css rule, we are done
					if ( currentStyle && !currentStyle.filter ) {
						return;
					}
				}

				// otherwise, set new filter values
				style.filter = ralpha.test( filter ) ?
					filter.replace( ralpha, opacity ) :
					filter + " " + opacity;
			}
		};
	}

// These hooks cannot be added until DOM ready because the support test
// for it is not run until after DOM ready
	jQuery(function() {
		if ( !jQuery.support.reliableMarginRight ) {
			jQuery.cssHooks.marginRight = {
				get: function( elem, computed ) {
					// WebKit Bug 13343 - getComputedStyle returns wrong value for margin-right
					// Work around by temporarily setting element display to inline-block
					return jQuery.swap( elem, { "display": "inline-block" }, function() {
						if ( computed ) {
							return curCSS( elem, "marginRight" );
						}
					});
				}
			};
		}

		// Webkit bug: https://bugs.webkit.org/show_bug.cgi?id=29084
		// getComputedStyle returns percent when specified for top/left/bottom/right
		// rather than make the css module depend on the offset module, we just check for it here
		if ( !jQuery.support.pixelPosition && jQuery.fn.position ) {
			jQuery.each( [ "top", "left" ], function( i, prop ) {
				jQuery.cssHooks[ prop ] = {
					get: function( elem, computed ) {
						if ( computed ) {
							var ret = curCSS( elem, prop );
							// if curCSS returns percentage, fallback to offset
							return rnumnonpx.test( ret ) ? jQuery( elem ).position()[ prop ] + "px" : ret;
						}
					}
				};
			});
		}

	});

	if ( jQuery.expr && jQuery.expr.filters ) {
		jQuery.expr.filters.hidden = function( elem ) {
			return ( elem.offsetWidth === 0 && elem.offsetHeight === 0 ) || (!jQuery.support.reliableHiddenOffsets && ((elem.style && elem.style.display) || curCSS( elem, "display" )) === "none");
		};

		jQuery.expr.filters.visible = function( elem ) {
			return !jQuery.expr.filters.hidden( elem );
		};
	}

// These hooks are used by animate to expand properties
	jQuery.each({
		margin: "",
		padding: "",
		border: "Width"
	}, function( prefix, suffix ) {
		jQuery.cssHooks[ prefix + suffix ] = {
			expand: function( value ) {
				var i,

				// assumes a single number if not a string
					parts = typeof value === "string" ? value.split(" ") : [ value ],
					expanded = {};

				for ( i = 0; i < 4; i++ ) {
					expanded[ prefix + cssExpand[ i ] + suffix ] =
						parts[ i ] || parts[ i - 2 ] || parts[ 0 ];
				}

				return expanded;
			}
		};

		if ( !rmargin.test( prefix ) ) {
			jQuery.cssHooks[ prefix + suffix ].set = setPositiveNumber;
		}
	});
	var r20 = /%20/g,
		rbracket = /\[\]$/,
		rCRLF = /\r?\n/g,
		rinput = /^(?:color|date|datetime|datetime-local|email|hidden|month|number|password|range|search|tel|text|time|url|week)$/i,
		rselectTextarea = /^(?:select|textarea)/i;

	jQuery.fn.extend({
		serialize: function() {
			return jQuery.param( this.serializeArray() );
		},
		serializeArray: function() {
			return this.map(function(){
				return this.elements ? jQuery.makeArray( this.elements ) : this;
			})
				.filter(function(){
					return this.name && !this.disabled &&
						( this.checked || rselectTextarea.test( this.nodeName ) ||
							rinput.test( this.type ) );
				})
				.map(function( i, elem ){
					var val = jQuery( this ).val();

					return val == null ?
						null :
						jQuery.isArray( val ) ?
							jQuery.map( val, function( val, i ){
								return { name: elem.name, value: val.replace( rCRLF, "\r\n" ) };
							}) :
						{ name: elem.name, value: val.replace( rCRLF, "\r\n" ) };
				}).get();
		}
	});

//Serialize an array of form elements or a set of
//key/values into a query string
	jQuery.param = function( a, traditional ) {
		var prefix,
			s = [],
			add = function( key, value ) {
				// If value is a function, invoke it and return its value
				value = jQuery.isFunction( value ) ? value() : ( value == null ? "" : value );
				s[ s.length ] = encodeURIComponent( key ) + "=" + encodeURIComponent( value );
			};

		// Set traditional to true for jQuery <= 1.3.2 behavior.
		if ( traditional === undefined ) {
			traditional = jQuery.ajaxSettings && jQuery.ajaxSettings.traditional;
		}

		// If an array was passed in, assume that it is an array of form elements.
		if ( jQuery.isArray( a ) || ( a.jquery && !jQuery.isPlainObject( a ) ) ) {
			// Serialize the form elements
			jQuery.each( a, function() {
				add( this.name, this.value );
			});

		} else {
			// If traditional, encode the "old" way (the way 1.3.2 or older
			// did it), otherwise encode params recursively.
			for ( prefix in a ) {
				buildParams( prefix, a[ prefix ], traditional, add );
			}
		}

		// Return the resulting serialization
		return s.join( "&" ).replace( r20, "+" );
	};

	function buildParams( prefix, obj, traditional, add ) {
		var name;

		if ( jQuery.isArray( obj ) ) {
			// Serialize array item.
			jQuery.each( obj, function( i, v ) {
				if ( traditional || rbracket.test( prefix ) ) {
					// Treat each array item as a scalar.
					add( prefix, v );

				} else {
					// If array item is non-scalar (array or object), encode its
					// numeric index to resolve deserialization ambiguity issues.
					// Note that rack (as of 1.0.0) can't currently deserialize
					// nested arrays properly, and attempting to do so may cause
					// a server error. Possible fixes are to modify rack's
					// deserialization algorithm or to provide an option or flag
					// to force array serialization to be shallow.
					buildParams( prefix + "[" + ( typeof v === "object" ? i : "" ) + "]", v, traditional, add );
				}
			});

		} else if ( !traditional && jQuery.type( obj ) === "object" ) {
			// Serialize object item.
			for ( name in obj ) {
				buildParams( prefix + "[" + name + "]", obj[ name ], traditional, add );
			}

		} else {
			// Serialize scalar item.
			add( prefix, obj );
		}
	}
	var
	// Document location
		ajaxLocParts,
		ajaxLocation,

		rhash = /#.*$/,
		rheaders = /^(.*?):[ \t]*([^\r\n]*)\r?$/mg, // IE leaves an \r character at EOL
	// #7653, #8125, #8152: local protocol detection
		rlocalProtocol = /^(?:about|app|app\-storage|.+\-extension|file|res|widget):$/,
		rnoContent = /^(?:GET|HEAD)$/,
		rprotocol = /^\/\//,
		rquery = /\?/,
		rscript = /<script\b[^<]*(?:(?!<\/script>)<[^<]*)*<\/script>/gi,
		rts = /([?&])_=[^&]*/,
		rurl = /^([\w\+\.\-]+:)(?:\/\/([^\/?#:]*)(?::(\d+)|)|)/,

	// Keep a copy of the old load method
		_load = jQuery.fn.load,

	/* Prefilters
	 * 1) They are useful to introduce custom dataTypes (see ajax/jsonp.js for an example)
	 * 2) These are called:
	 *    - BEFORE asking for a transport
	 *    - AFTER param serialization (s.data is a string if s.processData is true)
	 * 3) key is the dataType
	 * 4) the catchall symbol "*" can be used
	 * 5) execution will start with transport dataType and THEN continue down to "*" if needed
	 */
		prefilters = {},

	/* Transports bindings
	 * 1) key is the dataType
	 * 2) the catchall symbol "*" can be used
	 * 3) selection will start with transport dataType and THEN go to "*" if needed
	 */
		transports = {},

	// Avoid comment-prolog char sequence (#10098); must appease lint and evade compression
		allTypes = ["*/"] + ["*"];

// #8138, IE may throw an exception when accessing
// a field from window.location if document.domain has been set
	try {
		ajaxLocation = location.href;
	} catch( e ) {
		// Use the href attribute of an A element
		// since IE will modify it given document.location
		ajaxLocation = document.createElement( "a" );
		ajaxLocation.href = "";
		ajaxLocation = ajaxLocation.href;
	}

// Segment location into parts
	ajaxLocParts = rurl.exec( ajaxLocation.toLowerCase() ) || [];

// Base "constructor" for jQuery.ajaxPrefilter and jQuery.ajaxTransport
	function addToPrefiltersOrTransports( structure ) {

		// dataTypeExpression is optional and defaults to "*"
		return function( dataTypeExpression, func ) {

			if ( typeof dataTypeExpression !== "string" ) {
				func = dataTypeExpression;
				dataTypeExpression = "*";
			}

			var dataType, list, placeBefore,
				dataTypes = dataTypeExpression.toLowerCase().split( core_rspace ),
				i = 0,
				length = dataTypes.length;

			if ( jQuery.isFunction( func ) ) {
				// For each dataType in the dataTypeExpression
				for ( ; i < length; i++ ) {
					dataType = dataTypes[ i ];
					// We control if we're asked to add before
					// any existing element
					placeBefore = /^\+/.test( dataType );
					if ( placeBefore ) {
						dataType = dataType.substr( 1 ) || "*";
					}
					list = structure[ dataType ] = structure[ dataType ] || [];
					// then we add to the structure accordingly
					list[ placeBefore ? "unshift" : "push" ]( func );
				}
			}
		};
	}

// Base inspection function for prefilters and transports
	function inspectPrefiltersOrTransports( structure, options, originalOptions, jqXHR,
											dataType /* internal */, inspected /* internal */ ) {

		dataType = dataType || options.dataTypes[ 0 ];
		inspected = inspected || {};

		inspected[ dataType ] = true;

		var selection,
			list = structure[ dataType ],
			i = 0,
			length = list ? list.length : 0,
			executeOnly = ( structure === prefilters );

		for ( ; i < length && ( executeOnly || !selection ); i++ ) {
			selection = list[ i ]( options, originalOptions, jqXHR );
			// If we got redirected to another dataType
			// we try there if executing only and not done already
			if ( typeof selection === "string" ) {
				if ( !executeOnly || inspected[ selection ] ) {
					selection = undefined;
				} else {
					options.dataTypes.unshift( selection );
					selection = inspectPrefiltersOrTransports(
						structure, options, originalOptions, jqXHR, selection, inspected );
				}
			}
		}
		// If we're only executing or nothing was selected
		// we try the catchall dataType if not done already
		if ( ( executeOnly || !selection ) && !inspected[ "*" ] ) {
			selection = inspectPrefiltersOrTransports(
				structure, options, originalOptions, jqXHR, "*", inspected );
		}
		// unnecessary when only executing (prefilters)
		// but it'll be ignored by the caller in that case
		return selection;
	}

// A special extend for ajax options
// that takes "flat" options (not to be deep extended)
// Fixes #9887
	function ajaxExtend( target, src ) {
		var key, deep,
			flatOptions = jQuery.ajaxSettings.flatOptions || {};
		for ( key in src ) {
			if ( src[ key ] !== undefined ) {
				( flatOptions[ key ] ? target : ( deep || ( deep = {} ) ) )[ key ] = src[ key ];
			}
		}
		if ( deep ) {
			jQuery.extend( true, target, deep );
		}
	}

	jQuery.fn.load = function( url, params, callback ) {
		if ( typeof url !== "string" && _load ) {
			return _load.apply( this, arguments );
		}

		// Don't do a request if no elements are being requested
		if ( !this.length ) {
			return this;
		}

		var selector, type, response,
			self = this,
			off = url.indexOf(" ");

		if ( off >= 0 ) {
			selector = url.slice( off, url.length );
			url = url.slice( 0, off );
		}

		// If it's a function
		if ( jQuery.isFunction( params ) ) {

			// We assume that it's the callback
			callback = params;
			params = undefined;

			// Otherwise, build a param string
		} else if ( params && typeof params === "object" ) {
			type = "POST";
		}

		// Request the remote document
		jQuery.ajax({
			url: url,

			// if "type" variable is undefined, then "GET" method will be used
			type: type,
			dataType: "html",
			data: params,
			complete: function( jqXHR, status ) {
				if ( callback ) {
					self.each( callback, response || [ jqXHR.responseText, status, jqXHR ] );
				}
			}
		}).done(function( responseText ) {

				// Save response for use in complete callback
				response = arguments;

				// See if a selector was specified
				self.html( selector ?

					// Create a dummy div to hold the results
					jQuery("<div>")

						// inject the contents of the document in, removing the scripts
						// to avoid any 'Permission Denied' errors in IE
						.append( responseText.replace( rscript, "" ) )

						// Locate the specified elements
						.find( selector ) :

					// If not, just inject the full result
					responseText );

			});

		return this;
	};

// Attach a bunch of functions for handling common AJAX events
	jQuery.each( "ajaxStart ajaxStop ajaxComplete ajaxError ajaxSuccess ajaxSend".split( " " ), function( i, o ){
		jQuery.fn[ o ] = function( f ){
			return this.on( o, f );
		};
	});

	jQuery.each( [ "get", "post" ], function( i, method ) {
		jQuery[ method ] = function( url, data, callback, type ) {
			// shift arguments if data argument was omitted
			if ( jQuery.isFunction( data ) ) {
				type = type || callback;
				callback = data;
				data = undefined;
			}

			return jQuery.ajax({
				type: method,
				url: url,
				data: data,
				success: callback,
				dataType: type
			});
		};
	});

	jQuery.extend({

		getScript: function( url, callback ) {
			return jQuery.get( url, undefined, callback, "script" );
		},

		getJSON: function( url, data, callback ) {
			return jQuery.get( url, data, callback, "json" );
		},

		// Creates a full fledged settings object into target
		// with both ajaxSettings and settings fields.
		// If target is omitted, writes into ajaxSettings.
		ajaxSetup: function( target, settings ) {
			if ( settings ) {
				// Building a settings object
				ajaxExtend( target, jQuery.ajaxSettings );
			} else {
				// Extending ajaxSettings
				settings = target;
				target = jQuery.ajaxSettings;
			}
			ajaxExtend( target, settings );
			return target;
		},

		ajaxSettings: {
			url: ajaxLocation,
			isLocal: rlocalProtocol.test( ajaxLocParts[ 1 ] ),
			global: true,
			type: "GET",
			contentType: "application/x-www-form-urlencoded; charset=UTF-8",
			processData: true,
			async: true,
			/*
			 timeout: 0,
			 data: null,
			 dataType: null,
			 username: null,
			 password: null,
			 cache: null,
			 throws: false,
			 traditional: false,
			 headers: {},
			 */

			accepts: {
				xml: "application/xml, text/xml",
				html: "text/html",
				text: "text/plain",
				json: "application/json, text/javascript",
				"*": allTypes
			},

			contents: {
				xml: /xml/,
				html: /html/,
				json: /json/
			},

			responseFields: {
				xml: "responseXML",
				text: "responseText"
			},

			// List of data converters
			// 1) key format is "source_type destination_type" (a single space in-between)
			// 2) the catchall symbol "*" can be used for source_type
			converters: {

				// Convert anything to text
				"* text": window.String,

				// Text to html (true = no transformation)
				"text html": true,

				// Evaluate text as a json expression
				"text json": jQuery.parseJSON,

				// Parse text as xml
				"text xml": jQuery.parseXML
			},

			// For options that shouldn't be deep extended:
			// you can add your own custom options here if
			// and when you create one that shouldn't be
			// deep extended (see ajaxExtend)
			flatOptions: {
				context: true,
				url: true
			}
		},

		ajaxPrefilter: addToPrefiltersOrTransports( prefilters ),
		ajaxTransport: addToPrefiltersOrTransports( transports ),

		// Main method
		ajax: function( url, options ) {

			// If url is an object, simulate pre-1.5 signature
			if ( typeof url === "object" ) {
				options = url;
				url = undefined;
			}

			// Force options to be an object
			options = options || {};

			var // ifModified key
				ifModifiedKey,
			// Response headers
				responseHeadersString,
				responseHeaders,
			// transport
				transport,
			// timeout handle
				timeoutTimer,
			// Cross-domain detection vars
				parts,
			// To know if global events are to be dispatched
				fireGlobals,
			// Loop variable
				i,
			// Create the final options object
				s = jQuery.ajaxSetup( {}, options ),
			// Callbacks context
				callbackContext = s.context || s,
			// Context for global events
			// It's the callbackContext if one was provided in the options
			// and if it's a DOM node or a jQuery collection
				globalEventContext = callbackContext !== s &&
					( callbackContext.nodeType || callbackContext instanceof jQuery ) ?
					jQuery( callbackContext ) : jQuery.event,
			// Deferreds
				deferred = jQuery.Deferred(),
				completeDeferred = jQuery.Callbacks( "once memory" ),
			// Status-dependent callbacks
				statusCode = s.statusCode || {},
			// Headers (they are sent all at once)
				requestHeaders = {},
				requestHeadersNames = {},
			// The jqXHR state
				state = 0,
			// Default abort message
				strAbort = "canceled",
			// Fake xhr
				jqXHR = {

					readyState: 0,

					// Caches the header
					setRequestHeader: function( name, value ) {
						if ( !state ) {
							var lname = name.toLowerCase();
							name = requestHeadersNames[ lname ] = requestHeadersNames[ lname ] || name;
							requestHeaders[ name ] = value;
						}
						return this;
					},

					// Raw string
					getAllResponseHeaders: function() {
						return state === 2 ? responseHeadersString : null;
					},

					// Builds headers hashtable if needed
					getResponseHeader: function( key ) {
						var match;
						if ( state === 2 ) {
							if ( !responseHeaders ) {
								responseHeaders = {};
								while( ( match = rheaders.exec( responseHeadersString ) ) ) {
									responseHeaders[ match[1].toLowerCase() ] = match[ 2 ];
								}
							}
							match = responseHeaders[ key.toLowerCase() ];
						}
						return match === undefined ? null : match;
					},

					// Overrides response content-type header
					overrideMimeType: function( type ) {
						if ( !state ) {
							s.mimeType = type;
						}
						return this;
					},

					// Cancel the request
					abort: function( statusText ) {
						statusText = statusText || strAbort;
						if ( transport ) {
							transport.abort( statusText );
						}
						done( 0, statusText );
						return this;
					}
				};

			// Callback for when everything is done
			// It is defined here because jslint complains if it is declared
			// at the end of the function (which would be more logical and readable)
			function done( status, nativeStatusText, responses, headers ) {
				var isSuccess, success, error, response, modified,
					statusText = nativeStatusText;

				// Called once
				if ( state === 2 ) {
					return;
				}

				// State is "done" now
				state = 2;

				// Clear timeout if it exists
				if ( timeoutTimer ) {
					clearTimeout( timeoutTimer );
				}

				// Dereference transport for early garbage collection
				// (no matter how long the jqXHR object will be used)
				transport = undefined;

				// Cache response headers
				responseHeadersString = headers || "";

				// Set readyState
				jqXHR.readyState = status > 0 ? 4 : 0;

				// Get response data
				if ( responses ) {
					response = ajaxHandleResponses( s, jqXHR, responses );
				}

				// If successful, handle type chaining
				if ( status >= 200 && status < 300 || status === 304 ) {

					// Set the If-Modified-Since and/or If-None-Match header, if in ifModified mode.
					if ( s.ifModified ) {

						modified = jqXHR.getResponseHeader("Last-Modified");
						if ( modified ) {
							jQuery.lastModified[ ifModifiedKey ] = modified;
						}
						modified = jqXHR.getResponseHeader("Etag");
						if ( modified ) {
							jQuery.etag[ ifModifiedKey ] = modified;
						}
					}

					// If not modified
					if ( status === 304 ) {

						statusText = "notmodified";
						isSuccess = true;

						// If we have data
					} else {

						isSuccess = ajaxConvert( s, response );
						statusText = isSuccess.state;
						success = isSuccess.data;
						error = isSuccess.error;
						isSuccess = !error;
					}
				} else {
					// We extract error from statusText
					// then normalize statusText and status for non-aborts
					error = statusText;
					if ( !statusText || status ) {
						statusText = "error";
						if ( status < 0 ) {
							status = 0;
						}
					}
				}

				// Set data for the fake xhr object
				jqXHR.status = status;
				jqXHR.statusText = ( nativeStatusText || statusText ) + "";

				// Success/Error
				if ( isSuccess ) {
					deferred.resolveWith( callbackContext, [ success, statusText, jqXHR ] );
				} else {
					deferred.rejectWith( callbackContext, [ jqXHR, statusText, error ] );
				}

				// Status-dependent callbacks
				jqXHR.statusCode( statusCode );
				statusCode = undefined;

				if ( fireGlobals ) {
					globalEventContext.trigger( "ajax" + ( isSuccess ? "Success" : "Error" ),
						[ jqXHR, s, isSuccess ? success : error ] );
				}

				// Complete
				completeDeferred.fireWith( callbackContext, [ jqXHR, statusText ] );

				if ( fireGlobals ) {
					globalEventContext.trigger( "ajaxComplete", [ jqXHR, s ] );
					// Handle the global AJAX counter
					if ( !( --jQuery.active ) ) {
						jQuery.event.trigger( "ajaxStop" );
					}
				}
			}

			// Attach deferreds
			deferred.promise( jqXHR );
			jqXHR.success = jqXHR.done;
			jqXHR.error = jqXHR.fail;
			jqXHR.complete = completeDeferred.add;

			// Status-dependent callbacks
			jqXHR.statusCode = function( map ) {
				if ( map ) {
					var tmp;
					if ( state < 2 ) {
						for ( tmp in map ) {
							statusCode[ tmp ] = [ statusCode[tmp], map[tmp] ];
						}
					} else {
						tmp = map[ jqXHR.status ];
						jqXHR.always( tmp );
					}
				}
				return this;
			};

			// Remove hash character (#7531: and string promotion)
			// Add protocol if not provided (#5866: IE7 issue with protocol-less urls)
			// We also use the url parameter if available
			s.url = ( ( url || s.url ) + "" ).replace( rhash, "" ).replace( rprotocol, ajaxLocParts[ 1 ] + "//" );

			// Extract dataTypes list
			s.dataTypes = jQuery.trim( s.dataType || "*" ).toLowerCase().split( core_rspace );

			// A cross-domain request is in order when we have a protocol:host:port mismatch
			if ( s.crossDomain == null ) {
				parts = rurl.exec( s.url.toLowerCase() );
				s.crossDomain = !!( parts &&
					( parts[ 1 ] !== ajaxLocParts[ 1 ] || parts[ 2 ] !== ajaxLocParts[ 2 ] ||
						( parts[ 3 ] || ( parts[ 1 ] === "http:" ? 80 : 443 ) ) !=
							( ajaxLocParts[ 3 ] || ( ajaxLocParts[ 1 ] === "http:" ? 80 : 443 ) ) )
					);
			}

			// Convert data if not already a string
			if ( s.data && s.processData && typeof s.data !== "string" ) {
				s.data = jQuery.param( s.data, s.traditional );
			}

			// Apply prefilters
			inspectPrefiltersOrTransports( prefilters, s, options, jqXHR );

			// If request was aborted inside a prefilter, stop there
			if ( state === 2 ) {
				return jqXHR;
			}

			// We can fire global events as of now if asked to
			fireGlobals = s.global;

			// Uppercase the type
			s.type = s.type.toUpperCase();

			// Determine if request has content
			s.hasContent = !rnoContent.test( s.type );

			// Watch for a new set of requests
			if ( fireGlobals && jQuery.active++ === 0 ) {
				jQuery.event.trigger( "ajaxStart" );
			}

			// More options handling for requests with no content
			if ( !s.hasContent ) {

				// If data is available, append data to url
				if ( s.data ) {
					s.url += ( rquery.test( s.url ) ? "&" : "?" ) + s.data;
					// #9682: remove data so that it's not used in an eventual retry
					delete s.data;
				}

				// Get ifModifiedKey before adding the anti-cache parameter
				ifModifiedKey = s.url;

				// Add anti-cache in url if needed
				if ( s.cache === false ) {

					var ts = jQuery.now(),
					// try replacing _= if it is there
						ret = s.url.replace( rts, "$1_=" + ts );

					// if nothing was replaced, add timestamp to the end
					s.url = ret + ( ( ret === s.url ) ? ( rquery.test( s.url ) ? "&" : "?" ) + "_=" + ts : "" );
				}
			}

			// Set the correct header, if data is being sent
			if ( s.data && s.hasContent && s.contentType !== false || options.contentType ) {
				jqXHR.setRequestHeader( "Content-Type", s.contentType );
			}

			// Set the If-Modified-Since and/or If-None-Match header, if in ifModified mode.
			if ( s.ifModified ) {
				ifModifiedKey = ifModifiedKey || s.url;
				if ( jQuery.lastModified[ ifModifiedKey ] ) {
					jqXHR.setRequestHeader( "If-Modified-Since", jQuery.lastModified[ ifModifiedKey ] );
				}
				if ( jQuery.etag[ ifModifiedKey ] ) {
					jqXHR.setRequestHeader( "If-None-Match", jQuery.etag[ ifModifiedKey ] );
				}
			}

			// Set the Accepts header for the server, depending on the dataType
			jqXHR.setRequestHeader(
				"Accept",
				s.dataTypes[ 0 ] && s.accepts[ s.dataTypes[0] ] ?
					s.accepts[ s.dataTypes[0] ] + ( s.dataTypes[ 0 ] !== "*" ? ", " + allTypes + "; q=0.01" : "" ) :
					s.accepts[ "*" ]
			);

			// Check for headers option
			for ( i in s.headers ) {
				jqXHR.setRequestHeader( i, s.headers[ i ] );
			}

			// Allow custom headers/mimetypes and early abort
			if ( s.beforeSend && ( s.beforeSend.call( callbackContext, jqXHR, s ) === false || state === 2 ) ) {
				// Abort if not done already and return
				return jqXHR.abort();

			}

			// aborting is no longer a cancellation
			strAbort = "abort";

			// Install callbacks on deferreds
			for ( i in { success: 1, error: 1, complete: 1 } ) {
				jqXHR[ i ]( s[ i ] );
			}

			// Get transport
			transport = inspectPrefiltersOrTransports( transports, s, options, jqXHR );

			// If no transport, we auto-abort
			if ( !transport ) {
				done( -1, "No Transport" );
			} else {
				jqXHR.readyState = 1;
				// Send global event
				if ( fireGlobals ) {
					globalEventContext.trigger( "ajaxSend", [ jqXHR, s ] );
				}
				// Timeout
				if ( s.async && s.timeout > 0 ) {
					timeoutTimer = setTimeout( function(){
						jqXHR.abort( "timeout" );
					}, s.timeout );
				}

				try {
					state = 1;
					transport.send( requestHeaders, done );
				} catch (e) {
					// Propagate exception as error if not done
					if ( state < 2 ) {
						done( -1, e );
						// Simply rethrow otherwise
					} else {
						throw e;
					}
				}
			}

			return jqXHR;
		},

		// Counter for holding the number of active queries
		active: 0,

		// Last-Modified header cache for next request
		lastModified: {},
		etag: {}

	});

	/* Handles responses to an ajax request:
	 * - sets all responseXXX fields accordingly
	 * - finds the right dataType (mediates between content-type and expected dataType)
	 * - returns the corresponding response
	 */
	function ajaxHandleResponses( s, jqXHR, responses ) {

		var ct, type, finalDataType, firstDataType,
			contents = s.contents,
			dataTypes = s.dataTypes,
			responseFields = s.responseFields;

		// Fill responseXXX fields
		for ( type in responseFields ) {
			if ( type in responses ) {
				jqXHR[ responseFields[type] ] = responses[ type ];
			}
		}

		// Remove auto dataType and get content-type in the process
		while( dataTypes[ 0 ] === "*" ) {
			dataTypes.shift();
			if ( ct === undefined ) {
				ct = s.mimeType || jqXHR.getResponseHeader( "content-type" );
			}
		}

		// Check if we're dealing with a known content-type
		if ( ct ) {
			for ( type in contents ) {
				if ( contents[ type ] && contents[ type ].test( ct ) ) {
					dataTypes.unshift( type );
					break;
				}
			}
		}

		// Check to see if we have a response for the expected dataType
		if ( dataTypes[ 0 ] in responses ) {
			finalDataType = dataTypes[ 0 ];
		} else {
			// Try convertible dataTypes
			for ( type in responses ) {
				if ( !dataTypes[ 0 ] || s.converters[ type + " " + dataTypes[0] ] ) {
					finalDataType = type;
					break;
				}
				if ( !firstDataType ) {
					firstDataType = type;
				}
			}
			// Or just use first one
			finalDataType = finalDataType || firstDataType;
		}

		// If we found a dataType
		// We add the dataType to the list if needed
		// and return the corresponding response
		if ( finalDataType ) {
			if ( finalDataType !== dataTypes[ 0 ] ) {
				dataTypes.unshift( finalDataType );
			}
			return responses[ finalDataType ];
		}
	}

// Chain conversions given the request and the original response
	function ajaxConvert( s, response ) {

		var conv, conv2, current, tmp,
		// Work with a copy of dataTypes in case we need to modify it for conversion
			dataTypes = s.dataTypes.slice(),
			prev = dataTypes[ 0 ],
			converters = {},
			i = 0;

		// Apply the dataFilter if provided
		if ( s.dataFilter ) {
			response = s.dataFilter( response, s.dataType );
		}

		// Create converters map with lowercased keys
		if ( dataTypes[ 1 ] ) {
			for ( conv in s.converters ) {
				converters[ conv.toLowerCase() ] = s.converters[ conv ];
			}
		}

		// Convert to each sequential dataType, tolerating list modification
		for ( ; (current = dataTypes[++i]); ) {

			// There's only work to do if current dataType is non-auto
			if ( current !== "*" ) {

				// Convert response if prev dataType is non-auto and differs from current
				if ( prev !== "*" && prev !== current ) {

					// Seek a direct converter
					conv = converters[ prev + " " + current ] || converters[ "* " + current ];

					// If none found, seek a pair
					if ( !conv ) {
						for ( conv2 in converters ) {

							// If conv2 outputs current
							tmp = conv2.split(" ");
							if ( tmp[ 1 ] === current ) {

								// If prev can be converted to accepted input
								conv = converters[ prev + " " + tmp[ 0 ] ] ||
									converters[ "* " + tmp[ 0 ] ];
								if ( conv ) {
									// Condense equivalence converters
									if ( conv === true ) {
										conv = converters[ conv2 ];

										// Otherwise, insert the intermediate dataType
									} else if ( converters[ conv2 ] !== true ) {
										current = tmp[ 0 ];
										dataTypes.splice( i--, 0, current );
									}

									break;
								}
							}
						}
					}

					// Apply converter (if not an equivalence)
					if ( conv !== true ) {

						// Unless errors are allowed to bubble, catch and return them
						if ( conv && s["throws"] ) {
							response = conv( response );
						} else {
							try {
								response = conv( response );
							} catch ( e ) {
								return { state: "parsererror", error: conv ? e : "No conversion from " + prev + " to " + current };
							}
						}
					}
				}

				// Update prev for next iteration
				prev = current;
			}
		}

		return { state: "success", data: response };
	}
	var oldCallbacks = [],
		rquestion = /\?/,
		rjsonp = /(=)\?(?=&|$)|\?\?/,
		nonce = jQuery.now();

// Default jsonp settings
	jQuery.ajaxSetup({
		jsonp: "callback",
		jsonpCallback: function() {
			var callback = oldCallbacks.pop() || ( jQuery.expando + "_" + ( nonce++ ) );
			this[ callback ] = true;
			return callback;
		}
	});

// Detect, normalize options and install callbacks for jsonp requests
	jQuery.ajaxPrefilter( "json jsonp", function( s, originalSettings, jqXHR ) {

		var callbackName, overwritten, responseContainer,
			data = s.data,
			url = s.url,
			hasCallback = s.jsonp !== false,
			replaceInUrl = hasCallback && rjsonp.test( url ),
			replaceInData = hasCallback && !replaceInUrl && typeof data === "string" &&
				!( s.contentType || "" ).indexOf("application/x-www-form-urlencoded") &&
				rjsonp.test( data );

		// Handle iff the expected data type is "jsonp" or we have a parameter to set
		if ( s.dataTypes[ 0 ] === "jsonp" || replaceInUrl || replaceInData ) {

			// Get callback name, remembering preexisting value associated with it
			callbackName = s.jsonpCallback = jQuery.isFunction( s.jsonpCallback ) ?
				s.jsonpCallback() :
				s.jsonpCallback;
			overwritten = window[ callbackName ];

			// Insert callback into url or form data
			if ( replaceInUrl ) {
				s.url = url.replace( rjsonp, "$1" + callbackName );
			} else if ( replaceInData ) {
				s.data = data.replace( rjsonp, "$1" + callbackName );
			} else if ( hasCallback ) {
				s.url += ( rquestion.test( url ) ? "&" : "?" ) + s.jsonp + "=" + callbackName;
			}

			// Use data converter to retrieve json after script execution
			s.converters["script json"] = function() {
				if ( !responseContainer ) {
					jQuery.error( callbackName + " was not called" );
				}
				return responseContainer[ 0 ];
			};

			// force json dataType
			s.dataTypes[ 0 ] = "json";

			// Install callback
			window[ callbackName ] = function() {
				responseContainer = arguments;
			};

			// Clean-up function (fires after converters)
			jqXHR.always(function() {
				// Restore preexisting value
				window[ callbackName ] = overwritten;

				// Save back as free
				if ( s[ callbackName ] ) {
					// make sure that re-using the options doesn't screw things around
					s.jsonpCallback = originalSettings.jsonpCallback;

					// save the callback name for future use
					oldCallbacks.push( callbackName );
				}

				// Call if it was a function and we have a response
				if ( responseContainer && jQuery.isFunction( overwritten ) ) {
					overwritten( responseContainer[ 0 ] );
				}

				responseContainer = overwritten = undefined;
			});

			// Delegate to script
			return "script";
		}
	});
// Install script dataType
	jQuery.ajaxSetup({
		accepts: {
			script: "text/javascript, application/javascript, application/ecmascript, application/x-ecmascript"
		},
		contents: {
			script: /javascript|ecmascript/
		},
		converters: {
			"text script": function( text ) {
				jQuery.globalEval( text );
				return text;
			}
		}
	});

// Handle cache's special case and global
	jQuery.ajaxPrefilter( "script", function( s ) {
		if ( s.cache === undefined ) {
			s.cache = false;
		}
		if ( s.crossDomain ) {
			s.type = "GET";
			s.global = false;
		}
	});

// Bind script tag hack transport
	jQuery.ajaxTransport( "script", function(s) {

		// This transport only deals with cross domain requests
		if ( s.crossDomain ) {

			var script,
				head = document.head || document.getElementsByTagName( "head" )[0] || document.documentElement;

			return {

				send: function( _, callback ) {

					script = document.createElement( "script" );

					script.async = "async";

					if ( s.scriptCharset ) {
						script.charset = s.scriptCharset;
					}

					script.src = s.url;

					// Attach handlers for all browsers
					script.onload = script.onreadystatechange = function( _, isAbort ) {

						if ( isAbort || !script.readyState || /loaded|complete/.test( script.readyState ) ) {

							// Handle memory leak in IE
							script.onload = script.onreadystatechange = null;

							// Remove the script
							if ( head && script.parentNode ) {
								head.removeChild( script );
							}

							// Dereference the script
							script = undefined;

							// Callback if not abort
							if ( !isAbort ) {
								callback( 200, "success" );
							}
						}
					};
					// Use insertBefore instead of appendChild  to circumvent an IE6 bug.
					// This arises when a base node is used (#2709 and #4378).
					head.insertBefore( script, head.firstChild );
				},

				abort: function() {
					if ( script ) {
						script.onload( 0, 1 );
					}
				}
			};
		}
	});
	var xhrCallbacks,
	// #5280: Internet Explorer will keep connections alive if we don't abort on unload
		xhrOnUnloadAbort = window.ActiveXObject ? function() {
			// Abort all pending requests
			for ( var key in xhrCallbacks ) {
				xhrCallbacks[ key ]( 0, 1 );
			}
		} : false,
		xhrId = 0;

// Functions to create xhrs
	function createStandardXHR() {
		try {
			return new window.XMLHttpRequest();
		} catch( e ) {}
	}

	function createActiveXHR() {
		try {
			return new window.ActiveXObject( "Microsoft.XMLHTTP" );
		} catch( e ) {}
	}

// Create the request object
// (This is still attached to ajaxSettings for backward compatibility)
	jQuery.ajaxSettings.xhr = window.ActiveXObject ?
		/* Microsoft failed to properly
		 * implement the XMLHttpRequest in IE7 (can't request local files),
		 * so we use the ActiveXObject when it is available
		 * Additionally XMLHttpRequest can be disabled in IE7/IE8 so
		 * we need a fallback.
		 */
		function() {
			return !this.isLocal && createStandardXHR() || createActiveXHR();
		} :
		// For all other browsers, use the standard XMLHttpRequest object
		createStandardXHR;

// Determine support properties
	(function( xhr ) {
		jQuery.extend( jQuery.support, {
			ajax: !!xhr,
			cors: !!xhr && ( "withCredentials" in xhr )
		});
	})( jQuery.ajaxSettings.xhr() );

// Create transport if the browser can provide an xhr
	if ( jQuery.support.ajax ) {

		jQuery.ajaxTransport(function( s ) {
			// Cross domain only allowed if supported through XMLHttpRequest
			if ( !s.crossDomain || jQuery.support.cors ) {

				var callback;

				return {
					send: function( headers, complete ) {

						// Get a new xhr
						var handle, i,
							xhr = s.xhr();

						// Open the socket
						// Passing null username, generates a login popup on Opera (#2865)
						if ( s.username ) {
							xhr.open( s.type, s.url, s.async, s.username, s.password );
						} else {
							xhr.open( s.type, s.url, s.async );
						}

						// Apply custom fields if provided
						if ( s.xhrFields ) {
							for ( i in s.xhrFields ) {
								xhr[ i ] = s.xhrFields[ i ];
							}
						}

						// Override mime type if needed
						if ( s.mimeType && xhr.overrideMimeType ) {
							xhr.overrideMimeType( s.mimeType );
						}

						// X-Requested-With header
						// For cross-domain requests, seeing as conditions for a preflight are
						// akin to a jigsaw puzzle, we simply never set it to be sure.
						// (it can always be set on a per-request basis or even using ajaxSetup)
						// For same-domain requests, won't change header if already provided.
						if ( !s.crossDomain && !headers["X-Requested-With"] ) {
							headers[ "X-Requested-With" ] = "XMLHttpRequest";
						}

						// Need an extra try/catch for cross domain requests in Firefox 3
						try {
							for ( i in headers ) {
								xhr.setRequestHeader( i, headers[ i ] );
							}
						} catch( _ ) {}

						// Do send the request
						// This may raise an exception which is actually
						// handled in jQuery.ajax (so no try/catch here)
						xhr.send( ( s.hasContent && s.data ) || null );

						// Listener
						callback = function( _, isAbort ) {

							var status,
								statusText,
								responseHeaders,
								responses,
								xml;

							// Firefox throws exceptions when accessing properties
							// of an xhr when a network error occurred
							// http://helpful.knobs-dials.com/index.php/Component_returned_failure_code:_0x80040111_(NS_ERROR_NOT_AVAILABLE)
							try {

								// Was never called and is aborted or complete
								if ( callback && ( isAbort || xhr.readyState === 4 ) ) {

									// Only called once
									callback = undefined;

									// Do not keep as active anymore
									if ( handle ) {
										xhr.onreadystatechange = jQuery.noop;
										if ( xhrOnUnloadAbort ) {
											delete xhrCallbacks[ handle ];
										}
									}

									// If it's an abort
									if ( isAbort ) {
										// Abort it manually if needed
										if ( xhr.readyState !== 4 ) {
											xhr.abort();
										}
									} else {
										status = xhr.status;
										responseHeaders = xhr.getAllResponseHeaders();
										responses = {};
										xml = xhr.responseXML;

										// Construct response list
										if ( xml && xml.documentElement /* #4958 */ ) {
											responses.xml = xml;
										}

										// When requesting binary data, IE6-9 will throw an exception
										// on any attempt to access responseText (#11426)
										try {
											responses.text = xhr.responseText;
										} catch( e ) {
										}

										// Firefox throws an exception when accessing
										// statusText for faulty cross-domain requests
										try {
											statusText = xhr.statusText;
										} catch( e ) {
											// We normalize with Webkit giving an empty statusText
											statusText = "";
										}

										// Filter status for non standard behaviors

										// If the request is local and we have data: assume a success
										// (success with no data won't get notified, that's the best we
										// can do given current implementations)
										if ( !status && s.isLocal && !s.crossDomain ) {
											status = responses.text ? 200 : 404;
											// IE - #1450: sometimes returns 1223 when it should be 204
										} else if ( status === 1223 ) {
											status = 204;
										}
									}
								}
							} catch( firefoxAccessException ) {
								if ( !isAbort ) {
									complete( -1, firefoxAccessException );
								}
							}

							// Call complete if needed
							if ( responses ) {
								complete( status, statusText, responses, responseHeaders );
							}
						};

						if ( !s.async ) {
							// if we're in sync mode we fire the callback
							callback();
						} else if ( xhr.readyState === 4 ) {
							// (IE6 & IE7) if it's in cache and has been
							// retrieved directly we need to fire the callback
							setTimeout( callback, 0 );
						} else {
							handle = ++xhrId;
							if ( xhrOnUnloadAbort ) {
								// Create the active xhrs callbacks list if needed
								// and attach the unload handler
								if ( !xhrCallbacks ) {
									xhrCallbacks = {};
									jQuery( window ).unload( xhrOnUnloadAbort );
								}
								// Add to list of active xhrs callbacks
								xhrCallbacks[ handle ] = callback;
							}
							xhr.onreadystatechange = callback;
						}
					},

					abort: function() {
						if ( callback ) {
							callback(0,1);
						}
					}
				};
			}
		});
	}
	var fxNow, timerId,
		rfxtypes = /^(?:toggle|show|hide)$/,
		rfxnum = new RegExp( "^(?:([-+])=|)(" + core_pnum + ")([a-z%]*)$", "i" ),
		rrun = /queueHooks$/,
		animationPrefilters = [ defaultPrefilter ],
		tweeners = {
			"*": [function( prop, value ) {
				var end, unit,
					tween = this.createTween( prop, value ),
					parts = rfxnum.exec( value ),
					target = tween.cur(),
					start = +target || 0,
					scale = 1,
					maxIterations = 20;

				if ( parts ) {
					end = +parts[2];
					unit = parts[3] || ( jQuery.cssNumber[ prop ] ? "" : "px" );

					// We need to compute starting value
					if ( unit !== "px" && start ) {
						// Iteratively approximate from a nonzero starting point
						// Prefer the current property, because this process will be trivial if it uses the same units
						// Fallback to end or a simple constant
						start = jQuery.css( tween.elem, prop, true ) || end || 1;

						do {
							// If previous iteration zeroed out, double until we get *something*
							// Use a string for doubling factor so we don't accidentally see scale as unchanged below
							scale = scale || ".5";

							// Adjust and apply
							start = start / scale;
							jQuery.style( tween.elem, prop, start + unit );

							// Update scale, tolerating zero or NaN from tween.cur()
							// And breaking the loop if scale is unchanged or perfect, or if we've just had enough
						} while ( scale !== (scale = tween.cur() / target) && scale !== 1 && --maxIterations );
					}

					tween.unit = unit;
					tween.start = start;
					// If a +=/-= token was provided, we're doing a relative animation
					tween.end = parts[1] ? start + ( parts[1] + 1 ) * end : end;
				}
				return tween;
			}]
		};

// Animations created synchronously will run synchronously
	function createFxNow() {
		setTimeout(function() {
			fxNow = undefined;
		}, 0 );
		return ( fxNow = jQuery.now() );
	}

	function createTweens( animation, props ) {
		jQuery.each( props, function( prop, value ) {
			var collection = ( tweeners[ prop ] || [] ).concat( tweeners[ "*" ] ),
				index = 0,
				length = collection.length;
			for ( ; index < length; index++ ) {
				if ( collection[ index ].call( animation, prop, value ) ) {

					// we're done with this property
					return;
				}
			}
		});
	}

	function Animation( elem, properties, options ) {
		var result,
			index = 0,
			tweenerIndex = 0,
			length = animationPrefilters.length,
			deferred = jQuery.Deferred().always( function() {
				// don't match elem in the :animated selector
				delete tick.elem;
			}),
			tick = function() {
				var currentTime = fxNow || createFxNow(),
					remaining = Math.max( 0, animation.startTime + animation.duration - currentTime ),
				// archaic crash bug won't allow us to use 1 - ( 0.5 || 0 ) (#12497)
					temp = remaining / animation.duration || 0,
					percent = 1 - temp,
					index = 0,
					length = animation.tweens.length;

				for ( ; index < length ; index++ ) {
					animation.tweens[ index ].run( percent );
				}

				deferred.notifyWith( elem, [ animation, percent, remaining ]);

				if ( percent < 1 && length ) {
					return remaining;
				} else {
					deferred.resolveWith( elem, [ animation ] );
					return false;
				}
			},
			animation = deferred.promise({
				elem: elem,
				props: jQuery.extend( {}, properties ),
				opts: jQuery.extend( true, { specialEasing: {} }, options ),
				originalProperties: properties,
				originalOptions: options,
				startTime: fxNow || createFxNow(),
				duration: options.duration,
				tweens: [],
				createTween: function( prop, end, easing ) {
					var tween = jQuery.Tween( elem, animation.opts, prop, end,
						animation.opts.specialEasing[ prop ] || animation.opts.easing );
					animation.tweens.push( tween );
					return tween;
				},
				stop: function( gotoEnd ) {
					var index = 0,
					// if we are going to the end, we want to run all the tweens
					// otherwise we skip this part
						length = gotoEnd ? animation.tweens.length : 0;

					for ( ; index < length ; index++ ) {
						animation.tweens[ index ].run( 1 );
					}

					// resolve when we played the last frame
					// otherwise, reject
					if ( gotoEnd ) {
						deferred.resolveWith( elem, [ animation, gotoEnd ] );
					} else {
						deferred.rejectWith( elem, [ animation, gotoEnd ] );
					}
					return this;
				}
			}),
			props = animation.props;

		propFilter( props, animation.opts.specialEasing );

		for ( ; index < length ; index++ ) {
			result = animationPrefilters[ index ].call( animation, elem, props, animation.opts );
			if ( result ) {
				return result;
			}
		}

		createTweens( animation, props );

		if ( jQuery.isFunction( animation.opts.start ) ) {
			animation.opts.start.call( elem, animation );
		}

		jQuery.fx.timer(
			jQuery.extend( tick, {
				anim: animation,
				queue: animation.opts.queue,
				elem: elem
			})
		);

		// attach callbacks from options
		return animation.progress( animation.opts.progress )
			.done( animation.opts.done, animation.opts.complete )
			.fail( animation.opts.fail )
			.always( animation.opts.always );
	}

	function propFilter( props, specialEasing ) {
		var index, name, easing, value, hooks;

		// camelCase, specialEasing and expand cssHook pass
		for ( index in props ) {
			name = jQuery.camelCase( index );
			easing = specialEasing[ name ];
			value = props[ index ];
			if ( jQuery.isArray( value ) ) {
				easing = value[ 1 ];
				value = props[ index ] = value[ 0 ];
			}

			if ( index !== name ) {
				props[ name ] = value;
				delete props[ index ];
			}

			hooks = jQuery.cssHooks[ name ];
			if ( hooks && "expand" in hooks ) {
				value = hooks.expand( value );
				delete props[ name ];

				// not quite $.extend, this wont overwrite keys already present.
				// also - reusing 'index' from above because we have the correct "name"
				for ( index in value ) {
					if ( !( index in props ) ) {
						props[ index ] = value[ index ];
						specialEasing[ index ] = easing;
					}
				}
			} else {
				specialEasing[ name ] = easing;
			}
		}
	}

	jQuery.Animation = jQuery.extend( Animation, {

		tweener: function( props, callback ) {
			if ( jQuery.isFunction( props ) ) {
				callback = props;
				props = [ "*" ];
			} else {
				props = props.split(" ");
			}

			var prop,
				index = 0,
				length = props.length;

			for ( ; index < length ; index++ ) {
				prop = props[ index ];
				tweeners[ prop ] = tweeners[ prop ] || [];
				tweeners[ prop ].unshift( callback );
			}
		},

		prefilter: function( callback, prepend ) {
			if ( prepend ) {
				animationPrefilters.unshift( callback );
			} else {
				animationPrefilters.push( callback );
			}
		}
	});

	function defaultPrefilter( elem, props, opts ) {
		var index, prop, value, length, dataShow, toggle, tween, hooks, oldfire,
			anim = this,
			style = elem.style,
			orig = {},
			handled = [],
			hidden = elem.nodeType && isHidden( elem );

		// handle queue: false promises
		if ( !opts.queue ) {
			hooks = jQuery._queueHooks( elem, "fx" );
			if ( hooks.unqueued == null ) {
				hooks.unqueued = 0;
				oldfire = hooks.empty.fire;
				hooks.empty.fire = function() {
					if ( !hooks.unqueued ) {
						oldfire();
					}
				};
			}
			hooks.unqueued++;

			anim.always(function() {
				// doing this makes sure that the complete handler will be called
				// before this completes
				anim.always(function() {
					hooks.unqueued--;
					if ( !jQuery.queue( elem, "fx" ).length ) {
						hooks.empty.fire();
					}
				});
			});
		}

		// height/width overflow pass
		if ( elem.nodeType === 1 && ( "height" in props || "width" in props ) ) {
			// Make sure that nothing sneaks out
			// Record all 3 overflow attributes because IE does not
			// change the overflow attribute when overflowX and
			// overflowY are set to the same value
			opts.overflow = [ style.overflow, style.overflowX, style.overflowY ];

			// Set display property to inline-block for height/width
			// animations on inline elements that are having width/height animated
			if ( jQuery.css( elem, "display" ) === "inline" &&
				jQuery.css( elem, "float" ) === "none" ) {

				// inline-level elements accept inline-block;
				// block-level elements need to be inline with layout
				if ( !jQuery.support.inlineBlockNeedsLayout || css_defaultDisplay( elem.nodeName ) === "inline" ) {
					style.display = "inline-block";

				} else {
					style.zoom = 1;
				}
			}
		}

		if ( opts.overflow ) {
			style.overflow = "hidden";
			if ( !jQuery.support.shrinkWrapBlocks ) {
				anim.done(function() {
					style.overflow = opts.overflow[ 0 ];
					style.overflowX = opts.overflow[ 1 ];
					style.overflowY = opts.overflow[ 2 ];
				});
			}
		}


		// show/hide pass
		for ( index in props ) {
			value = props[ index ];
			if ( rfxtypes.exec( value ) ) {
				delete props[ index ];
				toggle = toggle || value === "toggle";
				if ( value === ( hidden ? "hide" : "show" ) ) {
					continue;
				}
				handled.push( index );
			}
		}

		length = handled.length;
		if ( length ) {
			dataShow = jQuery._data( elem, "fxshow" ) || jQuery._data( elem, "fxshow", {} );
			if ( "hidden" in dataShow ) {
				hidden = dataShow.hidden;
			}

			// store state if its toggle - enables .stop().toggle() to "reverse"
			if ( toggle ) {
				dataShow.hidden = !hidden;
			}
			if ( hidden ) {
				jQuery( elem ).show();
			} else {
				anim.done(function() {
					jQuery( elem ).hide();
				});
			}
			anim.done(function() {
				var prop;
				jQuery.removeData( elem, "fxshow", true );
				for ( prop in orig ) {
					jQuery.style( elem, prop, orig[ prop ] );
				}
			});
			for ( index = 0 ; index < length ; index++ ) {
				prop = handled[ index ];
				tween = anim.createTween( prop, hidden ? dataShow[ prop ] : 0 );
				orig[ prop ] = dataShow[ prop ] || jQuery.style( elem, prop );

				if ( !( prop in dataShow ) ) {
					dataShow[ prop ] = tween.start;
					if ( hidden ) {
						tween.end = tween.start;
						tween.start = prop === "width" || prop === "height" ? 1 : 0;
					}
				}
			}
		}
	}

	function Tween( elem, options, prop, end, easing ) {
		return new Tween.prototype.init( elem, options, prop, end, easing );
	}
	jQuery.Tween = Tween;

	Tween.prototype = {
		constructor: Tween,
		init: function( elem, options, prop, end, easing, unit ) {
			this.elem = elem;
			this.prop = prop;
			this.easing = easing || "swing";
			this.options = options;
			this.start = this.now = this.cur();
			this.end = end;
			this.unit = unit || ( jQuery.cssNumber[ prop ] ? "" : "px" );
		},
		cur: function() {
			var hooks = Tween.propHooks[ this.prop ];

			return hooks && hooks.get ?
				hooks.get( this ) :
				Tween.propHooks._default.get( this );
		},
		run: function( percent ) {
			var eased,
				hooks = Tween.propHooks[ this.prop ];

			if ( this.options.duration ) {
				this.pos = eased = jQuery.easing[ this.easing ](
					percent, this.options.duration * percent, 0, 1, this.options.duration
				);
			} else {
				this.pos = eased = percent;
			}
			this.now = ( this.end - this.start ) * eased + this.start;

			if ( this.options.step ) {
				this.options.step.call( this.elem, this.now, this );
			}

			if ( hooks && hooks.set ) {
				hooks.set( this );
			} else {
				Tween.propHooks._default.set( this );
			}
			return this;
		}
	};

	Tween.prototype.init.prototype = Tween.prototype;

	Tween.propHooks = {
		_default: {
			get: function( tween ) {
				var result;

				if ( tween.elem[ tween.prop ] != null &&
					(!tween.elem.style || tween.elem.style[ tween.prop ] == null) ) {
					return tween.elem[ tween.prop ];
				}

				// passing any value as a 4th parameter to .css will automatically
				// attempt a parseFloat and fallback to a string if the parse fails
				// so, simple values such as "10px" are parsed to Float.
				// complex values such as "rotate(1rad)" are returned as is.
				result = jQuery.css( tween.elem, tween.prop, false, "" );
				// Empty strings, null, undefined and "auto" are converted to 0.
				return !result || result === "auto" ? 0 : result;
			},
			set: function( tween ) {
				// use step hook for back compat - use cssHook if its there - use .style if its
				// available and use plain properties where available
				if ( jQuery.fx.step[ tween.prop ] ) {
					jQuery.fx.step[ tween.prop ]( tween );
				} else if ( tween.elem.style && ( tween.elem.style[ jQuery.cssProps[ tween.prop ] ] != null || jQuery.cssHooks[ tween.prop ] ) ) {
					jQuery.style( tween.elem, tween.prop, tween.now + tween.unit );
				} else {
					tween.elem[ tween.prop ] = tween.now;
				}
			}
		}
	};

// Remove in 2.0 - this supports IE8's panic based approach
// to setting things on disconnected nodes

	Tween.propHooks.scrollTop = Tween.propHooks.scrollLeft = {
		set: function( tween ) {
			if ( tween.elem.nodeType && tween.elem.parentNode ) {
				tween.elem[ tween.prop ] = tween.now;
			}
		}
	};

	jQuery.each([ "toggle", "show", "hide" ], function( i, name ) {
		var cssFn = jQuery.fn[ name ];
		jQuery.fn[ name ] = function( speed, easing, callback ) {
			return speed == null || typeof speed === "boolean" ||
				// special check for .toggle( handler, handler, ... )
				( !i && jQuery.isFunction( speed ) && jQuery.isFunction( easing ) ) ?
				cssFn.apply( this, arguments ) :
				this.animate( genFx( name, true ), speed, easing, callback );
		};
	});

	jQuery.fn.extend({
		fadeTo: function( speed, to, easing, callback ) {

			// show any hidden elements after setting opacity to 0
			return this.filter( isHidden ).css( "opacity", 0 ).show()

				// animate to the value specified
				.end().animate({ opacity: to }, speed, easing, callback );
		},
		animate: function( prop, speed, easing, callback ) {
			var empty = jQuery.isEmptyObject( prop ),
				optall = jQuery.speed( speed, easing, callback ),
				doAnimation = function() {
					// Operate on a copy of prop so per-property easing won't be lost
					var anim = Animation( this, jQuery.extend( {}, prop ), optall );

					// Empty animations resolve immediately
					if ( empty ) {
						anim.stop( true );
					}
				};

			return empty || optall.queue === false ?
				this.each( doAnimation ) :
				this.queue( optall.queue, doAnimation );
		},
		stop: function( type, clearQueue, gotoEnd ) {
			var stopQueue = function( hooks ) {
				var stop = hooks.stop;
				delete hooks.stop;
				stop( gotoEnd );
			};

			if ( typeof type !== "string" ) {
				gotoEnd = clearQueue;
				clearQueue = type;
				type = undefined;
			}
			if ( clearQueue && type !== false ) {
				this.queue( type || "fx", [] );
			}

			return this.each(function() {
				var dequeue = true,
					index = type != null && type + "queueHooks",
					timers = jQuery.timers,
					data = jQuery._data( this );

				if ( index ) {
					if ( data[ index ] && data[ index ].stop ) {
						stopQueue( data[ index ] );
					}
				} else {
					for ( index in data ) {
						if ( data[ index ] && data[ index ].stop && rrun.test( index ) ) {
							stopQueue( data[ index ] );
						}
					}
				}

				for ( index = timers.length; index--; ) {
					if ( timers[ index ].elem === this && (type == null || timers[ index ].queue === type) ) {
						timers[ index ].anim.stop( gotoEnd );
						dequeue = false;
						timers.splice( index, 1 );
					}
				}

				// start the next in the queue if the last step wasn't forced
				// timers currently will call their complete callbacks, which will dequeue
				// but only if they were gotoEnd
				if ( dequeue || !gotoEnd ) {
					jQuery.dequeue( this, type );
				}
			});
		}
	});

// Generate parameters to create a standard animation
	function genFx( type, includeWidth ) {
		var which,
			attrs = { height: type },
			i = 0;

		// if we include width, step value is 1 to do all cssExpand values,
		// if we don't include width, step value is 2 to skip over Left and Right
		includeWidth = includeWidth? 1 : 0;
		for( ; i < 4 ; i += 2 - includeWidth ) {
			which = cssExpand[ i ];
			attrs[ "margin" + which ] = attrs[ "padding" + which ] = type;
		}

		if ( includeWidth ) {
			attrs.opacity = attrs.width = type;
		}

		return attrs;
	}

// Generate shortcuts for custom animations
	jQuery.each({
		slideDown: genFx("show"),
		slideUp: genFx("hide"),
		slideToggle: genFx("toggle"),
		fadeIn: { opacity: "show" },
		fadeOut: { opacity: "hide" },
		fadeToggle: { opacity: "toggle" }
	}, function( name, props ) {
		jQuery.fn[ name ] = function( speed, easing, callback ) {
			return this.animate( props, speed, easing, callback );
		};
	});

	jQuery.speed = function( speed, easing, fn ) {
		var opt = speed && typeof speed === "object" ? jQuery.extend( {}, speed ) : {
			complete: fn || !fn && easing ||
				jQuery.isFunction( speed ) && speed,
			duration: speed,
			easing: fn && easing || easing && !jQuery.isFunction( easing ) && easing
		};

		opt.duration = jQuery.fx.off ? 0 : typeof opt.duration === "number" ? opt.duration :
			opt.duration in jQuery.fx.speeds ? jQuery.fx.speeds[ opt.duration ] : jQuery.fx.speeds._default;

		// normalize opt.queue - true/undefined/null -> "fx"
		if ( opt.queue == null || opt.queue === true ) {
			opt.queue = "fx";
		}

		// Queueing
		opt.old = opt.complete;

		opt.complete = function() {
			if ( jQuery.isFunction( opt.old ) ) {
				opt.old.call( this );
			}

			if ( opt.queue ) {
				jQuery.dequeue( this, opt.queue );
			}
		};

		return opt;
	};

	jQuery.easing = {
		linear: function( p ) {
			return p;
		},
		swing: function( p ) {
			return 0.5 - Math.cos( p*Math.PI ) / 2;
		}
	};

	jQuery.timers = [];
	jQuery.fx = Tween.prototype.init;
	jQuery.fx.tick = function() {
		var timer,
			timers = jQuery.timers,
			i = 0;

		fxNow = jQuery.now();

		for ( ; i < timers.length; i++ ) {
			timer = timers[ i ];
			// Checks the timer has not already been removed
			if ( !timer() && timers[ i ] === timer ) {
				timers.splice( i--, 1 );
			}
		}

		if ( !timers.length ) {
			jQuery.fx.stop();
		}
		fxNow = undefined;
	};

	jQuery.fx.timer = function( timer ) {
		if ( timer() && jQuery.timers.push( timer ) && !timerId ) {
			timerId = setInterval( jQuery.fx.tick, jQuery.fx.interval );
		}
	};

	jQuery.fx.interval = 13;

	jQuery.fx.stop = function() {
		clearInterval( timerId );
		timerId = null;
	};

	jQuery.fx.speeds = {
		slow: 600,
		fast: 200,
		// Default speed
		_default: 400
	};

// Back Compat <1.8 extension point
	jQuery.fx.step = {};

	if ( jQuery.expr && jQuery.expr.filters ) {
		jQuery.expr.filters.animated = function( elem ) {
			return jQuery.grep(jQuery.timers, function( fn ) {
				return elem === fn.elem;
			}).length;
		};
	}
	var rroot = /^(?:body|html)$/i;

	jQuery.fn.offset = function( options ) {
		if ( arguments.length ) {
			return options === undefined ?
				this :
				this.each(function( i ) {
					jQuery.offset.setOffset( this, options, i );
				});
		}

		var docElem, body, win, clientTop, clientLeft, scrollTop, scrollLeft,
			box = { top: 0, left: 0 },
			elem = this[ 0 ],
			doc = elem && elem.ownerDocument;

		if ( !doc ) {
			return;
		}

		if ( (body = doc.body) === elem ) {
			return jQuery.offset.bodyOffset( elem );
		}

		docElem = doc.documentElement;

		// Make sure it's not a disconnected DOM node
		if ( !jQuery.contains( docElem, elem ) ) {
			return box;
		}

		// If we don't have gBCR, just use 0,0 rather than error
		// BlackBerry 5, iOS 3 (original iPhone)
		if ( typeof elem.getBoundingClientRect !== "undefined" ) {
			box = elem.getBoundingClientRect();
		}
		win = getWindow( doc );
		clientTop  = docElem.clientTop  || body.clientTop  || 0;
		clientLeft = docElem.clientLeft || body.clientLeft || 0;
		scrollTop  = win.pageYOffset || docElem.scrollTop;
		scrollLeft = win.pageXOffset || docElem.scrollLeft;
		return {
			top: box.top  + scrollTop  - clientTop,
			left: box.left + scrollLeft - clientLeft
		};
	};

	jQuery.offset = {

		bodyOffset: function( body ) {
			var top = body.offsetTop,
				left = body.offsetLeft;

			if ( jQuery.support.doesNotIncludeMarginInBodyOffset ) {
				top  += parseFloat( jQuery.css(body, "marginTop") ) || 0;
				left += parseFloat( jQuery.css(body, "marginLeft") ) || 0;
			}

			return { top: top, left: left };
		},

		setOffset: function( elem, options, i ) {
			var position = jQuery.css( elem, "position" );

			// set position first, in-case top/left are set even on static elem
			if ( position === "static" ) {
				elem.style.position = "relative";
			}

			var curElem = jQuery( elem ),
				curOffset = curElem.offset(),
				curCSSTop = jQuery.css( elem, "top" ),
				curCSSLeft = jQuery.css( elem, "left" ),
				calculatePosition = ( position === "absolute" || position === "fixed" ) && jQuery.inArray("auto", [curCSSTop, curCSSLeft]) > -1,
				props = {}, curPosition = {}, curTop, curLeft;

			// need to be able to calculate position if either top or left is auto and position is either absolute or fixed
			if ( calculatePosition ) {
				curPosition = curElem.position();
				curTop = curPosition.top;
				curLeft = curPosition.left;
			} else {
				curTop = parseFloat( curCSSTop ) || 0;
				curLeft = parseFloat( curCSSLeft ) || 0;
			}

			if ( jQuery.isFunction( options ) ) {
				options = options.call( elem, i, curOffset );
			}

			if ( options.top != null ) {
				props.top = ( options.top - curOffset.top ) + curTop;
			}
			if ( options.left != null ) {
				props.left = ( options.left - curOffset.left ) + curLeft;
			}

			if ( "using" in options ) {
				options.using.call( elem, props );
			} else {
				curElem.css( props );
			}
		}
	};


	jQuery.fn.extend({

		position: function() {
			if ( !this[0] ) {
				return;
			}

			var elem = this[0],

			// Get *real* offsetParent
				offsetParent = this.offsetParent(),

			// Get correct offsets
				offset       = this.offset(),
				parentOffset = rroot.test(offsetParent[0].nodeName) ? { top: 0, left: 0 } : offsetParent.offset();

			// Subtract element margins
			// note: when an element has margin: auto the offsetLeft and marginLeft
			// are the same in Safari causing offset.left to incorrectly be 0
			offset.top  -= parseFloat( jQuery.css(elem, "marginTop") ) || 0;
			offset.left -= parseFloat( jQuery.css(elem, "marginLeft") ) || 0;

			// Add offsetParent borders
			parentOffset.top  += parseFloat( jQuery.css(offsetParent[0], "borderTopWidth") ) || 0;
			parentOffset.left += parseFloat( jQuery.css(offsetParent[0], "borderLeftWidth") ) || 0;

			// Subtract the two offsets
			return {
				top:  offset.top  - parentOffset.top,
				left: offset.left - parentOffset.left
			};
		},

		offsetParent: function() {
			return this.map(function() {
				var offsetParent = this.offsetParent || document.body;
				while ( offsetParent && (!rroot.test(offsetParent.nodeName) && jQuery.css(offsetParent, "position") === "static") ) {
					offsetParent = offsetParent.offsetParent;
				}
				return offsetParent || document.body;
			});
		}
	});


// Create scrollLeft and scrollTop methods
	jQuery.each( {scrollLeft: "pageXOffset", scrollTop: "pageYOffset"}, function( method, prop ) {
		var top = /Y/.test( prop );

		jQuery.fn[ method ] = function( val ) {
			return jQuery.access( this, function( elem, method, val ) {
				var win = getWindow( elem );

				if ( val === undefined ) {
					return win ? (prop in win) ? win[ prop ] :
						win.document.documentElement[ method ] :
						elem[ method ];
				}

				if ( win ) {
					win.scrollTo(
						!top ? val : jQuery( win ).scrollLeft(),
						top ? val : jQuery( win ).scrollTop()
					);

				} else {
					elem[ method ] = val;
				}
			}, method, val, arguments.length, null );
		};
	});

	function getWindow( elem ) {
		return jQuery.isWindow( elem ) ?
			elem :
			elem.nodeType === 9 ?
				elem.defaultView || elem.parentWindow :
				false;
	}
// Create innerHeight, innerWidth, height, width, outerHeight and outerWidth methods
	jQuery.each( { Height: "height", Width: "width" }, function( name, type ) {
		jQuery.each( { padding: "inner" + name, content: type, "": "outer" + name }, function( defaultExtra, funcName ) {
			// margin is only for outerHeight, outerWidth
			jQuery.fn[ funcName ] = function( margin, value ) {
				var chainable = arguments.length && ( defaultExtra || typeof margin !== "boolean" ),
					extra = defaultExtra || ( margin === true || value === true ? "margin" : "border" );

				return jQuery.access( this, function( elem, type, value ) {
					var doc;

					if ( jQuery.isWindow( elem ) ) {
						// As of 5/8/2012 this will yield incorrect results for Mobile Safari, but there
						// isn't a whole lot we can do. See pull request at this URL for discussion:
						// https://github.com/jquery/jquery/pull/764
						return elem.document.documentElement[ "client" + name ];
					}

					// Get document width or height
					if ( elem.nodeType === 9 ) {
						doc = elem.documentElement;

						// Either scroll[Width/Height] or offset[Width/Height] or client[Width/Height], whichever is greatest
						// unfortunately, this causes bug #3838 in IE6/8 only, but there is currently no good, small way to fix it.
						return Math.max(
							elem.body[ "scroll" + name ], doc[ "scroll" + name ],
							elem.body[ "offset" + name ], doc[ "offset" + name ],
							doc[ "client" + name ]
						);
					}

					return value === undefined ?
						// Get width or height on the element, requesting but not forcing parseFloat
						jQuery.css( elem, type, value, extra ) :

						// Set width or height on the element
						jQuery.style( elem, type, value, extra );
				}, type, chainable ? margin : undefined, chainable, null );
			};
		});
	});
// Expose jQuery to the global object
	window.jQuery = window.$ = jQuery;

// Expose jQuery as an AMD module, but only for AMD loaders that
// understand the issues with loading multiple versions of jQuery
// in a page that all might call define(). The loader will indicate
// they have special allowances for multiple jQuery versions by
// specifying define.amd.jQuery = true. Register as a named module,
// since jQuery can be concatenated with other files that may use define,
// but not use a proper concatenation script that understands anonymous
// AMD modules. A named AMD is safest and most robust way to register.
// Lowercase jquery is used because AMD module names are derived from
// file names, and jQuery is normally delivered in a lowercase file name.
// Do this after creating the global so that if an AMD module wants to call
// noConflict to hide this version of jQuery, it will work.
	if ( typeof define === "function" && define.amd && define.amd.jQuery ) {
		define( "jquery", [], function () { return jQuery; } );
	}

})( window );
/*!
 * Lo-Dash 1.0.0-rc.3 <http://lodash.com>
 * (c) 2012 John-David Dalton <http://allyoucanleet.com/>
 * Based on Underscore.js 1.4.3 <http://underscorejs.org>
 * (c) 2009-2012 Jeremy Ashkenas, DocumentCloud Inc.
 * Available under MIT license <http://lodash.com/license>
 */
;(function(window, undefined) {

	/** Detect free variable `exports` */
	var freeExports = typeof exports == 'object' && exports;

	/** Detect free variable `global` and use it as `window` */
	var freeGlobal = typeof global == 'object' && global;
	if (freeGlobal.global === freeGlobal) {
		window = freeGlobal;
	}

	/** Used for array and object method references */
	var arrayRef = [],
	// avoid a Closure Compiler bug by creatively creating an object
		objectRef = new function(){};

	/** Used to generate unique IDs */
	var idCounter = 0;

	/** Used internally to indicate various things */
	var indicatorObject = objectRef;

	/** Used by `cachedContains` as the default size when optimizations are enabled for large arrays */
	var largeArraySize = 30;

	/** Used to restore the original `_` reference in `noConflict` */
	var oldDash = window._;

	/** Used to detect template delimiter values that require a with-statement */
	var reComplexDelimiter = /[-?+=!~*%&^<>|{(\/]|\[\D|\b(?:delete|in|instanceof|new|typeof|void)\b/;

	/** Used to match HTML entities */
	var reEscapedHtml = /&(?:amp|lt|gt|quot|#x27);/g;

	/** Used to match empty string literals in compiled template source */
	var reEmptyStringLeading = /\b__p \+= '';/g,
		reEmptyStringMiddle = /\b(__p \+=) '' \+/g,
		reEmptyStringTrailing = /(__e\(.*?\)|\b__t\)) \+\n'';/g;

	/** Used to match regexp flags from their coerced string values */
	var reFlags = /\w*$/;

	/** Used to insert the data object variable into compiled template source */
	var reInsertVariable = /(?:__e|__t = )\(\s*(?![\d\s"']|this\.)/g;

	/** Used to detect if a method is native */
	var reNative = RegExp('^' +
		(objectRef.valueOf + '')
			.replace(/[.*+?^=!:${}()|[\]\/\\]/g, '\\$&')
			.replace(/valueOf|for [^\]]+/g, '.+?') + '$'
	);

	/**
	 * Used to match ES6 template delimiters
	 * http://people.mozilla.org/~jorendorff/es6-draft.html#sec-7.8.6
	 */
	var reEsTemplate = /\$\{((?:(?=\\?)\\?[\s\S])*?)}/g;

	/** Used to match "interpolate" template delimiters */
	var reInterpolate = /<%=([\s\S]+?)%>/g;

	/** Used to ensure capturing order of template delimiters */
	var reNoMatch = /($^)/;

	/** Used to match HTML characters */
	var reUnescapedHtml = /[&<>"']/g;

	/** Used to match unescaped characters in compiled string literals */
	var reUnescapedString = /['\n\r\t\u2028\u2029\\]/g;

	/** Used to fix the JScript [[DontEnum]] bug */
	var shadowed = [
		'constructor', 'hasOwnProperty', 'isPrototypeOf', 'propertyIsEnumerable',
		'toLocaleString', 'toString', 'valueOf'
	];

	/** Used to make template sourceURLs easier to identify */
	var templateCounter = 0;

	/** Native method shortcuts */
	var ceil = Math.ceil,
		concat = arrayRef.concat,
		floor = Math.floor,
		getPrototypeOf = reNative.test(getPrototypeOf = Object.getPrototypeOf) && getPrototypeOf,
		hasOwnProperty = objectRef.hasOwnProperty,
		push = arrayRef.push,
		propertyIsEnumerable = objectRef.propertyIsEnumerable,
		toString = objectRef.toString;

	/* Native method shortcuts for methods with the same name as other `lodash` methods */
	var nativeBind = reNative.test(nativeBind = slice.bind) && nativeBind,
		nativeIsArray = reNative.test(nativeIsArray = Array.isArray) && nativeIsArray,
		nativeIsFinite = window.isFinite,
		nativeIsNaN = window.isNaN,
		nativeKeys = reNative.test(nativeKeys = Object.keys) && nativeKeys,
		nativeMax = Math.max,
		nativeMin = Math.min,
		nativeRandom = Math.random;

	/** `Object#toString` result shortcuts */
	var argsClass = '[object Arguments]',
		arrayClass = '[object Array]',
		boolClass = '[object Boolean]',
		dateClass = '[object Date]',
		funcClass = '[object Function]',
		numberClass = '[object Number]',
		objectClass = '[object Object]',
		regexpClass = '[object RegExp]',
		stringClass = '[object String]';

	/** Detect various environments */
	var isIeOpera = !!window.attachEvent,
		isV8 = nativeBind && !/\n|true/.test(nativeBind + isIeOpera);

	/* Detect if `Function#bind` exists and is inferred to be fast (all but V8) */
	var isBindFast = nativeBind && !isV8;

	/* Detect if `Object.keys` exists and is inferred to be fast (IE, Opera, V8) */
	var isKeysFast = nativeKeys && (isIeOpera || isV8);

	/**
	 * Detect the JScript [[DontEnum]] bug:
	 *
	 * In IE < 9 an objects own properties, shadowing non-enumerable ones, are
	 * made non-enumerable as well.
	 */
	var hasDontEnumBug;

	/** Detect if own properties are iterated after inherited properties (IE < 9) */
	var iteratesOwnLast;

	/**
	 * Detect if `Array#shift` and `Array#splice` augment array-like objects
	 * incorrectly:
	 *
	 * Firefox < 10, IE compatibility mode, and IE < 9 have buggy Array `shift()`
	 * and `splice()` functions that fail to remove the last element, `value[0]`,
	 * of array-like objects even though the `length` property is set to `0`.
	 * The `shift()` method is buggy in IE 8 compatibility mode, while `splice()`
	 * is buggy regardless of mode in IE < 9 and buggy in compatibility mode in IE 9.
	 */
	var hasObjectSpliceBug = (hasObjectSpliceBug = { '0': 1, 'length': 1 },
		arrayRef.splice.call(hasObjectSpliceBug, 0, 1), hasObjectSpliceBug[0]);

	/** Detect if an `arguments` object's indexes are non-enumerable (IE < 9) */
	var nonEnumArgs = true;

	(function() {
		var props = [];
		function ctor() { this.x = 1; }
		ctor.prototype = { 'valueOf': 1, 'y': 1 };
		for (var prop in new ctor) { props.push(prop); }
		for (prop in arguments) { nonEnumArgs = !prop; }

		hasDontEnumBug = !/valueOf/.test(props);
		iteratesOwnLast = props[0] != 'x';
	}(1));

	/** Detect if `arguments` objects are `Object` objects (all but Opera < 10.5) */
	var argsAreObjects = arguments.constructor == Object;

	/** Detect if `arguments` objects [[Class]] is unresolvable (Firefox < 4, IE < 9) */
	var noArgsClass = !isArguments(arguments);

	/**
	 * Detect lack of support for accessing string characters by index:
	 *
	 * IE < 8 can't access characters by index and IE 8 can only access
	 * characters by index on string literals.
	 */
	var noCharByIndex = ('x'[0] + Object('x')[0]) != 'xx';

	/**
	 * Detect if a node's [[Class]] is unresolvable (IE < 9)
	 * and that the JS engine won't error when attempting to coerce an object to
	 * a string without a `toString` property value of `typeof` "function".
	 */
	try {
		var noNodeClass = ({ 'toString': 0 } + '', toString.call(document) == objectClass);
	} catch(e) { }

	/**
	 * Detect if sourceURL syntax is usable without erroring:
	 *
	 * The JS engine embedded in Adobe products will throw a syntax error when
	 * it encounters a single line comment beginning with the `@` symbol.
	 *
	 * The JS engine in Narwhal will generate the function `function anonymous(){//}`
	 * and throw a syntax error.
	 *
	 * Avoid comments beginning `@` symbols in IE because they are part of its
	 * non-standard conditional compilation support.
	 * http://msdn.microsoft.com/en-us/library/121hztk3(v=vs.94).aspx
	 */
	try {
		var useSourceURL = (Function('//@')(), !isIeOpera);
	} catch(e) { }

	/** Used to identify object classifications that `_.clone` supports */
	var cloneableClasses = {};
	cloneableClasses[funcClass] = false;
	cloneableClasses[argsClass] = cloneableClasses[arrayClass] =
		cloneableClasses[boolClass] = cloneableClasses[dateClass] =
			cloneableClasses[numberClass] = cloneableClasses[objectClass] =
				cloneableClasses[regexpClass] = cloneableClasses[stringClass] = true;

	/** Used to lookup a built-in constructor by [[Class]] */
	var ctorByClass = {};
	ctorByClass[arrayClass] = Array;
	ctorByClass[boolClass] = Boolean;
	ctorByClass[dateClass] = Date;
	ctorByClass[objectClass] = Object;
	ctorByClass[numberClass] = Number;
	ctorByClass[regexpClass] = RegExp;
	ctorByClass[stringClass] = String;

	/** Used to determine if values are of the language type Object */
	var objectTypes = {
		'boolean': false,
		'function': true,
		'object': true,
		'number': false,
		'string': false,
		'undefined': false
	};

	/** Used to escape characters for inclusion in compiled string literals */
	var stringEscapes = {
		'\\': '\\',
		"'": "'",
		'\n': 'n',
		'\r': 'r',
		'\t': 't',
		'\u2028': 'u2028',
		'\u2029': 'u2029'
	};

	/*--------------------------------------------------------------------------*/

	/**
	 * Creates a `lodash` object, that wraps the given `value`, to enable
	 * method chaining.
	 *
	 * The chainable wrapper functions are:
	 * `after`, `assign`, `bind`, `bindAll`, `bindKey`, `chain`, `compact`, `compose`,
	 * `concat`, `countBy`, `debounce`, `defaults`, `defer`, `delay`, `difference`,
	 * `filter`, `flatten`, `forEach`, `forIn`, `forOwn`, `functions`, `groupBy`,
	 * `initial`, `intersection`, `invert`, `invoke`, `keys`, `map`, `max`, `memoize`,
	 * `merge`, `min`, `object`, `omit`, `once`, `pairs`, `partial`, `pick`, `pluck`,
	 * `push`, `range`, `reject`, `rest`, `reverse`, `shuffle`, `slice`, `sort`,
	 * `sortBy`, `splice`, `tap`, `throttle`, `times`, `toArray`, `union`, `uniq`,
	 * `unshift`, `values`, `where`, `without`, `wrap`, and `zip`
	 *
	 * The non-chainable wrapper functions are:
	 * `clone`, `cloneDeep`, `contains`, `escape`, `every`, `find`, `has`, `identity`,
	 * `indexOf`, `isArguments`, `isArray`, `isBoolean`, `isDate`, `isElement`, `isEmpty`,
	 * `isEqual`, `isFinite`, `isFunction`, `isNaN`, `isNull`, `isNumber`, `isObject`,
	 * `isPlainObject`, `isRegExp`, `isString`, `isUndefined`, `join`, `lastIndexOf`,
	 * `mixin`, `noConflict`, `pop`, `random`, `reduce`, `reduceRight`, `result`,
	 * `shift`, `size`, `some`, `sortedIndex`, `template`, `unescape`, and `uniqueId`
	 *
	 * The wrapper functions `first` and `last` return wrapped values when `n` is
	 * passed, otherwise they return unwrapped values.
	 *
	 * @name _
	 * @constructor
	 * @category Chaining
	 * @param {Mixed} value The value to wrap in a `lodash` instance.
	 * @returns {Object} Returns a `lodash` instance.
	 */
	function lodash(value) {
		// exit early if already wrapped, even if wrapped by a different `lodash` constructor
		if (value && typeof value == 'object' && value.__wrapped__) {
			return value;
		}
		// allow invoking `lodash` without the `new` operator
		if (!(this instanceof lodash)) {
			return new lodash(value);
		}
		this.__wrapped__ = value;
	}

	/**
	 * By default, the template delimiters used by Lo-Dash are similar to those in
	 * embedded Ruby (ERB). Change the following template settings to use alternative
	 * delimiters.
	 *
	 * @static
	 * @memberOf _
	 * @type Object
	 */
	lodash.templateSettings = {

		/**
		 * Used to detect `data` property values to be HTML-escaped.
		 *
		 * @static
		 * @memberOf _.templateSettings
		 * @type RegExp
		 */
		'escape': /<%-([\s\S]+?)%>/g,

		/**
		 * Used to detect code to be evaluated.
		 *
		 * @static
		 * @memberOf _.templateSettings
		 * @type RegExp
		 */
		'evaluate': /<%([\s\S]+?)%>/g,

		/**
		 * Used to detect `data` property values to inject.
		 *
		 * @static
		 * @memberOf _.templateSettings
		 * @type RegExp
		 */
		'interpolate': reInterpolate,

		/**
		 * Used to reference the data object in the template text.
		 *
		 * @static
		 * @memberOf _.templateSettings
		 * @type String
		 */
		'variable': ''
	};

	/*--------------------------------------------------------------------------*/

	/**
	 * The template used to create iterator functions.
	 *
	 * @private
	 * @param {Obect} data The data object used to populate the text.
	 * @returns {String} Returns the interpolated text.
	 */
	var iteratorTemplate = template(
		// conditional strict mode
		"<% if (obj.useStrict) { %>'use strict';\n<% } %>" +

			// the `iteratee` may be reassigned by the `top` snippet
			'var index, iteratee = <%= firstArg %>, ' +
			// assign the `result` variable an initial value
			'result = <%= firstArg %>;\n' +
			// exit early if the first argument is falsey
			'if (!<%= firstArg %>) return result;\n' +
			// add code before the iteration branches
			'<%= top %>;\n' +

			// array-like iteration:
			'<% if (arrayLoop) { %>' +
			'var length = iteratee.length; index = -1;\n' +
			"if (typeof length == 'number') {" +

			// add support for accessing string characters by index if needed
			'  <% if (noCharByIndex) { %>\n' +
			'  if (isString(iteratee)) {\n' +
			"    iteratee = iteratee.split('')\n" +
			'  }' +
			'  <% } %>\n' +

			// iterate over the array-like value
			'  while (++index < length) {\n' +
			'    <%= arrayLoop %>\n' +
			'  }\n' +
			'}\n' +
			'else {' +

			// object iteration:
			// add support for iterating over `arguments` objects if needed
			'  <%  } else if (nonEnumArgs) { %>\n' +
			'  var length = iteratee.length; index = -1;\n' +
			'  if (length && isArguments(iteratee)) {\n' +
			'    while (++index < length) {\n' +
			"      index += '';\n" +
			'      <%= objectLoop %>\n' +
			'    }\n' +
			'  } else {' +
			'  <% } %>' +

			// Firefox < 3.6, Opera > 9.50 - Opera < 11.60, and Safari < 5.1
			// (if the prototype or a property on the prototype has been set)
			// incorrectly sets a function's `prototype` property [[Enumerable]]
			// value to `true`. Because of this Lo-Dash standardizes on skipping
			// the the `prototype` property of functions regardless of its
			// [[Enumerable]] value.
			'  <% if (!hasDontEnumBug) { %>\n' +
			"  var skipProto = typeof iteratee == 'function' && \n" +
			"    propertyIsEnumerable.call(iteratee, 'prototype');\n" +
			'  <% } %>' +

			// iterate own properties using `Object.keys` if it's fast
			'  <% if (isKeysFast && useHas) { %>\n' +
			'  var ownIndex = -1,\n' +
			'      ownProps = objectTypes[typeof iteratee] ? nativeKeys(iteratee) : [],\n' +
			'      length = ownProps.length;\n\n' +
			'  while (++ownIndex < length) {\n' +
			'    index = ownProps[ownIndex];\n' +
			"    <% if (!hasDontEnumBug) { %>if (!(skipProto && index == 'prototype')) {\n  <% } %>" +
			'    <%= objectLoop %>\n' +
			'    <% if (!hasDontEnumBug) { %>}\n<% } %>' +
			'  }' +

			// else using a for-in loop
			'  <% } else { %>\n' +
			'  for (index in iteratee) {<%' +
			'    if (!hasDontEnumBug || useHas) { %>\n    if (<%' +
			"      if (!hasDontEnumBug) { %>!(skipProto && index == 'prototype')<% }" +
			'      if (!hasDontEnumBug && useHas) { %> && <% }' +
			'      if (useHas) { %>hasOwnProperty.call(iteratee, index)<% }' +
			'    %>) {' +
			'    <% } %>\n' +
			'    <%= objectLoop %>;' +
			'    <% if (!hasDontEnumBug || useHas) { %>\n    }<% } %>\n' +
			'  }' +
			'  <% } %>' +

			// Because IE < 9 can't set the `[[Enumerable]]` attribute of an
			// existing property and the `constructor` property of a prototype
			// defaults to non-enumerable, Lo-Dash skips the `constructor`
			// property when it infers it's iterating over a `prototype` object.
			'  <% if (hasDontEnumBug) { %>\n\n' +
			'  var ctor = iteratee.constructor;\n' +
			'    <% for (var k = 0; k < 7; k++) { %>\n' +
			"  index = '<%= shadowed[k] %>';\n" +
			'  if (<%' +
			"      if (shadowed[k] == 'constructor') {" +
			'        %>!(ctor && ctor.prototype === iteratee) && <%' +
			'      } %>hasOwnProperty.call(iteratee, index)) {\n' +
			'    <%= objectLoop %>\n' +
			'  }' +
			'    <% } %>' +
			'  <% } %>' +
			'  <% if (arrayLoop || nonEnumArgs) { %>\n}<% } %>\n' +

			// add code to the bottom of the iteration function
			'<%= bottom %>;\n' +
			// finally, return the `result`
			'return result'
	);

	/** Reusable iterator options for `assign` and `defaults` */
	var assignIteratorOptions = {
		'args': 'object, source, guard',
		'top':
			"for (var argsIndex = 1, argsLength = typeof guard == 'number' ? 2 : arguments.length; argsIndex < argsLength; argsIndex++) {\n" +
				'  if ((iteratee = arguments[argsIndex])) {',
		'objectLoop': 'result[index] = iteratee[index]',
		'bottom': '  }\n}'
	};

	/**
	 * Reusable iterator options shared by `each`, `forIn`, and `forOwn`.
	 */
	var eachIteratorOptions = {
		'args': 'collection, callback, thisArg',
		'top': "callback = callback && typeof thisArg == 'undefined' ? callback : createCallback(callback, thisArg)",
		'arrayLoop': 'if (callback(iteratee[index], index, collection) === false) return result',
		'objectLoop': 'if (callback(iteratee[index], index, collection) === false) return result'
	};

	/** Reusable iterator options for `forIn` and `forOwn` */
	var forOwnIteratorOptions = {
		'arrayLoop': null
	};

	/*--------------------------------------------------------------------------*/

	/**
	 * Creates a function optimized to search large arrays for a given `value`,
	 * starting at `fromIndex`, using strict equality for comparisons, i.e. `===`.
	 *
	 * @private
	 * @param {Array} array The array to search.
	 * @param {Mixed} value The value to search for.
	 * @param {Number} [fromIndex=0] The index to search from.
	 * @param {Number} [largeSize=30] The length at which an array is considered large.
	 * @returns {Boolean} Returns `true` if `value` is found, else `false`.
	 */
	function cachedContains(array, fromIndex, largeSize) {
		fromIndex || (fromIndex = 0);

		var length = array.length,
			isLarge = (length - fromIndex) >= (largeSize || largeArraySize);

		if (isLarge) {
			var cache = {},
				index = fromIndex - 1;

			while (++index < length) {
				// manually coerce `value` to a string because `hasOwnProperty`, in some
				// older versions of Firefox, coerces objects incorrectly
				var key = array[index] + '';
				(hasOwnProperty.call(cache, key) ? cache[key] : (cache[key] = [])).push(array[index]);
			}
		}
		return function(value) {
			if (isLarge) {
				var key = value + '';
				return hasOwnProperty.call(cache, key) && indexOf(cache[key], value) > -1;
			}
			return indexOf(array, value, fromIndex) > -1;
		}
	}

	/**
	 * Used by `_.max` and `_.min` as the default `callback` when a given
	 * `collection` is a string value.
	 *
	 * @private
	 * @param {String} value The character to inspect.
	 * @returns {Number} Returns the code unit of given character.
	 */
	function charAtCallback(value) {
		return value.charCodeAt(0);
	}

	/**
	 * Used by `sortBy` to compare transformed `collection` values, stable sorting
	 * them in ascending order.
	 *
	 * @private
	 * @param {Object} a The object to compare to `b`.
	 * @param {Object} b The object to compare to `a`.
	 * @returns {Number} Returns the sort order indicator of `1` or `-1`.
	 */
	function compareAscending(a, b) {
		var ai = a.index,
			bi = b.index;

		a = a.criteria;
		b = b.criteria;

		// ensure a stable sort in V8 and other engines
		// http://code.google.com/p/v8/issues/detail?id=90
		if (a !== b) {
			if (a > b || typeof a == 'undefined') {
				return 1;
			}
			if (a < b || typeof b == 'undefined') {
				return -1;
			}
		}
		return ai < bi ? -1 : 1;
	}

	/**
	 * Creates a function that, when called, invokes `func` with the `this`
	 * binding of `thisArg` and prepends any `partailArgs` to the arguments passed
	 * to the bound function.
	 *
	 * @private
	 * @param {Function|String} func The function to bind or the method name.
	 * @param {Mixed} [thisArg] The `this` binding of `func`.
	 * @param {Array} partialArgs An array of arguments to be partially applied.
	 * @returns {Function} Returns the new bound function.
	 */
	function createBound(func, thisArg, partialArgs) {
		var isFunc = isFunction(func),
			isPartial = !partialArgs,
			key = thisArg;

		// juggle arguments
		if (isPartial) {
			partialArgs = thisArg;
		}
		if (!isFunc) {
			thisArg = func;
		}

		function bound() {
			// `Function#bind` spec
			// http://es5.github.com/#x15.3.4.5
			var args = arguments,
				thisBinding = isPartial ? this : thisArg;

			if (!isFunc) {
				func = thisArg[key];
			}
			if (partialArgs.length) {
				args = args.length
					? partialArgs.concat(slice(args))
					: partialArgs;
			}
			if (this instanceof bound) {
				// ensure `new bound` is an instance of `bound` and `func`
				noop.prototype = func.prototype;
				thisBinding = new noop;
				noop.prototype = null;

				// mimic the constructor's `return` behavior
				// http://es5.github.com/#x13.2.2
				var result = func.apply(thisBinding, args);
				return isObject(result) ? result : thisBinding;
			}
			return func.apply(thisBinding, args);
		}
		return bound;
	}

	/**
	 * Produces an iteration callback bound to an optional `thisArg`. If `func` is
	 * a property name, the callback will return the property value for a given element.
	 *
	 * @private
	 * @param {Function|String} [func=identity|property] The function called per
	 * iteration or property name to query.
	 * @param {Mixed} [thisArg] The `this` binding of `callback`.
	 * @param {Object} [accumulating] Used to indicate that the callback should
	 *  accept an `accumulator` argument.
	 * @returns {Function} Returns a callback function.
	 */
	function createCallback(func, thisArg, accumulating) {
		if (!func) {
			return identity;
		}
		if (typeof func != 'function') {
			return function(object) {
				return object[func];
			};
		}
		if (typeof thisArg != 'undefined') {
			if (accumulating) {
				return function(accumulator, value, index, object) {
					return func.call(thisArg, accumulator, value, index, object);
				};
			}
			return function(value, index, object) {
				return func.call(thisArg, value, index, object);
			};
		}
		return func;
	}

	/**
	 * Creates compiled iteration functions.
	 *
	 * @private
	 * @param {Object} [options1, options2, ...] The compile options object(s).
	 *  useHas - A boolean to specify using `hasOwnProperty` checks in the object loop.
	 *  args - A string of comma separated arguments the iteration function will accept.
	 *  top - A string of code to execute before the iteration branches.
	 *  arrayLoop - A string of code to execute in the array loop.
	 *  objectLoop - A string of code to execute in the object loop.
	 *  bottom - A string of code to execute after the iteration branches.
	 *
	 * @returns {Function} Returns the compiled function.
	 */
	function createIterator() {
		var data = {
			'arrayLoop': '',
			'bottom': '',
			'hasDontEnumBug': hasDontEnumBug,
			'isKeysFast': isKeysFast,
			'objectLoop': '',
			'nonEnumArgs': nonEnumArgs,
			'noCharByIndex': noCharByIndex,
			'shadowed': shadowed,
			'top': '',
			'useHas': true
		};

		// merge options into a template data object
		for (var object, index = 0; object = arguments[index]; index++) {
			for (var key in object) {
				data[key] = object[key];
			}
		}
		var args = data.args;
		data.firstArg = /^[^,]+/.exec(args)[0];

		// create the function factory
		var factory = Function(
			'createCallback, hasOwnProperty, isArguments, isString, objectTypes, ' +
				'nativeKeys, propertyIsEnumerable',
			'return function(' + args + ') {\n' + iteratorTemplate(data) + '\n}'
		);
		// return the compiled function
		return factory(
			createCallback, hasOwnProperty, isArguments, isString, objectTypes,
			nativeKeys, propertyIsEnumerable
		);
	}

	/**
	 * A function compiled to iterate `arguments` objects, arrays, objects, and
	 * strings consistenly across environments, executing the `callback` for each
	 * element in the `collection`. The `callback` is bound to `thisArg` and invoked
	 * with three arguments; (value, index|key, collection). Callbacks may exit
	 * iteration early by explicitly returning `false`.
	 *
	 * @private
	 * @param {Array|Object|String} collection The collection to iterate over.
	 * @param {Function} [callback=identity] The function called per iteration.
	 * @param {Mixed} [thisArg] The `this` binding of `callback`.
	 * @returns {Array|Object|String} Returns `collection`.
	 */
	var each = createIterator(eachIteratorOptions);

	/**
	 * Used by `template` to escape characters for inclusion in compiled
	 * string literals.
	 *
	 * @private
	 * @param {String} match The matched character to escape.
	 * @returns {String} Returns the escaped character.
	 */
	function escapeStringChar(match) {
		return '\\' + stringEscapes[match];
	}

	/**
	 * Used by `escape` to convert characters to HTML entities.
	 *
	 * @private
	 * @param {String} match The matched character to escape.
	 * @returns {String} Returns the escaped character.
	 */
	function escapeHtmlChar(match) {
		return htmlEscapes[match];
	}

	/**
	 * Checks if `value` is a DOM node in IE < 9.
	 *
	 * @private
	 * @param {Mixed} value The value to check.
	 * @returns {Boolean} Returns `true` if the `value` is a DOM node, else `false`.
	 */
	function isNode(value) {
		// IE < 9 presents DOM nodes as `Object` objects except they have `toString`
		// methods that are `typeof` "string" and still can coerce nodes to strings
		return typeof value.toString != 'function' && typeof (value + '') == 'string';
	}

	/**
	 * A no-operation function.
	 *
	 * @private
	 */
	function noop() {
		// no operation performed
	}

	/**
	 * Slices the `collection` from the `start` index up to, but not including,
	 * the `end` index.
	 *
	 * Note: This function is used, instead of `Array#slice`, to support node lists
	 * in IE < 9 and to ensure dense arrays are returned.
	 *
	 * @private
	 * @param {Array|Object|String} collection The collection to slice.
	 * @param {Number} start The start index.
	 * @param {Number} end The end index.
	 * @returns {Array} Returns the new array.
	 */
	function slice(array, start, end) {
		start || (start = 0);
		if (typeof end == 'undefined') {
			end = array ? array.length : 0;
		}
		var index = -1,
			length = end - start || 0,
			result = Array(length < 0 ? 0 : length);

		while (++index < length) {
			result[index] = array[start + index];
		}
		return result;
	}

	/**
	 * Used by `unescape` to convert HTML entities to characters.
	 *
	 * @private
	 * @param {String} match The matched character to unescape.
	 * @returns {String} Returns the unescaped character.
	 */
	function unescapeHtmlChar(match) {
		return htmlUnescapes[match];
	}

	/*--------------------------------------------------------------------------*/

	/**
	 * Assigns own enumerable properties of source object(s) to the `destination`
	 * object. Subsequent sources will overwrite propery assignments of previous
	 * sources.
	 *
	 * @static
	 * @memberOf _
	 * @alias extend
	 * @category Objects
	 * @param {Object} object The destination object.
	 * @param {Object} [source1, source2, ...] The source objects.
	 * @returns {Object} Returns the destination object.
	 * @example
	 *
	 * _.assign({ 'name': 'moe' }, { 'age': 40 });
	 * // => { 'name': 'moe', 'age': 40 }
	 */
	var assign = createIterator(assignIteratorOptions);

	/**
	 * Checks if `value` is an `arguments` object.
	 *
	 * @static
	 * @memberOf _
	 * @category Objects
	 * @param {Mixed} value The value to check.
	 * @returns {Boolean} Returns `true` if the `value` is an `arguments` object, else `false`.
	 * @example
	 *
	 * (function() { return _.isArguments(arguments); })(1, 2, 3);
	 * // => true
	 *
	 * _.isArguments([1, 2, 3]);
	 * // => false
	 */
	function isArguments(value) {
		return toString.call(value) == argsClass;
	}
	// fallback for browsers that can't detect `arguments` objects by [[Class]]
	if (noArgsClass) {
		isArguments = function(value) {
			return value ? hasOwnProperty.call(value, 'callee') : false;
		};
	}

	/**
	 * Iterates over `object`'s own and inherited enumerable properties, executing
	 * the `callback` for each property. The `callback` is bound to `thisArg` and
	 * invoked with three arguments; (value, key, object). Callbacks may exit iteration
	 * early by explicitly returning `false`.
	 *
	 * @static
	 * @memberOf _
	 * @category Objects
	 * @param {Object} object The object to iterate over.
	 * @param {Function} [callback=identity] The function called per iteration.
	 * @param {Mixed} [thisArg] The `this` binding of `callback`.
	 * @returns {Object} Returns `object`.
	 * @example
	 *
	 * function Dog(name) {
   *   this.name = name;
   * }
	 *
	 * Dog.prototype.bark = function() {
   *   alert('Woof, woof!');
   * };
	 *
	 * _.forIn(new Dog('Dagny'), function(value, key) {
   *   alert(key);
   * });
	 * // => alerts 'name' and 'bark' (order is not guaranteed)
	 */
	var forIn = createIterator(eachIteratorOptions, forOwnIteratorOptions, {
		'useHas': false
	});

	/**
	 * Iterates over an object's own enumerable properties, executing the `callback`
	 * for each property. The `callback` is bound to `thisArg` and invoked with three
	 * arguments; (value, key, object). Callbacks may exit iteration early by explicitly
	 * returning `false`.
	 *
	 * @static
	 * @memberOf _
	 * @category Objects
	 * @param {Object} object The object to iterate over.
	 * @param {Function} [callback=identity] The function called per iteration.
	 * @param {Mixed} [thisArg] The `this` binding of `callback`.
	 * @returns {Object} Returns `object`.
	 * @example
	 *
	 * _.forOwn({ '0': 'zero', '1': 'one', 'length': 2 }, function(num, key) {
   *   alert(key);
   * });
	 * // => alerts '0', '1', and 'length' (order is not guaranteed)
	 */
	var forOwn = createIterator(eachIteratorOptions, forOwnIteratorOptions);

	/**
	 * A fallback implementation of `isPlainObject` that checks if a given `value`
	 * is an object created by the `Object` constructor, assuming objects created
	 * by the `Object` constructor have no inherited enumerable properties and that
	 * there are no `Object.prototype` extensions.
	 *
	 * @private
	 * @param {Mixed} value The value to check.
	 * @returns {Boolean} Returns `true` if `value` is a plain object, else `false`.
	 */
	function shimIsPlainObject(value) {
		// avoid non-objects and false positives for `arguments` objects
		var result = false;
		if (!(value && typeof value == 'object') || isArguments(value)) {
			return result;
		}
		// check that the constructor is `Object` (i.e. `Object instanceof Object`)
		var ctor = value.constructor;
		if ((!isFunction(ctor) && (!noNodeClass || !isNode(value))) || ctor instanceof ctor) {
			// IE < 9 iterates inherited properties before own properties. If the first
			// iterated property is an object's own property then there are no inherited
			// enumerable properties.
			if (iteratesOwnLast) {
				forIn(value, function(value, key, object) {
					result = !hasOwnProperty.call(object, key);
					return false;
				});
				return result === false;
			}
			// In most environments an object's own properties are iterated before
			// its inherited properties. If the last iterated property is an object's
			// own property then there are no inherited enumerable properties.
			forIn(value, function(value, key) {
				result = key;
			});
			return result === false || hasOwnProperty.call(value, result);
		}
		return result;
	}

	/**
	 * A fallback implementation of `Object.keys` that produces an array of the
	 * given object's own enumerable property names.
	 *
	 * @private
	 * @param {Object} object The object to inspect.
	 * @returns {Array} Returns a new array of property names.
	 */
	function shimKeys(object) {
		var result = [];
		forOwn(object, function(value, key) {
			result.push(key);
		});
		return result;
	}

	/**
	 * Used to convert characters to HTML entities:
	 *
	 * Though the `>` character is escaped for symmetry, characters like `>` and `/`
	 * don't require escaping in HTML and have no special meaning unless they're part
	 * of a tag or an unquoted attribute value.
	 * http://mathiasbynens.be/notes/ambiguous-ampersands (under "semi-related fun fact")
	 */
	var htmlEscapes = {
		'&': '&amp;',
		'<': '&lt;',
		'>': '&gt;',
		'"': '&quot;',
		"'": '&#x27;'
	};

	/** Used to convert HTML entities to characters */
	var htmlUnescapes = invert(htmlEscapes);

	/*--------------------------------------------------------------------------*/

	/**
	 * Creates a clone of `value`. If `deep` is `true`, nested objects will also
	 * be cloned, otherwise they will be assigned by reference.
	 *
	 * @static
	 * @memberOf _
	 * @category Objects
	 * @param {Mixed} value The value to clone.
	 * @param {Boolean} deep A flag to indicate a deep clone.
	 * @param- {Object} [guard] Internally used to allow this method to work with
	 *  others like `_.map` without using their callback `index` argument for `deep`.
	 * @param- {Array} [stackA=[]] Internally used to track traversed source objects.
	 * @param- {Array} [stackB=[]] Internally used to associate clones with their
	 *  source counterparts.
	 * @returns {Mixed} Returns the cloned `value`.
	 * @example
	 *
	 * var stooges = [
	 *   { 'name': 'moe', 'age': 40 },
	 *   { 'name': 'larry', 'age': 50 },
	 *   { 'name': 'curly', 'age': 60 }
	 * ];
	 *
	 * var shallow = _.clone(stooges);
	 * shallow[0] === stooges[0];
	 * // => true
	 *
	 * var deep = _.clone(stooges, true);
	 * deep[0] === stooges[0];
	 * // => false
	 */
	function clone(value, deep, guard, stackA, stackB) {
		if (value == null) {
			return value;
		}
		if (guard) {
			deep = false;
		}
		// inspect [[Class]]
		var isObj = isObject(value);
		if (isObj) {
			var className = toString.call(value);
			if (!cloneableClasses[className] || (noNodeClass && isNode(value))) {
				return value;
			}
			var isArr = isArray(value);
		}
		// shallow clone
		if (!isObj || !deep) {
			return isObj
				? (isArr ? slice(value) : assign({}, value))
				: value;
		}
		var ctor = ctorByClass[className];
		switch (className) {
			case boolClass:
			case dateClass:
				return new ctor(+value);

			case numberClass:
			case stringClass:
				return new ctor(value);

			case regexpClass:
				return ctor(value.source, reFlags.exec(value));
		}
		// check for circular references and return corresponding clone
		stackA || (stackA = []);
		stackB || (stackB = []);

		var length = stackA.length;
		while (length--) {
			if (stackA[length] == value) {
				return stackB[length];
			}
		}
		// init cloned object
		var result = isArr ? ctor(value.length) : {};

		// add the source value to the stack of traversed objects
		// and associate it with its clone
		stackA.push(value);
		stackB.push(result);

		// recursively populate clone (susceptible to call stack limits)
		(isArr ? forEach : forOwn)(value, function(objValue, key) {
			result[key] = clone(objValue, deep, null, stackA, stackB);
		});

		// add array properties assigned by `RegExp#exec`
		if (isArr) {
			if (hasOwnProperty.call(value, 'index')) {
				result.index = value.index;
			}
			if (hasOwnProperty.call(value, 'input')) {
				result.input = value.input;
			}
		}
		return result;
	}

	/**
	 * Creates a deep clone of `value`. Functions and DOM nodes are **not** cloned.
	 * The enumerable properties of `arguments` objects and objects created by
	 * constructors other than `Object` are cloned to plain `Object` objects.
	 *
	 * Note: This function is loosely based on the structured clone algorithm.
	 * See http://www.w3.org/TR/html5/common-dom-interfaces.html#internal-structured-cloning-algorithm.
	 *
	 * @static
	 * @memberOf _
	 * @category Objects
	 * @param {Mixed} value The value to deep clone.
	 * @returns {Mixed} Returns the deep cloned `value`.
	 * @example
	 *
	 * var stooges = [
	 *   { 'name': 'moe', 'age': 40 },
	 *   { 'name': 'larry', 'age': 50 },
	 *   { 'name': 'curly', 'age': 60 }
	 * ];
	 *
	 * var deep = _.cloneDeep(stooges);
	 * deep[0] === stooges[0];
	 * // => false
	 */
	function cloneDeep(value) {
		return clone(value, true);
	}

	/**
	 * Assigns own enumerable properties of source object(s) to the `destination`
	 * object for all `destination` properties that resolve to `null`/`undefined`.
	 * Once a property is set, additional defaults of the same property will be
	 * ignored.
	 *
	 * @static
	 * @memberOf _
	 * @category Objects
	 * @param {Object} object The destination object.
	 * @param {Object} [default1, default2, ...] The default objects.
	 * @returns {Object} Returns the destination object.
	 * @example
	 *
	 * var iceCream = { 'flavor': 'chocolate' };
	 * _.defaults(iceCream, { 'flavor': 'vanilla', 'sprinkles': 'rainbow' });
	 * // => { 'flavor': 'chocolate', 'sprinkles': 'rainbow' }
	 */
	var defaults = createIterator(assignIteratorOptions, {
		'objectLoop': 'if (result[index] == null) ' + assignIteratorOptions.objectLoop
	});

	/**
	 * Creates a sorted array of all enumerable properties, own and inherited,
	 * of `object` that have function values.
	 *
	 * @static
	 * @memberOf _
	 * @alias methods
	 * @category Objects
	 * @param {Object} object The object to inspect.
	 * @returns {Array} Returns a new array of property names that have function values.
	 * @example
	 *
	 * _.functions(_);
	 * // => ['all', 'any', 'bind', 'bindAll', 'clone', 'compact', 'compose', ...]
	 */
	function functions(object) {
		var result = [];
		forIn(object, function(value, key) {
			if (isFunction(value)) {
				result.push(key);
			}
		});
		return result.sort();
	}

	/**
	 * Checks if the specified object `property` exists and is a direct property,
	 * instead of an inherited property.
	 *
	 * @static
	 * @memberOf _
	 * @category Objects
	 * @param {Object} object The object to check.
	 * @param {String} property The property to check for.
	 * @returns {Boolean} Returns `true` if key is a direct property, else `false`.
	 * @example
	 *
	 * _.has({ 'a': 1, 'b': 2, 'c': 3 }, 'b');
	 * // => true
	 */
	function has(object, property) {
		return object ? hasOwnProperty.call(object, property) : false;
	}

	/**
	 * Creates an object composed of the inverted keys and values of the given `object`.
	 *
	 * @static
	 * @memberOf _
	 * @category Objects
	 * @param {Object} object The object to invert.
	 * @returns {Object} Returns the created inverted object.
	 * @example
	 *
	 *  _.invert({ 'first': 'Moe', 'second': 'Larry', 'third': 'Curly' });
	 * // => { 'Moe': 'first', 'Larry': 'second', 'Curly': 'third' } (order is not guaranteed)
	 */
	function invert(object) {
		var result = {};
		forOwn(object, function(value, key) {
			result[value] = key;
		});
		return result;
	}

	/**
	 * Checks if `value` is an array.
	 *
	 * @static
	 * @memberOf _
	 * @category Objects
	 * @param {Mixed} value The value to check.
	 * @returns {Boolean} Returns `true` if the `value` is an array, else `false`.
	 * @example
	 *
	 * (function() { return _.isArray(arguments); })();
	 * // => false
	 *
	 * _.isArray([1, 2, 3]);
	 * // => true
	 */
	var isArray = nativeIsArray || function(value) {
		// `instanceof` may cause a memory leak in IE 7 if `value` is a host object
		// http://ajaxian.com/archives/working-aroung-the-instanceof-memory-leak
		return (argsAreObjects && value instanceof Array) || toString.call(value) == arrayClass;
	};

	/**
	 * Checks if `value` is a boolean (`true` or `false`) value.
	 *
	 * @static
	 * @memberOf _
	 * @category Objects
	 * @param {Mixed} value The value to check.
	 * @returns {Boolean} Returns `true` if the `value` is a boolean value, else `false`.
	 * @example
	 *
	 * _.isBoolean(null);
	 * // => false
	 */
	function isBoolean(value) {
		return value === true || value === false || toString.call(value) == boolClass;
	}

	/**
	 * Checks if `value` is a date.
	 *
	 * @static
	 * @memberOf _
	 * @category Objects
	 * @param {Mixed} value The value to check.
	 * @returns {Boolean} Returns `true` if the `value` is a date, else `false`.
	 * @example
	 *
	 * _.isDate(new Date);
	 * // => true
	 */
	function isDate(value) {
		return value instanceof Date || toString.call(value) == dateClass;
	}

	/**
	 * Checks if `value` is a DOM element.
	 *
	 * @static
	 * @memberOf _
	 * @category Objects
	 * @param {Mixed} value The value to check.
	 * @returns {Boolean} Returns `true` if the `value` is a DOM element, else `false`.
	 * @example
	 *
	 * _.isElement(document.body);
	 * // => true
	 */
	function isElement(value) {
		return value ? value.nodeType === 1 : false;
	}

	/**
	 * Checks if `value` is empty. Arrays, strings, or `arguments` objects with a
	 * length of `0` and objects with no own enumerable properties are considered
	 * "empty".
	 *
	 * @static
	 * @memberOf _
	 * @category Objects
	 * @param {Array|Object|String} value The value to inspect.
	 * @returns {Boolean} Returns `true` if the `value` is empty, else `false`.
	 * @example
	 *
	 * _.isEmpty([1, 2, 3]);
	 * // => false
	 *
	 * _.isEmpty({});
	 * // => true
	 *
	 * _.isEmpty('');
	 * // => true
	 */
	function isEmpty(value) {
		var result = true;
		if (!value) {
			return result;
		}
		var className = toString.call(value),
			length = value.length;

		if ((className == arrayClass || className == stringClass ||
			className == argsClass || (noArgsClass && isArguments(value))) ||
			(className == objectClass && typeof length == 'number' && isFunction(value.splice))) {
			return !length;
		}
		forOwn(value, function() {
			return (result = false);
		});
		return result;
	}

	/**
	 * Performs a deep comparison between two values to determine if they are
	 * equivalent to each other.
	 *
	 * @static
	 * @memberOf _
	 * @category Objects
	 * @param {Mixed} a The value to compare.
	 * @param {Mixed} b The other value to compare.
	 * @param- {Object} [stackA=[]] Internally used track traversed `a` objects.
	 * @param- {Object} [stackB=[]] Internally used track traversed `b` objects.
	 * @returns {Boolean} Returns `true` if the values are equvalent, else `false`.
	 * @example
	 *
	 * var moe = { 'name': 'moe', 'luckyNumbers': [13, 27, 34] };
	 * var clone = { 'name': 'moe', 'luckyNumbers': [13, 27, 34] };
	 *
	 * moe == clone;
	 * // => false
	 *
	 * _.isEqual(moe, clone);
	 * // => true
	 */
	function isEqual(a, b, stackA, stackB) {
		// exit early for identical values
		if (a === b) {
			// treat `+0` vs. `-0` as not equal
			return a !== 0 || (1 / a == 1 / b);
		}
		// a strict comparison is necessary because `null == undefined`
		if (a == null || b == null) {
			return a === b;
		}
		// compare [[Class]] names
		var className = toString.call(a),
			otherName = toString.call(b);

		if (className == argsClass) {
			className = objectClass;
		}
		if (otherName == argsClass) {
			otherName = objectClass;
		}
		if (className != otherName) {
			return false;
		}
		switch (className) {
			case boolClass:
			case dateClass:
				// coerce dates and booleans to numbers, dates to milliseconds and booleans
				// to `1` or `0`, treating invalid dates coerced to `NaN` as not equal
				return +a == +b;

			case numberClass:
				// treat `NaN` vs. `NaN` as equal
				return a != +a
					? b != +b
					// but treat `+0` vs. `-0` as not equal
					: (a == 0 ? (1 / a == 1 / b) : a == +b);

			case regexpClass:
			case stringClass:
				// coerce regexes to strings (http://es5.github.com/#x15.10.6.4)
				// treat string primitives and their corresponding object instances as equal
				return a == b + '';
		}
		var isArr = className == arrayClass;
		if (!isArr) {
			// unwrap any `lodash` wrapped values
			if (a.__wrapped__ || b.__wrapped__) {
				return isEqual(a.__wrapped__ || a, b.__wrapped__ || b);
			}
			// exit for functions and DOM nodes
			if (className != objectClass || (noNodeClass && (isNode(a) || isNode(b)))) {
				return false;
			}
			// in older versions of Opera, `arguments` objects have `Array` constructors
			var ctorA = !argsAreObjects && isArguments(a) ? Object : a.constructor,
				ctorB = !argsAreObjects && isArguments(b) ? Object : b.constructor;

			// non `Object` object instances with different constructors are not equal
			if (ctorA != ctorB && !(
				isFunction(ctorA) && ctorA instanceof ctorA &&
					isFunction(ctorB) && ctorB instanceof ctorB
				)) {
				return false;
			}
		}
		// assume cyclic structures are equal
		// the algorithm for detecting cyclic structures is adapted from ES 5.1
		// section 15.12.3, abstract operation `JO` (http://es5.github.com/#x15.12.3)
		stackA || (stackA = []);
		stackB || (stackB = []);

		var length = stackA.length;
		while (length--) {
			if (stackA[length] == a) {
				return stackB[length] == b;
			}
		}
		var index = -1,
			result = true,
			size = 0;

		// add `a` and `b` to the stack of traversed objects
		stackA.push(a);
		stackB.push(b);

		// recursively compare objects and arrays (susceptible to call stack limits)
		if (isArr) {
			// compare lengths to determine if a deep comparison is necessary
			size = a.length;
			result = size == b.length;

			if (result) {
				// deep compare the contents, ignoring non-numeric properties
				while (size--) {
					if (!(result = isEqual(a[size], b[size], stackA, stackB))) {
						break;
					}
				}
			}
			return result;
		}
		// deep compare objects using `forIn`, instead of `forOwn`, to avoid `Object.keys`
		// which, in this case, is more costly
		forIn(a, function(value, key, a) {
			if (hasOwnProperty.call(a, key)) {
				// count the number of properties.
				size++;
				// deep compare each property value.
				return (result = hasOwnProperty.call(b, key) && isEqual(value, b[key], stackA, stackB));
			}
		});

		if (result) {
			// ensure both objects have the same number of properties
			forIn(b, function(value, key, b) {
				if (hasOwnProperty.call(b, key)) {
					// `size` will be `-1` if `b` has more properties than `a`
					return (result = --size > -1);
				}
			});
		}
		return result;
	}

	/**
	 * Checks if `value` is, or can be coerced to, a finite number.
	 *
	 * Note: This is not the same as native `isFinite`, which will return true for
	 * booleans and empty strings. See http://es5.github.com/#x15.1.2.5.
	 *
	 * @static
	 * @memberOf _
	 * @category Objects
	 * @param {Mixed} value The value to check.
	 * @returns {Boolean} Returns `true` if the `value` is a finite number, else `false`.
	 * @example
	 *
	 * _.isFinite(-101);
	 * // => true
	 *
	 * _.isFinite('10');
	 * // => true
	 *
	 * _.isFinite(true);
	 * // => false
	 *
	 * _.isFinite('');
	 * // => false
	 *
	 * _.isFinite(Infinity);
	 * // => false
	 */
	function isFinite(value) {
		return nativeIsFinite(value) && !nativeIsNaN(parseFloat(value));
	}

	/**
	 * Checks if `value` is a function.
	 *
	 * @static
	 * @memberOf _
	 * @category Objects
	 * @param {Mixed} value The value to check.
	 * @returns {Boolean} Returns `true` if the `value` is a function, else `false`.
	 * @example
	 *
	 * _.isFunction(_);
	 * // => true
	 */
	function isFunction(value) {
		return typeof value == 'function';
	}
	// fallback for older versions of Chrome and Safari
	if (isFunction(/x/)) {
		isFunction = function(value) {
			return value instanceof Function || toString.call(value) == funcClass;
		};
	}

	/**
	 * Checks if `value` is the language type of Object.
	 * (e.g. arrays, functions, objects, regexes, `new Number(0)`, and `new String('')`)
	 *
	 * @static
	 * @memberOf _
	 * @category Objects
	 * @param {Mixed} value The value to check.
	 * @returns {Boolean} Returns `true` if the `value` is an object, else `false`.
	 * @example
	 *
	 * _.isObject({});
	 * // => true
	 *
	 * _.isObject([1, 2, 3]);
	 * // => true
	 *
	 * _.isObject(1);
	 * // => false
	 */
	function isObject(value) {
		// check if the value is the ECMAScript language type of Object
		// http://es5.github.com/#x8
		// and avoid a V8 bug
		// http://code.google.com/p/v8/issues/detail?id=2291
		return value ? objectTypes[typeof value] : false;
	}

	/**
	 * Checks if `value` is `NaN`.
	 *
	 * Note: This is not the same as native `isNaN`, which will return `true` for
	 * `undefined` and other values. See http://es5.github.com/#x15.1.2.4.
	 *
	 * @static
	 * @memberOf _
	 * @category Objects
	 * @param {Mixed} value The value to check.
	 * @returns {Boolean} Returns `true` if the `value` is `NaN`, else `false`.
	 * @example
	 *
	 * _.isNaN(NaN);
	 * // => true
	 *
	 * _.isNaN(new Number(NaN));
	 * // => true
	 *
	 * isNaN(undefined);
	 * // => true
	 *
	 * _.isNaN(undefined);
	 * // => false
	 */
	function isNaN(value) {
		// `NaN` as a primitive is the only value that is not equal to itself
		// (perform the [[Class]] check first to avoid errors with some host objects in IE)
		return isNumber(value) && value != +value
	}

	/**
	 * Checks if `value` is `null`.
	 *
	 * @static
	 * @memberOf _
	 * @category Objects
	 * @param {Mixed} value The value to check.
	 * @returns {Boolean} Returns `true` if the `value` is `null`, else `false`.
	 * @example
	 *
	 * _.isNull(null);
	 * // => true
	 *
	 * _.isNull(undefined);
	 * // => false
	 */
	function isNull(value) {
		return value === null;
	}

	/**
	 * Checks if `value` is a number.
	 *
	 * @static
	 * @memberOf _
	 * @category Objects
	 * @param {Mixed} value The value to check.
	 * @returns {Boolean} Returns `true` if the `value` is a number, else `false`.
	 * @example
	 *
	 * _.isNumber(8.4 * 5);
	 * // => true
	 */
	function isNumber(value) {
		return typeof value == 'number' || toString.call(value) == numberClass;
	}

	/**
	 * Checks if a given `value` is an object created by the `Object` constructor.
	 *
	 * @static
	 * @memberOf _
	 * @category Objects
	 * @param {Mixed} value The value to check.
	 * @returns {Boolean} Returns `true` if `value` is a plain object, else `false`.
	 * @example
	 *
	 * function Stooge(name, age) {
   *   this.name = name;
   *   this.age = age;
   * }
	 *
	 * _.isPlainObject(new Stooge('moe', 40));
	 * // => false
	 *
	 * _.isPlainObject([1, 2, 3]);
	 * // => false
	 *
	 * _.isPlainObject({ 'name': 'moe', 'age': 40 });
	 * // => true
	 */
	var isPlainObject = !getPrototypeOf ? shimIsPlainObject : function(value) {
		if (!(value && typeof value == 'object')) {
			return false;
		}
		var valueOf = value.valueOf,
			objProto = typeof valueOf == 'function' && (objProto = getPrototypeOf(valueOf)) && getPrototypeOf(objProto);

		return objProto
			? value == objProto || (getPrototypeOf(value) == objProto && !isArguments(value))
			: shimIsPlainObject(value);
	};

	/**
	 * Checks if `value` is a regular expression.
	 *
	 * @static
	 * @memberOf _
	 * @category Objects
	 * @param {Mixed} value The value to check.
	 * @returns {Boolean} Returns `true` if the `value` is a regular expression, else `false`.
	 * @example
	 *
	 * _.isRegExp(/moe/);
	 * // => true
	 */
	function isRegExp(value) {
		return value instanceof RegExp || toString.call(value) == regexpClass;
	}

	/**
	 * Checks if `value` is a string.
	 *
	 * @static
	 * @memberOf _
	 * @category Objects
	 * @param {Mixed} value The value to check.
	 * @returns {Boolean} Returns `true` if the `value` is a string, else `false`.
	 * @example
	 *
	 * _.isString('moe');
	 * // => true
	 */
	function isString(value) {
		return typeof value == 'string' || toString.call(value) == stringClass;
	}

	/**
	 * Checks if `value` is `undefined`.
	 *
	 * @static
	 * @memberOf _
	 * @category Objects
	 * @param {Mixed} value The value to check.
	 * @returns {Boolean} Returns `true` if the `value` is `undefined`, else `false`.
	 * @example
	 *
	 * _.isUndefined(void 0);
	 * // => true
	 */
	function isUndefined(value) {
		return typeof value == 'undefined';
	}

	/**
	 * Creates an array composed of the own enumerable property names of `object`.
	 *
	 * @static
	 * @memberOf _
	 * @category Objects
	 * @param {Object} object The object to inspect.
	 * @returns {Array} Returns a new array of property names.
	 * @example
	 *
	 * _.keys({ 'one': 1, 'two': 2, 'three': 3 });
	 * // => ['one', 'two', 'three'] (order is not guaranteed)
	 */
	var keys = !nativeKeys ? shimKeys : function(object) {
		// avoid iterating over the `prototype` property
		return typeof object == 'function' && propertyIsEnumerable.call(object, 'prototype')
			? shimKeys(object)
			: (isObject(object) ? nativeKeys(object) : []);
	};

	/**
	 * Merges enumerable properties of the source object(s) into the `destination`
	 * object. Subsequent sources will overwrite propery assignments of previous
	 * sources.
	 *
	 * @static
	 * @memberOf _
	 * @category Objects
	 * @param {Object} object The destination object.
	 * @param {Object} [source1, source2, ...] The source objects.
	 * @param- {Object} [indicator] Internally used to indicate that the `stack`
	 *  argument is an array of traversed objects instead of another source object.
	 * @param- {Array} [stackA=[]] Internally used to track traversed source objects.
	 * @param- {Array} [stackB=[]] Internally used to associate values with their
	 *  source counterparts.
	 * @returns {Object} Returns the destination object.
	 * @example
	 *
	 * var stooges = [
	 *   { 'name': 'moe' },
	 *   { 'name': 'larry' }
	 * ];
	 *
	 * var ages = [
	 *   { 'age': 40 },
	 *   { 'age': 50 }
	 * ];
	 *
	 * _.merge(stooges, ages);
	 * // => [{ 'name': 'moe', 'age': 40 }, { 'name': 'larry', 'age': 50 }]
	 */
	function merge(object, source, indicator) {
		var args = arguments,
			index = 0,
			length = 2,
			stackA = args[3],
			stackB = args[4];

		if (indicator !== indicatorObject) {
			stackA = [];
			stackB = [];

			// work with `_.reduce` by only using its callback `accumulator` and `value` arguments
			if (typeof indicator != 'number') {
				length = args.length;
			}
		}
		while (++index < length) {
			forOwn(args[index], function(source, key) {
				var found, isArr, value;
				if (source && ((isArr = isArray(source)) || isPlainObject(source))) {
					// avoid merging previously merged cyclic sources
					var stackLength = stackA.length;
					while (stackLength--) {
						found = stackA[stackLength] == source;
						if (found) {
							break;
						}
					}
					if (found) {
						object[key] = stackB[stackLength];
					}
					else {
						// add `source` and associated `value` to the stack of traversed objects
						stackA.push(source);
						stackB.push(value = (value = object[key], isArr)
							? (isArray(value) ? value : [])
							: (isPlainObject(value) ? value : {})
						);
						// recursively merge objects and arrays (susceptible to call stack limits)
						object[key] = merge(value, source, indicatorObject, stackA, stackB);
					}
				} else if (source != null) {
					object[key] = source;
				}
			});
		}
		return object;
	}

	/**
	 * Creates a shallow clone of `object` excluding the specified properties.
	 * Property names may be specified as individual arguments or as arrays of
	 * property names. If `callback` is passed, it will be executed for each property
	 * in the `object`, omitting the properties `callback` returns truthy for. The
	 * `callback` is bound to `thisArg` and invoked with three arguments; (value, key, object).
	 *
	 * @static
	 * @memberOf _
	 * @category Objects
	 * @param {Object} object The source object.
	 * @param {Function|String} callback|[prop1, prop2, ...] The properties to omit
	 *  or the function called per iteration.
	 * @param {Mixed} [thisArg] The `this` binding of `callback`.
	 * @returns {Object} Returns an object without the omitted properties.
	 * @example
	 *
	 * _.omit({ 'name': 'moe', 'age': 40, 'userid': 'moe1' }, 'userid');
	 * // => { 'name': 'moe', 'age': 40 }
	 *
	 * _.omit({ 'name': 'moe', '_hint': 'knucklehead', '_seed': '96c4eb' }, function(value, key) {
   *   return key.charAt(0) == '_';
   * });
	 * // => { 'name': 'moe' }
	 */
	function omit(object, callback, thisArg) {
		var isFunc = typeof callback == 'function',
			result = {};

		if (isFunc) {
			callback = createCallback(callback, thisArg);
		} else {
			var props = concat.apply(arrayRef, arguments);
		}
		forIn(object, function(value, key, object) {
			if (isFunc
				? !callback(value, key, object)
				: indexOf(props, key, 1) < 0
				) {
				result[key] = value;
			}
		});
		return result;
	}

	/**
	 * Creates a two dimensional array of the given object's key-value pairs,
	 * i.e. `[[key1, value1], [key2, value2]]`.
	 *
	 * @static
	 * @memberOf _
	 * @category Objects
	 * @param {Object} object The object to inspect.
	 * @returns {Array} Returns new array of key-value pairs.
	 * @example
	 *
	 * _.pairs({ 'moe': 30, 'larry': 40, 'curly': 50 });
	 * // => [['moe', 30], ['larry', 40], ['curly', 50]] (order is not guaranteed)
	 */
	function pairs(object) {
		var result = [];
		forOwn(object, function(value, key) {
			result.push([key, value]);
		});
		return result;
	}

	/**
	 * Creates a shallow clone of `object` composed of the specified properties.
	 * Property names may be specified as individual arguments or as arrays of
	 * property names. If `callback` is passed, it will be executed for each property
	 * in the `object`, picking the properties `callback` returns truthy for. The
	 * `callback` is bound to `thisArg` and invoked with three arguments; (value, key, object).
	 *
	 * @static
	 * @memberOf _
	 * @category Objects
	 * @param {Object} object The source object.
	 * @param {Function|String} callback|[prop1, prop2, ...] The properties to pick
	 *  or the function called per iteration.
	 * @param {Mixed} [thisArg] The `this` binding of `callback`.
	 * @returns {Object} Returns an object composed of the picked properties.
	 * @example
	 *
	 * _.pick({ 'name': 'moe', 'age': 40, 'userid': 'moe1' }, 'name', 'age');
	 * // => { 'name': 'moe', 'age': 40 }
	 *
	 * _.pick({ 'name': 'moe', '_hint': 'knucklehead', '_seed': '96c4eb' }, function(value, key) {
   *   return key.charAt(0) != '_';
   * });
	 * // => { 'name': 'moe' }
	 */
	function pick(object, callback, thisArg) {
		var result = {};
		if (typeof callback != 'function') {
			var index = 0,
				props = concat.apply(arrayRef, arguments),
				length = props.length;

			while (++index < length) {
				var key = props[index];
				if (key in object) {
					result[key] = object[key];
				}
			}
		} else {
			callback = createCallback(callback, thisArg);
			forIn(object, function(value, key, object) {
				if (callback(value, key, object)) {
					result[key] = value;
				}
			});
		}
		return result;
	}

	/**
	 * Creates an array composed of the own enumerable property values of `object`.
	 *
	 * @static
	 * @memberOf _
	 * @category Objects
	 * @param {Object} object The object to inspect.
	 * @returns {Array} Returns a new array of property values.
	 * @example
	 *
	 * _.values({ 'one': 1, 'two': 2, 'three': 3 });
	 * // => [1, 2, 3]
	 */
	function values(object) {
		var result = [];
		forOwn(object, function(value) {
			result.push(value);
		});
		return result;
	}

	/*--------------------------------------------------------------------------*/

	/**
	 * Checks if a given `target` element is present in a `collection` using strict
	 * equality for comparisons, i.e. `===`. If `fromIndex` is negative, it is used
	 * as the offset from the end of the collection.
	 *
	 * @static
	 * @memberOf _
	 * @alias include
	 * @category Collections
	 * @param {Array|Object|String} collection The collection to iterate over.
	 * @param {Mixed} target The value to check for.
	 * @param {Number} [fromIndex=0] The index to search from.
	 * @returns {Boolean} Returns `true` if the `target` element is found, else `false`.
	 * @example
	 *
	 * _.contains([1, 2, 3], 1);
	 * // => true
	 *
	 * _.contains([1, 2, 3], 1, 2);
	 * // => false
	 *
	 * _.contains({ 'name': 'moe', 'age': 40 }, 'moe');
	 * // => true
	 *
	 * _.contains('curly', 'ur');
	 * // => true
	 */
	function contains(collection, target, fromIndex) {
		var index = -1,
			length = collection ? collection.length : 0,
			result = false;

		fromIndex = (fromIndex < 0 ? nativeMax(0, length + fromIndex) : fromIndex) || 0;
		if (typeof length == 'number') {
			result = (isString(collection)
				? collection.indexOf(target, fromIndex)
				: indexOf(collection, target, fromIndex)
				) > -1;
		} else {
			each(collection, function(value) {
				if (++index >= fromIndex) {
					return !(result = value === target);
				}
			});
		}
		return result;
	}

	/**
	 * Creates an object composed of keys returned from running each element of
	 * `collection` through a `callback`. The corresponding value of each key is
	 * the number of times the key was returned by `callback`. The `callback` is
	 * bound to `thisArg` and invoked with three arguments; (value, index|key, collection).
	 * The `callback` argument may also be the name of a property to count by (e.g. 'length').
	 *
	 * @static
	 * @memberOf _
	 * @category Collections
	 * @param {Array|Object|String} collection The collection to iterate over.
	 * @param {Function|String} callback|property The function called per iteration
	 *  or property name to count by.
	 * @param {Mixed} [thisArg] The `this` binding of `callback`.
	 * @returns {Object} Returns the composed aggregate object.
	 * @example
	 *
	 * _.countBy([4.3, 6.1, 6.4], function(num) { return Math.floor(num); });
	 * // => { '4': 1, '6': 2 }
	 *
	 * _.countBy([4.3, 6.1, 6.4], function(num) { return this.floor(num); }, Math);
	 * // => { '4': 1, '6': 2 }
	 *
	 * _.countBy(['one', 'two', 'three'], 'length');
	 * // => { '3': 2, '5': 1 }
	 */
	function countBy(collection, callback, thisArg) {
		var result = {};
		callback = createCallback(callback, thisArg);

		forEach(collection, function(value, key, collection) {
			key = callback(value, key, collection);
			(hasOwnProperty.call(result, key) ? result[key]++ : result[key] = 1);
		});
		return result;
	}

	/**
	 * Checks if the `callback` returns a truthy value for **all** elements of a
	 * `collection`. The `callback` is bound to `thisArg` and invoked with three
	 * arguments; (value, index|key, collection).
	 *
	 * @static
	 * @memberOf _
	 * @alias all
	 * @category Collections
	 * @param {Array|Object|String} collection The collection to iterate over.
	 * @param {Function} [callback=identity] The function called per iteration.
	 * @param {Mixed} [thisArg] The `this` binding of `callback`.
	 * @returns {Boolean} Returns `true` if all elements pass the callback check,
	 *  else `false`.
	 * @example
	 *
	 * _.every([true, 1, null, 'yes'], Boolean);
	 * // => false
	 */
	function every(collection, callback, thisArg) {
		var result = true;
		callback = createCallback(callback, thisArg);

		if (isArray(collection)) {
			var index = -1,
				length = collection.length;

			while (++index < length) {
				if (!(result = !!callback(collection[index], index, collection))) {
					break;
				}
			}
		} else {
			each(collection, function(value, index, collection) {
				return (result = !!callback(value, index, collection));
			});
		}
		return result;
	}

	/**
	 * Examines each element in a `collection`, returning an array of all elements
	 * the `callback` returns truthy for. The `callback` is bound to `thisArg` and
	 * invoked with three arguments; (value, index|key, collection).
	 *
	 * @static
	 * @memberOf _
	 * @alias select
	 * @category Collections
	 * @param {Array|Object|String} collection The collection to iterate over.
	 * @param {Function} [callback=identity] The function called per iteration.
	 * @param {Mixed} [thisArg] The `this` binding of `callback`.
	 * @returns {Array} Returns a new array of elements that passed the callback check.
	 * @example
	 *
	 * var evens = _.filter([1, 2, 3, 4, 5, 6], function(num) { return num % 2 == 0; });
	 * // => [2, 4, 6]
	 */
	function filter(collection, callback, thisArg) {
		var result = [];
		callback = createCallback(callback, thisArg);

		if (isArray(collection)) {
			var index = -1,
				length = collection.length;

			while (++index < length) {
				var value = collection[index];
				if (callback(value, index, collection)) {
					result.push(value);
				}
			}
		} else {
			each(collection, function(value, index, collection) {
				if (callback(value, index, collection)) {
					result.push(value);
				}
			});
		}
		return result;
	}

	/**
	 * Examines each element in a `collection`, returning the first one the `callback`
	 * returns truthy for. The function returns as soon as it finds an acceptable
	 * element, and does not iterate over the entire `collection`. The `callback` is
	 * bound to `thisArg` and invoked with three arguments; (value, index|key, collection).
	 *
	 * @static
	 * @memberOf _
	 * @alias detect
	 * @category Collections
	 * @param {Array|Object|String} collection The collection to iterate over.
	 * @param {Function} [callback=identity] The function called per iteration.
	 * @param {Mixed} [thisArg] The `this` binding of `callback`.
	 * @returns {Mixed} Returns the element that passed the callback check,
	 *  else `undefined`.
	 * @example
	 *
	 * var even = _.find([1, 2, 3, 4, 5, 6], function(num) { return num % 2 == 0; });
	 * // => 2
	 */
	function find(collection, callback, thisArg) {
		var result;
		callback = createCallback(callback, thisArg);

		forEach(collection, function(value, index, collection) {
			if (callback(value, index, collection)) {
				result = value;
				return false;
			}
		});
		return result;
	}

	/**
	 * Iterates over a `collection`, executing the `callback` for each element in
	 * the `collection`. The `callback` is bound to `thisArg` and invoked with three
	 * arguments; (value, index|key, collection). Callbacks may exit iteration early
	 * by explicitly returning `false`.
	 *
	 * @static
	 * @memberOf _
	 * @alias each
	 * @category Collections
	 * @param {Array|Object|String} collection The collection to iterate over.
	 * @param {Function} [callback=identity] The function called per iteration.
	 * @param {Mixed} [thisArg] The `this` binding of `callback`.
	 * @returns {Array|Object|String} Returns `collection`.
	 * @example
	 *
	 * _([1, 2, 3]).forEach(alert).join(',');
	 * // => alerts each number and returns '1,2,3'
	 *
	 * _.forEach({ 'one': 1, 'two': 2, 'three': 3 }, alert);
	 * // => alerts each number value (order is not guaranteed)
	 */
	function forEach(collection, callback, thisArg) {
		if (callback && typeof thisArg == 'undefined' && isArray(collection)) {
			var index = -1,
				length = collection.length;

			while (++index < length) {
				if (callback(collection[index], index, collection) === false) {
					break;
				}
			}
		} else {
			each(collection, callback, thisArg);
		}
		return collection;
	}

	/**
	 * Creates an object composed of keys returned from running each element of
	 * `collection` through a `callback`. The corresponding value of each key is an
	 * array of elements passed to `callback` that returned the key. The `callback`
	 * is bound to `thisArg` and invoked with three arguments; (value, index|key, collection).
	 * The `callback` argument may also be the name of a property to group by (e.g. 'length').
	 *
	 * @static
	 * @memberOf _
	 * @category Collections
	 * @param {Array|Object|String} collection The collection to iterate over.
	 * @param {Function|String} callback|property The function called per iteration
	 *  or property name to group by.
	 * @param {Mixed} [thisArg] The `this` binding of `callback`.
	 * @returns {Object} Returns the composed aggregate object.
	 * @example
	 *
	 * _.groupBy([4.2, 6.1, 6.4], function(num) { return Math.floor(num); });
	 * // => { '4': [4.2], '6': [6.1, 6.4] }
	 *
	 * _.groupBy([4.2, 6.1, 6.4], function(num) { return this.floor(num); }, Math);
	 * // => { '4': [4.2], '6': [6.1, 6.4] }
	 *
	 * _.groupBy(['one', 'two', 'three'], 'length');
	 * // => { '3': ['one', 'two'], '5': ['three'] }
	 */
	function groupBy(collection, callback, thisArg) {
		var result = {};
		callback = createCallback(callback, thisArg);

		forEach(collection, function(value, key, collection) {
			key = callback(value, key, collection);
			(hasOwnProperty.call(result, key) ? result[key] : result[key] = []).push(value);
		});
		return result;
	}

	/**
	 * Invokes the method named by `methodName` on each element in the `collection`,
	 * returning an array of the results of each invoked method. Additional arguments
	 * will be passed to each invoked method. If `methodName` is a function it will
	 * be invoked for, and `this` bound to, each element in the `collection`.
	 *
	 * @static
	 * @memberOf _
	 * @category Collections
	 * @param {Array|Object|String} collection The collection to iterate over.
	 * @param {Function|String} methodName The name of the method to invoke or
	 *  the function invoked per iteration.
	 * @param {Mixed} [arg1, arg2, ...] Arguments to invoke the method with.
	 * @returns {Array} Returns a new array of the results of each invoked method.
	 * @example
	 *
	 * _.invoke([[5, 1, 7], [3, 2, 1]], 'sort');
	 * // => [[1, 5, 7], [1, 2, 3]]
	 *
	 * _.invoke([123, 456], String.prototype.split, '');
	 * // => [['1', '2', '3'], ['4', '5', '6']]
	 */
	function invoke(collection, methodName) {
		var args = slice(arguments, 2),
			isFunc = typeof methodName == 'function',
			result = [];

		forEach(collection, function(value) {
			result.push((isFunc ? methodName : value[methodName]).apply(value, args));
		});
		return result;
	}

	/**
	 * Creates an array of values by running each element in the `collection`
	 * through a `callback`. The `callback` is bound to `thisArg` and invoked with
	 * three arguments; (value, index|key, collection).
	 *
	 * @static
	 * @memberOf _
	 * @alias collect
	 * @category Collections
	 * @param {Array|Object|String} collection The collection to iterate over.
	 * @param {Function} [callback=identity] The function called per iteration.
	 * @param {Mixed} [thisArg] The `this` binding of `callback`.
	 * @returns {Array} Returns a new array of the results of each `callback` execution.
	 * @example
	 *
	 * _.map([1, 2, 3], function(num) { return num * 3; });
	 * // => [3, 6, 9]
	 *
	 * _.map({ 'one': 1, 'two': 2, 'three': 3 }, function(num) { return num * 3; });
	 * // => [3, 6, 9] (order is not guaranteed)
	 */
	function map(collection, callback, thisArg) {
		var index = -1,
			length = collection ? collection.length : 0,
			result = Array(typeof length == 'number' ? length : 0);

		callback = createCallback(callback, thisArg);
		if (isArray(collection)) {
			while (++index < length) {
				result[index] = callback(collection[index], index, collection);
			}
		} else {
			each(collection, function(value, key, collection) {
				result[++index] = callback(value, key, collection);
			});
		}
		return result;
	}

	/**
	 * Retrieves the maximum value of an `array`. If `callback` is passed,
	 * it will be executed for each value in the `array` to generate the
	 * criterion by which the value is ranked. The `callback` is bound to
	 * `thisArg` and invoked with three arguments; (value, index, collection).
	 *
	 * @static
	 * @memberOf _
	 * @category Collections
	 * @param {Array|Object|String} collection The collection to iterate over.
	 * @param {Function} [callback] The function called per iteration.
	 * @param {Mixed} [thisArg] The `this` binding of `callback`.
	 * @returns {Mixed} Returns the maximum value.
	 * @example
	 *
	 * var stooges = [
	 *   { 'name': 'moe', 'age': 40 },
	 *   { 'name': 'larry', 'age': 50 },
	 *   { 'name': 'curly', 'age': 60 }
	 * ];
	 *
	 * _.max(stooges, function(stooge) { return stooge.age; });
	 * // => { 'name': 'curly', 'age': 60 };
	 */
	function max(collection, callback, thisArg) {
		var computed = -Infinity,
			index = -1,
			length = collection ? collection.length : 0,
			result = computed;

		if (callback || !isArray(collection)) {
			callback = !callback && isString(collection)
				? charAtCallback
				: createCallback(callback, thisArg);

			each(collection, function(value, index, collection) {
				var current = callback(value, index, collection);
				if (current > computed) {
					computed = current;
					result = value;
				}
			});
		} else {
			while (++index < length) {
				if (collection[index] > result) {
					result = collection[index];
				}
			}
		}
		return result;
	}

	/**
	 * Retrieves the minimum value of an `array`. If `callback` is passed,
	 * it will be executed for each value in the `array` to generate the
	 * criterion by which the value is ranked. The `callback` is bound to `thisArg`
	 * and invoked with three arguments; (value, index, collection).
	 *
	 * @static
	 * @memberOf _
	 * @category Collections
	 * @param {Array|Object|String} collection The collection to iterate over.
	 * @param {Function} [callback] The function called per iteration.
	 * @param {Mixed} [thisArg] The `this` binding of `callback`.
	 * @returns {Mixed} Returns the minimum value.
	 * @example
	 *
	 * _.min([10, 5, 100, 2, 1000]);
	 * // => 2
	 */
	function min(collection, callback, thisArg) {
		var computed = Infinity,
			index = -1,
			length = collection ? collection.length : 0,
			result = computed;

		if (callback || !isArray(collection)) {
			callback = !callback && isString(collection)
				? charAtCallback
				: createCallback(callback, thisArg);

			each(collection, function(value, index, collection) {
				var current = callback(value, index, collection);
				if (current < computed) {
					computed = current;
					result = value;
				}
			});
		} else {
			while (++index < length) {
				if (collection[index] < result) {
					result = collection[index];
				}
			}
		}
		return result;
	}

	/**
	 * Retrieves the value of a specified property from all elements in
	 * the `collection`.
	 *
	 * @static
	 * @memberOf _
	 * @category Collections
	 * @param {Array|Object|String} collection The collection to iterate over.
	 * @param {String} property The property to pluck.
	 * @returns {Array} Returns a new array of property values.
	 * @example
	 *
	 * var stooges = [
	 *   { 'name': 'moe', 'age': 40 },
	 *   { 'name': 'larry', 'age': 50 },
	 *   { 'name': 'curly', 'age': 60 }
	 * ];
	 *
	 * _.pluck(stooges, 'name');
	 * // => ['moe', 'larry', 'curly']
	 */
	function pluck(collection, property) {
		return map(collection, property + '');
	}

	/**
	 * Boils down a `collection` to a single value. The initial state of the
	 * reduction is `accumulator` and each successive step of it should be returned
	 * by the `callback`. The `callback` is bound to `thisArg` and invoked with 4
	 * arguments; for arrays they are (accumulator, value, index|key, collection).
	 *
	 * @static
	 * @memberOf _
	 * @alias foldl, inject
	 * @category Collections
	 * @param {Array|Object|String} collection The collection to iterate over.
	 * @param {Function} [callback=identity] The function called per iteration.
	 * @param {Mixed} [accumulator] Initial value of the accumulator.
	 * @param {Mixed} [thisArg] The `this` binding of `callback`.
	 * @returns {Mixed} Returns the accumulated value.
	 * @example
	 *
	 * var sum = _.reduce([1, 2, 3], function(memo, num) { return memo + num; });
	 * // => 6
	 */
	function reduce(collection, callback, accumulator, thisArg) {
		var noaccum = arguments.length < 3;
		callback = createCallback(callback, thisArg, indicatorObject);

		if (isArray(collection)) {
			var index = -1,
				length = collection.length;

			if (noaccum) {
				accumulator = collection[++index];
			}
			while (++index < length) {
				accumulator = callback(accumulator, collection[index], index, collection);
			}
		} else {
			each(collection, function(value, index, collection) {
				accumulator = noaccum
					? (noaccum = false, value)
					: callback(accumulator, value, index, collection)
			});
		}
		return accumulator;
	}

	/**
	 * The right-associative version of `_.reduce`.
	 *
	 * @static
	 * @memberOf _
	 * @alias foldr
	 * @category Collections
	 * @param {Array|Object|String} collection The collection to iterate over.
	 * @param {Function} [callback=identity] The function called per iteration.
	 * @param {Mixed} [accumulator] Initial value of the accumulator.
	 * @param {Mixed} [thisArg] The `this` binding of `callback`.
	 * @returns {Mixed} Returns the accumulated value.
	 * @example
	 *
	 * var list = [[0, 1], [2, 3], [4, 5]];
	 * var flat = _.reduceRight(list, function(a, b) { return a.concat(b); }, []);
	 * // => [4, 5, 2, 3, 0, 1]
	 */
	function reduceRight(collection, callback, accumulator, thisArg) {
		var iteratee = collection,
			length = collection ? collection.length : 0,
			noaccum = arguments.length < 3;

		if (typeof length != 'number') {
			var props = keys(collection);
			length = props.length;
		} else if (noCharByIndex && isString(collection)) {
			iteratee = collection.split('');
		}
		callback = createCallback(callback, thisArg, indicatorObject);
		forEach(collection, function(value, index, collection) {
			index = props ? props[--length] : --length;
			accumulator = noaccum
				? (noaccum = false, iteratee[index])
				: callback(accumulator, iteratee[index], index, collection);
		});
		return accumulator;
	}

	/**
	 * The opposite of `_.filter`, this method returns the values of a
	 * `collection` that `callback` does **not** return truthy for.
	 *
	 * @static
	 * @memberOf _
	 * @category Collections
	 * @param {Array|Object|String} collection The collection to iterate over.
	 * @param {Function} [callback=identity] The function called per iteration.
	 * @param {Mixed} [thisArg] The `this` binding of `callback`.
	 * @returns {Array} Returns a new array of elements that did **not** pass the
	 *  callback check.
	 * @example
	 *
	 * var odds = _.reject([1, 2, 3, 4, 5, 6], function(num) { return num % 2 == 0; });
	 * // => [1, 3, 5]
	 */
	function reject(collection, callback, thisArg) {
		callback = createCallback(callback, thisArg);
		return filter(collection, function(value, index, collection) {
			return !callback(value, index, collection);
		});
	}

	/**
	 * Creates an array of shuffled `array` values, using a version of the
	 * Fisher-Yates shuffle. See http://en.wikipedia.org/wiki/Fisher-Yates_shuffle.
	 *
	 * @static
	 * @memberOf _
	 * @category Collections
	 * @param {Array|Object|String} collection The collection to shuffle.
	 * @returns {Array} Returns a new shuffled collection.
	 * @example
	 *
	 * _.shuffle([1, 2, 3, 4, 5, 6]);
	 * // => [4, 1, 6, 3, 5, 2]
	 */
	function shuffle(collection) {
		var index = -1,
			result = Array(collection ? collection.length : 0);

		forEach(collection, function(value) {
			var rand = floor(nativeRandom() * (++index + 1));
			result[index] = result[rand];
			result[rand] = value;
		});
		return result;
	}

	/**
	 * Gets the size of the `collection` by returning `collection.length` for arrays
	 * and array-like objects or the number of own enumerable properties for objects.
	 *
	 * @static
	 * @memberOf _
	 * @category Collections
	 * @param {Array|Object|String} collection The collection to inspect.
	 * @returns {Number} Returns `collection.length` or number of own enumerable properties.
	 * @example
	 *
	 * _.size([1, 2]);
	 * // => 2
	 *
	 * _.size({ 'one': 1, 'two': 2, 'three': 3 });
	 * // => 3
	 *
	 * _.size('curly');
	 * // => 5
	 */
	function size(collection) {
		var length = collection ? collection.length : 0;
		return typeof length == 'number' ? length : keys(collection).length;
	}

	/**
	 * Checks if the `callback` returns a truthy value for **any** element of a
	 * `collection`. The function returns as soon as it finds passing value, and
	 * does not iterate over the entire `collection`. The `callback` is bound to
	 * `thisArg` and invoked with three arguments; (value, index|key, collection).
	 *
	 * @static
	 * @memberOf _
	 * @alias any
	 * @category Collections
	 * @param {Array|Object|String} collection The collection to iterate over.
	 * @param {Function} [callback=identity] The function called per iteration.
	 * @param {Mixed} [thisArg] The `this` binding of `callback`.
	 * @returns {Boolean} Returns `true` if any element passes the callback check,
	 *  else `false`.
	 * @example
	 *
	 * _.some([null, 0, 'yes', false], Boolean);
	 * // => true
	 */
	function some(collection, callback, thisArg) {
		var result;
		callback = createCallback(callback, thisArg);

		if (isArray(collection)) {
			var index = -1,
				length = collection.length;

			while (++index < length) {
				if ((result = callback(collection[index], index, collection))) {
					break;
				}
			}
		} else {
			each(collection, function(value, index, collection) {
				return !(result = callback(value, index, collection));
			});
		}
		return !!result;
	}

	/**
	 * Creates an array, stable sorted in ascending order by the results of
	 * running each element of `collection` through a `callback`. The `callback`
	 * is bound to `thisArg` and invoked with three arguments; (value, index|key, collection).
	 * The `callback` argument may also be the name of a property to sort by (e.g. 'length').
	 *
	 * @static
	 * @memberOf _
	 * @category Collections
	 * @param {Array|Object|String} collection The collection to iterate over.
	 * @param {Function|String} callback|property The function called per iteration
	 *  or property name to sort by.
	 * @param {Mixed} [thisArg] The `this` binding of `callback`.
	 * @returns {Array} Returns a new array of sorted elements.
	 * @example
	 *
	 * _.sortBy([1, 2, 3], function(num) { return Math.sin(num); });
	 * // => [3, 1, 2]
	 *
	 * _.sortBy([1, 2, 3], function(num) { return this.sin(num); }, Math);
	 * // => [3, 1, 2]
	 *
	 * _.sortBy(['larry', 'brendan', 'moe'], 'length');
	 * // => ['moe', 'larry', 'brendan']
	 */
	function sortBy(collection, callback, thisArg) {
		var result = [];
		callback = createCallback(callback, thisArg);

		forEach(collection, function(value, index, collection) {
			result.push({
				'criteria': callback(value, index, collection),
				'index': index,
				'value': value
			});
		});

		var length = result.length;
		result.sort(compareAscending);
		while (length--) {
			result[length] = result[length].value;
		}
		return result;
	}

	/**
	 * Converts the `collection` to an array.
	 *
	 * @static
	 * @memberOf _
	 * @category Collections
	 * @param {Array|Object|String} collection The collection to convert.
	 * @returns {Array} Returns the new converted array.
	 * @example
	 *
	 * (function() { return _.toArray(arguments).slice(1); })(1, 2, 3, 4);
	 * // => [2, 3, 4]
	 */
	function toArray(collection) {
		var length = collection ? collection.length : 0;
		if (typeof length == 'number') {
			return noCharByIndex && isString(collection)
				? collection.split('')
				: slice(collection);
		}
		return values(collection);
	}

	/**
	 * Examines each element in a `collection`, returning an array of all elements
	 * that contain the given `properties`.
	 *
	 * @static
	 * @memberOf _
	 * @category Collections
	 * @param {Array|Object|String} collection The collection to iterate over.
	 * @param {Object} properties The object of property values to filter by.
	 * @returns {Array} Returns a new array of elements that contain the given `properties`.
	 * @example
	 *
	 * var stooges = [
	 *   { 'name': 'moe', 'age': 40 },
	 *   { 'name': 'larry', 'age': 50 },
	 *   { 'name': 'curly', 'age': 60 }
	 * ];
	 *
	 * _.where(stooges, { 'age': 40 });
	 * // => [{ 'name': 'moe', 'age': 40 }]
	 */
	function where(collection, properties) {
		var props = keys(properties);
		return filter(collection, function(object) {
			var length = props.length;
			while (length--) {
				var result = object[props[length]] === properties[props[length]];
				if (!result) {
					break;
				}
			}
			return !!result;
		});
	}

	/*--------------------------------------------------------------------------*/

	/**
	 * Creates an array with all falsey values of `array` removed. The values
	 * `false`, `null`, `0`, `""`, `undefined` and `NaN` are all falsey.
	 *
	 * @static
	 * @memberOf _
	 * @category Arrays
	 * @param {Array} array The array to compact.
	 * @returns {Array} Returns a new filtered array.
	 * @example
	 *
	 * _.compact([0, 1, false, 2, '', 3]);
	 * // => [1, 2, 3]
	 */
	function compact(array) {
		var index = -1,
			length = array ? array.length : 0,
			result = [];

		while (++index < length) {
			var value = array[index];
			if (value) {
				result.push(value);
			}
		}
		return result;
	}

	/**
	 * Creates an array of `array` elements not present in the other arrays
	 * using strict equality for comparisons, i.e. `===`.
	 *
	 * @static
	 * @memberOf _
	 * @category Arrays
	 * @param {Array} array The array to process.
	 * @param {Array} [array1, array2, ...] Arrays to check.
	 * @returns {Array} Returns a new array of `array` elements not present in the
	 *  other arrays.
	 * @example
	 *
	 * _.difference([1, 2, 3, 4, 5], [5, 2, 10]);
	 * // => [1, 3, 4]
	 */
	function difference(array) {
		var index = -1,
			length = array ? array.length : 0,
			flattened = concat.apply(arrayRef, arguments),
			contains = cachedContains(flattened, length),
			result = [];

		while (++index < length) {
			var value = array[index];
			if (!contains(value)) {
				result.push(value);
			}
		}
		return result;
	}

	/**
	 * Gets the first element of the `array`. Pass `n` to return the first `n`
	 * elements of the `array`.
	 *
	 * @static
	 * @memberOf _
	 * @alias head, take
	 * @category Arrays
	 * @param {Array} array The array to query.
	 * @param {Number} [n] The number of elements to return.
	 * @param- {Object} [guard] Internally used to allow this method to work with
	 *  others like `_.map` without using their callback `index` argument for `n`.
	 * @returns {Mixed} Returns the first element, or an array of the first `n`
	 *  elements, of `array`.
	 * @example
	 *
	 * _.first([5, 4, 3, 2, 1]);
	 * // => 5
	 */
	function first(array, n, guard) {
		if (array) {
			var length = array.length;
			return (n == null || guard)
				? array[0]
				: slice(array, 0, nativeMin(nativeMax(0, n), length));
		}
	}

	/**
	 * Flattens a nested array (the nesting can be to any depth). If `shallow` is
	 * truthy, `array` will only be flattened a single level.
	 *
	 * @static
	 * @memberOf _
	 * @category Arrays
	 * @param {Array} array The array to compact.
	 * @param {Boolean} shallow A flag to indicate only flattening a single level.
	 * @returns {Array} Returns a new flattened array.
	 * @example
	 *
	 * _.flatten([1, [2], [3, [[4]]]]);
	 * // => [1, 2, 3, 4];
	 *
	 * _.flatten([1, [2], [3, [[4]]]], true);
	 * // => [1, 2, 3, [[4]]];
	 */
	function flatten(array, shallow) {
		var index = -1,
			length = array ? array.length : 0,
			result = [];

		while (++index < length) {
			var value = array[index];

			// recursively flatten arrays (susceptible to call stack limits)
			if (isArray(value)) {
				push.apply(result, shallow ? value : flatten(value));
			} else {
				result.push(value);
			}
		}
		return result;
	}

	/**
	 * Gets the index at which the first occurrence of `value` is found using
	 * strict equality for comparisons, i.e. `===`. If the `array` is already
	 * sorted, passing `true` for `fromIndex` will run a faster binary search.
	 *
	 * @static
	 * @memberOf _
	 * @category Arrays
	 * @param {Array} array The array to search.
	 * @param {Mixed} value The value to search for.
	 * @param {Boolean|Number} [fromIndex=0] The index to search from or `true` to
	 *  perform a binary search on a sorted `array`.
	 * @returns {Number} Returns the index of the matched value or `-1`.
	 * @example
	 *
	 * _.indexOf([1, 2, 3, 1, 2, 3], 2);
	 * // => 1
	 *
	 * _.indexOf([1, 2, 3, 1, 2, 3], 2, 3);
	 * // => 4
	 *
	 * _.indexOf([1, 1, 2, 2, 3, 3], 2, true);
	 * // => 2
	 */
	function indexOf(array, value, fromIndex) {
		var index = -1,
			length = array ? array.length : 0;

		if (typeof fromIndex == 'number') {
			index = (fromIndex < 0 ? nativeMax(0, length + fromIndex) : fromIndex || 0) - 1;
		} else if (fromIndex) {
			index = sortedIndex(array, value);
			return array[index] === value ? index : -1;
		}
		while (++index < length) {
			if (array[index] === value) {
				return index;
			}
		}
		return -1;
	}

	/**
	 * Gets all but the last element of `array`. Pass `n` to exclude the last `n`
	 * elements from the result.
	 *
	 * @static
	 * @memberOf _
	 * @category Arrays
	 * @param {Array} array The array to query.
	 * @param {Number} [n=1] The number of elements to exclude.
	 * @param- {Object} [guard] Internally used to allow this method to work with
	 *  others like `_.map` without using their callback `index` argument for `n`.
	 * @returns {Array} Returns all but the last element, or `n` elements, of `array`.
	 * @example
	 *
	 * _.initial([3, 2, 1]);
	 * // => [3, 2]
	 */
	function initial(array, n, guard) {
		if (!array) {
			return [];
		}
		var length = array.length;
		n = n == null || guard ? 1 : n || 0;
		return slice(array, 0, nativeMin(nativeMax(0, length - n), length));
	}

	/**
	 * Computes the intersection of all the passed-in arrays using strict equality
	 * for comparisons, i.e. `===`.
	 *
	 * @static
	 * @memberOf _
	 * @category Arrays
	 * @param {Array} [array1, array2, ...] Arrays to process.
	 * @returns {Array} Returns a new array of unique elements that are present
	 *  in **all** of the arrays.
	 * @example
	 *
	 * _.intersection([1, 2, 3], [101, 2, 1, 10], [2, 1]);
	 * // => [1, 2]
	 */
	function intersection(array) {
		var args = arguments,
			argsLength = args.length,
			cache = { '0': {} },
			index = -1,
			length = array ? array.length : 0,
			isLarge = length >= 100,
			result = [],
			seen = result;

		outer:
			while (++index < length) {
				var value = array[index];
				if (isLarge) {
					var key = value + '';
					var inited = hasOwnProperty.call(cache[0], key)
						? !(seen = cache[0][key])
						: (seen = cache[0][key] = []);
				}
				if (inited || indexOf(seen, value) < 0) {
					if (isLarge) {
						seen.push(value);
					}
					var argsIndex = argsLength;
					while (--argsIndex) {
						if (!(cache[argsIndex] || (cache[argsIndex] = cachedContains(args[argsIndex], 0, 100)))(value)) {
							continue outer;
						}
					}
					result.push(value);
				}
			}
		return result;
	}

	/**
	 * Gets the last element of the `array`. Pass `n` to return the last `n`
	 * elements of the `array`.
	 *
	 * @static
	 * @memberOf _
	 * @category Arrays
	 * @param {Array} array The array to query.
	 * @param {Number} [n] The number of elements to return.
	 * @param- {Object} [guard] Internally used to allow this method to work with
	 *  others like `_.map` without using their callback `index` argument for `n`.
	 * @returns {Mixed} Returns the last element, or an array of the last `n`
	 *  elements, of `array`.
	 * @example
	 *
	 * _.last([3, 2, 1]);
	 * // => 1
	 */
	function last(array, n, guard) {
		if (array) {
			var length = array.length;
			return (n == null || guard) ? array[length - 1] : slice(array, nativeMax(0, length - n));
		}
	}

	/**
	 * Gets the index at which the last occurrence of `value` is found using strict
	 * equality for comparisons, i.e. `===`. If `fromIndex` is negative, it is used
	 * as the offset from the end of the collection.
	 *
	 * @static
	 * @memberOf _
	 * @category Arrays
	 * @param {Array} array The array to search.
	 * @param {Mixed} value The value to search for.
	 * @param {Number} [fromIndex=array.length-1] The index to search from.
	 * @returns {Number} Returns the index of the matched value or `-1`.
	 * @example
	 *
	 * _.lastIndexOf([1, 2, 3, 1, 2, 3], 2);
	 * // => 4
	 *
	 * _.lastIndexOf([1, 2, 3, 1, 2, 3], 2, 3);
	 * // => 1
	 */
	function lastIndexOf(array, value, fromIndex) {
		var index = array ? array.length : 0;
		if (typeof fromIndex == 'number') {
			index = (fromIndex < 0 ? nativeMax(0, index + fromIndex) : nativeMin(fromIndex, index - 1)) + 1;
		}
		while (index--) {
			if (array[index] === value) {
				return index;
			}
		}
		return -1;
	}

	/**
	 * Creates an object composed from arrays of `keys` and `values`. Pass either
	 * a single two dimensional array, i.e. `[[key1, value1], [key2, value2]]`, or
	 * two arrays, one of `keys` and one of corresponding `values`.
	 *
	 * @static
	 * @memberOf _
	 * @category Arrays
	 * @param {Array} keys The array of keys.
	 * @param {Array} [values=[]] The array of values.
	 * @returns {Object} Returns an object composed of the given keys and
	 *  corresponding values.
	 * @example
	 *
	 * _.object(['moe', 'larry', 'curly'], [30, 40, 50]);
	 * // => { 'moe': 30, 'larry': 40, 'curly': 50 }
	 */
	function object(keys, values) {
		var index = -1,
			length = keys ? keys.length : 0,
			result = {};

		while (++index < length) {
			var key = keys[index];
			if (values) {
				result[key] = values[index];
			} else {
				result[key[0]] = key[1];
			}
		}
		return result;
	}

	/**
	 * Creates an array of numbers (positive and/or negative) progressing from
	 * `start` up to but not including `stop`. This method is a port of Python's
	 * `range()` function. See http://docs.python.org/library/functions.html#range.
	 *
	 * @static
	 * @memberOf _
	 * @category Arrays
	 * @param {Number} [start=0] The start of the range.
	 * @param {Number} end The end of the range.
	 * @param {Number} [step=1] The value to increment or descrement by.
	 * @returns {Array} Returns a new range array.
	 * @example
	 *
	 * _.range(10);
	 * // => [0, 1, 2, 3, 4, 5, 6, 7, 8, 9]
	 *
	 * _.range(1, 11);
	 * // => [1, 2, 3, 4, 5, 6, 7, 8, 9, 10]
	 *
	 * _.range(0, 30, 5);
	 * // => [0, 5, 10, 15, 20, 25]
	 *
	 * _.range(0, -10, -1);
	 * // => [0, -1, -2, -3, -4, -5, -6, -7, -8, -9]
	 *
	 * _.range(0);
	 * // => []
	 */
	function range(start, end, step) {
		start = +start || 0;
		step = +step || 1;

		if (end == null) {
			end = start;
			start = 0;
		}
		// use `Array(length)` so V8 will avoid the slower "dictionary" mode
		// http://youtu.be/XAqIpGU8ZZk#t=17m25s
		var index = -1,
			length = nativeMax(0, ceil((end - start) / step)),
			result = Array(length);

		while (++index < length) {
			result[index] = start;
			start += step;
		}
		return result;
	}

	/**
	 * The opposite of `_.initial`, this method gets all but the first value of
	 * `array`. Pass `n` to exclude the first `n` values from the result.
	 *
	 * @static
	 * @memberOf _
	 * @alias drop, tail
	 * @category Arrays
	 * @param {Array} array The array to query.
	 * @param {Number} [n=1] The number of elements to exclude.
	 * @param- {Object} [guard] Internally used to allow this method to work with
	 *  others like `_.map` without using their callback `index` argument for `n`.
	 * @returns {Array} Returns all but the first element, or `n` elements, of `array`.
	 * @example
	 *
	 * _.rest([3, 2, 1]);
	 * // => [2, 1]
	 */
	function rest(array, n, guard) {
		return slice(array, (n == null || guard) ? 1 : nativeMax(0, n));
	}

	/**
	 * Uses a binary search to determine the smallest index at which the `value`
	 * should be inserted into `array` in order to maintain the sort order of the
	 * sorted `array`. If `callback` is passed, it will be executed for `value` and
	 * each element in `array` to compute their sort ranking. The `callback` is
	 * bound to `thisArg` and invoked with one argument; (value). The `callback`
	 * argument may also be the name of a property to order by.
	 *
	 * @static
	 * @memberOf _
	 * @category Arrays
	 * @param {Array} array The array to iterate over.
	 * @param {Mixed} value The value to evaluate.
	 * @param {Function|String} [callback=identity|property] The function called
	 *  per iteration or property name to order by.
	 * @param {Mixed} [thisArg] The `this` binding of `callback`.
	 * @returns {Number} Returns the index at which the value should be inserted
	 *  into `array`.
	 * @example
	 *
	 * _.sortedIndex([20, 30, 50], 40);
	 * // => 2
	 *
	 * _.sortedIndex([{ 'x': 20 }, { 'x': 30 }, { 'x': 50 }], { 'x': 40 }, 'x');
	 * // => 2
	 *
	 * var dict = {
   *   'wordToNumber': { 'twenty': 20, 'thirty': 30, 'fourty': 40, 'fifty': 50 }
   * };
	 *
	 * _.sortedIndex(['twenty', 'thirty', 'fifty'], 'fourty', function(word) {
   *   return dict.wordToNumber[word];
   * });
	 * // => 2
	 *
	 * _.sortedIndex(['twenty', 'thirty', 'fifty'], 'fourty', function(word) {
   *   return this.wordToNumber[word];
   * }, dict);
	 * // => 2
	 */
	function sortedIndex(array, value, callback, thisArg) {
		var low = 0,
			high = array ? array.length : low;

		// explicitly reference `identity` for better inlining in Firefox
		callback = callback ? createCallback(callback, thisArg) : identity;
		value = callback(value);

		while (low < high) {
			var mid = (low + high) >>> 1;
			callback(array[mid]) < value
				? low = mid + 1
				: high = mid;
		}
		return low;
	}

	/**
	 * Computes the union of the passed-in arrays using strict equality for
	 * comparisons, i.e. `===`.
	 *
	 * @static
	 * @memberOf _
	 * @category Arrays
	 * @param {Array} [array1, array2, ...] Arrays to process.
	 * @returns {Array} Returns a new array of unique values, in order, that are
	 *  present in one or more of the arrays.
	 * @example
	 *
	 * _.union([1, 2, 3], [101, 2, 1, 10], [2, 1]);
	 * // => [1, 2, 3, 101, 10]
	 */
	function union() {
		return uniq(concat.apply(arrayRef, arguments));
	}

	/**
	 * Creates a duplicate-value-free version of the `array` using strict equality
	 * for comparisons, i.e. `===`. If the `array` is already sorted, passing `true`
	 * for `isSorted` will run a faster algorithm. If `callback` is passed, each
	 * element of `array` is passed through a callback` before uniqueness is computed.
	 * The `callback` is bound to `thisArg` and invoked with three arguments; (value, index, array).
	 *
	 * @static
	 * @memberOf _
	 * @alias unique
	 * @category Arrays
	 * @param {Array} array The array to process.
	 * @param {Boolean} [isSorted=false] A flag to indicate that the `array` is already sorted.
	 * @param {Function} [callback=identity] The function called per iteration.
	 * @param {Mixed} [thisArg] The `this` binding of `callback`.
	 * @returns {Array} Returns a duplicate-value-free array.
	 * @example
	 *
	 * _.uniq([1, 2, 1, 3, 1]);
	 * // => [1, 2, 3]
	 *
	 * _.uniq([1, 1, 2, 2, 3], true);
	 * // => [1, 2, 3]
	 *
	 * _.uniq([1, 2, 1.5, 3, 2.5], function(num) { return Math.floor(num); });
	 * // => [1, 2, 3]
	 *
	 * _.uniq([1, 2, 1.5, 3, 2.5], function(num) { return this.floor(num); }, Math);
	 * // => [1, 2, 3]
	 */
	function uniq(array, isSorted, callback, thisArg) {
		var index = -1,
			length = array ? array.length : 0,
			result = [],
			seen = result;

		// juggle arguments
		if (typeof isSorted == 'function') {
			thisArg = callback;
			callback = isSorted;
			isSorted = false;
		}
		// init value cache for large arrays
		var isLarge = !isSorted && length >= 75;
		if (isLarge) {
			var cache = {};
		}
		if (callback) {
			seen = [];
			callback = createCallback(callback, thisArg);
		}
		while (++index < length) {
			var value = array[index],
				computed = callback ? callback(value, index, array) : value;

			if (isLarge) {
				var key = computed + '';
				var inited = hasOwnProperty.call(cache, key)
					? !(seen = cache[key])
					: (seen = cache[key] = []);
			}
			if (isSorted
				? !index || seen[seen.length - 1] !== computed
				: inited || indexOf(seen, computed) < 0
				) {
				if (callback || isLarge) {
					seen.push(computed);
				}
				result.push(value);
			}
		}
		return result;
	}

	/**
	 * Creates an array with all occurrences of the passed values removed using
	 * strict equality for comparisons, i.e. `===`.
	 *
	 * @static
	 * @memberOf _
	 * @category Arrays
	 * @param {Array} array The array to filter.
	 * @param {Mixed} [value1, value2, ...] Values to remove.
	 * @returns {Array} Returns a new filtered array.
	 * @example
	 *
	 * _.without([1, 2, 1, 0, 3, 1, 4], 0, 1);
	 * // => [2, 3, 4]
	 */
	function without(array) {
		var index = -1,
			length = array ? array.length : 0,
			contains = cachedContains(arguments, 1, 20),
			result = [];

		while (++index < length) {
			var value = array[index];
			if (!contains(value)) {
				result.push(value);
			}
		}
		return result;
	}

	/**
	 * Groups the elements of each array at their corresponding indexes. Useful for
	 * separate data sources that are coordinated through matching array indexes.
	 * For a matrix of nested arrays, `_.zip.apply(...)` can transpose the matrix
	 * in a similar fashion.
	 *
	 * @static
	 * @memberOf _
	 * @category Arrays
	 * @param {Array} [array1, array2, ...] Arrays to process.
	 * @returns {Array} Returns a new array of grouped elements.
	 * @example
	 *
	 * _.zip(['moe', 'larry', 'curly'], [30, 40, 50], [true, false, false]);
	 * // => [['moe', 30, true], ['larry', 40, false], ['curly', 50, false]]
	 */
	function zip(array) {
		var index = -1,
			length = array ? max(pluck(arguments, 'length')) : 0,
			result = Array(length);

		while (++index < length) {
			result[index] = pluck(arguments, index);
		}
		return result;
	}

	/*--------------------------------------------------------------------------*/

	/**
	 * Creates a function that is restricted to executing `func` only after it is
	 * called `n` times. The `func` is executed with the `this` binding of the
	 * created function.
	 *
	 * @static
	 * @memberOf _
	 * @category Functions
	 * @param {Number} n The number of times the function must be called before
	 * it is executed.
	 * @param {Function} func The function to restrict.
	 * @returns {Function} Returns the new restricted function.
	 * @example
	 *
	 * var renderNotes = _.after(notes.length, render);
	 * _.forEach(notes, function(note) {
   *   note.asyncSave({ 'success': renderNotes });
   * });
	 * // `renderNotes` is run once, after all notes have saved
	 */
	function after(n, func) {
		if (n < 1) {
			return func();
		}
		return function() {
			if (--n < 1) {
				return func.apply(this, arguments);
			}
		};
	}

	/**
	 * Creates a function that, when called, invokes `func` with the `this`
	 * binding of `thisArg` and prepends any additional `bind` arguments to those
	 * passed to the bound function.
	 *
	 * @static
	 * @memberOf _
	 * @category Functions
	 * @param {Function} func The function to bind.
	 * @param {Mixed} [thisArg] The `this` binding of `func`.
	 * @param {Mixed} [arg1, arg2, ...] Arguments to be partially applied.
	 * @returns {Function} Returns the new bound function.
	 * @example
	 *
	 * var func = function(greeting) {
   *   return greeting + ' ' + this.name;
   * };
	 *
	 * func = _.bind(func, { 'name': 'moe' }, 'hi');
	 * func();
	 * // => 'hi moe'
	 */
	function bind(func, thisArg) {
		// use `Function#bind` if it exists and is fast
		// (in V8 `Function#bind` is slower except when partially applied)
		return isBindFast || (nativeBind && arguments.length > 2)
			? nativeBind.call.apply(nativeBind, arguments)
			: createBound(func, thisArg, slice(arguments, 2));
	}

	/**
	 * Binds methods on `object` to `object`, overwriting the existing method.
	 * If no method names are provided, all the function properties of `object`
	 * will be bound.
	 *
	 * @static
	 * @memberOf _
	 * @category Functions
	 * @param {Object} object The object to bind and assign the bound methods to.
	 * @param {String} [methodName1, methodName2, ...] Method names on the object to bind.
	 * @returns {Object} Returns `object`.
	 * @example
	 *
	 * var buttonView = {
   *  'label': 'lodash',
   *  'onClick': function() { alert('clicked: ' + this.label); }
   * };
	 *
	 * _.bindAll(buttonView);
	 * jQuery('#lodash_button').on('click', buttonView.onClick);
	 * // => When the button is clicked, `this.label` will have the correct value
	 */
	function bindAll(object) {
		var funcs = arguments,
			index = funcs.length > 1 ? 0 : (funcs = functions(object), -1),
			length = funcs.length;

		while (++index < length) {
			var key = funcs[index];
			object[key] = bind(object[key], object);
		}
		return object;
	}

	/**
	 * Creates a function that, when called, invokes the method at `object[key]`
	 * and prepends any additional `bindKey` arguments to those passed to the bound
	 * function. This method differs from `_.bind` by allowing bound functions to
	 * reference methods that will be redefined or don't yet exist.
	 * See http://michaux.ca/articles/lazy-function-definition-pattern.
	 *
	 * @static
	 * @memberOf _
	 * @category Functions
	 * @param {Object} object The object the method belongs to.
	 * @param {String} key The key of the method.
	 * @param {Mixed} [arg1, arg2, ...] Arguments to be partially applied.
	 * @returns {Function} Returns the new bound function.
	 * @example
	 *
	 * var object = {
   *   'name': 'moe',
   *   'greet': function(greeting) {
   *     return greeting + ' ' + this.name;
   *   }
   * };
	 *
	 * var func = _.bindKey(object, 'greet', 'hi');
	 * func();
	 * // => 'hi moe'
	 *
	 * object.greet = function(greeting) {
   *   return greeting + ', ' + this.name + '!';
   * };
	 *
	 * func();
	 * // => 'hi, moe!'
	 */
	function bindKey(object, key) {
		return createBound(object, key, slice(arguments, 2));
	}

	/**
	 * Creates a function that is the composition of the passed functions,
	 * where each function consumes the return value of the function that follows.
	 * In math terms, composing the functions `f()`, `g()`, and `h()` produces `f(g(h()))`.
	 * Each function is executed with the `this` binding of the composed function.
	 *
	 * @static
	 * @memberOf _
	 * @category Functions
	 * @param {Function} [func1, func2, ...] Functions to compose.
	 * @returns {Function} Returns the new composed function.
	 * @example
	 *
	 * var greet = function(name) { return 'hi: ' + name; };
	 * var exclaim = function(statement) { return statement + '!'; };
	 * var welcome = _.compose(exclaim, greet);
	 * welcome('moe');
	 * // => 'hi: moe!'
	 */
	function compose() {
		var funcs = arguments;
		return function() {
			var args = arguments,
				length = funcs.length;

			while (length--) {
				args = [funcs[length].apply(this, args)];
			}
			return args[0];
		};
	}

	/**
	 * Creates a function that will delay the execution of `func` until after
	 * `wait` milliseconds have elapsed since the last time it was invoked. Pass
	 * `true` for `immediate` to cause debounce to invoke `func` on the leading,
	 * instead of the trailing, edge of the `wait` timeout. Subsequent calls to
	 * the debounced function will return the result of the last `func` call.
	 *
	 * @static
	 * @memberOf _
	 * @category Functions
	 * @param {Function} func The function to debounce.
	 * @param {Number} wait The number of milliseconds to delay.
	 * @param {Boolean} immediate A flag to indicate execution is on the leading
	 *  edge of the timeout.
	 * @returns {Function} Returns the new debounced function.
	 * @example
	 *
	 * var lazyLayout = _.debounce(calculateLayout, 300);
	 * jQuery(window).on('resize', lazyLayout);
	 */
	function debounce(func, wait, immediate) {
		var args,
			result,
			thisArg,
			timeoutId;

		function delayed() {
			timeoutId = null;
			if (!immediate) {
				result = func.apply(thisArg, args);
			}
		}
		return function() {
			var isImmediate = immediate && !timeoutId;
			args = arguments;
			thisArg = this;

			clearTimeout(timeoutId);
			timeoutId = setTimeout(delayed, wait);

			if (isImmediate) {
				result = func.apply(thisArg, args);
			}
			return result;
		};
	}

	/**
	 * Executes the `func` function after `wait` milliseconds. Additional arguments
	 * will be passed to `func` when it is invoked.
	 *
	 * @static
	 * @memberOf _
	 * @category Functions
	 * @param {Function} func The function to delay.
	 * @param {Number} wait The number of milliseconds to delay execution.
	 * @param {Mixed} [arg1, arg2, ...] Arguments to invoke the function with.
	 * @returns {Number} Returns the `setTimeout` timeout id.
	 * @example
	 *
	 * var log = _.bind(console.log, console);
	 * _.delay(log, 1000, 'logged later');
	 * // => 'logged later' (Appears after one second.)
	 */
	function delay(func, wait) {
		var args = slice(arguments, 2);
		return setTimeout(function() { func.apply(undefined, args); }, wait);
	}

	/**
	 * Defers executing the `func` function until the current call stack has cleared.
	 * Additional arguments will be passed to `func` when it is invoked.
	 *
	 * @static
	 * @memberOf _
	 * @category Functions
	 * @param {Function} func The function to defer.
	 * @param {Mixed} [arg1, arg2, ...] Arguments to invoke the function with.
	 * @returns {Number} Returns the `setTimeout` timeout id.
	 * @example
	 *
	 * _.defer(function() { alert('deferred'); });
	 * // returns from the function before `alert` is called
	 */
	function defer(func) {
		var args = slice(arguments, 1);
		return setTimeout(function() { func.apply(undefined, args); }, 1);
	}

	/**
	 * Creates a function that memoizes the result of `func`. If `resolver` is
	 * passed, it will be used to determine the cache key for storing the result
	 * based on the arguments passed to the memoized function. By default, the first
	 * argument passed to the memoized function is used as the cache key. The `func`
	 * is executed with the `this` binding of the memoized function.
	 *
	 * @static
	 * @memberOf _
	 * @category Functions
	 * @param {Function} func The function to have its output memoized.
	 * @param {Function} [resolver] A function used to resolve the cache key.
	 * @returns {Function} Returns the new memoizing function.
	 * @example
	 *
	 * var fibonacci = _.memoize(function(n) {
   *   return n < 2 ? n : fibonacci(n - 1) + fibonacci(n - 2);
   * });
	 */
	function memoize(func, resolver) {
		var cache = {};
		return function() {
			var key = resolver ? resolver.apply(this, arguments) : arguments[0];
			return hasOwnProperty.call(cache, key)
				? cache[key]
				: (cache[key] = func.apply(this, arguments));
		};
	}

	/**
	 * Creates a function that is restricted to execute `func` once. Repeat calls to
	 * the function will return the value of the first call. The `func` is executed
	 * with the `this` binding of the created function.
	 *
	 * @static
	 * @memberOf _
	 * @category Functions
	 * @param {Function} func The function to restrict.
	 * @returns {Function} Returns the new restricted function.
	 * @example
	 *
	 * var initialize = _.once(createApplication);
	 * initialize();
	 * initialize();
	 * // Application is only created once.
	 */
	function once(func) {
		var result,
			ran = false;

		return function() {
			if (ran) {
				return result;
			}
			ran = true;
			result = func.apply(this, arguments);

			// clear the `func` variable so the function may be garbage collected
			func = null;
			return result;
		};
	}

	/**
	 * Creates a function that, when called, invokes `func` with any additional
	 * `partial` arguments prepended to those passed to the new function. This
	 * method is similar to `bind`, except it does **not** alter the `this` binding.
	 *
	 * @static
	 * @memberOf _
	 * @category Functions
	 * @param {Function} func The function to partially apply arguments to.
	 * @param {Mixed} [arg1, arg2, ...] Arguments to be partially applied.
	 * @returns {Function} Returns the new partially applied function.
	 * @example
	 *
	 * var greet = function(greeting, name) { return greeting + ': ' + name; };
	 * var hi = _.partial(greet, 'hi');
	 * hi('moe');
	 * // => 'hi: moe'
	 */
	function partial(func) {
		return createBound(func, slice(arguments, 1));
	}

	/**
	 * Creates a function that, when executed, will only call the `func`
	 * function at most once per every `wait` milliseconds. If the throttled
	 * function is invoked more than once during the `wait` timeout, `func` will
	 * also be called on the trailing edge of the timeout. Subsequent calls to the
	 * throttled function will return the result of the last `func` call.
	 *
	 * @static
	 * @memberOf _
	 * @category Functions
	 * @param {Function} func The function to throttle.
	 * @param {Number} wait The number of milliseconds to throttle executions to.
	 * @returns {Function} Returns the new throttled function.
	 * @example
	 *
	 * var throttled = _.throttle(updatePosition, 100);
	 * jQuery(window).on('scroll', throttled);
	 */
	function throttle(func, wait) {
		var args,
			result,
			thisArg,
			timeoutId,
			lastCalled = 0;

		function trailingCall() {
			lastCalled = new Date;
			timeoutId = null;
			result = func.apply(thisArg, args);
		}
		return function() {
			var now = new Date,
				remaining = wait - (now - lastCalled);

			args = arguments;
			thisArg = this;

			if (remaining <= 0) {
				clearTimeout(timeoutId);
				timeoutId = null;
				lastCalled = now;
				result = func.apply(thisArg, args);
			}
			else if (!timeoutId) {
				timeoutId = setTimeout(trailingCall, remaining);
			}
			return result;
		};
	}

	/**
	 * Creates a function that passes `value` to the `wrapper` function as its
	 * first argument. Additional arguments passed to the function are appended
	 * to those passed to the `wrapper` function. The `wrapper` is executed with
	 * the `this` binding of the created function.
	 *
	 * @static
	 * @memberOf _
	 * @category Functions
	 * @param {Mixed} value The value to wrap.
	 * @param {Function} wrapper The wrapper function.
	 * @returns {Function} Returns the new function.
	 * @example
	 *
	 * var hello = function(name) { return 'hello ' + name; };
	 * hello = _.wrap(hello, function(func) {
   *   return 'before, ' + func('moe') + ', after';
   * });
	 * hello();
	 * // => 'before, hello moe, after'
	 */
	function wrap(value, wrapper) {
		return function() {
			var args = [value];
			push.apply(args, arguments);
			return wrapper.apply(this, args);
		};
	}

	/*--------------------------------------------------------------------------*/

	/**
	 * Converts the characters `&`, `<`, `>`, `"`, and `'` in `string` to their
	 * corresponding HTML entities.
	 *
	 * @static
	 * @memberOf _
	 * @category Utilities
	 * @param {String} string The string to escape.
	 * @returns {String} Returns the escaped string.
	 * @example
	 *
	 * _.escape('Moe, Larry & Curly');
	 * // => 'Moe, Larry &amp; Curly'
	 */
	function escape(string) {
		return string == null ? '' : (string + '').replace(reUnescapedHtml, escapeHtmlChar);
	}

	/**
	 * This function returns the first argument passed to it.
	 *
	 * @static
	 * @memberOf _
	 * @category Utilities
	 * @param {Mixed} value Any value.
	 * @returns {Mixed} Returns `value`.
	 * @example
	 *
	 * var moe = { 'name': 'moe' };
	 * moe === _.identity(moe);
	 * // => true
	 */
	function identity(value) {
		return value;
	}

	/**
	 * Adds functions properties of `object` to the `lodash` function and chainable
	 * wrapper.
	 *
	 * @static
	 * @memberOf _
	 * @category Utilities
	 * @param {Object} object The object of function properties to add to `lodash`.
	 * @example
	 *
	 * _.mixin({
   *   'capitalize': function(string) {
   *     return string.charAt(0).toUpperCase() + string.slice(1).toLowerCase();
   *   }
   * });
	 *
	 * _.capitalize('larry');
	 * // => 'Larry'
	 *
	 * _('curly').capitalize();
	 * // => 'Curly'
	 */
	function mixin(object) {
		forEach(functions(object), function(methodName) {
			var func = lodash[methodName] = object[methodName];

			lodash.prototype[methodName] = function() {
				var args = [this.__wrapped__];
				push.apply(args, arguments);

				var result = func.apply(lodash, args);
				return new lodash(result);
			};
		});
	}

	/**
	 * Reverts the '_' variable to its previous value and returns a reference to
	 * the `lodash` function.
	 *
	 * @static
	 * @memberOf _
	 * @category Utilities
	 * @returns {Function} Returns the `lodash` function.
	 * @example
	 *
	 * var lodash = _.noConflict();
	 */
	function noConflict() {
		window._ = oldDash;
		return this;
	}

	/**
	 * Produces a random number between `min` and `max` (inclusive). If only one
	 * argument is passed, a number between `0` and the given number will be returned.
	 *
	 * @static
	 * @memberOf _
	 * @category Utilities
	 * @param {Number} [min=0] The minimum possible value.
	 * @param {Number} [max=1] The maximum possible value.
	 * @returns {Number} Returns a random number.
	 * @example
	 *
	 * _.random(0, 5);
	 * // => a number between 1 and 5
	 *
	 * _.random(5);
	 * // => also a number between 1 and 5
	 */
	function random(min, max) {
		if (min == null && max == null) {
			max = 1;
		}
		min = +min || 0;
		if (max == null) {
			max = min;
			min = 0;
		}
		return min + floor(nativeRandom() * ((+max || 0) - min + 1));
	}

	/**
	 * Resolves the value of `property` on `object`. If `property` is a function
	 * it will be invoked and its result returned, else the property value is
	 * returned. If `object` is falsey, then `null` is returned.
	 *
	 * @static
	 * @memberOf _
	 * @category Utilities
	 * @param {Object} object The object to inspect.
	 * @param {String} property The property to get the value of.
	 * @returns {Mixed} Returns the resolved value.
	 * @example
	 *
	 * var object = {
   *   'cheese': 'crumpets',
   *   'stuff': function() {
   *     return 'nonsense';
   *   }
   * };
	 *
	 * _.result(object, 'cheese');
	 * // => 'crumpets'
	 *
	 * _.result(object, 'stuff');
	 * // => 'nonsense'
	 */
	function result(object, property) {
		// based on Backbone's private `getValue` function
		// https://github.com/documentcloud/backbone/blob/0.9.2/backbone.js#L1419-1424
		var value = object ? object[property] : null;
		return isFunction(value) ? object[property]() : value;
	}

	/**
	 * A micro-templating method that handles arbitrary delimiters, preserves
	 * whitespace, and correctly escapes quotes within interpolated code.
	 *
	 * Note: In the development build `_.template` utilizes sourceURLs for easier
	 * debugging. See http://www.html5rocks.com/en/tutorials/developertools/sourcemaps/#toc-sourceurl
	 *
	 * Note: Lo-Dash may be used in Chrome extensions by either creating a `lodash csp`
	 * build and avoiding `_.template` use, or loading Lo-Dash in a sandboxed page.
	 * See http://developer.chrome.com/trunk/extensions/sandboxingEval.html
	 *
	 * @static
	 * @memberOf _
	 * @category Utilities
	 * @param {String} text The template text.
	 * @param {Obect} data The data object used to populate the text.
	 * @param {Object} options The options object.
	 *  escape - The "escape" delimiter regexp.
	 *  evaluate - The "evaluate" delimiter regexp.
	 *  interpolate - The "interpolate" delimiter regexp.
	 *  sourceURL - The sourceURL of the template's compiled source.
	 *  variable - The data object variable name.
	 *
	 * @returns {Function|String} Returns a compiled function when no `data` object
	 *  is given, else it returns the interpolated text.
	 * @example
	 *
	 * // using a compiled template
	 * var compiled = _.template('hello <%= name %>');
	 * compiled({ 'name': 'moe' });
	 * // => 'hello moe'
	 *
	 * var list = '<% _.forEach(people, function(name) { %><li><%= name %></li><% }); %>';
	 * _.template(list, { 'people': ['moe', 'larry', 'curly'] });
	 * // => '<li>moe</li><li>larry</li><li>curly</li>'
	 *
	 * // using the "escape" delimiter to escape HTML in data property values
	 * _.template('<b><%- value %></b>', { 'value': '<script>' });
	 * // => '<b>&lt;script&gt;</b>'
	 *
	 * // using the ES6 delimiter as an alternative to the default "interpolate" delimiter
	 * _.template('hello ${ name }', { 'name': 'curly' });
	 * // => 'hello curly'
	 *
	 * // using the internal `print` function in "evaluate" delimiters
	 * _.template('<% print("hello " + epithet); %>!', { 'epithet': 'stooge' });
	 * // => 'hello stooge!'
	 *
	 * // using custom template delimiters
	 * _.templateSettings = {
   *   'interpolate': /{{([\s\S]+?)}}/g
   * };
	 *
	 * _.template('hello {{ name }}!', { 'name': 'mustache' });
	 * // => 'hello mustache!'
	 *
	 * // using the `sourceURL` option to specify a custom sourceURL for the template
	 * var compiled = _.template('hello <%= name %>', null, { 'sourceURL': '/basic/greeting.jst' });
	 * compiled(data);
	 * // => find the source of "greeting.jst" under the Sources tab or Resources panel of the web inspector
	 *
	 * // using the `variable` option to ensure a with-statement isn't used in the compiled template
	 * var compiled = _.template('hello <%= data.name %>!', null, { 'variable': 'data' });
	 * compiled.source;
	 * // => function(data) {
   *   var __t, __p = '', __e = _.escape;
   *   __p += 'hello ' + ((__t = ( data.name )) == null ? '' : __t) + '!';
   *   return __p;
   * }
	 *
	 * // using the `source` property to inline compiled templates for meaningful
	 * // line numbers in error messages and a stack trace
	 * fs.writeFileSync(path.join(cwd, 'jst.js'), '\
	 *   var JST = {\
   *     "main": ' + _.template(mainText).source + '\
   *   };\
	 * ');
	 */
	function template(text, data, options) {
		// based on John Resig's `tmpl` implementation
		// http://ejohn.org/blog/javascript-micro-templating/
		// and Laura Doktorova's doT.js
		// https://github.com/olado/doT
		text || (text = '');
		options || (options = {});

		var isEvaluating,
			result,
			settings = lodash.templateSettings,
			index = 0,
			interpolate = options.interpolate || settings.interpolate || reNoMatch,
			source = "__p += '",
			variable = options.variable || settings.variable,
			hasVariable = variable;

		// compile regexp to match each delimiter
		var reDelimiters = RegExp(
			(options.escape || settings.escape || reNoMatch).source + '|' +
				interpolate.source + '|' +
				(interpolate === reInterpolate ? reEsTemplate : reNoMatch).source + '|' +
				(options.evaluate || settings.evaluate || reNoMatch).source + '|$'
			, 'g');

		text.replace(reDelimiters, function(match, escapeValue, interpolateValue, esTemplateValue, evaluateValue, offset) {
			interpolateValue || (interpolateValue = esTemplateValue);

			// escape characters that cannot be included in string literals
			source += text.slice(index, offset).replace(reUnescapedString, escapeStringChar);

			// replace delimiters with snippets
			if (escapeValue) {
				source += "' +\n__e(" + escapeValue + ") +\n'";
			}
			if (evaluateValue) {
				source += "';\n" + evaluateValue + ";\n__p += '";
			}
			if (interpolateValue) {
				source += "' +\n((__t = (" + interpolateValue + ")) == null ? '' : __t) +\n'";
			}
			isEvaluating || (isEvaluating = evaluateValue || reComplexDelimiter.test(escapeValue || interpolateValue));
			index = offset + match.length;

			// the JS engine embedded in Adobe products requires returning the `match`
			// string in order to produce the correct `offset` value
			return match;
		});

		source += "';\n";

		// if `variable` is not specified and the template contains "evaluate"
		// delimiters, wrap a with-statement around the generated code to add the
		// data object to the top of the scope chain
		if (!hasVariable) {
			variable = 'obj';
			if (isEvaluating) {
				source = 'with (' + variable + ') {\n' + source + '\n}\n';
			}
			else {
				// avoid a with-statement by prepending data object references to property names
				var reDoubleVariable = RegExp('(\\(\\s*)' + variable + '\\.' + variable + '\\b', 'g');
				source = source
					.replace(reInsertVariable, '$&' + variable + '.')
					.replace(reDoubleVariable, '$1__d');
			}
		}

		// cleanup code by stripping empty strings
		source = (isEvaluating ? source.replace(reEmptyStringLeading, '') : source)
			.replace(reEmptyStringMiddle, '$1')
			.replace(reEmptyStringTrailing, '$1;');

		// frame code as the function body
		source = 'function(' + variable + ') {\n' +
			(hasVariable ? '' : variable + ' || (' + variable + ' = {});\n') +
			"var __t, __p = '', __e = _.escape" +
			(isEvaluating
				? ', __j = Array.prototype.join;\n' +
				"function print() { __p += __j.call(arguments, '') }\n"
				: (hasVariable ? '' : ', __d = ' + variable + '.' + variable + ' || ' + variable) + ';\n'
				) +
			source +
			'return __p\n}';

		// use a sourceURL for easier debugging
		// http://www.html5rocks.com/en/tutorials/developertools/sourcemaps/#toc-sourceurl
		var sourceURL = useSourceURL
			? '\n//@ sourceURL=' + (options.sourceURL || '/lodash/template/source[' + (templateCounter++) + ']')
			: '';

		try {
			result = Function('_', 'return ' + source + sourceURL)(lodash);
		} catch(e) {
			e.source = source;
			throw e;
		}

		if (data) {
			return result(data);
		}
		// provide the compiled function's source via its `toString` method, in
		// supported environments, or the `source` property as a convenience for
		// inlining compiled templates during the build process
		result.source = source;
		return result;
	}

	/**
	 * Executes the `callback` function `n` times, returning an array of the results
	 * of each `callback` execution. The `callback` is bound to `thisArg` and invoked
	 * with one argument; (index).
	 *
	 * @static
	 * @memberOf _
	 * @category Utilities
	 * @param {Number} n The number of times to execute the callback.
	 * @param {Function} callback The function called per iteration.
	 * @param {Mixed} [thisArg] The `this` binding of `callback`.
	 * @returns {Array} Returns a new array of the results of each `callback` execution.
	 * @example
	 *
	 * var diceRolls = _.times(3, _.partial(_.random, 1, 6));
	 * // => [3, 6, 4]
	 *
	 * _.times(3, function(n) { mage.castSpell(n); });
	 * // => calls `mage.castSpell(n)` three times, passing `n` of `0`, `1`, and `2` respectively
	 *
	 * _.times(3, function(n) { this.cast(n); }, mage);
	 * // => also calls `mage.castSpell(n)` three times
	 */
	function times(n, callback, thisArg) {
		n = +n || 0;
		var index = -1,
			result = Array(n);

		while (++index < n) {
			result[index] = callback.call(thisArg, index);
		}
		return result;
	}

	/**
	 * The opposite of `_.escape`, this method converts the HTML entities
	 * `&amp;`, `&lt;`, `&gt;`, `&quot;`, and `&#x27;` in `string` to their
	 * corresponding characters.
	 *
	 * @static
	 * @memberOf _
	 * @category Utilities
	 * @param {String} string The string to unescape.
	 * @returns {String} Returns the unescaped string.
	 * @example
	 *
	 * _.unescape('Moe, Larry &amp; Curly');
	 * // => 'Moe, Larry & Curly'
	 */
	function unescape(string) {
		return string == null ? '' : (string + '').replace(reEscapedHtml, unescapeHtmlChar);
	}

	/**
	 * Generates a unique ID. If `prefix` is passed, the ID will be appended to it.
	 *
	 * @static
	 * @memberOf _
	 * @category Utilities
	 * @param {String} [prefix] The value to prefix the ID with.
	 * @returns {String} Returns the unique ID.
	 * @example
	 *
	 * _.uniqueId('contact_');
	 * // => 'contact_104'
	 *
	 * _.uniqueId();
	 * // => '105'
	 */
	function uniqueId(prefix) {
		return (prefix == null ? '' : prefix + '') + (++idCounter);
	}

	/*--------------------------------------------------------------------------*/

	/**
	 * Invokes `interceptor` with the `value` as the first argument, and then
	 * returns `value`. The purpose of this method is to "tap into" a method chain,
	 * in order to perform operations on intermediate results within the chain.
	 *
	 * @static
	 * @memberOf _
	 * @category Chaining
	 * @param {Mixed} value The value to pass to `interceptor`.
	 * @param {Function} interceptor The function to invoke.
	 * @returns {Mixed} Returns `value`.
	 * @example
	 *
	 * _.chain([1, 2, 3, 200])
	 *  .filter(function(num) { return num % 2 == 0; })
	 *  .tap(alert)
	 *  .map(function(num) { return num * num; })
	 *  .value();
	 * // => // [2, 200] (alerted)
	 * // => [4, 40000]
	 */
	function tap(value, interceptor) {
		interceptor(value);
		return value;
	}

	/**
	 * Produces the `toString` result of the wrapped value.
	 *
	 * @name toString
	 * @memberOf _
	 * @category Chaining
	 * @returns {String} Returns the string result.
	 * @example
	 *
	 * _([1, 2, 3]).toString();
	 * // => '1,2,3'
	 */
	function wrapperToString() {
		return this.__wrapped__ + '';
	}

	/**
	 * Extracts the wrapped value.
	 *
	 * @name valueOf
	 * @memberOf _
	 * @alias value
	 * @category Chaining
	 * @returns {Mixed} Returns the wrapped value.
	 * @example
	 *
	 * _([1, 2, 3]).valueOf();
	 * // => [1, 2, 3]
	 */
	function wrapperValueOf() {
		return this.__wrapped__;
	}

	/*--------------------------------------------------------------------------*/

	// add functions that return wrapped values when chaining
	lodash.after = after;
	lodash.assign = assign;
	lodash.bind = bind;
	lodash.bindAll = bindAll;
	lodash.bindKey = bindKey;
	lodash.compact = compact;
	lodash.compose = compose;
	lodash.countBy = countBy;
	lodash.debounce = debounce;
	lodash.defaults = defaults;
	lodash.defer = defer;
	lodash.delay = delay;
	lodash.difference = difference;
	lodash.filter = filter;
	lodash.flatten = flatten;
	lodash.forEach = forEach;
	lodash.forIn = forIn;
	lodash.forOwn = forOwn;
	lodash.functions = functions;
	lodash.groupBy = groupBy;
	lodash.initial = initial;
	lodash.intersection = intersection;
	lodash.invert = invert;
	lodash.invoke = invoke;
	lodash.keys = keys;
	lodash.map = map;
	lodash.max = max;
	lodash.memoize = memoize;
	lodash.merge = merge;
	lodash.min = min;
	lodash.object = object;
	lodash.omit = omit;
	lodash.once = once;
	lodash.pairs = pairs;
	lodash.partial = partial;
	lodash.pick = pick;
	lodash.pluck = pluck;
	lodash.range = range;
	lodash.reject = reject;
	lodash.rest = rest;
	lodash.shuffle = shuffle;
	lodash.sortBy = sortBy;
	lodash.tap = tap;
	lodash.throttle = throttle;
	lodash.times = times;
	lodash.toArray = toArray;
	lodash.union = union;
	lodash.uniq = uniq;
	lodash.values = values;
	lodash.where = where;
	lodash.without = without;
	lodash.wrap = wrap;
	lodash.zip = zip;

	// add aliases
	lodash.collect = map;
	lodash.drop = rest;
	lodash.each = forEach;
	lodash.extend = assign;
	lodash.methods = functions;
	lodash.select = filter;
	lodash.tail = rest;
	lodash.unique = uniq;

	// add functions to `lodash.prototype`
	mixin(lodash);

	/*--------------------------------------------------------------------------*/

	// add functions that return unwrapped values when chaining
	lodash.clone = clone;
	lodash.cloneDeep = cloneDeep;
	lodash.contains = contains;
	lodash.escape = escape;
	lodash.every = every;
	lodash.find = find;
	lodash.has = has;
	lodash.identity = identity;
	lodash.indexOf = indexOf;
	lodash.isArguments = isArguments;
	lodash.isArray = isArray;
	lodash.isBoolean = isBoolean;
	lodash.isDate = isDate;
	lodash.isElement = isElement;
	lodash.isEmpty = isEmpty;
	lodash.isEqual = isEqual;
	lodash.isFinite = isFinite;
	lodash.isFunction = isFunction;
	lodash.isNaN = isNaN;
	lodash.isNull = isNull;
	lodash.isNumber = isNumber;
	lodash.isObject = isObject;
	lodash.isPlainObject = isPlainObject;
	lodash.isRegExp = isRegExp;
	lodash.isString = isString;
	lodash.isUndefined = isUndefined;
	lodash.lastIndexOf = lastIndexOf;
	lodash.mixin = mixin;
	lodash.noConflict = noConflict;
	lodash.random = random;
	lodash.reduce = reduce;
	lodash.reduceRight = reduceRight;
	lodash.result = result;
	lodash.size = size;
	lodash.some = some;
	lodash.sortedIndex = sortedIndex;
	lodash.template = template;
	lodash.unescape = unescape;
	lodash.uniqueId = uniqueId;

	// add aliases
	lodash.all = every;
	lodash.any = some;
	lodash.detect = find;
	lodash.foldl = reduce;
	lodash.foldr = reduceRight;
	lodash.include = contains;
	lodash.inject = reduce;

	forOwn(lodash, function(func, methodName) {
		if (!lodash.prototype[methodName]) {
			lodash.prototype[methodName] = function() {
				var args = [this.__wrapped__];
				push.apply(args, arguments);
				return func.apply(lodash, args);
			};
		}
	});

	/*--------------------------------------------------------------------------*/

	// add functions capable of returning wrapped and unwrapped values when chaining
	lodash.first = first;
	lodash.last = last;

	// add aliases
	lodash.take = first;
	lodash.head = first;

	forOwn(lodash, function(func, methodName) {
		if (!lodash.prototype[methodName]) {
			lodash.prototype[methodName]= function(n, guard) {
				var result = func(this.__wrapped__, n, guard);
				return (n == null || guard) ? result : new lodash(result);
			};
		}
	});

	/*--------------------------------------------------------------------------*/

	/**
	 * The semantic version number.
	 *
	 * @static
	 * @memberOf _
	 * @type String
	 */
	lodash.VERSION = '1.0.0-rc.3';

	// add "Chaining" functions to the wrapper
	lodash.prototype.toString = wrapperToString;
	lodash.prototype.value = wrapperValueOf;
	lodash.prototype.valueOf = wrapperValueOf;

	// add `Array` functions that return unwrapped values
	each(['join', 'pop', 'shift'], function(methodName) {
		var func = arrayRef[methodName];
		lodash.prototype[methodName] = function() {
			return func.apply(this.__wrapped__, arguments);
		};
	});

	// add `Array` functions that return the wrapped value
	each(['push', 'reverse', 'sort', 'unshift'], function(methodName) {
		var func = arrayRef[methodName];
		lodash.prototype[methodName] = function() {
			func.apply(this.__wrapped__, arguments);
			return this;
		};
	});

	// add `Array` functions that return new wrapped values
	each(['concat', 'slice', 'splice'], function(methodName) {
		var func = arrayRef[methodName];
		lodash.prototype[methodName] = function() {
			var result = func.apply(this.__wrapped__, arguments);
			return new lodash(result);
		};
	});

	// avoid array-like object bugs with `Array#shift` and `Array#splice`
	// in Firefox < 10 and IE < 9
	if (hasObjectSpliceBug) {
		each(['pop', 'shift', 'splice'], function(methodName) {
			var func = arrayRef[methodName],
				isSplice = methodName == 'splice';

			lodash.prototype[methodName] = function() {
				var value = this.__wrapped__,
					result = func.apply(value, arguments);

				if (value.length === 0) {
					delete value[0];
				}
				return isSplice ? new lodash(result) : result;
			};
		});
	}

	// add pseudo private property to be used and removed during the build process
	lodash._each = each;
	lodash._iteratorTemplate = iteratorTemplate;

	/*--------------------------------------------------------------------------*/

	// expose Lo-Dash
	// some AMD build optimizers, like r.js, check for specific condition patterns like the following:
	if (typeof define == 'function' && typeof define.amd == 'object' && define.amd) {
		// Expose Lo-Dash to the global object even when an AMD loader is present in
		// case Lo-Dash was injected by a third-party script and not intended to be
		// loaded as a module. The global assignment can be reverted in the Lo-Dash
		// module via its `noConflict()` method.
		window._ = lodash;

		// define as an anonymous module so, through path mapping, it can be
		// referenced as the "underscore" module
		define(function() {
			return lodash;
		});
	}
	// check for `exports` after `define` in case a build optimizer adds an `exports` object
	else if (freeExports) {
		// in Node.js or RingoJS v0.8.0+
		if (typeof module == 'object' && module && module.exports == freeExports) {
			(module.exports = lodash)._ = lodash;
		}
		// in Narwhal or RingoJS v0.7.0-
		else {
			freeExports._ = lodash;
		}
	}
	else {
		// in a browser or Rhino
		window._ = lodash;
	}
}(this));
// Knockout JavaScript library v2.3.0
// (c) Steven Sanderson - http://knockoutjs.com/
// License: MIT (http://www.opensource.org/licenses/mit-license.php)

(function(){
var DEBUG=true;
(function(undefined){
    // (0, eval)('this') is a robust way of getting a reference to the global object
    // For details, see http://stackoverflow.com/questions/14119988/return-this-0-evalthis/14120023#14120023
    var window = this || (0, eval)('this'),
        document = window['document'],
        navigator = window['navigator'],
        jQuery = window["jQuery"],
        JSON = window["JSON"];
(function(factory) {
    // Support three module loading scenarios
    if (typeof require === 'function' && typeof exports === 'object' && typeof module === 'object') {
        // [1] CommonJS/Node.js
        var target = module['exports'] || exports; // module.exports is for Node.js
        factory(target);
    } else if (typeof define === 'function' && define['amd']) {
        // [2] AMD anonymous module
        define(['exports'], factory);
    } else {
        // [3] No module loader (plain <script> tag) - put directly in global namespace
        factory(window['ko'] = {});
    }
}(function(koExports){
// Internally, all KO objects are attached to koExports (even the non-exported ones whose names will be minified by the closure compiler).
// In the future, the following "ko" variable may be made distinct from "koExports" so that private objects are not externally reachable.
var ko = typeof koExports !== 'undefined' ? koExports : {};
// Google Closure Compiler helpers (used only to make the minified file smaller)
ko.exportSymbol = function(koPath, object) {
	var tokens = koPath.split(".");

	// In the future, "ko" may become distinct from "koExports" (so that non-exported objects are not reachable)
	// At that point, "target" would be set to: (typeof koExports !== "undefined" ? koExports : ko)
	var target = ko;

	for (var i = 0; i < tokens.length - 1; i++)
		target = target[tokens[i]];
	target[tokens[tokens.length - 1]] = object;
};
ko.exportProperty = function(owner, publicName, object) {
  owner[publicName] = object;
};
ko.version = "2.3.0";

ko.exportSymbol('version', ko.version);
ko.utils = (function () {
    var objectForEach = function(obj, action) {
        for (var prop in obj) {
            if (obj.hasOwnProperty(prop)) {
                action(prop, obj[prop]);
            }
        }
    };

    // Represent the known event types in a compact way, then at runtime transform it into a hash with event name as key (for fast lookup)
    var knownEvents = {}, knownEventTypesByEventName = {};
    var keyEventTypeName = (navigator && /Firefox\/2/i.test(navigator.userAgent)) ? 'KeyboardEvent' : 'UIEvents';
    knownEvents[keyEventTypeName] = ['keyup', 'keydown', 'keypress'];
    knownEvents['MouseEvents'] = ['click', 'dblclick', 'mousedown', 'mouseup', 'mousemove', 'mouseover', 'mouseout', 'mouseenter', 'mouseleave'];
    objectForEach(knownEvents, function(eventType, knownEventsForType) {
        if (knownEventsForType.length) {
            for (var i = 0, j = knownEventsForType.length; i < j; i++)
                knownEventTypesByEventName[knownEventsForType[i]] = eventType;
        }
    });
    var eventsThatMustBeRegisteredUsingAttachEvent = { 'propertychange': true }; // Workaround for an IE9 issue - https://github.com/SteveSanderson/knockout/issues/406

    // Detect IE versions for bug workarounds (uses IE conditionals, not UA string, for robustness)
    // Note that, since IE 10 does not support conditional comments, the following logic only detects IE < 10.
    // Currently this is by design, since IE 10+ behaves correctly when treated as a standard browser.
    // If there is a future need to detect specific versions of IE10+, we will amend this.
    var ieVersion = document && (function() {
        var version = 3, div = document.createElement('div'), iElems = div.getElementsByTagName('i');

        // Keep constructing conditional HTML blocks until we hit one that resolves to an empty fragment
        while (
            div.innerHTML = '<!--[if gt IE ' + (++version) + ']><i></i><![endif]-->',
            iElems[0]
        ) {}
        return version > 4 ? version : undefined;
    }());
    var isIe6 = ieVersion === 6,
        isIe7 = ieVersion === 7;

    function isClickOnCheckableElement(element, eventType) {
        if ((ko.utils.tagNameLower(element) !== "input") || !element.type) return false;
        if (eventType.toLowerCase() != "click") return false;
        var inputType = element.type;
        return (inputType == "checkbox") || (inputType == "radio");
    }

    return {
        fieldsIncludedWithJsonPost: ['authenticity_token', /^__RequestVerificationToken(_.*)?$/],

        arrayForEach: function (array, action) {
            for (var i = 0, j = array.length; i < j; i++)
                action(array[i]);
        },

        arrayIndexOf: function (array, item) {
            if (typeof Array.prototype.indexOf == "function")
                return Array.prototype.indexOf.call(array, item);
            for (var i = 0, j = array.length; i < j; i++)
                if (array[i] === item)
                    return i;
            return -1;
        },

        arrayFirst: function (array, predicate, predicateOwner) {
            for (var i = 0, j = array.length; i < j; i++)
                if (predicate.call(predicateOwner, array[i]))
                    return array[i];
            return null;
        },

        arrayRemoveItem: function (array, itemToRemove) {
            var index = ko.utils.arrayIndexOf(array, itemToRemove);
            if (index >= 0)
                array.splice(index, 1);
        },

        arrayGetDistinctValues: function (array) {
            array = array || [];
            var result = [];
            for (var i = 0, j = array.length; i < j; i++) {
                if (ko.utils.arrayIndexOf(result, array[i]) < 0)
                    result.push(array[i]);
            }
            return result;
        },

        arrayMap: function (array, mapping) {
            array = array || [];
            var result = [];
            for (var i = 0, j = array.length; i < j; i++)
                result.push(mapping(array[i]));
            return result;
        },

        arrayFilter: function (array, predicate) {
            array = array || [];
            var result = [];
            for (var i = 0, j = array.length; i < j; i++)
                if (predicate(array[i]))
                    result.push(array[i]);
            return result;
        },

        arrayPushAll: function (array, valuesToPush) {
            if (valuesToPush instanceof Array)
                array.push.apply(array, valuesToPush);
            else
                for (var i = 0, j = valuesToPush.length; i < j; i++)
                    array.push(valuesToPush[i]);
            return array;
        },

        addOrRemoveItem: function(array, value, included) {
            var existingEntryIndex = array.indexOf ? array.indexOf(value) : ko.utils.arrayIndexOf(array, value);
            if (existingEntryIndex < 0) {
                if (included)
                    array.push(value);
            } else {
                if (!included)
                    array.splice(existingEntryIndex, 1);
            }
        },

        extend: function (target, source) {
            if (source) {
                for(var prop in source) {
                    if(source.hasOwnProperty(prop)) {
                        target[prop] = source[prop];
                    }
                }
            }
            return target;
        },

        objectForEach: objectForEach,

        emptyDomNode: function (domNode) {
            while (domNode.firstChild) {
                ko.removeNode(domNode.firstChild);
            }
        },

        moveCleanedNodesToContainerElement: function(nodes) {
            // Ensure it's a real array, as we're about to reparent the nodes and
            // we don't want the underlying collection to change while we're doing that.
            var nodesArray = ko.utils.makeArray(nodes);

            var container = document.createElement('div');
            for (var i = 0, j = nodesArray.length; i < j; i++) {
                container.appendChild(ko.cleanNode(nodesArray[i]));
            }
            return container;
        },

        cloneNodes: function (nodesArray, shouldCleanNodes) {
            for (var i = 0, j = nodesArray.length, newNodesArray = []; i < j; i++) {
                var clonedNode = nodesArray[i].cloneNode(true);
                newNodesArray.push(shouldCleanNodes ? ko.cleanNode(clonedNode) : clonedNode);
            }
            return newNodesArray;
        },

        setDomNodeChildren: function (domNode, childNodes) {
            ko.utils.emptyDomNode(domNode);
            if (childNodes) {
                for (var i = 0, j = childNodes.length; i < j; i++)
                    domNode.appendChild(childNodes[i]);
            }
        },

        replaceDomNodes: function (nodeToReplaceOrNodeArray, newNodesArray) {
            var nodesToReplaceArray = nodeToReplaceOrNodeArray.nodeType ? [nodeToReplaceOrNodeArray] : nodeToReplaceOrNodeArray;
            if (nodesToReplaceArray.length > 0) {
                var insertionPoint = nodesToReplaceArray[0];
                var parent = insertionPoint.parentNode;
                for (var i = 0, j = newNodesArray.length; i < j; i++)
                    parent.insertBefore(newNodesArray[i], insertionPoint);
                for (var i = 0, j = nodesToReplaceArray.length; i < j; i++) {
                    ko.removeNode(nodesToReplaceArray[i]);
                }
            }
        },

        setOptionNodeSelectionState: function (optionNode, isSelected) {
            // IE6 sometimes throws "unknown error" if you try to write to .selected directly, whereas Firefox struggles with setAttribute. Pick one based on browser.
            if (ieVersion < 7)
                optionNode.setAttribute("selected", isSelected);
            else
                optionNode.selected = isSelected;
        },

        stringTrim: function (string) {
            return string === null || string === undefined ? '' :
                string.trim ?
                    string.trim() :
                    string.toString().replace(/^[\s\xa0]+|[\s\xa0]+$/g, '');
        },

        stringTokenize: function (string, delimiter) {
            var result = [];
            var tokens = (string || "").split(delimiter);
            for (var i = 0, j = tokens.length; i < j; i++) {
                var trimmed = ko.utils.stringTrim(tokens[i]);
                if (trimmed !== "")
                    result.push(trimmed);
            }
            return result;
        },

        stringStartsWith: function (string, startsWith) {
            string = string || "";
            if (startsWith.length > string.length)
                return false;
            return string.substring(0, startsWith.length) === startsWith;
        },

        domNodeIsContainedBy: function (node, containedByNode) {
            if (containedByNode.compareDocumentPosition)
                return (containedByNode.compareDocumentPosition(node) & 16) == 16;
            while (node != null) {
                if (node == containedByNode)
                    return true;
                node = node.parentNode;
            }
            return false;
        },

        domNodeIsAttachedToDocument: function (node) {
            return ko.utils.domNodeIsContainedBy(node, node.ownerDocument);
        },

        anyDomNodeIsAttachedToDocument: function(nodes) {
            return !!ko.utils.arrayFirst(nodes, ko.utils.domNodeIsAttachedToDocument);
        },

        tagNameLower: function(element) {
            // For HTML elements, tagName will always be upper case; for XHTML elements, it'll be lower case.
            // Possible future optimization: If we know it's an element from an XHTML document (not HTML),
            // we don't need to do the .toLowerCase() as it will always be lower case anyway.
            return element && element.tagName && element.tagName.toLowerCase();
        },

        registerEventHandler: function (element, eventType, handler) {
            var mustUseAttachEvent = ieVersion && eventsThatMustBeRegisteredUsingAttachEvent[eventType];
            if (!mustUseAttachEvent && typeof jQuery != "undefined") {
                if (isClickOnCheckableElement(element, eventType)) {
                    // For click events on checkboxes, jQuery interferes with the event handling in an awkward way:
                    // it toggles the element checked state *after* the click event handlers run, whereas native
                    // click events toggle the checked state *before* the event handler.
                    // Fix this by intecepting the handler and applying the correct checkedness before it runs.
                    var originalHandler = handler;
                    handler = function(event, eventData) {
                        var jQuerySuppliedCheckedState = this.checked;
                        if (eventData)
                            this.checked = eventData.checkedStateBeforeEvent !== true;
                        originalHandler.call(this, event);
                        this.checked = jQuerySuppliedCheckedState; // Restore the state jQuery applied
                    };
                }
                jQuery(element)['bind'](eventType, handler);
            } else if (!mustUseAttachEvent && typeof element.addEventListener == "function")
                element.addEventListener(eventType, handler, false);
            else if (typeof element.attachEvent != "undefined") {
                var attachEventHandler = function (event) { handler.call(element, event); },
                    attachEventName = "on" + eventType;
                element.attachEvent(attachEventName, attachEventHandler);

                // IE does not dispose attachEvent handlers automatically (unlike with addEventListener)
                // so to avoid leaks, we have to remove them manually. See bug #856
                ko.utils.domNodeDisposal.addDisposeCallback(element, function() {
                    element.detachEvent(attachEventName, attachEventHandler);
                });
            } else
                throw new Error("Browser doesn't support addEventListener or attachEvent");
        },

        triggerEvent: function (element, eventType) {
            if (!(element && element.nodeType))
                throw new Error("element must be a DOM node when calling triggerEvent");

            if (typeof jQuery != "undefined") {
                var eventData = [];
                if (isClickOnCheckableElement(element, eventType)) {
                    // Work around the jQuery "click events on checkboxes" issue described above by storing the original checked state before triggering the handler
                    eventData.push({ checkedStateBeforeEvent: element.checked });
                }
                jQuery(element)['trigger'](eventType, eventData);
            } else if (typeof document.createEvent == "function") {
                if (typeof element.dispatchEvent == "function") {
                    var eventCategory = knownEventTypesByEventName[eventType] || "HTMLEvents";
                    var event = document.createEvent(eventCategory);
                    event.initEvent(eventType, true, true, window, 0, 0, 0, 0, 0, false, false, false, false, 0, element);
                    element.dispatchEvent(event);
                }
                else
                    throw new Error("The supplied element doesn't support dispatchEvent");
            } else if (typeof element.fireEvent != "undefined") {
                // Unlike other browsers, IE doesn't change the checked state of checkboxes/radiobuttons when you trigger their "click" event
                // so to make it consistent, we'll do it manually here
                if (isClickOnCheckableElement(element, eventType))
                    element.checked = element.checked !== true;
                element.fireEvent("on" + eventType);
            }
            else
                throw new Error("Browser doesn't support triggering events");
        },

        unwrapObservable: function (value) {
            return ko.isObservable(value) ? value() : value;
        },

        peekObservable: function (value) {
            return ko.isObservable(value) ? value.peek() : value;
        },

        toggleDomNodeCssClass: function (node, classNames, shouldHaveClass) {
            if (classNames) {
                var cssClassNameRegex = /\S+/g,
                    currentClassNames = node.className.match(cssClassNameRegex) || [];
                ko.utils.arrayForEach(classNames.match(cssClassNameRegex), function(className) {
                    ko.utils.addOrRemoveItem(currentClassNames, className, shouldHaveClass);
                });
                node.className = currentClassNames.join(" ");
            }
        },

        setTextContent: function(element, textContent) {
            var value = ko.utils.unwrapObservable(textContent);
            if ((value === null) || (value === undefined))
                value = "";

            // We need there to be exactly one child: a text node.
            // If there are no children, more than one, or if it's not a text node,
            // we'll clear everything and create a single text node.
            var innerTextNode = ko.virtualElements.firstChild(element);
            if (!innerTextNode || innerTextNode.nodeType != 3 || ko.virtualElements.nextSibling(innerTextNode)) {
                ko.virtualElements.setDomNodeChildren(element, [document.createTextNode(value)]);
            } else {
                innerTextNode.data = value;
            }

            ko.utils.forceRefresh(element);
        },

        setElementName: function(element, name) {
            element.name = name;

            // Workaround IE 6/7 issue
            // - https://github.com/SteveSanderson/knockout/issues/197
            // - http://www.matts411.com/post/setting_the_name_attribute_in_ie_dom/
            if (ieVersion <= 7) {
                try {
                    element.mergeAttributes(document.createElement("<input name='" + element.name + "'/>"), false);
                }
                catch(e) {} // For IE9 with doc mode "IE9 Standards" and browser mode "IE9 Compatibility View"
            }
        },

        forceRefresh: function(node) {
            // Workaround for an IE9 rendering bug - https://github.com/SteveSanderson/knockout/issues/209
            if (ieVersion >= 9) {
                // For text nodes and comment nodes (most likely virtual elements), we will have to refresh the container
                var elem = node.nodeType == 1 ? node : node.parentNode;
                if (elem.style)
                    elem.style.zoom = elem.style.zoom;
            }
        },

        ensureSelectElementIsRenderedCorrectly: function(selectElement) {
            // Workaround for IE9 rendering bug - it doesn't reliably display all the text in dynamically-added select boxes unless you force it to re-render by updating the width.
            // (See https://github.com/SteveSanderson/knockout/issues/312, http://stackoverflow.com/questions/5908494/select-only-shows-first-char-of-selected-option)
            // Also fixes IE7 and IE8 bug that causes selects to be zero width if enclosed by 'if' or 'with'. (See issue #839)
            if (ieVersion) {
                var originalWidth = selectElement.style.width;
                selectElement.style.width = 0;
                selectElement.style.width = originalWidth;
            }
        },

        range: function (min, max) {
            min = ko.utils.unwrapObservable(min);
            max = ko.utils.unwrapObservable(max);
            var result = [];
            for (var i = min; i <= max; i++)
                result.push(i);
            return result;
        },

        makeArray: function(arrayLikeObject) {
            var result = [];
            for (var i = 0, j = arrayLikeObject.length; i < j; i++) {
                result.push(arrayLikeObject[i]);
            };
            return result;
        },

        isIe6 : isIe6,
        isIe7 : isIe7,
        ieVersion : ieVersion,

        getFormFields: function(form, fieldName) {
            var fields = ko.utils.makeArray(form.getElementsByTagName("input")).concat(ko.utils.makeArray(form.getElementsByTagName("textarea")));
            var isMatchingField = (typeof fieldName == 'string')
                ? function(field) { return field.name === fieldName }
                : function(field) { return fieldName.test(field.name) }; // Treat fieldName as regex or object containing predicate
            var matches = [];
            for (var i = fields.length - 1; i >= 0; i--) {
                if (isMatchingField(fields[i]))
                    matches.push(fields[i]);
            };
            return matches;
        },

        parseJson: function (jsonString) {
            if (typeof jsonString == "string") {
                jsonString = ko.utils.stringTrim(jsonString);
                if (jsonString) {
                    if (JSON && JSON.parse) // Use native parsing where available
                        return JSON.parse(jsonString);
                    return (new Function("return " + jsonString))(); // Fallback on less safe parsing for older browsers
                }
            }
            return null;
        },

        stringifyJson: function (data, replacer, space) {   // replacer and space are optional
            if (!JSON || !JSON.stringify)
                throw new Error("Cannot find JSON.stringify(). Some browsers (e.g., IE < 8) don't support it natively, but you can overcome this by adding a script reference to json2.js, downloadable from http://www.json.org/json2.js");
            return JSON.stringify(ko.utils.unwrapObservable(data), replacer, space);
        },

        postJson: function (urlOrForm, data, options) {
            options = options || {};
            var params = options['params'] || {};
            var includeFields = options['includeFields'] || this.fieldsIncludedWithJsonPost;
            var url = urlOrForm;

            // If we were given a form, use its 'action' URL and pick out any requested field values
            if((typeof urlOrForm == 'object') && (ko.utils.tagNameLower(urlOrForm) === "form")) {
                var originalForm = urlOrForm;
                url = originalForm.action;
                for (var i = includeFields.length - 1; i >= 0; i--) {
                    var fields = ko.utils.getFormFields(originalForm, includeFields[i]);
                    for (var j = fields.length - 1; j >= 0; j--)
                        params[fields[j].name] = fields[j].value;
                }
            }

            data = ko.utils.unwrapObservable(data);
            var form = document.createElement("form");
            form.style.display = "none";
            form.action = url;
            form.method = "post";
            for (var key in data) {
                // Since 'data' this is a model object, we include all properties including those inherited from its prototype
                var input = document.createElement("input");
                input.name = key;
                input.value = ko.utils.stringifyJson(ko.utils.unwrapObservable(data[key]));
                form.appendChild(input);
            }
            objectForEach(params, function(key, value) {
                var input = document.createElement("input");
                input.name = key;
                input.value = value;
                form.appendChild(input);
            });
            document.body.appendChild(form);
            options['submitter'] ? options['submitter'](form) : form.submit();
            setTimeout(function () { form.parentNode.removeChild(form); }, 0);
        }
    }
}());

ko.exportSymbol('utils', ko.utils);
ko.exportSymbol('utils.arrayForEach', ko.utils.arrayForEach);
ko.exportSymbol('utils.arrayFirst', ko.utils.arrayFirst);
ko.exportSymbol('utils.arrayFilter', ko.utils.arrayFilter);
ko.exportSymbol('utils.arrayGetDistinctValues', ko.utils.arrayGetDistinctValues);
ko.exportSymbol('utils.arrayIndexOf', ko.utils.arrayIndexOf);
ko.exportSymbol('utils.arrayMap', ko.utils.arrayMap);
ko.exportSymbol('utils.arrayPushAll', ko.utils.arrayPushAll);
ko.exportSymbol('utils.arrayRemoveItem', ko.utils.arrayRemoveItem);
ko.exportSymbol('utils.extend', ko.utils.extend);
ko.exportSymbol('utils.fieldsIncludedWithJsonPost', ko.utils.fieldsIncludedWithJsonPost);
ko.exportSymbol('utils.getFormFields', ko.utils.getFormFields);
ko.exportSymbol('utils.peekObservable', ko.utils.peekObservable);
ko.exportSymbol('utils.postJson', ko.utils.postJson);
ko.exportSymbol('utils.parseJson', ko.utils.parseJson);
ko.exportSymbol('utils.registerEventHandler', ko.utils.registerEventHandler);
ko.exportSymbol('utils.stringifyJson', ko.utils.stringifyJson);
ko.exportSymbol('utils.range', ko.utils.range);
ko.exportSymbol('utils.toggleDomNodeCssClass', ko.utils.toggleDomNodeCssClass);
ko.exportSymbol('utils.triggerEvent', ko.utils.triggerEvent);
ko.exportSymbol('utils.unwrapObservable', ko.utils.unwrapObservable);
ko.exportSymbol('utils.objectForEach', ko.utils.objectForEach);
ko.exportSymbol('utils.addOrRemoveItem', ko.utils.addOrRemoveItem);
ko.exportSymbol('unwrap', ko.utils.unwrapObservable); // Convenient shorthand, because this is used so commonly

if (!Function.prototype['bind']) {
    // Function.prototype.bind is a standard part of ECMAScript 5th Edition (December 2009, http://www.ecma-international.org/publications/files/ECMA-ST/ECMA-262.pdf)
    // In case the browser doesn't implement it natively, provide a JavaScript implementation. This implementation is based on the one in prototype.js
    Function.prototype['bind'] = function (object) {
        var originalFunction = this, args = Array.prototype.slice.call(arguments), object = args.shift();
        return function () {
            return originalFunction.apply(object, args.concat(Array.prototype.slice.call(arguments)));
        };
    };
}

ko.utils.domData = new (function () {
    var uniqueId = 0;
    var dataStoreKeyExpandoPropertyName = "__ko__" + (new Date).getTime();
    var dataStore = {};
    return {
        get: function (node, key) {
            var allDataForNode = ko.utils.domData.getAll(node, false);
            return allDataForNode === undefined ? undefined : allDataForNode[key];
        },
        set: function (node, key, value) {
            if (value === undefined) {
                // Make sure we don't actually create a new domData key if we are actually deleting a value
                if (ko.utils.domData.getAll(node, false) === undefined)
                    return;
            }
            var allDataForNode = ko.utils.domData.getAll(node, true);
            allDataForNode[key] = value;
        },
        getAll: function (node, createIfNotFound) {
            var dataStoreKey = node[dataStoreKeyExpandoPropertyName];
            var hasExistingDataStore = dataStoreKey && (dataStoreKey !== "null") && dataStore[dataStoreKey];
            if (!hasExistingDataStore) {
                if (!createIfNotFound)
                    return undefined;
                dataStoreKey = node[dataStoreKeyExpandoPropertyName] = "ko" + uniqueId++;
                dataStore[dataStoreKey] = {};
            }
            return dataStore[dataStoreKey];
        },
        clear: function (node) {
            var dataStoreKey = node[dataStoreKeyExpandoPropertyName];
            if (dataStoreKey) {
                delete dataStore[dataStoreKey];
                node[dataStoreKeyExpandoPropertyName] = null;
                return true; // Exposing "did clean" flag purely so specs can infer whether things have been cleaned up as intended
            }
            return false;
        }
    }
})();

ko.exportSymbol('utils.domData', ko.utils.domData);
ko.exportSymbol('utils.domData.clear', ko.utils.domData.clear); // Exporting only so specs can clear up after themselves fully

ko.utils.domNodeDisposal = new (function () {
    var domDataKey = "__ko_domNodeDisposal__" + (new Date).getTime();
    var cleanableNodeTypes = { 1: true, 8: true, 9: true };       // Element, Comment, Document
    var cleanableNodeTypesWithDescendants = { 1: true, 9: true }; // Element, Document

    function getDisposeCallbacksCollection(node, createIfNotFound) {
        var allDisposeCallbacks = ko.utils.domData.get(node, domDataKey);
        if ((allDisposeCallbacks === undefined) && createIfNotFound) {
            allDisposeCallbacks = [];
            ko.utils.domData.set(node, domDataKey, allDisposeCallbacks);
        }
        return allDisposeCallbacks;
    }
    function destroyCallbacksCollection(node) {
        ko.utils.domData.set(node, domDataKey, undefined);
    }

    function cleanSingleNode(node) {
        // Run all the dispose callbacks
        var callbacks = getDisposeCallbacksCollection(node, false);
        if (callbacks) {
            callbacks = callbacks.slice(0); // Clone, as the array may be modified during iteration (typically, callbacks will remove themselves)
            for (var i = 0; i < callbacks.length; i++)
                callbacks[i](node);
        }

        // Also erase the DOM data
        ko.utils.domData.clear(node);

        // Special support for jQuery here because it's so commonly used.
        // Many jQuery plugins (including jquery.tmpl) store data using jQuery's equivalent of domData
        // so notify it to tear down any resources associated with the node & descendants here.
        if ((typeof jQuery == "function") && (typeof jQuery['cleanData'] == "function"))
            jQuery['cleanData']([node]);

        // Also clear any immediate-child comment nodes, as these wouldn't have been found by
        // node.getElementsByTagName("*") in cleanNode() (comment nodes aren't elements)
        if (cleanableNodeTypesWithDescendants[node.nodeType])
            cleanImmediateCommentTypeChildren(node);
    }

    function cleanImmediateCommentTypeChildren(nodeWithChildren) {
        var child, nextChild = nodeWithChildren.firstChild;
        while (child = nextChild) {
            nextChild = child.nextSibling;
            if (child.nodeType === 8)
                cleanSingleNode(child);
        }
    }

    return {
        addDisposeCallback : function(node, callback) {
            if (typeof callback != "function")
                throw new Error("Callback must be a function");
            getDisposeCallbacksCollection(node, true).push(callback);
        },

        removeDisposeCallback : function(node, callback) {
            var callbacksCollection = getDisposeCallbacksCollection(node, false);
            if (callbacksCollection) {
                ko.utils.arrayRemoveItem(callbacksCollection, callback);
                if (callbacksCollection.length == 0)
                    destroyCallbacksCollection(node);
            }
        },

        cleanNode : function(node) {
            // First clean this node, where applicable
            if (cleanableNodeTypes[node.nodeType]) {
                cleanSingleNode(node);

                // ... then its descendants, where applicable
                if (cleanableNodeTypesWithDescendants[node.nodeType]) {
                    // Clone the descendants list in case it changes during iteration
                    var descendants = [];
                    ko.utils.arrayPushAll(descendants, node.getElementsByTagName("*"));
                    for (var i = 0, j = descendants.length; i < j; i++)
                        cleanSingleNode(descendants[i]);
                }
            }
            return node;
        },

        removeNode : function(node) {
            ko.cleanNode(node);
            if (node.parentNode)
                node.parentNode.removeChild(node);
        }
    }
})();
ko.cleanNode = ko.utils.domNodeDisposal.cleanNode; // Shorthand name for convenience
ko.removeNode = ko.utils.domNodeDisposal.removeNode; // Shorthand name for convenience
ko.exportSymbol('cleanNode', ko.cleanNode);
ko.exportSymbol('removeNode', ko.removeNode);
ko.exportSymbol('utils.domNodeDisposal', ko.utils.domNodeDisposal);
ko.exportSymbol('utils.domNodeDisposal.addDisposeCallback', ko.utils.domNodeDisposal.addDisposeCallback);
ko.exportSymbol('utils.domNodeDisposal.removeDisposeCallback', ko.utils.domNodeDisposal.removeDisposeCallback);
(function () {
    var leadingCommentRegex = /^(\s*)<!--(.*?)-->/;

    function simpleHtmlParse(html) {
        // Based on jQuery's "clean" function, but only accounting for table-related elements.
        // If you have referenced jQuery, this won't be used anyway - KO will use jQuery's "clean" function directly

        // Note that there's still an issue in IE < 9 whereby it will discard comment nodes that are the first child of
        // a descendant node. For example: "<div><!-- mycomment -->abc</div>" will get parsed as "<div>abc</div>"
        // This won't affect anyone who has referenced jQuery, and there's always the workaround of inserting a dummy node
        // (possibly a text node) in front of the comment. So, KO does not attempt to workaround this IE issue automatically at present.

        // Trim whitespace, otherwise indexOf won't work as expected
        var tags = ko.utils.stringTrim(html).toLowerCase(), div = document.createElement("div");

        // Finds the first match from the left column, and returns the corresponding "wrap" data from the right column
        var wrap = tags.match(/^<(thead|tbody|tfoot)/)              && [1, "<table>", "</table>"] ||
                   !tags.indexOf("<tr")                             && [2, "<table><tbody>", "</tbody></table>"] ||
                   (!tags.indexOf("<td") || !tags.indexOf("<th"))   && [3, "<table><tbody><tr>", "</tr></tbody></table>"] ||
                   /* anything else */                                 [0, "", ""];

        // Go to html and back, then peel off extra wrappers
        // Note that we always prefix with some dummy text, because otherwise, IE<9 will strip out leading comment nodes in descendants. Total madness.
        var markup = "ignored<div>" + wrap[1] + html + wrap[2] + "</div>";
        if (typeof window['innerShiv'] == "function") {
            div.appendChild(window['innerShiv'](markup));
        } else {
            div.innerHTML = markup;
        }

        // Move to the right depth
        while (wrap[0]--)
            div = div.lastChild;

        return ko.utils.makeArray(div.lastChild.childNodes);
    }

    function jQueryHtmlParse(html) {
        // jQuery's "parseHTML" function was introduced in jQuery 1.8.0 and is a documented public API.
        if (jQuery['parseHTML']) {
            return jQuery['parseHTML'](html) || []; // Ensure we always return an array and never null
        } else {
            // For jQuery < 1.8.0, we fall back on the undocumented internal "clean" function.
            var elems = jQuery['clean']([html]);

            // As of jQuery 1.7.1, jQuery parses the HTML by appending it to some dummy parent nodes held in an in-memory document fragment.
            // Unfortunately, it never clears the dummy parent nodes from the document fragment, so it leaks memory over time.
            // Fix this by finding the top-most dummy parent element, and detaching it from its owner fragment.
            if (elems && elems[0]) {
                // Find the top-most parent element that's a direct child of a document fragment
                var elem = elems[0];
                while (elem.parentNode && elem.parentNode.nodeType !== 11 /* i.e., DocumentFragment */)
                    elem = elem.parentNode;
                // ... then detach it
                if (elem.parentNode)
                    elem.parentNode.removeChild(elem);
            }

            return elems;
        }
    }

    ko.utils.parseHtmlFragment = function(html) {
        return typeof jQuery != 'undefined' ? jQueryHtmlParse(html)   // As below, benefit from jQuery's optimisations where possible
                                            : simpleHtmlParse(html);  // ... otherwise, this simple logic will do in most common cases.
    };

    ko.utils.setHtml = function(node, html) {
        ko.utils.emptyDomNode(node);

        // There's no legitimate reason to display a stringified observable without unwrapping it, so we'll unwrap it
        html = ko.utils.unwrapObservable(html);

        if ((html !== null) && (html !== undefined)) {
            if (typeof html != 'string')
                html = html.toString();

            // jQuery contains a lot of sophisticated code to parse arbitrary HTML fragments,
            // for example <tr> elements which are not normally allowed to exist on their own.
            // If you've referenced jQuery we'll use that rather than duplicating its code.
            if (typeof jQuery != 'undefined') {
                jQuery(node)['html'](html);
            } else {
                // ... otherwise, use KO's own parsing logic.
                var parsedNodes = ko.utils.parseHtmlFragment(html);
                for (var i = 0; i < parsedNodes.length; i++)
                    node.appendChild(parsedNodes[i]);
            }
        }
    };
})();

ko.exportSymbol('utils.parseHtmlFragment', ko.utils.parseHtmlFragment);
ko.exportSymbol('utils.setHtml', ko.utils.setHtml);

ko.memoization = (function () {
    var memos = {};

    function randomMax8HexChars() {
        return (((1 + Math.random()) * 0x100000000) | 0).toString(16).substring(1);
    }
    function generateRandomId() {
        return randomMax8HexChars() + randomMax8HexChars();
    }
    function findMemoNodes(rootNode, appendToArray) {
        if (!rootNode)
            return;
        if (rootNode.nodeType == 8) {
            var memoId = ko.memoization.parseMemoText(rootNode.nodeValue);
            if (memoId != null)
                appendToArray.push({ domNode: rootNode, memoId: memoId });
        } else if (rootNode.nodeType == 1) {
            for (var i = 0, childNodes = rootNode.childNodes, j = childNodes.length; i < j; i++)
                findMemoNodes(childNodes[i], appendToArray);
        }
    }

    return {
        memoize: function (callback) {
            if (typeof callback != "function")
                throw new Error("You can only pass a function to ko.memoization.memoize()");
            var memoId = generateRandomId();
            memos[memoId] = callback;
            return "<!--[ko_memo:" + memoId + "]-->";
        },

        unmemoize: function (memoId, callbackParams) {
            var callback = memos[memoId];
            if (callback === undefined)
                throw new Error("Couldn't find any memo with ID " + memoId + ". Perhaps it's already been unmemoized.");
            try {
                callback.apply(null, callbackParams || []);
                return true;
            }
            finally { delete memos[memoId]; }
        },

        unmemoizeDomNodeAndDescendants: function (domNode, extraCallbackParamsArray) {
            var memos = [];
            findMemoNodes(domNode, memos);
            for (var i = 0, j = memos.length; i < j; i++) {
                var node = memos[i].domNode;
                var combinedParams = [node];
                if (extraCallbackParamsArray)
                    ko.utils.arrayPushAll(combinedParams, extraCallbackParamsArray);
                ko.memoization.unmemoize(memos[i].memoId, combinedParams);
                node.nodeValue = ""; // Neuter this node so we don't try to unmemoize it again
                if (node.parentNode)
                    node.parentNode.removeChild(node); // If possible, erase it totally (not always possible - someone else might just hold a reference to it then call unmemoizeDomNodeAndDescendants again)
            }
        },

        parseMemoText: function (memoText) {
            var match = memoText.match(/^\[ko_memo\:(.*?)\]$/);
            return match ? match[1] : null;
        }
    };
})();

ko.exportSymbol('memoization', ko.memoization);
ko.exportSymbol('memoization.memoize', ko.memoization.memoize);
ko.exportSymbol('memoization.unmemoize', ko.memoization.unmemoize);
ko.exportSymbol('memoization.parseMemoText', ko.memoization.parseMemoText);
ko.exportSymbol('memoization.unmemoizeDomNodeAndDescendants', ko.memoization.unmemoizeDomNodeAndDescendants);
ko.extenders = {
    'throttle': function(target, timeout) {
        // Throttling means two things:

        // (1) For dependent observables, we throttle *evaluations* so that, no matter how fast its dependencies
        //     notify updates, the target doesn't re-evaluate (and hence doesn't notify) faster than a certain rate
        target['throttleEvaluation'] = timeout;

        // (2) For writable targets (observables, or writable dependent observables), we throttle *writes*
        //     so the target cannot change value synchronously or faster than a certain rate
        var writeTimeoutInstance = null;
        return ko.dependentObservable({
            'read': target,
            'write': function(value) {
                clearTimeout(writeTimeoutInstance);
                writeTimeoutInstance = setTimeout(function() {
                    target(value);
                }, timeout);
            }
        });
    },

    'notify': function(target, notifyWhen) {
        target["equalityComparer"] = notifyWhen == "always"
            ? function() { return false } // Treat all values as not equal
            : ko.observable["fn"]["equalityComparer"];
        return target;
    }
};

function applyExtenders(requestedExtenders) {
    var target = this;
    if (requestedExtenders) {
        ko.utils.objectForEach(requestedExtenders, function(key, value) {
            var extenderHandler = ko.extenders[key];
            if (typeof extenderHandler == 'function') {
                target = extenderHandler(target, value);
            }
        });
    }
    return target;
}

ko.exportSymbol('extenders', ko.extenders);

ko.subscription = function (target, callback, disposeCallback) {
    this.target = target;
    this.callback = callback;
    this.disposeCallback = disposeCallback;
    ko.exportProperty(this, 'dispose', this.dispose);
};
ko.subscription.prototype.dispose = function () {
    this.isDisposed = true;
    this.disposeCallback();
};

ko.subscribable = function () {
    this._subscriptions = {};

    ko.utils.extend(this, ko.subscribable['fn']);
    ko.exportProperty(this, 'subscribe', this.subscribe);
    ko.exportProperty(this, 'extend', this.extend);
    ko.exportProperty(this, 'getSubscriptionsCount', this.getSubscriptionsCount);
}

var defaultEvent = "change";

ko.subscribable['fn'] = {
    subscribe: function (callback, callbackTarget, event) {
        event = event || defaultEvent;
        var boundCallback = callbackTarget ? callback.bind(callbackTarget) : callback;

        var subscription = new ko.subscription(this, boundCallback, function () {
            ko.utils.arrayRemoveItem(this._subscriptions[event], subscription);
        }.bind(this));

        if (!this._subscriptions[event])
            this._subscriptions[event] = [];
        this._subscriptions[event].push(subscription);
        return subscription;
    },

    "notifySubscribers": function (valueToNotify, event) {
        event = event || defaultEvent;
        if (this._subscriptions[event]) {
            ko.dependencyDetection.ignore(function() {
                ko.utils.arrayForEach(this._subscriptions[event].slice(0), function (subscription) {
                    // In case a subscription was disposed during the arrayForEach cycle, check
                    // for isDisposed on each subscription before invoking its callback
                    if (subscription && (subscription.isDisposed !== true))
                        subscription.callback(valueToNotify);
                });
            }, this);
        }
    },

    getSubscriptionsCount: function () {
        var total = 0;
        ko.utils.objectForEach(this._subscriptions, function(eventName, subscriptions) {
            total += subscriptions.length;
        });
        return total;
    },

    extend: applyExtenders
};


ko.isSubscribable = function (instance) {
    return instance != null && typeof instance.subscribe == "function" && typeof instance["notifySubscribers"] == "function";
};

ko.exportSymbol('subscribable', ko.subscribable);
ko.exportSymbol('isSubscribable', ko.isSubscribable);

ko.dependencyDetection = (function () {
    var _frames = [];

    return {
        begin: function (callback) {
            _frames.push({ callback: callback, distinctDependencies:[] });
        },

        end: function () {
            _frames.pop();
        },

        registerDependency: function (subscribable) {
            if (!ko.isSubscribable(subscribable))
                throw new Error("Only subscribable things can act as dependencies");
            if (_frames.length > 0) {
                var topFrame = _frames[_frames.length - 1];
                if (!topFrame || ko.utils.arrayIndexOf(topFrame.distinctDependencies, subscribable) >= 0)
                    return;
                topFrame.distinctDependencies.push(subscribable);
                topFrame.callback(subscribable);
            }
        },

        ignore: function(callback, callbackTarget, callbackArgs) {
            try {
                _frames.push(null);
                return callback.apply(callbackTarget, callbackArgs || []);
            } finally {
                _frames.pop();
            }
        }
    };
})();
var primitiveTypes = { 'undefined':true, 'boolean':true, 'number':true, 'string':true };

ko.observable = function (initialValue) {
    var _latestValue = initialValue;

    function observable() {
        if (arguments.length > 0) {
            // Write

            // Ignore writes if the value hasn't changed
            if ((!observable['equalityComparer']) || !observable['equalityComparer'](_latestValue, arguments[0])) {
                observable.valueWillMutate();
                _latestValue = arguments[0];
                if (DEBUG) observable._latestValue = _latestValue;
                observable.valueHasMutated();
            }
            return this; // Permits chained assignments
        }
        else {
            // Read
            ko.dependencyDetection.registerDependency(observable); // The caller only needs to be notified of changes if they did a "read" operation
            return _latestValue;
        }
    }
    if (DEBUG) observable._latestValue = _latestValue;
    ko.subscribable.call(observable);
    observable.peek = function() { return _latestValue };
    observable.valueHasMutated = function () { observable["notifySubscribers"](_latestValue); }
    observable.valueWillMutate = function () { observable["notifySubscribers"](_latestValue, "beforeChange"); }
    ko.utils.extend(observable, ko.observable['fn']);

    ko.exportProperty(observable, 'peek', observable.peek);
    ko.exportProperty(observable, "valueHasMutated", observable.valueHasMutated);
    ko.exportProperty(observable, "valueWillMutate", observable.valueWillMutate);

    return observable;
}

ko.observable['fn'] = {
    "equalityComparer": function valuesArePrimitiveAndEqual(a, b) {
        var oldValueIsPrimitive = (a === null) || (typeof(a) in primitiveTypes);
        return oldValueIsPrimitive ? (a === b) : false;
    }
};

var protoProperty = ko.observable.protoProperty = "__ko_proto__";
ko.observable['fn'][protoProperty] = ko.observable;

ko.hasPrototype = function(instance, prototype) {
    if ((instance === null) || (instance === undefined) || (instance[protoProperty] === undefined)) return false;
    if (instance[protoProperty] === prototype) return true;
    return ko.hasPrototype(instance[protoProperty], prototype); // Walk the prototype chain
};

ko.isObservable = function (instance) {
    return ko.hasPrototype(instance, ko.observable);
}
ko.isWriteableObservable = function (instance) {
    // Observable
    if ((typeof instance == "function") && instance[protoProperty] === ko.observable)
        return true;
    // Writeable dependent observable
    if ((typeof instance == "function") && (instance[protoProperty] === ko.dependentObservable) && (instance.hasWriteFunction))
        return true;
    // Anything else
    return false;
}


ko.exportSymbol('observable', ko.observable);
ko.exportSymbol('isObservable', ko.isObservable);
ko.exportSymbol('isWriteableObservable', ko.isWriteableObservable);
ko.observableArray = function (initialValues) {
    initialValues = initialValues || [];

    if (typeof initialValues != 'object' || !('length' in initialValues))
        throw new Error("The argument passed when initializing an observable array must be an array, or null, or undefined.");

    var result = ko.observable(initialValues);
    ko.utils.extend(result, ko.observableArray['fn']);
    return result;
};

ko.observableArray['fn'] = {
    'remove': function (valueOrPredicate) {
        var underlyingArray = this.peek();
        var removedValues = [];
        var predicate = typeof valueOrPredicate == "function" ? valueOrPredicate : function (value) { return value === valueOrPredicate; };
        for (var i = 0; i < underlyingArray.length; i++) {
            var value = underlyingArray[i];
            if (predicate(value)) {
                if (removedValues.length === 0) {
                    this.valueWillMutate();
                }
                removedValues.push(value);
                underlyingArray.splice(i, 1);
                i--;
            }
        }
        if (removedValues.length) {
            this.valueHasMutated();
        }
        return removedValues;
    },

    'removeAll': function (arrayOfValues) {
        // If you passed zero args, we remove everything
        if (arrayOfValues === undefined) {
            var underlyingArray = this.peek();
            var allValues = underlyingArray.slice(0);
            this.valueWillMutate();
            underlyingArray.splice(0, underlyingArray.length);
            this.valueHasMutated();
            return allValues;
        }
        // If you passed an arg, we interpret it as an array of entries to remove
        if (!arrayOfValues)
            return [];
        return this['remove'](function (value) {
            return ko.utils.arrayIndexOf(arrayOfValues, value) >= 0;
        });
    },

    'destroy': function (valueOrPredicate) {
        var underlyingArray = this.peek();
        var predicate = typeof valueOrPredicate == "function" ? valueOrPredicate : function (value) { return value === valueOrPredicate; };
        this.valueWillMutate();
        for (var i = underlyingArray.length - 1; i >= 0; i--) {
            var value = underlyingArray[i];
            if (predicate(value))
                underlyingArray[i]["_destroy"] = true;
        }
        this.valueHasMutated();
    },

    'destroyAll': function (arrayOfValues) {
        // If you passed zero args, we destroy everything
        if (arrayOfValues === undefined)
            return this['destroy'](function() { return true });

        // If you passed an arg, we interpret it as an array of entries to destroy
        if (!arrayOfValues)
            return [];
        return this['destroy'](function (value) {
            return ko.utils.arrayIndexOf(arrayOfValues, value) >= 0;
        });
    },

    'indexOf': function (item) {
        var underlyingArray = this();
        return ko.utils.arrayIndexOf(underlyingArray, item);
    },

    'replace': function(oldItem, newItem) {
        var index = this['indexOf'](oldItem);
        if (index >= 0) {
            this.valueWillMutate();
            this.peek()[index] = newItem;
            this.valueHasMutated();
        }
    }
};

// Populate ko.observableArray.fn with read/write functions from native arrays
// Important: Do not add any additional functions here that may reasonably be used to *read* data from the array
// because we'll eval them without causing subscriptions, so ko.computed output could end up getting stale
ko.utils.arrayForEach(["pop", "push", "reverse", "shift", "sort", "splice", "unshift"], function (methodName) {
    ko.observableArray['fn'][methodName] = function () {
        // Use "peek" to avoid creating a subscription in any computed that we're executing in the context of
        // (for consistency with mutating regular observables)
        var underlyingArray = this.peek();
        this.valueWillMutate();
        var methodCallResult = underlyingArray[methodName].apply(underlyingArray, arguments);
        this.valueHasMutated();
        return methodCallResult;
    };
});

// Populate ko.observableArray.fn with read-only functions from native arrays
ko.utils.arrayForEach(["slice"], function (methodName) {
    ko.observableArray['fn'][methodName] = function () {
        var underlyingArray = this();
        return underlyingArray[methodName].apply(underlyingArray, arguments);
    };
});

ko.exportSymbol('observableArray', ko.observableArray);
ko.dependentObservable = function (evaluatorFunctionOrOptions, evaluatorFunctionTarget, options) {
    var _latestValue,
        _hasBeenEvaluated = false,
        _isBeingEvaluated = false,
        readFunction = evaluatorFunctionOrOptions;

    if (readFunction && typeof readFunction == "object") {
        // Single-parameter syntax - everything is on this "options" param
        options = readFunction;
        readFunction = options["read"];
    } else {
        // Multi-parameter syntax - construct the options according to the params passed
        options = options || {};
        if (!readFunction)
            readFunction = options["read"];
    }
    if (typeof readFunction != "function")
        throw new Error("Pass a function that returns the value of the ko.computed");

    function addSubscriptionToDependency(subscribable) {
        _subscriptionsToDependencies.push(subscribable.subscribe(evaluatePossiblyAsync));
    }

    function disposeAllSubscriptionsToDependencies() {
        ko.utils.arrayForEach(_subscriptionsToDependencies, function (subscription) {
            subscription.dispose();
        });
        _subscriptionsToDependencies = [];
    }

    function evaluatePossiblyAsync() {
        var throttleEvaluationTimeout = dependentObservable['throttleEvaluation'];
        if (throttleEvaluationTimeout && throttleEvaluationTimeout >= 0) {
            clearTimeout(evaluationTimeoutInstance);
            evaluationTimeoutInstance = setTimeout(evaluateImmediate, throttleEvaluationTimeout);
        } else
            evaluateImmediate();
    }

    function evaluateImmediate() {
        if (_isBeingEvaluated) {
            // If the evaluation of a ko.computed causes side effects, it's possible that it will trigger its own re-evaluation.
            // This is not desirable (it's hard for a developer to realise a chain of dependencies might cause this, and they almost
            // certainly didn't intend infinite re-evaluations). So, for predictability, we simply prevent ko.computeds from causing
            // their own re-evaluation. Further discussion at https://github.com/SteveSanderson/knockout/pull/387
            return;
        }

        // Don't dispose on first evaluation, because the "disposeWhen" callback might
        // e.g., dispose when the associated DOM element isn't in the doc, and it's not
        // going to be in the doc until *after* the first evaluation
        if (_hasBeenEvaluated && disposeWhen()) {
            dispose();
            return;
        }

        _isBeingEvaluated = true;
        try {
            // Initially, we assume that none of the subscriptions are still being used (i.e., all are candidates for disposal).
            // Then, during evaluation, we cross off any that are in fact still being used.
            var disposalCandidates = ko.utils.arrayMap(_subscriptionsToDependencies, function(item) {return item.target;});

            ko.dependencyDetection.begin(function(subscribable) {
                var inOld;
                if ((inOld = ko.utils.arrayIndexOf(disposalCandidates, subscribable)) >= 0)
                    disposalCandidates[inOld] = undefined; // Don't want to dispose this subscription, as it's still being used
                else
                    addSubscriptionToDependency(subscribable); // Brand new subscription - add it
            });

            var newValue = readFunction.call(evaluatorFunctionTarget);

            // For each subscription no longer being used, remove it from the active subscriptions list and dispose it
            for (var i = disposalCandidates.length - 1; i >= 0; i--) {
                if (disposalCandidates[i])
                    _subscriptionsToDependencies.splice(i, 1)[0].dispose();
            }
            _hasBeenEvaluated = true;

            dependentObservable["notifySubscribers"](_latestValue, "beforeChange");

            _latestValue = newValue;
            if (DEBUG) dependentObservable._latestValue = _latestValue;
            dependentObservable["notifySubscribers"](_latestValue);

        } finally {
            ko.dependencyDetection.end();
            _isBeingEvaluated = false;
        }

        if (!_subscriptionsToDependencies.length)
            dispose();
    }

    function dependentObservable() {
        if (arguments.length > 0) {
            if (typeof writeFunction === "function") {
                // Writing a value
                writeFunction.apply(evaluatorFunctionTarget, arguments);
            } else {
                throw new Error("Cannot write a value to a ko.computed unless you specify a 'write' option. If you wish to read the current value, don't pass any parameters.");
            }
            return this; // Permits chained assignments
        } else {
            // Reading the value
            if (!_hasBeenEvaluated)
                evaluateImmediate();
            ko.dependencyDetection.registerDependency(dependentObservable);
            return _latestValue;
        }
    }

    function peek() {
        if (!_hasBeenEvaluated)
            evaluateImmediate();
        return _latestValue;
    }

    function isActive() {
        return !_hasBeenEvaluated || _subscriptionsToDependencies.length > 0;
    }

    // By here, "options" is always non-null
    var writeFunction = options["write"],
        disposeWhenNodeIsRemoved = options["disposeWhenNodeIsRemoved"] || options.disposeWhenNodeIsRemoved || null,
        disposeWhen = options["disposeWhen"] || options.disposeWhen || function() { return false; },
        dispose = disposeAllSubscriptionsToDependencies,
        _subscriptionsToDependencies = [],
        evaluationTimeoutInstance = null;

    if (!evaluatorFunctionTarget)
        evaluatorFunctionTarget = options["owner"];

    dependentObservable.peek = peek;
    dependentObservable.getDependenciesCount = function () { return _subscriptionsToDependencies.length; };
    dependentObservable.hasWriteFunction = typeof options["write"] === "function";
    dependentObservable.dispose = function () { dispose(); };
    dependentObservable.isActive = isActive;

    ko.subscribable.call(dependentObservable);
    ko.utils.extend(dependentObservable, ko.dependentObservable['fn']);

    ko.exportProperty(dependentObservable, 'peek', dependentObservable.peek);
    ko.exportProperty(dependentObservable, 'dispose', dependentObservable.dispose);
    ko.exportProperty(dependentObservable, 'isActive', dependentObservable.isActive);
    ko.exportProperty(dependentObservable, 'getDependenciesCount', dependentObservable.getDependenciesCount);

    // Evaluate, unless deferEvaluation is true
    if (options['deferEvaluation'] !== true)
        evaluateImmediate();

    // Build "disposeWhenNodeIsRemoved" and "disposeWhenNodeIsRemovedCallback" option values.
    // But skip if isActive is false (there will never be any dependencies to dispose).
    // (Note: "disposeWhenNodeIsRemoved" option both proactively disposes as soon as the node is removed using ko.removeNode(),
    // plus adds a "disposeWhen" callback that, on each evaluation, disposes if the node was removed by some other means.)
    if (disposeWhenNodeIsRemoved && isActive()) {
        dispose = function() {
            ko.utils.domNodeDisposal.removeDisposeCallback(disposeWhenNodeIsRemoved, dispose);
            disposeAllSubscriptionsToDependencies();
        };
        ko.utils.domNodeDisposal.addDisposeCallback(disposeWhenNodeIsRemoved, dispose);
        var existingDisposeWhenFunction = disposeWhen;
        disposeWhen = function () {
            return !ko.utils.domNodeIsAttachedToDocument(disposeWhenNodeIsRemoved) || existingDisposeWhenFunction();
        }
    }

    return dependentObservable;
};

ko.isComputed = function(instance) {
    return ko.hasPrototype(instance, ko.dependentObservable);
};

var protoProp = ko.observable.protoProperty; // == "__ko_proto__"
ko.dependentObservable[protoProp] = ko.observable;

ko.dependentObservable['fn'] = {};
ko.dependentObservable['fn'][protoProp] = ko.dependentObservable;

ko.exportSymbol('dependentObservable', ko.dependentObservable);
ko.exportSymbol('computed', ko.dependentObservable); // Make "ko.computed" an alias for "ko.dependentObservable"
ko.exportSymbol('isComputed', ko.isComputed);

(function() {
    var maxNestedObservableDepth = 10; // Escape the (unlikely) pathalogical case where an observable's current value is itself (or similar reference cycle)

    ko.toJS = function(rootObject) {
        if (arguments.length == 0)
            throw new Error("When calling ko.toJS, pass the object you want to convert.");

        // We just unwrap everything at every level in the object graph
        return mapJsObjectGraph(rootObject, function(valueToMap) {
            // Loop because an observable's value might in turn be another observable wrapper
            for (var i = 0; ko.isObservable(valueToMap) && (i < maxNestedObservableDepth); i++)
                valueToMap = valueToMap();
            return valueToMap;
        });
    };

    ko.toJSON = function(rootObject, replacer, space) {     // replacer and space are optional
        var plainJavaScriptObject = ko.toJS(rootObject);
        return ko.utils.stringifyJson(plainJavaScriptObject, replacer, space);
    };

    function mapJsObjectGraph(rootObject, mapInputCallback, visitedObjects) {
        visitedObjects = visitedObjects || new objectLookup();

        rootObject = mapInputCallback(rootObject);
        var canHaveProperties = (typeof rootObject == "object") && (rootObject !== null) && (rootObject !== undefined) && (!(rootObject instanceof Date)) && (!(rootObject instanceof String)) && (!(rootObject instanceof Number)) && (!(rootObject instanceof Boolean));
        if (!canHaveProperties)
            return rootObject;

        var outputProperties = rootObject instanceof Array ? [] : {};
        visitedObjects.save(rootObject, outputProperties);

        visitPropertiesOrArrayEntries(rootObject, function(indexer) {
            var propertyValue = mapInputCallback(rootObject[indexer]);

            switch (typeof propertyValue) {
                case "boolean":
                case "number":
                case "string":
                case "function":
                    outputProperties[indexer] = propertyValue;
                    break;
                case "object":
                case "undefined":
                    var previouslyMappedValue = visitedObjects.get(propertyValue);
                    outputProperties[indexer] = (previouslyMappedValue !== undefined)
                        ? previouslyMappedValue
                        : mapJsObjectGraph(propertyValue, mapInputCallback, visitedObjects);
                    break;
            }
        });

        return outputProperties;
    }

    function visitPropertiesOrArrayEntries(rootObject, visitorCallback) {
        if (rootObject instanceof Array) {
            for (var i = 0; i < rootObject.length; i++)
                visitorCallback(i);

            // For arrays, also respect toJSON property for custom mappings (fixes #278)
            if (typeof rootObject['toJSON'] == 'function')
                visitorCallback('toJSON');
        } else {
            for (var propertyName in rootObject) {
                visitorCallback(propertyName);
            }
        }
    };

    function objectLookup() {
        this.keys = [];
        this.values = [];
    };

    objectLookup.prototype = {
        constructor: objectLookup,
        save: function(key, value) {
            var existingIndex = ko.utils.arrayIndexOf(this.keys, key);
            if (existingIndex >= 0)
                this.values[existingIndex] = value;
            else {
                this.keys.push(key);
                this.values.push(value);
            }
        },
        get: function(key) {
            var existingIndex = ko.utils.arrayIndexOf(this.keys, key);
            return (existingIndex >= 0) ? this.values[existingIndex] : undefined;
        }
    };
})();

ko.exportSymbol('toJS', ko.toJS);
ko.exportSymbol('toJSON', ko.toJSON);
(function () {
    var hasDomDataExpandoProperty = '__ko__hasDomDataOptionValue__';

    // Normally, SELECT elements and their OPTIONs can only take value of type 'string' (because the values
    // are stored on DOM attributes). ko.selectExtensions provides a way for SELECTs/OPTIONs to have values
    // that are arbitrary objects. This is very convenient when implementing things like cascading dropdowns.
    ko.selectExtensions = {
        readValue : function(element) {
            switch (ko.utils.tagNameLower(element)) {
                case 'option':
                    if (element[hasDomDataExpandoProperty] === true)
                        return ko.utils.domData.get(element, ko.bindingHandlers.options.optionValueDomDataKey);
                    return ko.utils.ieVersion <= 7
                        ? (element.getAttributeNode('value') && element.getAttributeNode('value').specified ? element.value : element.text)
                        : element.value;
                case 'select':
                    return element.selectedIndex >= 0 ? ko.selectExtensions.readValue(element.options[element.selectedIndex]) : undefined;
                default:
                    return element.value;
            }
        },

        writeValue: function(element, value) {
            switch (ko.utils.tagNameLower(element)) {
                case 'option':
                    switch(typeof value) {
                        case "string":
                            ko.utils.domData.set(element, ko.bindingHandlers.options.optionValueDomDataKey, undefined);
                            if (hasDomDataExpandoProperty in element) { // IE <= 8 throws errors if you delete non-existent properties from a DOM node
                                delete element[hasDomDataExpandoProperty];
                            }
                            element.value = value;
                            break;
                        default:
                            // Store arbitrary object using DomData
                            ko.utils.domData.set(element, ko.bindingHandlers.options.optionValueDomDataKey, value);
                            element[hasDomDataExpandoProperty] = true;

                            // Special treatment of numbers is just for backward compatibility. KO 1.2.1 wrote numerical values to element.value.
                            element.value = typeof value === "number" ? value : "";
                            break;
                    }
                    break;
                case 'select':
                    if (value === "")
                        value = undefined;
                    if (value === null || value === undefined)
                        element.selectedIndex = -1;
                    for (var i = element.options.length - 1; i >= 0; i--) {
                        if (ko.selectExtensions.readValue(element.options[i]) == value) {
                            element.selectedIndex = i;
                            break;
                        }
                    }
                    // for drop-down select, ensure first is selected
                    if (!(element.size > 1) && element.selectedIndex === -1) {
                        element.selectedIndex = 0;
                    }
                    break;
                default:
                    if ((value === null) || (value === undefined))
                        value = "";
                    element.value = value;
                    break;
            }
        }
    };
})();

ko.exportSymbol('selectExtensions', ko.selectExtensions);
ko.exportSymbol('selectExtensions.readValue', ko.selectExtensions.readValue);
ko.exportSymbol('selectExtensions.writeValue', ko.selectExtensions.writeValue);
ko.expressionRewriting = (function () {
    var restoreCapturedTokensRegex = /\@ko_token_(\d+)\@/g;
    var javaScriptReservedWords = ["true", "false", "null", "undefined"];

    // Matches something that can be assigned to--either an isolated identifier or something ending with a property accessor
    // This is designed to be simple and avoid false negatives, but could produce false positives (e.g., a+b.c).
    var javaScriptAssignmentTarget = /^(?:[$_a-z][$\w]*|(.+)(\.\s*[$_a-z][$\w]*|\[.+\]))$/i;

    function restoreTokens(string, tokens) {
        var prevValue = null;
        while (string != prevValue) { // Keep restoring tokens until it no longer makes a difference (they may be nested)
            prevValue = string;
            string = string.replace(restoreCapturedTokensRegex, function (match, tokenIndex) {
                return tokens[tokenIndex];
            });
        }
        return string;
    }

    function getWriteableValue(expression) {
        if (ko.utils.arrayIndexOf(javaScriptReservedWords, ko.utils.stringTrim(expression).toLowerCase()) >= 0)
            return false;
        var match = expression.match(javaScriptAssignmentTarget);
        return match === null ? false : match[1] ? ('Object(' + match[1] + ')' + match[2]) : expression;
    }

    function ensureQuoted(key) {
        var trimmedKey = ko.utils.stringTrim(key);
        switch (trimmedKey.length && trimmedKey.charAt(0)) {
            case "'":
            case '"':
                return key;
            default:
                return "'" + trimmedKey + "'";
        }
    }

    return {
        bindingRewriteValidators: [],

        parseObjectLiteral: function(objectLiteralString) {
            // A full tokeniser+lexer would add too much weight to this library, so here's a simple parser
            // that is sufficient just to split an object literal string into a set of top-level key-value pairs

            var str = ko.utils.stringTrim(objectLiteralString);
            if (str.length < 3)
                return [];
            if (str.charAt(0) === "{")// Ignore any braces surrounding the whole object literal
                str = str.substring(1, str.length - 1);

            // Pull out any string literals and regex literals
            var tokens = [];
            var tokenStart = null, tokenEndChar;
            for (var position = 0; position < str.length; position++) {
                var c = str.charAt(position);
                if (tokenStart === null) {
                    switch (c) {
                        case '"':
                        case "'":
                        case "/":
                            tokenStart = position;
                            tokenEndChar = c;
                            break;
                    }
                } else if ((c == tokenEndChar) && (str.charAt(position - 1) !== "\\")) {
                    var token = str.substring(tokenStart, position + 1);
                    tokens.push(token);
                    var replacement = "@ko_token_" + (tokens.length - 1) + "@";
                    str = str.substring(0, tokenStart) + replacement + str.substring(position + 1);
                    position -= (token.length - replacement.length);
                    tokenStart = null;
                }
            }

            // Next pull out balanced paren, brace, and bracket blocks
            tokenStart = null;
            tokenEndChar = null;
            var tokenDepth = 0, tokenStartChar = null;
            for (var position = 0; position < str.length; position++) {
                var c = str.charAt(position);
                if (tokenStart === null) {
                    switch (c) {
                        case "{": tokenStart = position; tokenStartChar = c;
                                  tokenEndChar = "}";
                                  break;
                        case "(": tokenStart = position; tokenStartChar = c;
                                  tokenEndChar = ")";
                                  break;
                        case "[": tokenStart = position; tokenStartChar = c;
                                  tokenEndChar = "]";
                                  break;
                    }
                }

                if (c === tokenStartChar)
                    tokenDepth++;
                else if (c === tokenEndChar) {
                    tokenDepth--;
                    if (tokenDepth === 0) {
                        var token = str.substring(tokenStart, position + 1);
                        tokens.push(token);
                        var replacement = "@ko_token_" + (tokens.length - 1) + "@";
                        str = str.substring(0, tokenStart) + replacement + str.substring(position + 1);
                        position -= (token.length - replacement.length);
                        tokenStart = null;
                    }
                }
            }

            // Now we can safely split on commas to get the key/value pairs
            var result = [];
            var keyValuePairs = str.split(",");
            for (var i = 0, j = keyValuePairs.length; i < j; i++) {
                var pair = keyValuePairs[i];
                var colonPos = pair.indexOf(":");
                if ((colonPos > 0) && (colonPos < pair.length - 1)) {
                    var key = pair.substring(0, colonPos);
                    var value = pair.substring(colonPos + 1);
                    result.push({ 'key': restoreTokens(key, tokens), 'value': restoreTokens(value, tokens) });
                } else {
                    result.push({ 'unknown': restoreTokens(pair, tokens) });
                }
            }
            return result;
        },

        preProcessBindings: function (objectLiteralStringOrKeyValueArray) {
            var keyValueArray = typeof objectLiteralStringOrKeyValueArray === "string"
                ? ko.expressionRewriting.parseObjectLiteral(objectLiteralStringOrKeyValueArray)
                : objectLiteralStringOrKeyValueArray;
            var resultStrings = [], propertyAccessorResultStrings = [];

            var keyValueEntry;
            for (var i = 0; keyValueEntry = keyValueArray[i]; i++) {
                if (resultStrings.length > 0)
                    resultStrings.push(",");

                if (keyValueEntry['key']) {
                    var quotedKey = ensureQuoted(keyValueEntry['key']), val = keyValueEntry['value'];
                    resultStrings.push(quotedKey);
                    resultStrings.push(":");
                    resultStrings.push(val);

                    if (val = getWriteableValue(ko.utils.stringTrim(val))) {
                        if (propertyAccessorResultStrings.length > 0)
                            propertyAccessorResultStrings.push(", ");
                        propertyAccessorResultStrings.push(quotedKey + " : function(__ko_value) { " + val + " = __ko_value; }");
                    }
                } else if (keyValueEntry['unknown']) {
                    resultStrings.push(keyValueEntry['unknown']);
                }
            }

            var combinedResult = resultStrings.join("");
            if (propertyAccessorResultStrings.length > 0) {
                var allPropertyAccessors = propertyAccessorResultStrings.join("");
                combinedResult = combinedResult + ", '_ko_property_writers' : { " + allPropertyAccessors + " } ";
            }

            return combinedResult;
        },

        keyValueArrayContainsKey: function(keyValueArray, key) {
            for (var i = 0; i < keyValueArray.length; i++)
                if (ko.utils.stringTrim(keyValueArray[i]['key']) == key)
                    return true;
            return false;
        },

        // Internal, private KO utility for updating model properties from within bindings
        // property:            If the property being updated is (or might be) an observable, pass it here
        //                      If it turns out to be a writable observable, it will be written to directly
        // allBindingsAccessor: All bindings in the current execution context.
        //                      This will be searched for a '_ko_property_writers' property in case you're writing to a non-observable
        // key:                 The key identifying the property to be written. Example: for { hasFocus: myValue }, write to 'myValue' by specifying the key 'hasFocus'
        // value:               The value to be written
        // checkIfDifferent:    If true, and if the property being written is a writable observable, the value will only be written if
        //                      it is !== existing value on that writable observable
        writeValueToProperty: function(property, allBindingsAccessor, key, value, checkIfDifferent) {
            if (!property || !ko.isObservable(property)) {
                var propWriters = allBindingsAccessor()['_ko_property_writers'];
                if (propWriters && propWriters[key])
                    propWriters[key](value);
            } else if (ko.isWriteableObservable(property) && (!checkIfDifferent || property.peek() !== value)) {
                property(value);
            }
        }
    };
})();

ko.exportSymbol('expressionRewriting', ko.expressionRewriting);
ko.exportSymbol('expressionRewriting.bindingRewriteValidators', ko.expressionRewriting.bindingRewriteValidators);
ko.exportSymbol('expressionRewriting.parseObjectLiteral', ko.expressionRewriting.parseObjectLiteral);
ko.exportSymbol('expressionRewriting.preProcessBindings', ko.expressionRewriting.preProcessBindings);

// For backward compatibility, define the following aliases. (Previously, these function names were misleading because
// they referred to JSON specifically, even though they actually work with arbitrary JavaScript object literal expressions.)
ko.exportSymbol('jsonExpressionRewriting', ko.expressionRewriting);
ko.exportSymbol('jsonExpressionRewriting.insertPropertyAccessorsIntoJson', ko.expressionRewriting.preProcessBindings);(function() {
    // "Virtual elements" is an abstraction on top of the usual DOM API which understands the notion that comment nodes
    // may be used to represent hierarchy (in addition to the DOM's natural hierarchy).
    // If you call the DOM-manipulating functions on ko.virtualElements, you will be able to read and write the state
    // of that virtual hierarchy
    //
    // The point of all this is to support containerless templates (e.g., <!-- ko foreach:someCollection -->blah<!-- /ko -->)
    // without having to scatter special cases all over the binding and templating code.

    // IE 9 cannot reliably read the "nodeValue" property of a comment node (see https://github.com/SteveSanderson/knockout/issues/186)
    // but it does give them a nonstandard alternative property called "text" that it can read reliably. Other browsers don't have that property.
    // So, use node.text where available, and node.nodeValue elsewhere
    var commentNodesHaveTextProperty = document && document.createComment("test").text === "<!--test-->";

    var startCommentRegex = commentNodesHaveTextProperty ? /^<!--\s*ko(?:\s+(.+\s*\:[\s\S]*))?\s*-->$/ : /^\s*ko(?:\s+(.+\s*\:[\s\S]*))?\s*$/;
    var endCommentRegex =   commentNodesHaveTextProperty ? /^<!--\s*\/ko\s*-->$/ : /^\s*\/ko\s*$/;
    var htmlTagsWithOptionallyClosingChildren = { 'ul': true, 'ol': true };

    function isStartComment(node) {
        return (node.nodeType == 8) && (commentNodesHaveTextProperty ? node.text : node.nodeValue).match(startCommentRegex);
    }

    function isEndComment(node) {
        return (node.nodeType == 8) && (commentNodesHaveTextProperty ? node.text : node.nodeValue).match(endCommentRegex);
    }

    function getVirtualChildren(startComment, allowUnbalanced) {
        var currentNode = startComment;
        var depth = 1;
        var children = [];
        while (currentNode = currentNode.nextSibling) {
            if (isEndComment(currentNode)) {
                depth--;
                if (depth === 0)
                    return children;
            }

            children.push(currentNode);

            if (isStartComment(currentNode))
                depth++;
        }
        if (!allowUnbalanced)
            throw new Error("Cannot find closing comment tag to match: " + startComment.nodeValue);
        return null;
    }

    function getMatchingEndComment(startComment, allowUnbalanced) {
        var allVirtualChildren = getVirtualChildren(startComment, allowUnbalanced);
        if (allVirtualChildren) {
            if (allVirtualChildren.length > 0)
                return allVirtualChildren[allVirtualChildren.length - 1].nextSibling;
            return startComment.nextSibling;
        } else
            return null; // Must have no matching end comment, and allowUnbalanced is true
    }

    function getUnbalancedChildTags(node) {
        // e.g., from <div>OK</div><!-- ko blah --><span>Another</span>, returns: <!-- ko blah --><span>Another</span>
        //       from <div>OK</div><!-- /ko --><!-- /ko -->,             returns: <!-- /ko --><!-- /ko -->
        var childNode = node.firstChild, captureRemaining = null;
        if (childNode) {
            do {
                if (captureRemaining)                   // We already hit an unbalanced node and are now just scooping up all subsequent nodes
                    captureRemaining.push(childNode);
                else if (isStartComment(childNode)) {
                    var matchingEndComment = getMatchingEndComment(childNode, /* allowUnbalanced: */ true);
                    if (matchingEndComment)             // It's a balanced tag, so skip immediately to the end of this virtual set
                        childNode = matchingEndComment;
                    else
                        captureRemaining = [childNode]; // It's unbalanced, so start capturing from this point
                } else if (isEndComment(childNode)) {
                    captureRemaining = [childNode];     // It's unbalanced (if it wasn't, we'd have skipped over it already), so start capturing
                }
            } while (childNode = childNode.nextSibling);
        }
        return captureRemaining;
    }

    ko.virtualElements = {
        allowedBindings: {},

        childNodes: function(node) {
            return isStartComment(node) ? getVirtualChildren(node) : node.childNodes;
        },

        emptyNode: function(node) {
            if (!isStartComment(node))
                ko.utils.emptyDomNode(node);
            else {
                var virtualChildren = ko.virtualElements.childNodes(node);
                for (var i = 0, j = virtualChildren.length; i < j; i++)
                    ko.removeNode(virtualChildren[i]);
            }
        },

        setDomNodeChildren: function(node, childNodes) {
            if (!isStartComment(node))
                ko.utils.setDomNodeChildren(node, childNodes);
            else {
                ko.virtualElements.emptyNode(node);
                var endCommentNode = node.nextSibling; // Must be the next sibling, as we just emptied the children
                for (var i = 0, j = childNodes.length; i < j; i++)
                    endCommentNode.parentNode.insertBefore(childNodes[i], endCommentNode);
            }
        },

        prepend: function(containerNode, nodeToPrepend) {
            if (!isStartComment(containerNode)) {
                if (containerNode.firstChild)
                    containerNode.insertBefore(nodeToPrepend, containerNode.firstChild);
                else
                    containerNode.appendChild(nodeToPrepend);
            } else {
                // Start comments must always have a parent and at least one following sibling (the end comment)
                containerNode.parentNode.insertBefore(nodeToPrepend, containerNode.nextSibling);
            }
        },

        insertAfter: function(containerNode, nodeToInsert, insertAfterNode) {
            if (!insertAfterNode) {
                ko.virtualElements.prepend(containerNode, nodeToInsert);
            } else if (!isStartComment(containerNode)) {
                // Insert after insertion point
                if (insertAfterNode.nextSibling)
                    containerNode.insertBefore(nodeToInsert, insertAfterNode.nextSibling);
                else
                    containerNode.appendChild(nodeToInsert);
            } else {
                // Children of start comments must always have a parent and at least one following sibling (the end comment)
                containerNode.parentNode.insertBefore(nodeToInsert, insertAfterNode.nextSibling);
            }
        },

        firstChild: function(node) {
            if (!isStartComment(node))
                return node.firstChild;
            if (!node.nextSibling || isEndComment(node.nextSibling))
                return null;
            return node.nextSibling;
        },

        nextSibling: function(node) {
            if (isStartComment(node))
                node = getMatchingEndComment(node);
            if (node.nextSibling && isEndComment(node.nextSibling))
                return null;
            return node.nextSibling;
        },

        virtualNodeBindingValue: function(node) {
            var regexMatch = isStartComment(node);
            return regexMatch ? regexMatch[1] : null;
        },

        normaliseVirtualElementDomStructure: function(elementVerified) {
            // Workaround for https://github.com/SteveSanderson/knockout/issues/155
            // (IE <= 8 or IE 9 quirks mode parses your HTML weirdly, treating closing </li> tags as if they don't exist, thereby moving comment nodes
            // that are direct descendants of <ul> into the preceding <li>)
            if (!htmlTagsWithOptionallyClosingChildren[ko.utils.tagNameLower(elementVerified)])
                return;

            // Scan immediate children to see if they contain unbalanced comment tags. If they do, those comment tags
            // must be intended to appear *after* that child, so move them there.
            var childNode = elementVerified.firstChild;
            if (childNode) {
                do {
                    if (childNode.nodeType === 1) {
                        var unbalancedTags = getUnbalancedChildTags(childNode);
                        if (unbalancedTags) {
                            // Fix up the DOM by moving the unbalanced tags to where they most likely were intended to be placed - *after* the child
                            var nodeToInsertBefore = childNode.nextSibling;
                            for (var i = 0; i < unbalancedTags.length; i++) {
                                if (nodeToInsertBefore)
                                    elementVerified.insertBefore(unbalancedTags[i], nodeToInsertBefore);
                                else
                                    elementVerified.appendChild(unbalancedTags[i]);
                            }
                        }
                    }
                } while (childNode = childNode.nextSibling);
            }
        }
    };
})();
ko.exportSymbol('virtualElements', ko.virtualElements);
ko.exportSymbol('virtualElements.allowedBindings', ko.virtualElements.allowedBindings);
ko.exportSymbol('virtualElements.emptyNode', ko.virtualElements.emptyNode);
//ko.exportSymbol('virtualElements.firstChild', ko.virtualElements.firstChild);     // firstChild is not minified
ko.exportSymbol('virtualElements.insertAfter', ko.virtualElements.insertAfter);
//ko.exportSymbol('virtualElements.nextSibling', ko.virtualElements.nextSibling);   // nextSibling is not minified
ko.exportSymbol('virtualElements.prepend', ko.virtualElements.prepend);
ko.exportSymbol('virtualElements.setDomNodeChildren', ko.virtualElements.setDomNodeChildren);
(function() {
    var defaultBindingAttributeName = "data-bind";

    ko.bindingProvider = function() {
        this.bindingCache = {};
    };

    ko.utils.extend(ko.bindingProvider.prototype, {
        'nodeHasBindings': function(node) {
            switch (node.nodeType) {
                case 1: return node.getAttribute(defaultBindingAttributeName) != null;   // Element
                case 8: return ko.virtualElements.virtualNodeBindingValue(node) != null; // Comment node
                default: return false;
            }
        },

        'getBindings': function(node, bindingContext) {
            var bindingsString = this['getBindingsString'](node, bindingContext);
            return bindingsString ? this['parseBindingsString'](bindingsString, bindingContext, node) : null;
        },

        // The following function is only used internally by this default provider.
        // It's not part of the interface definition for a general binding provider.
        'getBindingsString': function(node, bindingContext) {
            switch (node.nodeType) {
                case 1: return node.getAttribute(defaultBindingAttributeName);   // Element
                case 8: return ko.virtualElements.virtualNodeBindingValue(node); // Comment node
                default: return null;
            }
        },

        // The following function is only used internally by this default provider.
        // It's not part of the interface definition for a general binding provider.
        'parseBindingsString': function(bindingsString, bindingContext, node) {
            try {
                var bindingFunction = createBindingsStringEvaluatorViaCache(bindingsString, this.bindingCache);
                return bindingFunction(bindingContext, node);
            } catch (ex) {
                ex.message = "Unable to parse bindings.\nBindings value: " + bindingsString + "\nMessage: " + ex.message;
                throw ex;
            }
        }
    });

    ko.bindingProvider['instance'] = new ko.bindingProvider();

    function createBindingsStringEvaluatorViaCache(bindingsString, cache) {
        var cacheKey = bindingsString;
        return cache[cacheKey]
            || (cache[cacheKey] = createBindingsStringEvaluator(bindingsString));
    }

    function createBindingsStringEvaluator(bindingsString) {
        // Build the source for a function that evaluates "expression"
        // For each scope variable, add an extra level of "with" nesting
        // Example result: with(sc1) { with(sc0) { return (expression) } }
        var rewrittenBindings = ko.expressionRewriting.preProcessBindings(bindingsString),
            functionBody = "with($context){with($data||{}){return{" + rewrittenBindings + "}}}";
        return new Function("$context", "$element", functionBody);
    }
})();

ko.exportSymbol('bindingProvider', ko.bindingProvider);
(function () {
    ko.bindingHandlers = {};

    ko.bindingContext = function(dataItem, parentBindingContext, dataItemAlias) {
        if (parentBindingContext) {
            ko.utils.extend(this, parentBindingContext); // Inherit $root and any custom properties
            this['$parentContext'] = parentBindingContext;
            this['$parent'] = parentBindingContext['$data'];
            this['$parents'] = (parentBindingContext['$parents'] || []).slice(0);
            this['$parents'].unshift(this['$parent']);
        } else {
            this['$parents'] = [];
            this['$root'] = dataItem;
            // Export 'ko' in the binding context so it will be available in bindings and templates
            // even if 'ko' isn't exported as a global, such as when using an AMD loader.
            // See https://github.com/SteveSanderson/knockout/issues/490
            this['ko'] = ko;
        }
        this['$data'] = dataItem;
        if (dataItemAlias)
            this[dataItemAlias] = dataItem;
    }
    ko.bindingContext.prototype['createChildContext'] = function (dataItem, dataItemAlias) {
        return new ko.bindingContext(dataItem, this, dataItemAlias);
    };
    ko.bindingContext.prototype['extend'] = function(properties) {
        var clone = ko.utils.extend(new ko.bindingContext(), this);
        return ko.utils.extend(clone, properties);
    };

    function validateThatBindingIsAllowedForVirtualElements(bindingName) {
        var validator = ko.virtualElements.allowedBindings[bindingName];
        if (!validator)
            throw new Error("The binding '" + bindingName + "' cannot be used with virtual elements")
    }

    function applyBindingsToDescendantsInternal (viewModel, elementOrVirtualElement, bindingContextsMayDifferFromDomParentElement) {
        var currentChild, nextInQueue = ko.virtualElements.firstChild(elementOrVirtualElement);
        while (currentChild = nextInQueue) {
            // Keep a record of the next child *before* applying bindings, in case the binding removes the current child from its position
            nextInQueue = ko.virtualElements.nextSibling(currentChild);
            applyBindingsToNodeAndDescendantsInternal(viewModel, currentChild, bindingContextsMayDifferFromDomParentElement);
        }
    }

    function applyBindingsToNodeAndDescendantsInternal (viewModel, nodeVerified, bindingContextMayDifferFromDomParentElement) {
        var shouldBindDescendants = true;

        // Perf optimisation: Apply bindings only if...
        // (1) We need to store the binding context on this node (because it may differ from the DOM parent node's binding context)
        //     Note that we can't store binding contexts on non-elements (e.g., text nodes), as IE doesn't allow expando properties for those
        // (2) It might have bindings (e.g., it has a data-bind attribute, or it's a marker for a containerless template)
        var isElement = (nodeVerified.nodeType === 1);
        if (isElement) // Workaround IE <= 8 HTML parsing weirdness
            ko.virtualElements.normaliseVirtualElementDomStructure(nodeVerified);

        var shouldApplyBindings = (isElement && bindingContextMayDifferFromDomParentElement)             // Case (1)
                               || ko.bindingProvider['instance']['nodeHasBindings'](nodeVerified);       // Case (2)
        if (shouldApplyBindings)
            shouldBindDescendants = applyBindingsToNodeInternal(nodeVerified, null, viewModel, bindingContextMayDifferFromDomParentElement).shouldBindDescendants;

        if (shouldBindDescendants) {
            // We're recursing automatically into (real or virtual) child nodes without changing binding contexts. So,
            //  * For children of a *real* element, the binding context is certainly the same as on their DOM .parentNode,
            //    hence bindingContextsMayDifferFromDomParentElement is false
            //  * For children of a *virtual* element, we can't be sure. Evaluating .parentNode on those children may
            //    skip over any number of intermediate virtual elements, any of which might define a custom binding context,
            //    hence bindingContextsMayDifferFromDomParentElement is true
            applyBindingsToDescendantsInternal(viewModel, nodeVerified, /* bindingContextsMayDifferFromDomParentElement: */ !isElement);
        }
    }

    var boundElementDomDataKey = '__ko_boundElement';
    function applyBindingsToNodeInternal (node, bindings, viewModelOrBindingContext, bindingContextMayDifferFromDomParentElement) {
        // Need to be sure that inits are only run once, and updates never run until all the inits have been run
        var initPhase = 0; // 0 = before all inits, 1 = during inits, 2 = after all inits

        // Each time the dependentObservable is evaluated (after data changes),
        // the binding attribute is reparsed so that it can pick out the correct
        // model properties in the context of the changed data.
        // DOM event callbacks need to be able to access this changed data,
        // so we need a single parsedBindings variable (shared by all callbacks
        // associated with this node's bindings) that all the closures can access.
        var parsedBindings;
        function makeValueAccessor(bindingKey) {
            return function () { return parsedBindings[bindingKey] }
        }
        function parsedBindingsAccessor() {
            return parsedBindings;
        }

        var bindingHandlerThatControlsDescendantBindings;

        // Prevent multiple applyBindings calls for the same node, except when a binding value is specified
        var alreadyBound = ko.utils.domData.get(node, boundElementDomDataKey);
        if (!bindings) {
            if (alreadyBound) {
                throw Error("You cannot apply bindings multiple times to the same element.");
            }
            ko.utils.domData.set(node, boundElementDomDataKey, true);
        }

        ko.dependentObservable(
            function () {
                // Ensure we have a nonnull binding context to work with
                var bindingContextInstance = viewModelOrBindingContext && (viewModelOrBindingContext instanceof ko.bindingContext)
                    ? viewModelOrBindingContext
                    : new ko.bindingContext(ko.utils.unwrapObservable(viewModelOrBindingContext));
                var viewModel = bindingContextInstance['$data'];

                // Optimization: Don't store the binding context on this node if it's definitely the same as on node.parentNode, because
                // we can easily recover it just by scanning up the node's ancestors in the DOM
                // (note: here, parent node means "real DOM parent" not "virtual parent", as there's no O(1) way to find the virtual parent)
                if (!alreadyBound && bindingContextMayDifferFromDomParentElement)
                    ko.storedBindingContextForNode(node, bindingContextInstance);

                // Use evaluatedBindings if given, otherwise fall back on asking the bindings provider to give us some bindings
                var evaluatedBindings = (typeof bindings == "function") ? bindings(bindingContextInstance, node) : bindings;
                parsedBindings = evaluatedBindings || ko.bindingProvider['instance']['getBindings'](node, bindingContextInstance);

                if (parsedBindings) {
                    // First run all the inits, so bindings can register for notification on changes
                    if (initPhase === 0) {
                        initPhase = 1;
                        ko.utils.objectForEach(parsedBindings, function(bindingKey) {
                            var binding = ko.bindingHandlers[bindingKey];
                            if (binding && node.nodeType === 8)
                                validateThatBindingIsAllowedForVirtualElements(bindingKey);

                            if (binding && typeof binding["init"] == "function") {
                                var handlerInitFn = binding["init"];
                                var initResult = handlerInitFn(node, makeValueAccessor(bindingKey), parsedBindingsAccessor, viewModel, bindingContextInstance);

                                // If this binding handler claims to control descendant bindings, make a note of this
                                if (initResult && initResult['controlsDescendantBindings']) {
                                    if (bindingHandlerThatControlsDescendantBindings !== undefined)
                                        throw new Error("Multiple bindings (" + bindingHandlerThatControlsDescendantBindings + " and " + bindingKey + ") are trying to control descendant bindings of the same element. You cannot use these bindings together on the same element.");
                                    bindingHandlerThatControlsDescendantBindings = bindingKey;
                                }
                            }
                        });
                        initPhase = 2;
                    }

                    // ... then run all the updates, which might trigger changes even on the first evaluation
                    if (initPhase === 2) {
                        ko.utils.objectForEach(parsedBindings, function(bindingKey) {
                            var binding = ko.bindingHandlers[bindingKey];
                            if (binding && typeof binding["update"] == "function") {
                                var handlerUpdateFn = binding["update"];
                                handlerUpdateFn(node, makeValueAccessor(bindingKey), parsedBindingsAccessor, viewModel, bindingContextInstance);
                            }
                        });
                    }
                }
            },
            null,
            { disposeWhenNodeIsRemoved : node }
        );

        return {
            shouldBindDescendants: bindingHandlerThatControlsDescendantBindings === undefined
        };
    };

    var storedBindingContextDomDataKey = "__ko_bindingContext__";
    ko.storedBindingContextForNode = function (node, bindingContext) {
        if (arguments.length == 2)
            ko.utils.domData.set(node, storedBindingContextDomDataKey, bindingContext);
        else
            return ko.utils.domData.get(node, storedBindingContextDomDataKey);
    }

    ko.applyBindingsToNode = function (node, bindings, viewModel) {
        if (node.nodeType === 1) // If it's an element, workaround IE <= 8 HTML parsing weirdness
            ko.virtualElements.normaliseVirtualElementDomStructure(node);
        return applyBindingsToNodeInternal(node, bindings, viewModel, true);
    };

    ko.applyBindingsToDescendants = function(viewModel, rootNode) {
        if (rootNode.nodeType === 1 || rootNode.nodeType === 8)
            applyBindingsToDescendantsInternal(viewModel, rootNode, true);
    };

    ko.applyBindings = function (viewModel, rootNode) {
        if (rootNode && (rootNode.nodeType !== 1) && (rootNode.nodeType !== 8))
            throw new Error("ko.applyBindings: first parameter should be your view model; second parameter should be a DOM node");
        rootNode = rootNode || window.document.body; // Make "rootNode" parameter optional

        applyBindingsToNodeAndDescendantsInternal(viewModel, rootNode, true);
    };

    // Retrieving binding context from arbitrary nodes
    ko.contextFor = function(node) {
        // We can only do something meaningful for elements and comment nodes (in particular, not text nodes, as IE can't store domdata for them)
        switch (node.nodeType) {
            case 1:
            case 8:
                var context = ko.storedBindingContextForNode(node);
                if (context) return context;
                if (node.parentNode) return ko.contextFor(node.parentNode);
                break;
        }
        return undefined;
    };
    ko.dataFor = function(node) {
        var context = ko.contextFor(node);
        return context ? context['$data'] : undefined;
    };

    ko.exportSymbol('bindingHandlers', ko.bindingHandlers);
    ko.exportSymbol('applyBindings', ko.applyBindings);
    ko.exportSymbol('applyBindingsToDescendants', ko.applyBindingsToDescendants);
    ko.exportSymbol('applyBindingsToNode', ko.applyBindingsToNode);
    ko.exportSymbol('contextFor', ko.contextFor);
    ko.exportSymbol('dataFor', ko.dataFor);
})();
var attrHtmlToJavascriptMap = { 'class': 'className', 'for': 'htmlFor' };
ko.bindingHandlers['attr'] = {
    'update': function(element, valueAccessor, allBindingsAccessor) {
        var value = ko.utils.unwrapObservable(valueAccessor()) || {};
        ko.utils.objectForEach(value, function(attrName, attrValue) {
            attrValue = ko.utils.unwrapObservable(attrValue);

            // To cover cases like "attr: { checked:someProp }", we want to remove the attribute entirely
            // when someProp is a "no value"-like value (strictly null, false, or undefined)
            // (because the absence of the "checked" attr is how to mark an element as not checked, etc.)
            var toRemove = (attrValue === false) || (attrValue === null) || (attrValue === undefined);
            if (toRemove)
                element.removeAttribute(attrName);

            // In IE <= 7 and IE8 Quirks Mode, you have to use the Javascript property name instead of the
            // HTML attribute name for certain attributes. IE8 Standards Mode supports the correct behavior,
            // but instead of figuring out the mode, we'll just set the attribute through the Javascript
            // property for IE <= 8.
            if (ko.utils.ieVersion <= 8 && attrName in attrHtmlToJavascriptMap) {
                attrName = attrHtmlToJavascriptMap[attrName];
                if (toRemove)
                    element.removeAttribute(attrName);
                else
                    element[attrName] = attrValue;
            } else if (!toRemove) {
                element.setAttribute(attrName, attrValue.toString());
            }

            // Treat "name" specially - although you can think of it as an attribute, it also needs
            // special handling on older versions of IE (https://github.com/SteveSanderson/knockout/pull/333)
            // Deliberately being case-sensitive here because XHTML would regard "Name" as a different thing
            // entirely, and there's no strong reason to allow for such casing in HTML.
            if (attrName === "name") {
                ko.utils.setElementName(element, toRemove ? "" : attrValue.toString());
            }
        });
    }
};
ko.bindingHandlers['checked'] = {
    'init': function (element, valueAccessor, allBindingsAccessor) {
        var updateHandler = function() {
            var valueToWrite;
            if (element.type == "checkbox") {
                valueToWrite = element.checked;
            } else if ((element.type == "radio") && (element.checked)) {
                valueToWrite = element.value;
            } else {
                return; // "checked" binding only responds to checkboxes and selected radio buttons
            }

            var modelValue = valueAccessor(), unwrappedValue = ko.utils.unwrapObservable(modelValue);
            if ((element.type == "checkbox") && (unwrappedValue instanceof Array)) {
                // For checkboxes bound to an array, we add/remove the checkbox value to that array
                // This works for both observable and non-observable arrays
                ko.utils.addOrRemoveItem(modelValue, element.value, element.checked);
            } else {
                ko.expressionRewriting.writeValueToProperty(modelValue, allBindingsAccessor, 'checked', valueToWrite, true);
            }
        };
        ko.utils.registerEventHandler(element, "click", updateHandler);

        // IE 6 won't allow radio buttons to be selected unless they have a name
        if ((element.type == "radio") && !element.name)
            ko.bindingHandlers['uniqueName']['init'](element, function() { return true });
    },
    'update': function (element, valueAccessor) {
        var value = ko.utils.unwrapObservable(valueAccessor());

        if (element.type == "checkbox") {
            if (value instanceof Array) {
                // When bound to an array, the checkbox being checked represents its value being present in that array
                element.checked = ko.utils.arrayIndexOf(value, element.value) >= 0;
            } else {
                // When bound to any other value (not an array), the checkbox being checked represents the value being trueish
                element.checked = value;
            }
        } else if (element.type == "radio") {
            element.checked = (element.value == value);
        }
    }
};
var classesWrittenByBindingKey = '__ko__cssValue';
ko.bindingHandlers['css'] = {
    'update': function (element, valueAccessor) {
        var value = ko.utils.unwrapObservable(valueAccessor());
        if (typeof value == "object") {
            ko.utils.objectForEach(value, function(className, shouldHaveClass) {
                shouldHaveClass = ko.utils.unwrapObservable(shouldHaveClass);
                ko.utils.toggleDomNodeCssClass(element, className, shouldHaveClass);
            });
        } else {
            value = String(value || ''); // Make sure we don't try to store or set a non-string value
            ko.utils.toggleDomNodeCssClass(element, element[classesWrittenByBindingKey], false);
            element[classesWrittenByBindingKey] = value;
            ko.utils.toggleDomNodeCssClass(element, value, true);
        }
    }
};
ko.bindingHandlers['enable'] = {
    'update': function (element, valueAccessor) {
        var value = ko.utils.unwrapObservable(valueAccessor());
        if (value && element.disabled)
            element.removeAttribute("disabled");
        else if ((!value) && (!element.disabled))
            element.disabled = true;
    }
};

ko.bindingHandlers['disable'] = {
    'update': function (element, valueAccessor) {
        ko.bindingHandlers['enable']['update'](element, function() { return !ko.utils.unwrapObservable(valueAccessor()) });
    }
};
// For certain common events (currently just 'click'), allow a simplified data-binding syntax
// e.g. click:handler instead of the usual full-length event:{click:handler}
function makeEventHandlerShortcut(eventName) {
    ko.bindingHandlers[eventName] = {
        'init': function(element, valueAccessor, allBindingsAccessor, viewModel) {
            var newValueAccessor = function () {
                var result = {};
                result[eventName] = valueAccessor();
                return result;
            };
            return ko.bindingHandlers['event']['init'].call(this, element, newValueAccessor, allBindingsAccessor, viewModel);
        }
    }
}

ko.bindingHandlers['event'] = {
    'init' : function (element, valueAccessor, allBindingsAccessor, viewModel) {
        var eventsToHandle = valueAccessor() || {};
        ko.utils.objectForEach(eventsToHandle, function(eventName) {
            if (typeof eventName == "string") {
                ko.utils.registerEventHandler(element, eventName, function (event) {
                    var handlerReturnValue;
                    var handlerFunction = valueAccessor()[eventName];
                    if (!handlerFunction)
                        return;
                    var allBindings = allBindingsAccessor();

                    try {
                        // Take all the event args, and prefix with the viewmodel
                        var argsForHandler = ko.utils.makeArray(arguments);
                        argsForHandler.unshift(viewModel);
                        handlerReturnValue = handlerFunction.apply(viewModel, argsForHandler);
                    } finally {
                        if (handlerReturnValue !== true) { // Normally we want to prevent default action. Developer can override this be explicitly returning true.
                            if (event.preventDefault)
                                event.preventDefault();
                            else
                                event.returnValue = false;
                        }
                    }

                    var bubble = allBindings[eventName + 'Bubble'] !== false;
                    if (!bubble) {
                        event.cancelBubble = true;
                        if (event.stopPropagation)
                            event.stopPropagation();
                    }
                });
            }
        });
    }
};
// "foreach: someExpression" is equivalent to "template: { foreach: someExpression }"
// "foreach: { data: someExpression, afterAdd: myfn }" is equivalent to "template: { foreach: someExpression, afterAdd: myfn }"
ko.bindingHandlers['foreach'] = {
    makeTemplateValueAccessor: function(valueAccessor) {
        return function() {
            var modelValue = valueAccessor(),
                unwrappedValue = ko.utils.peekObservable(modelValue);    // Unwrap without setting a dependency here

            // If unwrappedValue is the array, pass in the wrapped value on its own
            // The value will be unwrapped and tracked within the template binding
            // (See https://github.com/SteveSanderson/knockout/issues/523)
            if ((!unwrappedValue) || typeof unwrappedValue.length == "number")
                return { 'foreach': modelValue, 'templateEngine': ko.nativeTemplateEngine.instance };

            // If unwrappedValue.data is the array, preserve all relevant options and unwrap again value so we get updates
            ko.utils.unwrapObservable(modelValue);
            return {
                'foreach': unwrappedValue['data'],
                'as': unwrappedValue['as'],
                'includeDestroyed': unwrappedValue['includeDestroyed'],
                'afterAdd': unwrappedValue['afterAdd'],
                'beforeRemove': unwrappedValue['beforeRemove'],
                'afterRender': unwrappedValue['afterRender'],
                'beforeMove': unwrappedValue['beforeMove'],
                'afterMove': unwrappedValue['afterMove'],
                'templateEngine': ko.nativeTemplateEngine.instance
            };
        };
    },
    'init': function(element, valueAccessor, allBindingsAccessor, viewModel, bindingContext) {
        return ko.bindingHandlers['template']['init'](element, ko.bindingHandlers['foreach'].makeTemplateValueAccessor(valueAccessor));
    },
    'update': function(element, valueAccessor, allBindingsAccessor, viewModel, bindingContext) {
        return ko.bindingHandlers['template']['update'](element, ko.bindingHandlers['foreach'].makeTemplateValueAccessor(valueAccessor), allBindingsAccessor, viewModel, bindingContext);
    }
};
ko.expressionRewriting.bindingRewriteValidators['foreach'] = false; // Can't rewrite control flow bindings
ko.virtualElements.allowedBindings['foreach'] = true;
var hasfocusUpdatingProperty = '__ko_hasfocusUpdating';
var hasfocusLastValue = '__ko_hasfocusLastValue';
ko.bindingHandlers['hasfocus'] = {
    'init': function(element, valueAccessor, allBindingsAccessor) {
        var handleElementFocusChange = function(isFocused) {
            // Where possible, ignore which event was raised and determine focus state using activeElement,
            // as this avoids phantom focus/blur events raised when changing tabs in modern browsers.
            // However, not all KO-targeted browsers (Firefox 2) support activeElement. For those browsers,
            // prevent a loss of focus when changing tabs/windows by setting a flag that prevents hasfocus
            // from calling 'blur()' on the element when it loses focus.
            // Discussion at https://github.com/SteveSanderson/knockout/pull/352
            element[hasfocusUpdatingProperty] = true;
            var ownerDoc = element.ownerDocument;
            if ("activeElement" in ownerDoc) {
                var active;
                try {
                    active = ownerDoc.activeElement;
                } catch(e) {
                    // IE9 throws if you access activeElement during page load (see issue #703)
                    active = ownerDoc.body;
                }
                isFocused = (active === element);
            }
            var modelValue = valueAccessor();
            ko.expressionRewriting.writeValueToProperty(modelValue, allBindingsAccessor, 'hasfocus', isFocused, true);

            //cache the latest value, so we can avoid unnecessarily calling focus/blur in the update function
            element[hasfocusLastValue] = isFocused;
            element[hasfocusUpdatingProperty] = false;
        };
        var handleElementFocusIn = handleElementFocusChange.bind(null, true);
        var handleElementFocusOut = handleElementFocusChange.bind(null, false);

        ko.utils.registerEventHandler(element, "focus", handleElementFocusIn);
        ko.utils.registerEventHandler(element, "focusin", handleElementFocusIn); // For IE
        ko.utils.registerEventHandler(element, "blur",  handleElementFocusOut);
        ko.utils.registerEventHandler(element, "focusout",  handleElementFocusOut); // For IE
    },
    'update': function(element, valueAccessor) {
        var value = !!ko.utils.unwrapObservable(valueAccessor()); //force boolean to compare with last value
        if (!element[hasfocusUpdatingProperty] && element[hasfocusLastValue] !== value) {
            value ? element.focus() : element.blur();
            ko.dependencyDetection.ignore(ko.utils.triggerEvent, null, [element, value ? "focusin" : "focusout"]); // For IE, which doesn't reliably fire "focus" or "blur" events synchronously
        }
    }
};

ko.bindingHandlers['hasFocus'] = ko.bindingHandlers['hasfocus']; // Make "hasFocus" an alias
ko.bindingHandlers['html'] = {
    'init': function() {
        // Prevent binding on the dynamically-injected HTML (as developers are unlikely to expect that, and it has security implications)
        return { 'controlsDescendantBindings': true };
    },
    'update': function (element, valueAccessor) {
        // setHtml will unwrap the value if needed
        ko.utils.setHtml(element, valueAccessor());
    }
};
var withIfDomDataKey = '__ko_withIfBindingData';
// Makes a binding like with or if
function makeWithIfBinding(bindingKey, isWith, isNot, makeContextCallback) {
    ko.bindingHandlers[bindingKey] = {
        'init': function(element, valueAccessor, allBindingsAccessor, viewModel, bindingContext) {
            ko.utils.domData.set(element, withIfDomDataKey, {});
            return { 'controlsDescendantBindings': true };
        },
        'update': function(element, valueAccessor, allBindingsAccessor, viewModel, bindingContext) {
            var withIfData = ko.utils.domData.get(element, withIfDomDataKey),
                dataValue = ko.utils.unwrapObservable(valueAccessor()),
                shouldDisplay = !isNot !== !dataValue, // equivalent to isNot ? !dataValue : !!dataValue
                isFirstRender = !withIfData.savedNodes,
                needsRefresh = isFirstRender || isWith || (shouldDisplay !== withIfData.didDisplayOnLastUpdate);

            if (needsRefresh) {
                if (isFirstRender) {
                    withIfData.savedNodes = ko.utils.cloneNodes(ko.virtualElements.childNodes(element), true /* shouldCleanNodes */);
                }

                if (shouldDisplay) {
                    if (!isFirstRender) {
                        ko.virtualElements.setDomNodeChildren(element, ko.utils.cloneNodes(withIfData.savedNodes));
                    }
                    ko.applyBindingsToDescendants(makeContextCallback ? makeContextCallback(bindingContext, dataValue) : bindingContext, element);
                } else {
                    ko.virtualElements.emptyNode(element);
                }

                withIfData.didDisplayOnLastUpdate = shouldDisplay;
            }
        }
    };
    ko.expressionRewriting.bindingRewriteValidators[bindingKey] = false; // Can't rewrite control flow bindings
    ko.virtualElements.allowedBindings[bindingKey] = true;
}

// Construct the actual binding handlers
makeWithIfBinding('if');
makeWithIfBinding('ifnot', false /* isWith */, true /* isNot */);
makeWithIfBinding('with', true /* isWith */, false /* isNot */,
    function(bindingContext, dataValue) {
        return bindingContext['createChildContext'](dataValue);
    }
);
function ensureDropdownSelectionIsConsistentWithModelValue(element, modelValue, preferModelValue) {
    if (preferModelValue) {
        if (modelValue !== ko.selectExtensions.readValue(element))
            ko.selectExtensions.writeValue(element, modelValue);
    }

    // No matter which direction we're syncing in, we want the end result to be equality between dropdown value and model value.
    // If they aren't equal, either we prefer the dropdown value, or the model value couldn't be represented, so either way,
    // change the model value to match the dropdown.
    if (modelValue !== ko.selectExtensions.readValue(element))
        ko.dependencyDetection.ignore(ko.utils.triggerEvent, null, [element, "change"]);
};

ko.bindingHandlers['options'] = {
    'init': function(element) {
        if (ko.utils.tagNameLower(element) !== "select")
            throw new Error("options binding applies only to SELECT elements");

        // Remove all existing <option>s.
        while (element.length > 0) {
            element.remove(0);
        }

        // Ensures that the binding processor doesn't try to bind the options
        return { 'controlsDescendantBindings': true };
    },
    'update': function (element, valueAccessor, allBindingsAccessor) {
        var selectWasPreviouslyEmpty = element.length == 0;
        var previousScrollTop = (!selectWasPreviouslyEmpty && element.multiple) ? element.scrollTop : null;

        var unwrappedArray = ko.utils.unwrapObservable(valueAccessor());
        var allBindings = allBindingsAccessor();
        var includeDestroyed = allBindings['optionsIncludeDestroyed'];
        var captionPlaceholder = {};
        var captionValue;
        var previousSelectedValues;
        if (element.multiple) {
            previousSelectedValues = ko.utils.arrayMap(element.selectedOptions || ko.utils.arrayFilter(element.childNodes, function (node) {
                    return node.tagName && (ko.utils.tagNameLower(node) === "option") && node.selected;
                }), function (node) {
                    return ko.selectExtensions.readValue(node);
                });
        } else if (element.selectedIndex >= 0) {
            previousSelectedValues = [ ko.selectExtensions.readValue(element.options[element.selectedIndex]) ];
        }

        if (unwrappedArray) {
            if (typeof unwrappedArray.length == "undefined") // Coerce single value into array
                unwrappedArray = [unwrappedArray];

            // Filter out any entries marked as destroyed
            var filteredArray = ko.utils.arrayFilter(unwrappedArray, function(item) {
                return includeDestroyed || item === undefined || item === null || !ko.utils.unwrapObservable(item['_destroy']);
            });

            // If caption is included, add it to the array
            if ('optionsCaption' in allBindings) {
                captionValue = ko.utils.unwrapObservable(allBindings['optionsCaption']);
                // If caption value is null or undefined, don't show a caption
                if (captionValue !== null && captionValue !== undefined) {
                    filteredArray.unshift(captionPlaceholder);
                }
            }
        } else {
            // If a falsy value is provided (e.g. null), we'll simply empty the select element
            unwrappedArray = [];
        }

        function applyToObject(object, predicate, defaultValue) {
            var predicateType = typeof predicate;
            if (predicateType == "function")    // Given a function; run it against the data value
                return predicate(object);
            else if (predicateType == "string") // Given a string; treat it as a property name on the data value
                return object[predicate];
            else                                // Given no optionsText arg; use the data value itself
                return defaultValue;
        }

        // The following functions can run at two different times:
        // The first is when the whole array is being updated directly from this binding handler.
        // The second is when an observable value for a specific array entry is updated.
        // oldOptions will be empty in the first case, but will be filled with the previously generated option in the second.
        function optionForArrayItem(arrayEntry, index, oldOptions) {
            if (oldOptions.length) {
                previousSelectedValues = oldOptions[0].selected && [ ko.selectExtensions.readValue(oldOptions[0]) ];
            }
            var option = document.createElement("option");
            if (arrayEntry === captionPlaceholder) {
                ko.utils.setHtml(option, captionValue);
                ko.selectExtensions.writeValue(option, undefined);
            } else {
                // Apply a value to the option element
                var optionValue = applyToObject(arrayEntry, allBindings['optionsValue'], arrayEntry);
                ko.selectExtensions.writeValue(option, ko.utils.unwrapObservable(optionValue));

                // Apply some text to the option element
                var optionText = applyToObject(arrayEntry, allBindings['optionsText'], optionValue);
                ko.utils.setTextContent(option, optionText);
            }
            return [option];
        }

        function setSelectionCallback(arrayEntry, newOptions) {
            // IE6 doesn't like us to assign selection to OPTION nodes before they're added to the document.
            // That's why we first added them without selection. Now it's time to set the selection.
            if (previousSelectedValues) {
                var isSelected = ko.utils.arrayIndexOf(previousSelectedValues, ko.selectExtensions.readValue(newOptions[0])) >= 0;
                ko.utils.setOptionNodeSelectionState(newOptions[0], isSelected);
            }
        }

        var callback = setSelectionCallback;
        if (allBindings['optionsAfterRender']) {
            callback = function(arrayEntry, newOptions) {
                setSelectionCallback(arrayEntry, newOptions);
                ko.dependencyDetection.ignore(allBindings['optionsAfterRender'], null, [newOptions[0], arrayEntry !== captionPlaceholder ? arrayEntry : undefined]);
            }
        }

        ko.utils.setDomNodeChildrenFromArrayMapping(element, filteredArray, optionForArrayItem, null, callback);

        // Clear previousSelectedValues so that future updates to individual objects don't get stale data
        previousSelectedValues = null;

        if (selectWasPreviouslyEmpty && ('value' in allBindings)) {
            // Ensure consistency between model value and selected option.
            // If the dropdown is being populated for the first time here (or was otherwise previously empty),
            // the dropdown selection state is meaningless, so we preserve the model value.
            ensureDropdownSelectionIsConsistentWithModelValue(element, ko.utils.peekObservable(allBindings['value']), /* preferModelValue */ true);
        }

        // Workaround for IE bug
        ko.utils.ensureSelectElementIsRenderedCorrectly(element);

        if (previousScrollTop && Math.abs(previousScrollTop - element.scrollTop) > 20)
            element.scrollTop = previousScrollTop;
    }
};
ko.bindingHandlers['options'].optionValueDomDataKey = '__ko.optionValueDomData__';
ko.bindingHandlers['selectedOptions'] = {
    'init': function (element, valueAccessor, allBindingsAccessor) {
        ko.utils.registerEventHandler(element, "change", function () {
            var value = valueAccessor(), valueToWrite = [];
            ko.utils.arrayForEach(element.getElementsByTagName("option"), function(node) {
                if (node.selected)
                    valueToWrite.push(ko.selectExtensions.readValue(node));
            });
            ko.expressionRewriting.writeValueToProperty(value, allBindingsAccessor, 'selectedOptions', valueToWrite);
        });
    },
    'update': function (element, valueAccessor) {
        if (ko.utils.tagNameLower(element) != "select")
            throw new Error("values binding applies only to SELECT elements");

        var newValue = ko.utils.unwrapObservable(valueAccessor());
        if (newValue && typeof newValue.length == "number") {
            ko.utils.arrayForEach(element.getElementsByTagName("option"), function(node) {
                var isSelected = ko.utils.arrayIndexOf(newValue, ko.selectExtensions.readValue(node)) >= 0;
                ko.utils.setOptionNodeSelectionState(node, isSelected);
            });
        }
    }
};
ko.bindingHandlers['style'] = {
    'update': function (element, valueAccessor) {
        var value = ko.utils.unwrapObservable(valueAccessor() || {});
        ko.utils.objectForEach(value, function(styleName, styleValue) {
            styleValue = ko.utils.unwrapObservable(styleValue);
            element.style[styleName] = styleValue || ""; // Empty string removes the value, whereas null/undefined have no effect
        });
    }
};
ko.bindingHandlers['submit'] = {
    'init': function (element, valueAccessor, allBindingsAccessor, viewModel) {
        if (typeof valueAccessor() != "function")
            throw new Error("The value for a submit binding must be a function");
        ko.utils.registerEventHandler(element, "submit", function (event) {
            var handlerReturnValue;
            var value = valueAccessor();
            try { handlerReturnValue = value.call(viewModel, element); }
            finally {
                if (handlerReturnValue !== true) { // Normally we want to prevent default action. Developer can override this be explicitly returning true.
                    if (event.preventDefault)
                        event.preventDefault();
                    else
                        event.returnValue = false;
                }
            }
        });
    }
};
ko.bindingHandlers['text'] = {
    'update': function (element, valueAccessor) {
        ko.utils.setTextContent(element, valueAccessor());
    }
};
ko.virtualElements.allowedBindings['text'] = true;
ko.bindingHandlers['uniqueName'] = {
    'init': function (element, valueAccessor) {
        if (valueAccessor()) {
            var name = "ko_unique_" + (++ko.bindingHandlers['uniqueName'].currentIndex);
            ko.utils.setElementName(element, name);
        }
    }
};
ko.bindingHandlers['uniqueName'].currentIndex = 0;
ko.bindingHandlers['value'] = {
    'init': function (element, valueAccessor, allBindingsAccessor) {
        // Always catch "change" event; possibly other events too if asked
        var eventsToCatch = ["change"];
        var requestedEventsToCatch = allBindingsAccessor()["valueUpdate"];
        var propertyChangedFired = false;
        if (requestedEventsToCatch) {
            if (typeof requestedEventsToCatch == "string") // Allow both individual event names, and arrays of event names
                requestedEventsToCatch = [requestedEventsToCatch];
            ko.utils.arrayPushAll(eventsToCatch, requestedEventsToCatch);
            eventsToCatch = ko.utils.arrayGetDistinctValues(eventsToCatch);
        }

        var valueUpdateHandler = function() {
            propertyChangedFired = false;
            var modelValue = valueAccessor();
            var elementValue = ko.selectExtensions.readValue(element);
            ko.expressionRewriting.writeValueToProperty(modelValue, allBindingsAccessor, 'value', elementValue);
        }

        // Workaround for https://github.com/SteveSanderson/knockout/issues/122
        // IE doesn't fire "change" events on textboxes if the user selects a value from its autocomplete list
        var ieAutoCompleteHackNeeded = ko.utils.ieVersion && element.tagName.toLowerCase() == "input" && element.type == "text"
                                       && element.autocomplete != "off" && (!element.form || element.form.autocomplete != "off");
        if (ieAutoCompleteHackNeeded && ko.utils.arrayIndexOf(eventsToCatch, "propertychange") == -1) {
            ko.utils.registerEventHandler(element, "propertychange", function () { propertyChangedFired = true });
            ko.utils.registerEventHandler(element, "blur", function() {
                if (propertyChangedFired) {
                    valueUpdateHandler();
                }
            });
        }

        ko.utils.arrayForEach(eventsToCatch, function(eventName) {
            // The syntax "after<eventname>" means "run the handler asynchronously after the event"
            // This is useful, for example, to catch "keydown" events after the browser has updated the control
            // (otherwise, ko.selectExtensions.readValue(this) will receive the control's value *before* the key event)
            var handler = valueUpdateHandler;
            if (ko.utils.stringStartsWith(eventName, "after")) {
                handler = function() { setTimeout(valueUpdateHandler, 0) };
                eventName = eventName.substring("after".length);
            }
            ko.utils.registerEventHandler(element, eventName, handler);
        });
    },
    'update': function (element, valueAccessor) {
        var valueIsSelectOption = ko.utils.tagNameLower(element) === "select";
        var newValue = ko.utils.unwrapObservable(valueAccessor());
        var elementValue = ko.selectExtensions.readValue(element);
        var valueHasChanged = (newValue !== elementValue);

        if (valueHasChanged) {
            var applyValueAction = function () { ko.selectExtensions.writeValue(element, newValue); };
            applyValueAction();

            // Workaround for IE6 bug: It won't reliably apply values to SELECT nodes during the same execution thread
            // right after you've changed the set of OPTION nodes on it. So for that node type, we'll schedule a second thread
            // to apply the value as well.
            var alsoApplyAsynchronously = valueIsSelectOption;
            if (alsoApplyAsynchronously)
                setTimeout(applyValueAction, 0);
        }

        // If you try to set a model value that can't be represented in an already-populated dropdown, reject that change,
        // because you're not allowed to have a model value that disagrees with a visible UI selection.
        if (valueIsSelectOption && (element.length > 0))
            ensureDropdownSelectionIsConsistentWithModelValue(element, newValue, /* preferModelValue */ false);
    }
};
ko.bindingHandlers['visible'] = {
    'update': function (element, valueAccessor) {
        var value = ko.utils.unwrapObservable(valueAccessor());
        var isCurrentlyVisible = !(element.style.display == "none");
        if (value && !isCurrentlyVisible)
            element.style.display = "";
        else if ((!value) && isCurrentlyVisible)
            element.style.display = "none";
    }
};
// 'click' is just a shorthand for the usual full-length event:{click:handler}
makeEventHandlerShortcut('click');
// If you want to make a custom template engine,
//
// [1] Inherit from this class (like ko.nativeTemplateEngine does)
// [2] Override 'renderTemplateSource', supplying a function with this signature:
//
//        function (templateSource, bindingContext, options) {
//            // - templateSource.text() is the text of the template you should render
//            // - bindingContext.$data is the data you should pass into the template
//            //   - you might also want to make bindingContext.$parent, bindingContext.$parents,
//            //     and bindingContext.$root available in the template too
//            // - options gives you access to any other properties set on "data-bind: { template: options }"
//            //
//            // Return value: an array of DOM nodes
//        }
//
// [3] Override 'createJavaScriptEvaluatorBlock', supplying a function with this signature:
//
//        function (script) {
//            // Return value: Whatever syntax means "Evaluate the JavaScript statement 'script' and output the result"
//            //               For example, the jquery.tmpl template engine converts 'someScript' to '${ someScript }'
//        }
//
//     This is only necessary if you want to allow data-bind attributes to reference arbitrary template variables.
//     If you don't want to allow that, you can set the property 'allowTemplateRewriting' to false (like ko.nativeTemplateEngine does)
//     and then you don't need to override 'createJavaScriptEvaluatorBlock'.

ko.templateEngine = function () { };

ko.templateEngine.prototype['renderTemplateSource'] = function (templateSource, bindingContext, options) {
    throw new Error("Override renderTemplateSource");
};

ko.templateEngine.prototype['createJavaScriptEvaluatorBlock'] = function (script) {
    throw new Error("Override createJavaScriptEvaluatorBlock");
};

ko.templateEngine.prototype['makeTemplateSource'] = function(template, templateDocument) {
    // Named template
    if (typeof template == "string") {
        templateDocument = templateDocument || document;
        var elem = templateDocument.getElementById(template);
        if (!elem)
            throw new Error("Cannot find template with ID " + template);
        return new ko.templateSources.domElement(elem);
    } else if ((template.nodeType == 1) || (template.nodeType == 8)) {
        // Anonymous template
        return new ko.templateSources.anonymousTemplate(template);
    } else
        throw new Error("Unknown template type: " + template);
};

ko.templateEngine.prototype['renderTemplate'] = function (template, bindingContext, options, templateDocument) {
    var templateSource = this['makeTemplateSource'](template, templateDocument);
    return this['renderTemplateSource'](templateSource, bindingContext, options);
};

ko.templateEngine.prototype['isTemplateRewritten'] = function (template, templateDocument) {
    // Skip rewriting if requested
    if (this['allowTemplateRewriting'] === false)
        return true;
    return this['makeTemplateSource'](template, templateDocument)['data']("isRewritten");
};

ko.templateEngine.prototype['rewriteTemplate'] = function (template, rewriterCallback, templateDocument) {
    var templateSource = this['makeTemplateSource'](template, templateDocument);
    var rewritten = rewriterCallback(templateSource['text']());
    templateSource['text'](rewritten);
    templateSource['data']("isRewritten", true);
};

ko.exportSymbol('templateEngine', ko.templateEngine);

ko.templateRewriting = (function () {
    var memoizeDataBindingAttributeSyntaxRegex = /(<([a-z]+\d*)(?:\s+(?!data-bind\s*=\s*)[a-z0-9\-]+(?:=(?:\"[^\"]*\"|\'[^\']*\'))?)*\s+)data-bind\s*=\s*(["'])([\s\S]*?)\3/gi;
    var memoizeVirtualContainerBindingSyntaxRegex = /<!--\s*ko\b\s*([\s\S]*?)\s*-->/g;

    function validateDataBindValuesForRewriting(keyValueArray) {
        var allValidators = ko.expressionRewriting.bindingRewriteValidators;
        for (var i = 0; i < keyValueArray.length; i++) {
            var key = keyValueArray[i]['key'];
            if (allValidators.hasOwnProperty(key)) {
                var validator = allValidators[key];

                if (typeof validator === "function") {
                    var possibleErrorMessage = validator(keyValueArray[i]['value']);
                    if (possibleErrorMessage)
                        throw new Error(possibleErrorMessage);
                } else if (!validator) {
                    throw new Error("This template engine does not support the '" + key + "' binding within its templates");
                }
            }
        }
    }

    function constructMemoizedTagReplacement(dataBindAttributeValue, tagToRetain, nodeName, templateEngine) {
        var dataBindKeyValueArray = ko.expressionRewriting.parseObjectLiteral(dataBindAttributeValue);
        validateDataBindValuesForRewriting(dataBindKeyValueArray);
        var rewrittenDataBindAttributeValue = ko.expressionRewriting.preProcessBindings(dataBindKeyValueArray);

        // For no obvious reason, Opera fails to evaluate rewrittenDataBindAttributeValue unless it's wrapped in an additional
        // anonymous function, even though Opera's built-in debugger can evaluate it anyway. No other browser requires this
        // extra indirection.
        var applyBindingsToNextSiblingScript =
            "ko.__tr_ambtns(function($context,$element){return(function(){return{ " + rewrittenDataBindAttributeValue + " } })()},'" + nodeName.toLowerCase() + "')";
        return templateEngine['createJavaScriptEvaluatorBlock'](applyBindingsToNextSiblingScript) + tagToRetain;
    }

    return {
        ensureTemplateIsRewritten: function (template, templateEngine, templateDocument) {
            if (!templateEngine['isTemplateRewritten'](template, templateDocument))
                templateEngine['rewriteTemplate'](template, function (htmlString) {
                    return ko.templateRewriting.memoizeBindingAttributeSyntax(htmlString, templateEngine);
                }, templateDocument);
        },

        memoizeBindingAttributeSyntax: function (htmlString, templateEngine) {
            return htmlString.replace(memoizeDataBindingAttributeSyntaxRegex, function () {
                return constructMemoizedTagReplacement(/* dataBindAttributeValue: */ arguments[4], /* tagToRetain: */ arguments[1], /* nodeName: */ arguments[2], templateEngine);
            }).replace(memoizeVirtualContainerBindingSyntaxRegex, function() {
                return constructMemoizedTagReplacement(/* dataBindAttributeValue: */ arguments[1], /* tagToRetain: */ "<!-- ko -->", /* nodeName: */ "#comment", templateEngine);
            });
        },

        applyMemoizedBindingsToNextSibling: function (bindings, nodeName) {
            return ko.memoization.memoize(function (domNode, bindingContext) {
                var nodeToBind = domNode.nextSibling;
                if (nodeToBind && nodeToBind.nodeName.toLowerCase() === nodeName) {
                    ko.applyBindingsToNode(nodeToBind, bindings, bindingContext);
                }
            });
        }
    }
})();


// Exported only because it has to be referenced by string lookup from within rewritten template
ko.exportSymbol('__tr_ambtns', ko.templateRewriting.applyMemoizedBindingsToNextSibling);
(function() {
    // A template source represents a read/write way of accessing a template. This is to eliminate the need for template loading/saving
    // logic to be duplicated in every template engine (and means they can all work with anonymous templates, etc.)
    //
    // Two are provided by default:
    //  1. ko.templateSources.domElement       - reads/writes the text content of an arbitrary DOM element
    //  2. ko.templateSources.anonymousElement - uses ko.utils.domData to read/write text *associated* with the DOM element, but
    //                                           without reading/writing the actual element text content, since it will be overwritten
    //                                           with the rendered template output.
    // You can implement your own template source if you want to fetch/store templates somewhere other than in DOM elements.
    // Template sources need to have the following functions:
    //   text() 			- returns the template text from your storage location
    //   text(value)		- writes the supplied template text to your storage location
    //   data(key)			- reads values stored using data(key, value) - see below
    //   data(key, value)	- associates "value" with this template and the key "key". Is used to store information like "isRewritten".
    //
    // Optionally, template sources can also have the following functions:
    //   nodes()            - returns a DOM element containing the nodes of this template, where available
    //   nodes(value)       - writes the given DOM element to your storage location
    // If a DOM element is available for a given template source, template engines are encouraged to use it in preference over text()
    // for improved speed. However, all templateSources must supply text() even if they don't supply nodes().
    //
    // Once you've implemented a templateSource, make your template engine use it by subclassing whatever template engine you were
    // using and overriding "makeTemplateSource" to return an instance of your custom template source.

    ko.templateSources = {};

    // ---- ko.templateSources.domElement -----

    ko.templateSources.domElement = function(element) {
        this.domElement = element;
    }

    ko.templateSources.domElement.prototype['text'] = function(/* valueToWrite */) {
        var tagNameLower = ko.utils.tagNameLower(this.domElement),
            elemContentsProperty = tagNameLower === "script" ? "text"
                                 : tagNameLower === "textarea" ? "value"
                                 : "innerHTML";

        if (arguments.length == 0) {
            return this.domElement[elemContentsProperty];
        } else {
            var valueToWrite = arguments[0];
            if (elemContentsProperty === "innerHTML")
                ko.utils.setHtml(this.domElement, valueToWrite);
            else
                this.domElement[elemContentsProperty] = valueToWrite;
        }
    };

    ko.templateSources.domElement.prototype['data'] = function(key /*, valueToWrite */) {
        if (arguments.length === 1) {
            return ko.utils.domData.get(this.domElement, "templateSourceData_" + key);
        } else {
            ko.utils.domData.set(this.domElement, "templateSourceData_" + key, arguments[1]);
        }
    };

    // ---- ko.templateSources.anonymousTemplate -----
    // Anonymous templates are normally saved/retrieved as DOM nodes through "nodes".
    // For compatibility, you can also read "text"; it will be serialized from the nodes on demand.
    // Writing to "text" is still supported, but then the template data will not be available as DOM nodes.

    var anonymousTemplatesDomDataKey = "__ko_anon_template__";
    ko.templateSources.anonymousTemplate = function(element) {
        this.domElement = element;
    }
    ko.templateSources.anonymousTemplate.prototype = new ko.templateSources.domElement();
    ko.templateSources.anonymousTemplate.prototype.constructor = ko.templateSources.anonymousTemplate;
    ko.templateSources.anonymousTemplate.prototype['text'] = function(/* valueToWrite */) {
        if (arguments.length == 0) {
            var templateData = ko.utils.domData.get(this.domElement, anonymousTemplatesDomDataKey) || {};
            if (templateData.textData === undefined && templateData.containerData)
                templateData.textData = templateData.containerData.innerHTML;
            return templateData.textData;
        } else {
            var valueToWrite = arguments[0];
            ko.utils.domData.set(this.domElement, anonymousTemplatesDomDataKey, {textData: valueToWrite});
        }
    };
    ko.templateSources.domElement.prototype['nodes'] = function(/* valueToWrite */) {
        if (arguments.length == 0) {
            var templateData = ko.utils.domData.get(this.domElement, anonymousTemplatesDomDataKey) || {};
            return templateData.containerData;
        } else {
            var valueToWrite = arguments[0];
            ko.utils.domData.set(this.domElement, anonymousTemplatesDomDataKey, {containerData: valueToWrite});
        }
    };

    ko.exportSymbol('templateSources', ko.templateSources);
    ko.exportSymbol('templateSources.domElement', ko.templateSources.domElement);
    ko.exportSymbol('templateSources.anonymousTemplate', ko.templateSources.anonymousTemplate);
})();
(function () {
    var _templateEngine;
    ko.setTemplateEngine = function (templateEngine) {
        if ((templateEngine != undefined) && !(templateEngine instanceof ko.templateEngine))
            throw new Error("templateEngine must inherit from ko.templateEngine");
        _templateEngine = templateEngine;
    }

    function invokeForEachNodeOrCommentInContinuousRange(firstNode, lastNode, action) {
        var node, nextInQueue = firstNode, firstOutOfRangeNode = ko.virtualElements.nextSibling(lastNode);
        while (nextInQueue && ((node = nextInQueue) !== firstOutOfRangeNode)) {
            nextInQueue = ko.virtualElements.nextSibling(node);
            if (node.nodeType === 1 || node.nodeType === 8)
                action(node);
        }
    }

    function activateBindingsOnContinuousNodeArray(continuousNodeArray, bindingContext) {
        // To be used on any nodes that have been rendered by a template and have been inserted into some parent element
        // Walks through continuousNodeArray (which *must* be continuous, i.e., an uninterrupted sequence of sibling nodes, because
        // the algorithm for walking them relies on this), and for each top-level item in the virtual-element sense,
        // (1) Does a regular "applyBindings" to associate bindingContext with this node and to activate any non-memoized bindings
        // (2) Unmemoizes any memos in the DOM subtree (e.g., to activate bindings that had been memoized during template rewriting)

        if (continuousNodeArray.length) {
            var firstNode = continuousNodeArray[0], lastNode = continuousNodeArray[continuousNodeArray.length - 1];

            // Need to applyBindings *before* unmemoziation, because unmemoization might introduce extra nodes (that we don't want to re-bind)
            // whereas a regular applyBindings won't introduce new memoized nodes
            invokeForEachNodeOrCommentInContinuousRange(firstNode, lastNode, function(node) {
                ko.applyBindings(bindingContext, node);
            });
            invokeForEachNodeOrCommentInContinuousRange(firstNode, lastNode, function(node) {
                ko.memoization.unmemoizeDomNodeAndDescendants(node, [bindingContext]);
            });
        }
    }

    function getFirstNodeFromPossibleArray(nodeOrNodeArray) {
        return nodeOrNodeArray.nodeType ? nodeOrNodeArray
                                        : nodeOrNodeArray.length > 0 ? nodeOrNodeArray[0]
                                        : null;
    }

    function executeTemplate(targetNodeOrNodeArray, renderMode, template, bindingContext, options) {
        options = options || {};
        var firstTargetNode = targetNodeOrNodeArray && getFirstNodeFromPossibleArray(targetNodeOrNodeArray);
        var templateDocument = firstTargetNode && firstTargetNode.ownerDocument;
        var templateEngineToUse = (options['templateEngine'] || _templateEngine);
        ko.templateRewriting.ensureTemplateIsRewritten(template, templateEngineToUse, templateDocument);
        var renderedNodesArray = templateEngineToUse['renderTemplate'](template, bindingContext, options, templateDocument);

        // Loosely check result is an array of DOM nodes
        if ((typeof renderedNodesArray.length != "number") || (renderedNodesArray.length > 0 && typeof renderedNodesArray[0].nodeType != "number"))
            throw new Error("Template engine must return an array of DOM nodes");

        var haveAddedNodesToParent = false;
        switch (renderMode) {
            case "replaceChildren":
                ko.virtualElements.setDomNodeChildren(targetNodeOrNodeArray, renderedNodesArray);
                haveAddedNodesToParent = true;
                break;
            case "replaceNode":
                ko.utils.replaceDomNodes(targetNodeOrNodeArray, renderedNodesArray);
                haveAddedNodesToParent = true;
                break;
            case "ignoreTargetNode": break;
            default:
                throw new Error("Unknown renderMode: " + renderMode);
        }

        if (haveAddedNodesToParent) {
            activateBindingsOnContinuousNodeArray(renderedNodesArray, bindingContext);
            if (options['afterRender'])
                ko.dependencyDetection.ignore(options['afterRender'], null, [renderedNodesArray, bindingContext['$data']]);
        }

        return renderedNodesArray;
    }

    ko.renderTemplate = function (template, dataOrBindingContext, options, targetNodeOrNodeArray, renderMode) {
        options = options || {};
        if ((options['templateEngine'] || _templateEngine) == undefined)
            throw new Error("Set a template engine before calling renderTemplate");
        renderMode = renderMode || "replaceChildren";

        if (targetNodeOrNodeArray) {
            var firstTargetNode = getFirstNodeFromPossibleArray(targetNodeOrNodeArray);

            var whenToDispose = function () { return (!firstTargetNode) || !ko.utils.domNodeIsAttachedToDocument(firstTargetNode); }; // Passive disposal (on next evaluation)
            var activelyDisposeWhenNodeIsRemoved = (firstTargetNode && renderMode == "replaceNode") ? firstTargetNode.parentNode : firstTargetNode;

            return ko.dependentObservable( // So the DOM is automatically updated when any dependency changes
                function () {
                    // Ensure we've got a proper binding context to work with
                    var bindingContext = (dataOrBindingContext && (dataOrBindingContext instanceof ko.bindingContext))
                        ? dataOrBindingContext
                        : new ko.bindingContext(ko.utils.unwrapObservable(dataOrBindingContext));

                    // Support selecting template as a function of the data being rendered
                    var templateName = typeof(template) == 'function' ? template(bindingContext['$data'], bindingContext) : template;

                    var renderedNodesArray = executeTemplate(targetNodeOrNodeArray, renderMode, templateName, bindingContext, options);
                    if (renderMode == "replaceNode") {
                        targetNodeOrNodeArray = renderedNodesArray;
                        firstTargetNode = getFirstNodeFromPossibleArray(targetNodeOrNodeArray);
                    }
                },
                null,
                { disposeWhen: whenToDispose, disposeWhenNodeIsRemoved: activelyDisposeWhenNodeIsRemoved }
            );
        } else {
            // We don't yet have a DOM node to evaluate, so use a memo and render the template later when there is a DOM node
            return ko.memoization.memoize(function (domNode) {
                ko.renderTemplate(template, dataOrBindingContext, options, domNode, "replaceNode");
            });
        }
    };

    ko.renderTemplateForEach = function (template, arrayOrObservableArray, options, targetNode, parentBindingContext) {
        // Since setDomNodeChildrenFromArrayMapping always calls executeTemplateForArrayItem and then
        // activateBindingsCallback for added items, we can store the binding context in the former to use in the latter.
        var arrayItemContext;

        // This will be called by setDomNodeChildrenFromArrayMapping to get the nodes to add to targetNode
        var executeTemplateForArrayItem = function (arrayValue, index) {
            // Support selecting template as a function of the data being rendered
            arrayItemContext = parentBindingContext['createChildContext'](ko.utils.unwrapObservable(arrayValue), options['as']);
            arrayItemContext['$index'] = index;
            var templateName = typeof(template) == 'function' ? template(arrayValue, arrayItemContext) : template;
            return executeTemplate(null, "ignoreTargetNode", templateName, arrayItemContext, options);
        }

        // This will be called whenever setDomNodeChildrenFromArrayMapping has added nodes to targetNode
        var activateBindingsCallback = function(arrayValue, addedNodesArray, index) {
            activateBindingsOnContinuousNodeArray(addedNodesArray, arrayItemContext);
            if (options['afterRender'])
                options['afterRender'](addedNodesArray, arrayValue);
        };

        return ko.dependentObservable(function () {
            var unwrappedArray = ko.utils.unwrapObservable(arrayOrObservableArray) || [];
            if (typeof unwrappedArray.length == "undefined") // Coerce single value into array
                unwrappedArray = [unwrappedArray];

            // Filter out any entries marked as destroyed
            var filteredArray = ko.utils.arrayFilter(unwrappedArray, function(item) {
                return options['includeDestroyed'] || item === undefined || item === null || !ko.utils.unwrapObservable(item['_destroy']);
            });

            // Call setDomNodeChildrenFromArrayMapping, ignoring any observables unwrapped within (most likely from a callback function).
            // If the array items are observables, though, they will be unwrapped in executeTemplateForArrayItem and managed within setDomNodeChildrenFromArrayMapping.
            ko.dependencyDetection.ignore(ko.utils.setDomNodeChildrenFromArrayMapping, null, [targetNode, filteredArray, executeTemplateForArrayItem, options, activateBindingsCallback]);

        }, null, { disposeWhenNodeIsRemoved: targetNode });
    };

    var templateComputedDomDataKey = '__ko__templateComputedDomDataKey__';
    function disposeOldComputedAndStoreNewOne(element, newComputed) {
        var oldComputed = ko.utils.domData.get(element, templateComputedDomDataKey);
        if (oldComputed && (typeof(oldComputed.dispose) == 'function'))
            oldComputed.dispose();
        ko.utils.domData.set(element, templateComputedDomDataKey, (newComputed && newComputed.isActive()) ? newComputed : undefined);
    }

    ko.bindingHandlers['template'] = {
        'init': function(element, valueAccessor) {
            // Support anonymous templates
            var bindingValue = ko.utils.unwrapObservable(valueAccessor());
            if ((typeof bindingValue != "string") && (!bindingValue['name']) && (element.nodeType == 1 || element.nodeType == 8)) {
                // It's an anonymous template - store the element contents, then clear the element
                var templateNodes = element.nodeType == 1 ? element.childNodes : ko.virtualElements.childNodes(element),
                    container = ko.utils.moveCleanedNodesToContainerElement(templateNodes); // This also removes the nodes from their current parent
                new ko.templateSources.anonymousTemplate(element)['nodes'](container);
            }
            return { 'controlsDescendantBindings': true };
        },
        'update': function (element, valueAccessor, allBindingsAccessor, viewModel, bindingContext) {
            var templateName = ko.utils.unwrapObservable(valueAccessor()),
                options = {},
                shouldDisplay = true,
                dataValue,
                templateComputed = null;

            if (typeof templateName != "string") {
                options = templateName;
                templateName = ko.utils.unwrapObservable(options['name']);

                // Support "if"/"ifnot" conditions
                if ('if' in options)
                    shouldDisplay = ko.utils.unwrapObservable(options['if']);
                if (shouldDisplay && 'ifnot' in options)
                    shouldDisplay = !ko.utils.unwrapObservable(options['ifnot']);

                dataValue = ko.utils.unwrapObservable(options['data']);
            }

            if ('foreach' in options) {
                // Render once for each data point (treating data set as empty if shouldDisplay==false)
                var dataArray = (shouldDisplay && options['foreach']) || [];
                templateComputed = ko.renderTemplateForEach(templateName || element, dataArray, options, element, bindingContext);
            } else if (!shouldDisplay) {
                ko.virtualElements.emptyNode(element);
            } else {
                // Render once for this single data point (or use the viewModel if no data was provided)
                var innerBindingContext = ('data' in options) ?
                    bindingContext['createChildContext'](dataValue, options['as']) :  // Given an explitit 'data' value, we create a child binding context for it
                    bindingContext;                                                        // Given no explicit 'data' value, we retain the same binding context
                templateComputed = ko.renderTemplate(templateName || element, innerBindingContext, options, element);
            }

            // It only makes sense to have a single template computed per element (otherwise which one should have its output displayed?)
            disposeOldComputedAndStoreNewOne(element, templateComputed);
        }
    };

    // Anonymous templates can't be rewritten. Give a nice error message if you try to do it.
    ko.expressionRewriting.bindingRewriteValidators['template'] = function(bindingValue) {
        var parsedBindingValue = ko.expressionRewriting.parseObjectLiteral(bindingValue);

        if ((parsedBindingValue.length == 1) && parsedBindingValue[0]['unknown'])
            return null; // It looks like a string literal, not an object literal, so treat it as a named template (which is allowed for rewriting)

        if (ko.expressionRewriting.keyValueArrayContainsKey(parsedBindingValue, "name"))
            return null; // Named templates can be rewritten, so return "no error"
        return "This template engine does not support anonymous templates nested within its templates";
    };

    ko.virtualElements.allowedBindings['template'] = true;
})();

ko.exportSymbol('setTemplateEngine', ko.setTemplateEngine);
ko.exportSymbol('renderTemplate', ko.renderTemplate);

ko.utils.compareArrays = (function () {
    var statusNotInOld = 'added', statusNotInNew = 'deleted';

    // Simple calculation based on Levenshtein distance.
    function compareArrays(oldArray, newArray, dontLimitMoves) {
        oldArray = oldArray || [];
        newArray = newArray || [];

        if (oldArray.length <= newArray.length)
            return compareSmallArrayToBigArray(oldArray, newArray, statusNotInOld, statusNotInNew, dontLimitMoves);
        else
            return compareSmallArrayToBigArray(newArray, oldArray, statusNotInNew, statusNotInOld, dontLimitMoves);
    }

    function compareSmallArrayToBigArray(smlArray, bigArray, statusNotInSml, statusNotInBig, dontLimitMoves) {
        var myMin = Math.min,
            myMax = Math.max,
            editDistanceMatrix = [],
            smlIndex, smlIndexMax = smlArray.length,
            bigIndex, bigIndexMax = bigArray.length,
            compareRange = (bigIndexMax - smlIndexMax) || 1,
            maxDistance = smlIndexMax + bigIndexMax + 1,
            thisRow, lastRow,
            bigIndexMaxForRow, bigIndexMinForRow;

        for (smlIndex = 0; smlIndex <= smlIndexMax; smlIndex++) {
            lastRow = thisRow;
            editDistanceMatrix.push(thisRow = []);
            bigIndexMaxForRow = myMin(bigIndexMax, smlIndex + compareRange);
            bigIndexMinForRow = myMax(0, smlIndex - 1);
            for (bigIndex = bigIndexMinForRow; bigIndex <= bigIndexMaxForRow; bigIndex++) {
                if (!bigIndex)
                    thisRow[bigIndex] = smlIndex + 1;
                else if (!smlIndex)  // Top row - transform empty array into new array via additions
                    thisRow[bigIndex] = bigIndex + 1;
                else if (smlArray[smlIndex - 1] === bigArray[bigIndex - 1])
                    thisRow[bigIndex] = lastRow[bigIndex - 1];                  // copy value (no edit)
                else {
                    var northDistance = lastRow[bigIndex] || maxDistance;       // not in big (deletion)
                    var westDistance = thisRow[bigIndex - 1] || maxDistance;    // not in small (addition)
                    thisRow[bigIndex] = myMin(northDistance, westDistance) + 1;
                }
            }
        }

        var editScript = [], meMinusOne, notInSml = [], notInBig = [];
        for (smlIndex = smlIndexMax, bigIndex = bigIndexMax; smlIndex || bigIndex;) {
            meMinusOne = editDistanceMatrix[smlIndex][bigIndex] - 1;
            if (bigIndex && meMinusOne === editDistanceMatrix[smlIndex][bigIndex-1]) {
                notInSml.push(editScript[editScript.length] = {     // added
                    'status': statusNotInSml,
                    'value': bigArray[--bigIndex],
                    'index': bigIndex });
            } else if (smlIndex && meMinusOne === editDistanceMatrix[smlIndex - 1][bigIndex]) {
                notInBig.push(editScript[editScript.length] = {     // deleted
                    'status': statusNotInBig,
                    'value': smlArray[--smlIndex],
                    'index': smlIndex });
            } else {
                editScript.push({
                    'status': "retained",
                    'value': bigArray[--bigIndex] });
                --smlIndex;
            }
        }

        if (notInSml.length && notInBig.length) {
            // Set a limit on the number of consecutive non-matching comparisons; having it a multiple of
            // smlIndexMax keeps the time complexity of this algorithm linear.
            var limitFailedCompares = smlIndexMax * 10, failedCompares,
                a, d, notInSmlItem, notInBigItem;
            // Go through the items that have been added and deleted and try to find matches between them.
            for (failedCompares = a = 0; (dontLimitMoves || failedCompares < limitFailedCompares) && (notInSmlItem = notInSml[a]); a++) {
                for (d = 0; notInBigItem = notInBig[d]; d++) {
                    if (notInSmlItem['value'] === notInBigItem['value']) {
                        notInSmlItem['moved'] = notInBigItem['index'];
                        notInBigItem['moved'] = notInSmlItem['index'];
                        notInBig.splice(d,1);       // This item is marked as moved; so remove it from notInBig list
                        failedCompares = d = 0;     // Reset failed compares count because we're checking for consecutive failures
                        break;
                    }
                }
                failedCompares += d;
            }
        }
        return editScript.reverse();
    }

    return compareArrays;
})();

ko.exportSymbol('utils.compareArrays', ko.utils.compareArrays);

(function () {
    // Objective:
    // * Given an input array, a container DOM node, and a function from array elements to arrays of DOM nodes,
    //   map the array elements to arrays of DOM nodes, concatenate together all these arrays, and use them to populate the container DOM node
    // * Next time we're given the same combination of things (with the array possibly having mutated), update the container DOM node
    //   so that its children is again the concatenation of the mappings of the array elements, but don't re-map any array elements that we
    //   previously mapped - retain those nodes, and just insert/delete other ones

    // "callbackAfterAddingNodes" will be invoked after any "mapping"-generated nodes are inserted into the container node
    // You can use this, for example, to activate bindings on those nodes.

    function fixUpNodesToBeMovedOrRemoved(contiguousNodeArray) {
        // Before moving, deleting, or replacing a set of nodes that were previously outputted by the "map" function, we have to reconcile
        // them against what is in the DOM right now. It may be that some of the nodes have already been removed from the document,
        // or that new nodes might have been inserted in the middle, for example by a binding. Also, there may previously have been
        // leading comment nodes (created by rewritten string-based templates) that have since been removed during binding.
        // So, this function translates the old "map" output array into its best guess of what set of current DOM nodes should be removed.
        //
        // Rules:
        //   [A] Any leading nodes that aren't in the document any more should be ignored
        //       These most likely correspond to memoization nodes that were already removed during binding
        //       See https://github.com/SteveSanderson/knockout/pull/440
        //   [B] We want to output a contiguous series of nodes that are still in the document. So, ignore any nodes that
        //       have already been removed, and include any nodes that have been inserted among the previous collection

        // Rule [A]
        while (contiguousNodeArray.length && !ko.utils.domNodeIsAttachedToDocument(contiguousNodeArray[0]))
            contiguousNodeArray.splice(0, 1);

        // Rule [B]
        if (contiguousNodeArray.length > 1) {
            // Build up the actual new contiguous node set
            var current = contiguousNodeArray[0], last = contiguousNodeArray[contiguousNodeArray.length - 1], newContiguousSet = [current];
            while (current !== last) {
                current = current.nextSibling;
                if (!current) // Won't happen, except if the developer has manually removed some DOM elements (then we're in an undefined scenario)
                    return;
                newContiguousSet.push(current);
            }

            // ... then mutate the input array to match this.
            // (The following line replaces the contents of contiguousNodeArray with newContiguousSet)
            Array.prototype.splice.apply(contiguousNodeArray, [0, contiguousNodeArray.length].concat(newContiguousSet));
        }
        return contiguousNodeArray;
    }

    function mapNodeAndRefreshWhenChanged(containerNode, mapping, valueToMap, callbackAfterAddingNodes, index) {
        // Map this array value inside a dependentObservable so we re-map when any dependency changes
        var mappedNodes = [];
        var dependentObservable = ko.dependentObservable(function() {
            var newMappedNodes = mapping(valueToMap, index, fixUpNodesToBeMovedOrRemoved(mappedNodes)) || [];

            // On subsequent evaluations, just replace the previously-inserted DOM nodes
            if (mappedNodes.length > 0) {
                ko.utils.replaceDomNodes(mappedNodes, newMappedNodes);
                if (callbackAfterAddingNodes)
                    ko.dependencyDetection.ignore(callbackAfterAddingNodes, null, [valueToMap, newMappedNodes, index]);
            }

            // Replace the contents of the mappedNodes array, thereby updating the record
            // of which nodes would be deleted if valueToMap was itself later removed
            mappedNodes.splice(0, mappedNodes.length);
            ko.utils.arrayPushAll(mappedNodes, newMappedNodes);
        }, null, { disposeWhenNodeIsRemoved: containerNode, disposeWhen: function() { return !ko.utils.anyDomNodeIsAttachedToDocument(mappedNodes); } });
        return { mappedNodes : mappedNodes, dependentObservable : (dependentObservable.isActive() ? dependentObservable : undefined) };
    }

    var lastMappingResultDomDataKey = "setDomNodeChildrenFromArrayMapping_lastMappingResult";

    ko.utils.setDomNodeChildrenFromArrayMapping = function (domNode, array, mapping, options, callbackAfterAddingNodes) {
        // Compare the provided array against the previous one
        array = array || [];
        options = options || {};
        var isFirstExecution = ko.utils.domData.get(domNode, lastMappingResultDomDataKey) === undefined;
        var lastMappingResult = ko.utils.domData.get(domNode, lastMappingResultDomDataKey) || [];
        var lastArray = ko.utils.arrayMap(lastMappingResult, function (x) { return x.arrayEntry; });
        var editScript = ko.utils.compareArrays(lastArray, array, options['dontLimitMoves']);

        // Build the new mapping result
        var newMappingResult = [];
        var lastMappingResultIndex = 0;
        var newMappingResultIndex = 0;

        var nodesToDelete = [];
        var itemsToProcess = [];
        var itemsForBeforeRemoveCallbacks = [];
        var itemsForMoveCallbacks = [];
        var itemsForAfterAddCallbacks = [];
        var mapData;

        function itemMovedOrRetained(editScriptIndex, oldPosition) {
            mapData = lastMappingResult[oldPosition];
            if (newMappingResultIndex !== oldPosition)
                itemsForMoveCallbacks[editScriptIndex] = mapData;
            // Since updating the index might change the nodes, do so before calling fixUpNodesToBeMovedOrRemoved
            mapData.indexObservable(newMappingResultIndex++);
            fixUpNodesToBeMovedOrRemoved(mapData.mappedNodes);
            newMappingResult.push(mapData);
            itemsToProcess.push(mapData);
        }

        function callCallback(callback, items) {
            if (callback) {
                for (var i = 0, n = items.length; i < n; i++) {
                    if (items[i]) {
                        ko.utils.arrayForEach(items[i].mappedNodes, function(node) {
                            callback(node, i, items[i].arrayEntry);
                        });
                    }
                }
            }
        }

        for (var i = 0, editScriptItem, movedIndex; editScriptItem = editScript[i]; i++) {
            movedIndex = editScriptItem['moved'];
            switch (editScriptItem['status']) {
                case "deleted":
                    if (movedIndex === undefined) {
                        mapData = lastMappingResult[lastMappingResultIndex];

                        // Stop tracking changes to the mapping for these nodes
                        if (mapData.dependentObservable)
                            mapData.dependentObservable.dispose();

                        // Queue these nodes for later removal
                        nodesToDelete.push.apply(nodesToDelete, fixUpNodesToBeMovedOrRemoved(mapData.mappedNodes));
                        if (options['beforeRemove']) {
                            itemsForBeforeRemoveCallbacks[i] = mapData;
                            itemsToProcess.push(mapData);
                        }
                    }
                    lastMappingResultIndex++;
                    break;

                case "retained":
                    itemMovedOrRetained(i, lastMappingResultIndex++);
                    break;

                case "added":
                    if (movedIndex !== undefined) {
                        itemMovedOrRetained(i, movedIndex);
                    } else {
                        mapData = { arrayEntry: editScriptItem['value'], indexObservable: ko.observable(newMappingResultIndex++) };
                        newMappingResult.push(mapData);
                        itemsToProcess.push(mapData);
                        if (!isFirstExecution)
                            itemsForAfterAddCallbacks[i] = mapData;
                    }
                    break;
            }
        }

        // Call beforeMove first before any changes have been made to the DOM
        callCallback(options['beforeMove'], itemsForMoveCallbacks);

        // Next remove nodes for deleted items (or just clean if there's a beforeRemove callback)
        ko.utils.arrayForEach(nodesToDelete, options['beforeRemove'] ? ko.cleanNode : ko.removeNode);

        // Next add/reorder the remaining items (will include deleted items if there's a beforeRemove callback)
        for (var i = 0, nextNode = ko.virtualElements.firstChild(domNode), lastNode, node; mapData = itemsToProcess[i]; i++) {
            // Get nodes for newly added items
            if (!mapData.mappedNodes)
                ko.utils.extend(mapData, mapNodeAndRefreshWhenChanged(domNode, mapping, mapData.arrayEntry, callbackAfterAddingNodes, mapData.indexObservable));

            // Put nodes in the right place if they aren't there already
            for (var j = 0; node = mapData.mappedNodes[j]; nextNode = node.nextSibling, lastNode = node, j++) {
                if (node !== nextNode)
                    ko.virtualElements.insertAfter(domNode, node, lastNode);
            }

            // Run the callbacks for newly added nodes (for example, to apply bindings, etc.)
            if (!mapData.initialized && callbackAfterAddingNodes) {
                callbackAfterAddingNodes(mapData.arrayEntry, mapData.mappedNodes, mapData.indexObservable);
                mapData.initialized = true;
            }
        }

        // If there's a beforeRemove callback, call it after reordering.
        // Note that we assume that the beforeRemove callback will usually be used to remove the nodes using
        // some sort of animation, which is why we first reorder the nodes that will be removed. If the
        // callback instead removes the nodes right away, it would be more efficient to skip reordering them.
        // Perhaps we'll make that change in the future if this scenario becomes more common.
        callCallback(options['beforeRemove'], itemsForBeforeRemoveCallbacks);

        // Finally call afterMove and afterAdd callbacks
        callCallback(options['afterMove'], itemsForMoveCallbacks);
        callCallback(options['afterAdd'], itemsForAfterAddCallbacks);

        // Store a copy of the array items we just considered so we can difference it next time
        ko.utils.domData.set(domNode, lastMappingResultDomDataKey, newMappingResult);
    }
})();

ko.exportSymbol('utils.setDomNodeChildrenFromArrayMapping', ko.utils.setDomNodeChildrenFromArrayMapping);
ko.nativeTemplateEngine = function () {
    this['allowTemplateRewriting'] = false;
}

ko.nativeTemplateEngine.prototype = new ko.templateEngine();
ko.nativeTemplateEngine.prototype.constructor = ko.nativeTemplateEngine;
ko.nativeTemplateEngine.prototype['renderTemplateSource'] = function (templateSource, bindingContext, options) {
    var useNodesIfAvailable = !(ko.utils.ieVersion < 9), // IE<9 cloneNode doesn't work properly
        templateNodesFunc = useNodesIfAvailable ? templateSource['nodes'] : null,
        templateNodes = templateNodesFunc ? templateSource['nodes']() : null;

    if (templateNodes) {
        return ko.utils.makeArray(templateNodes.cloneNode(true).childNodes);
    } else {
        var templateText = templateSource['text']();
        return ko.utils.parseHtmlFragment(templateText);
    }
};

ko.nativeTemplateEngine.instance = new ko.nativeTemplateEngine();
ko.setTemplateEngine(ko.nativeTemplateEngine.instance);

ko.exportSymbol('nativeTemplateEngine', ko.nativeTemplateEngine);
(function() {
    ko.jqueryTmplTemplateEngine = function () {
        // Detect which version of jquery-tmpl you're using. Unfortunately jquery-tmpl
        // doesn't expose a version number, so we have to infer it.
        // Note that as of Knockout 1.3, we only support jQuery.tmpl 1.0.0pre and later,
        // which KO internally refers to as version "2", so older versions are no longer detected.
        var jQueryTmplVersion = this.jQueryTmplVersion = (function() {
            if ((typeof(jQuery) == "undefined") || !(jQuery['tmpl']))
                return 0;
            // Since it exposes no official version number, we use our own numbering system. To be updated as jquery-tmpl evolves.
            try {
                if (jQuery['tmpl']['tag']['tmpl']['open'].toString().indexOf('__') >= 0) {
                    // Since 1.0.0pre, custom tags should append markup to an array called "__"
                    return 2; // Final version of jquery.tmpl
                }
            } catch(ex) { /* Apparently not the version we were looking for */ }

            return 1; // Any older version that we don't support
        })();

        function ensureHasReferencedJQueryTemplates() {
            if (jQueryTmplVersion < 2)
                throw new Error("Your version of jQuery.tmpl is too old. Please upgrade to jQuery.tmpl 1.0.0pre or later.");
        }

        function executeTemplate(compiledTemplate, data, jQueryTemplateOptions) {
            return jQuery['tmpl'](compiledTemplate, data, jQueryTemplateOptions);
        }

        this['renderTemplateSource'] = function(templateSource, bindingContext, options) {
            options = options || {};
            ensureHasReferencedJQueryTemplates();

            // Ensure we have stored a precompiled version of this template (don't want to reparse on every render)
            var precompiled = templateSource['data']('precompiled');
            if (!precompiled) {
                var templateText = templateSource['text']() || "";
                // Wrap in "with($whatever.koBindingContext) { ... }"
                templateText = "{{ko_with $item.koBindingContext}}" + templateText + "{{/ko_with}}";

                precompiled = jQuery['template'](null, templateText);
                templateSource['data']('precompiled', precompiled);
            }

            var data = [bindingContext['$data']]; // Prewrap the data in an array to stop jquery.tmpl from trying to unwrap any arrays
            var jQueryTemplateOptions = jQuery['extend']({ 'koBindingContext': bindingContext }, options['templateOptions']);

            var resultNodes = executeTemplate(precompiled, data, jQueryTemplateOptions);
            resultNodes['appendTo'](document.createElement("div")); // Using "appendTo" forces jQuery/jQuery.tmpl to perform necessary cleanup work

            jQuery['fragments'] = {}; // Clear jQuery's fragment cache to avoid a memory leak after a large number of template renders
            return resultNodes;
        };

        this['createJavaScriptEvaluatorBlock'] = function(script) {
            return "{{ko_code ((function() { return " + script + " })()) }}";
        };

        this['addTemplate'] = function(templateName, templateMarkup) {
            document.write("<script type='text/html' id='" + templateName + "'>" + templateMarkup + "<" + "/script>");
        };

        if (jQueryTmplVersion > 0) {
            jQuery['tmpl']['tag']['ko_code'] = {
                open: "__.push($1 || '');"
            };
            jQuery['tmpl']['tag']['ko_with'] = {
                open: "with($1) {",
                close: "} "
            };
        }
    };

    ko.jqueryTmplTemplateEngine.prototype = new ko.templateEngine();
    ko.jqueryTmplTemplateEngine.prototype.constructor = ko.jqueryTmplTemplateEngine;

    // Use this one by default *only if jquery.tmpl is referenced*
    var jqueryTmplTemplateEngineInstance = new ko.jqueryTmplTemplateEngine();
    if (jqueryTmplTemplateEngineInstance.jQueryTmplVersion > 0)
        ko.setTemplateEngine(jqueryTmplTemplateEngineInstance);

    ko.exportSymbol('jqueryTmplTemplateEngine', ko.jqueryTmplTemplateEngine);
})();
}));
}());
})();

// oktell.js 1.5.3


/*	SWFObject v2.2 <http://code.google.com/p/swfobject/> is released under the MIT License <http://www.opensource.org/licenses/mit-license.php> */
var swfobject=function(){var D="undefined",r="object",S="Shockwave Flash",W="ShockwaveFlash.ShockwaveFlash",q="application/x-shockwave-flash",R="SWFObjectExprInst",x="onreadystatechange",O=window,j=document,t=navigator,T=false,U=[h],o=[],N=[],I=[],l,Q,E,B,J=false,a=false,n,G,m=true,M=function(){var aa=typeof j.getElementById!=D&&typeof j.getElementsByTagName!=D&&typeof j.createElement!=D,ah=t.userAgent.toLowerCase(),Y=t.platform.toLowerCase(),ae=Y?/win/.test(Y):/win/.test(ah),ac=Y?/mac/.test(Y):/mac/.test(ah),af=/webkit/.test(ah)?parseFloat(ah.replace(/^.*webkit\/(\d+(\.\d+)?).*$/,"$1")):false,X=!+"\v1",ag=[0,0,0],ab=null;if(typeof t.plugins!=D&&typeof t.plugins[S]==r){ab=t.plugins[S].description;if(ab&&!(typeof t.mimeTypes!=D&&t.mimeTypes[q]&&!t.mimeTypes[q].enabledPlugin)){T=true;X=false;ab=ab.replace(/^.*\s+(\S+\s+\S+$)/,"$1");ag[0]=parseInt(ab.replace(/^(.*)\..*$/,"$1"),10);ag[1]=parseInt(ab.replace(/^.*\.(.*)\s.*$/,"$1"),10);ag[2]=/[a-zA-Z]/.test(ab)?parseInt(ab.replace(/^.*[a-zA-Z]+(.*)$/,"$1"),10):0}}else{if(typeof O.ActiveXObject!=D){try{var ad=new ActiveXObject(W);if(ad){ab=ad.GetVariable("$version");if(ab){X=true;ab=ab.split(" ")[1].split(",");ag=[parseInt(ab[0],10),parseInt(ab[1],10),parseInt(ab[2],10)]}}}catch(Z){}}}return{w3:aa,pv:ag,wk:af,ie:X,win:ae,mac:ac}}(),k=function(){if(!M.w3){return}if((typeof j.readyState!=D&&j.readyState=="complete")||(typeof j.readyState==D&&(j.getElementsByTagName("body")[0]||j.body))){f()}if(!J){if(typeof j.addEventListener!=D){j.addEventListener("DOMContentLoaded",f,false)}if(M.ie&&M.win){j.attachEvent(x,function(){if(j.readyState=="complete"){j.detachEvent(x,arguments.callee);f()}});if(O==top){(function(){if(J){return}try{j.documentElement.doScroll("left")}catch(X){setTimeout(arguments.callee,0);return}f()})()}}if(M.wk){(function(){if(J){return}if(!/loaded|complete/.test(j.readyState)){setTimeout(arguments.callee,0);return}f()})()}s(f)}}();function f(){if(J){return}try{var Z=j.getElementsByTagName("body")[0].appendChild(C("span"));Z.parentNode.removeChild(Z)}catch(aa){return}J=true;var X=U.length;for(var Y=0;Y<X;Y++){U[Y]()}}function K(X){if(J){X()}else{U[U.length]=X}}function s(Y){if(typeof O.addEventListener!=D){O.addEventListener("load",Y,false)}else{if(typeof j.addEventListener!=D){j.addEventListener("load",Y,false)}else{if(typeof O.attachEvent!=D){i(O,"onload",Y)}else{if(typeof O.onload=="function"){var X=O.onload;O.onload=function(){X();Y()}}else{O.onload=Y}}}}}function h(){if(T){V()}else{H()}}function V(){var X=j.getElementsByTagName("body")[0];var aa=C(r);aa.setAttribute("type",q);var Z=X.appendChild(aa);if(Z){var Y=0;(function(){if(typeof Z.GetVariable!=D){var ab=Z.GetVariable("$version");if(ab){ab=ab.split(" ")[1].split(",");M.pv=[parseInt(ab[0],10),parseInt(ab[1],10),parseInt(ab[2],10)]}}else{if(Y<10){Y++;setTimeout(arguments.callee,10);return}}X.removeChild(aa);Z=null;H()})()}else{H()}}function H(){var ag=o.length;if(ag>0){for(var af=0;af<ag;af++){var Y=o[af].id;var ab=o[af].callbackFn;var aa={success:false,id:Y};if(M.pv[0]>0){var ae=c(Y);if(ae){if(F(o[af].swfVersion)&&!(M.wk&&M.wk<312)){w(Y,true);if(ab){aa.success=true;aa.ref=z(Y);ab(aa)}}else{if(o[af].expressInstall&&A()){var ai={};ai.data=o[af].expressInstall;ai.width=ae.getAttribute("width")||"0";ai.height=ae.getAttribute("height")||"0";if(ae.getAttribute("class")){ai.styleclass=ae.getAttribute("class")}if(ae.getAttribute("align")){ai.align=ae.getAttribute("align")}var ah={};var X=ae.getElementsByTagName("param");var ac=X.length;for(var ad=0;ad<ac;ad++){if(X[ad].getAttribute("name").toLowerCase()!="movie"){ah[X[ad].getAttribute("name")]=X[ad].getAttribute("value")}}P(ai,ah,Y,ab)}else{p(ae);if(ab){ab(aa)}}}}}else{w(Y,true);if(ab){var Z=z(Y);if(Z&&typeof Z.SetVariable!=D){aa.success=true;aa.ref=Z}ab(aa)}}}}}function z(aa){var X=null;var Y=c(aa);if(Y&&Y.nodeName=="OBJECT"){if(typeof Y.SetVariable!=D){X=Y}else{var Z=Y.getElementsByTagName(r)[0];if(Z){X=Z}}}return X}function A(){return !a&&F("6.0.65")&&(M.win||M.mac)&&!(M.wk&&M.wk<312)}function P(aa,ab,X,Z){a=true;E=Z||null;B={success:false,id:X};var ae=c(X);if(ae){if(ae.nodeName=="OBJECT"){l=g(ae);Q=null}else{l=ae;Q=X}aa.id=R;if(typeof aa.width==D||(!/%$/.test(aa.width)&&parseInt(aa.width,10)<310)){aa.width="310"}if(typeof aa.height==D||(!/%$/.test(aa.height)&&parseInt(aa.height,10)<137)){aa.height="137"}j.title=j.title.slice(0,47)+" - Flash Player Installation";var ad=M.ie&&M.win?"ActiveX":"PlugIn",ac="MMredirectURL="+O.location.toString().replace(/&/g,"%26")+"&MMplayerType="+ad+"&MMdoctitle="+j.title;if(typeof ab.flashvars!=D){ab.flashvars+="&"+ac}else{ab.flashvars=ac}if(M.ie&&M.win&&ae.readyState!=4){var Y=C("div");X+="SWFObjectNew";Y.setAttribute("id",X);ae.parentNode.insertBefore(Y,ae);ae.style.display="none";(function(){if(ae.readyState==4){ae.parentNode.removeChild(ae)}else{setTimeout(arguments.callee,10)}})()}u(aa,ab,X)}}function p(Y){if(M.ie&&M.win&&Y.readyState!=4){var X=C("div");Y.parentNode.insertBefore(X,Y);X.parentNode.replaceChild(g(Y),X);Y.style.display="none";(function(){if(Y.readyState==4){Y.parentNode.removeChild(Y)}else{setTimeout(arguments.callee,10)}})()}else{Y.parentNode.replaceChild(g(Y),Y)}}function g(ab){var aa=C("div");if(M.win&&M.ie){aa.innerHTML=ab.innerHTML}else{var Y=ab.getElementsByTagName(r)[0];if(Y){var ad=Y.childNodes;if(ad){var X=ad.length;for(var Z=0;Z<X;Z++){if(!(ad[Z].nodeType==1&&ad[Z].nodeName=="PARAM")&&!(ad[Z].nodeType==8)){aa.appendChild(ad[Z].cloneNode(true))}}}}}return aa}function u(ai,ag,Y){var X,aa=c(Y);if(M.wk&&M.wk<312){return X}if(aa){if(typeof ai.id==D){ai.id=Y}if(M.ie&&M.win){var ah="";for(var ae in ai){if(ai[ae]!=Object.prototype[ae]){if(ae.toLowerCase()=="data"){ag.movie=ai[ae]}else{if(ae.toLowerCase()=="styleclass"){ah+=' class="'+ai[ae]+'"'}else{if(ae.toLowerCase()!="classid"){ah+=" "+ae+'="'+ai[ae]+'"'}}}}}var af="";for(var ad in ag){if(ag[ad]!=Object.prototype[ad]){af+='<param name="'+ad+'" value="'+ag[ad]+'" />'}}aa.outerHTML='<object classid="clsid:D27CDB6E-AE6D-11cf-96B8-444553540000"'+ah+">"+af+"</object>";N[N.length]=ai.id;X=c(ai.id)}else{var Z=C(r);Z.setAttribute("type",q);for(var ac in ai){if(ai[ac]!=Object.prototype[ac]){if(ac.toLowerCase()=="styleclass"){Z.setAttribute("class",ai[ac])}else{if(ac.toLowerCase()!="classid"){Z.setAttribute(ac,ai[ac])}}}}for(var ab in ag){if(ag[ab]!=Object.prototype[ab]&&ab.toLowerCase()!="movie"){e(Z,ab,ag[ab])}}aa.parentNode.replaceChild(Z,aa);X=Z}}return X}function e(Z,X,Y){var aa=C("param");aa.setAttribute("name",X);aa.setAttribute("value",Y);Z.appendChild(aa)}function y(Y){var X=c(Y);if(X&&X.nodeName=="OBJECT"){if(M.ie&&M.win){X.style.display="none";(function(){if(X.readyState==4){b(Y)}else{setTimeout(arguments.callee,10)}})()}else{X.parentNode.removeChild(X)}}}function b(Z){var Y=c(Z);if(Y){for(var X in Y){if(typeof Y[X]=="function"){Y[X]=null}}Y.parentNode.removeChild(Y)}}function c(Z){var X=null;try{X=j.getElementById(Z)}catch(Y){}return X}function C(X){return j.createElement(X)}function i(Z,X,Y){Z.attachEvent(X,Y);I[I.length]=[Z,X,Y]}function F(Z){var Y=M.pv,X=Z.split(".");X[0]=parseInt(X[0],10);X[1]=parseInt(X[1],10)||0;X[2]=parseInt(X[2],10)||0;return(Y[0]>X[0]||(Y[0]==X[0]&&Y[1]>X[1])||(Y[0]==X[0]&&Y[1]==X[1]&&Y[2]>=X[2]))?true:false}function v(ac,Y,ad,ab){if(M.ie&&M.mac){return}var aa=j.getElementsByTagName("head")[0];if(!aa){return}var X=(ad&&typeof ad=="string")?ad:"screen";if(ab){n=null;G=null}if(!n||G!=X){var Z=C("style");Z.setAttribute("type","text/css");Z.setAttribute("media",X);n=aa.appendChild(Z);if(M.ie&&M.win&&typeof j.styleSheets!=D&&j.styleSheets.length>0){n=j.styleSheets[j.styleSheets.length-1]}G=X}if(M.ie&&M.win){if(n&&typeof n.addRule==r){n.addRule(ac,Y)}}else{if(n&&typeof j.createTextNode!=D){n.appendChild(j.createTextNode(ac+" {"+Y+"}"))}}}function w(Z,X){if(!m){return}var Y=X?"visible":"hidden";if(J&&c(Z)){c(Z).style.visibility=Y}else{v("#"+Z,"visibility:"+Y)}}function L(Y){var Z=/[\\\"<>\.;]/;var X=Z.exec(Y)!=null;return X&&typeof encodeURIComponent!=D?encodeURIComponent(Y):Y}var d=function(){if(M.ie&&M.win){window.attachEvent("onunload",function(){var ac=I.length;for(var ab=0;ab<ac;ab++){I[ab][0].detachEvent(I[ab][1],I[ab][2])}var Z=N.length;for(var aa=0;aa<Z;aa++){y(N[aa])}for(var Y in M){M[Y]=null}M=null;for(var X in swfobject){swfobject[X]=null}swfobject=null})}}();return{registerObject:function(ab,X,aa,Z){if(M.w3&&ab&&X){var Y={};Y.id=ab;Y.swfVersion=X;Y.expressInstall=aa;Y.callbackFn=Z;o[o.length]=Y;w(ab,false)}else{if(Z){Z({success:false,id:ab})}}},getObjectById:function(X){if(M.w3){return z(X)}},embedSWF:function(ab,ah,ae,ag,Y,aa,Z,ad,af,ac){var X={success:false,id:ah};if(M.w3&&!(M.wk&&M.wk<312)&&ab&&ah&&ae&&ag&&Y){w(ah,false);K(function(){ae+="";ag+="";var aj={};if(af&&typeof af===r){for(var al in af){aj[al]=af[al]}}aj.data=ab;aj.width=ae;aj.height=ag;var am={};if(ad&&typeof ad===r){for(var ak in ad){am[ak]=ad[ak]}}if(Z&&typeof Z===r){for(var ai in Z){if(typeof am.flashvars!=D){am.flashvars+="&"+ai+"="+Z[ai]}else{am.flashvars=ai+"="+Z[ai]}}}if(F(Y)){var an=u(aj,am,ah);if(aj.id==ah){w(ah,true)}X.success=true;X.ref=an}else{if(aa&&A()){aj.data=aa;P(aj,am,ah,ac);return}else{w(ah,true)}}if(ac){ac(X)}})}else{if(ac){ac(X)}}},switchOffAutoHideShow:function(){m=false},ua:M,getFlashPlayerVersion:function(){return{major:M.pv[0],minor:M.pv[1],release:M.pv[2]}},hasFlashPlayerVersion:F,createSWF:function(Z,Y,X){if(M.w3){return u(Z,Y,X)}else{return undefined}},showExpressInstall:function(Z,aa,X,Y){if(M.w3&&A()){P(Z,aa,X,Y)}},removeSWF:function(X){if(M.w3){y(X)}},createCSS:function(aa,Z,Y,X){if(M.w3){v(aa,Z,Y,X)}},addDomLoadEvent:K,addLoadEvent:s,getQueryParamValue:function(aa){var Z=j.location.search||j.location.hash;if(Z){if(/\?/.test(Z)){Z=Z.split("?")[1]}if(aa==null){return L(Z)}var Y=Z.split("&");for(var X=0;X<Y.length;X++){if(Y[X].substring(0,Y[X].indexOf("="))==aa){return L(Y[X].substring((Y[X].indexOf("=")+1)))}}}return""},expressInstallCallback:function(){if(a){var X=c(R);if(X&&l){X.parentNode.replaceChild(l,X);if(Q){w(Q,true);if(M.ie&&M.win){l.style.display="block"}}if(E){E(B)}}a=false}}}}();

// Oktell
Oktell = (function(){

	var self = this;
	var JSON = {};
	(function () {
		function f(n) {
			return n < 10 ? '0' + n : n;
		}
		if (typeof Date.prototype.toOktellJSON !== 'function') {
			Date.prototype.toOktellJSON = function (key) {
				return isFinite(this.valueOf()) ?
					this.getUTCFullYear()   + '-' +
						f(this.getUTCMonth() + 1) + '-' +
						f(this.getUTCDate())      + 'T' +
						f(this.getUTCHours())     + ':' +
						f(this.getUTCMinutes())   + ':' +
						f(this.getUTCSeconds())   + 'Z' : null;
			};

			String.prototype.toOktellJSON =
				Number.prototype.toOktellJSON =
					Boolean.prototype.toOktellJSON = function (key) {
						return this.valueOf();
					};
		}

		var cx = /[\u0000\u00ad\u0600-\u0604\u070f\u17b4\u17b5\u200c-\u200f\u2028-\u202f\u2060-\u206f\ufeff\ufff0-\uffff]/g,
			escapable = /[\\\"\x00-\x1f\x7f-\x9f\u00ad\u0600-\u0604\u070f\u17b4\u17b5\u200c-\u200f\u2028-\u202f\u2060-\u206f\ufeff\ufff0-\uffff]/g,
			gap,
			indent,
			meta = {    // table of character substitutions
				'\b': '\\b',
				'\t': '\\t',
				'\n': '\\n',
				'\f': '\\f',
				'\r': '\\r',
				'"' : '\\"',
				'\\': '\\\\'
			},
			rep;


		function quote(string) {

			escapable.lastIndex = 0;
			return escapable.test(string) ?
				'"' + string.replace(escapable, function (a) {
					var c = meta[a];
					return typeof c === 'string' ? c :
						'\\u' + ('0000' + a.charCodeAt(0).toString(16)).slice(-4);
				}) + '"' :
				'"' + string + '"';
		}


		function str(key, holder) {


			var i,          // The loop counter.
				k,          // The member key.
				v,          // The member value.
				length,
				mind = gap,
				partial,
				value = holder[key];


			if (value && typeof value === 'object' &&
				typeof value.toOktellJSON === 'function') {
				value = value.toOktellJSON(key);
			}

			if (typeof rep === 'function') {
				value = rep.call(holder, key, value);
			}


			switch (typeof value) {
				case 'string':
					return quote(value);

				case 'number':



					return isFinite(value) ? String(value) : 'null';

				case 'boolean':
				case 'null':

					return String(value);

				case 'object':

					if (!value) {
						return 'null';
					}


					gap += indent;
					partial = [];

					if (Object.prototype.toString.apply(value) === '[object Array]') {


						length = value.length;
						for (i = 0; i < length; i += 1) {
							partial[i] = str(i, value) || 'null';
						}

						v = partial.length === 0 ? '[]' :
							gap ? '[\n' + gap +
								partial.join(',\n' + gap) + '\n' +
								mind + ']' :
								'[' + partial.join(',') + ']';
						gap = mind;
						return v;
					}


					if (rep && typeof rep === 'object') {
						length = rep.length;
						for (i = 0; i < length; i += 1) {
							k = rep[i];
							if (typeof k === 'string') {
								v = str(k, value);
								if (v) {
									partial.push(quote(k) + (gap ? ': ' : ':') + v);
								}
							}
						}
					} else {


						for (k in value) {
							if (Object.hasOwnProperty.call(value, k)) {
								v = str(k, value);
								if (v) {
									partial.push(quote(k) + (gap ? ': ' : ':') + v);
								}
							}
						}
					}


					v = partial.length === 0 ? '{}' :
						gap ? '{\n' + gap + partial.join(',\n' + gap) + '\n' +
							mind + '}' : '{' + partial.join(',') + '}';
					gap = mind;
					return v;
			}
		}


		if (typeof JSON.stringify !== 'function') {
			JSON.stringify = function (value, replacer, space) {


				var i;
				gap = '';
				indent = '';

				if (typeof space === 'number') {
					for (i = 0; i < space; i += 1) {
						indent += ' ';
					}


				} else if (typeof space === 'string') {
					indent = space;
				}

				rep = replacer;
				if (replacer && typeof replacer !== 'function' &&
					(typeof replacer !== 'object' ||
						typeof replacer.length !== 'number')) {
					throw new Error('JSON.stringify');
				}


				return str('', {'': value});
			};
		}



		if (typeof JSON.parse !== 'function') {
			JSON.parse = function (text, reviver) {


				var j;

				function walk(holder, key) {

					var k, v, value = holder[key];
					if (value && typeof value === 'object') {
						for (k in value) {
							if (Object.hasOwnProperty.call(value, k)) {
								v = walk(value, k);
								if (v !== undefined) {
									value[k] = v;
								} else {
									delete value[k];
								}
							}
						}
					}
					return reviver.call(holder, key, value);
				}


				text = String(text);
				cx.lastIndex = 0;
				if (cx.test(text)) {
					text = text.replace(cx, function (a) {
						return '\\u' +
							('0000' + a.charCodeAt(0).toString(16)).slice(-4);
					});
				}


				if (/^[\],:{}\s]*$/.
					test(text.replace(/\\(?:["\\\/bfnrt]|u[0-9a-fA-F]{4})/g, '@').
						replace(/"[^"\\\n\r]*"|true|false|null|-?\d+(?:\.\d*)?(?:[eE][+\-]?\d+)?/g, ']').
						replace(/(?:^|:|,)(?:\s*\[)+/g, ''))) {

					j = eval('(' + text + ')');


					return typeof reviver === 'function' ?
						walk({'': j}, '') : j;
				}

				throw new SyntaxError('JSON.parse');
			};
		}
	}());


	// Flash WebSocket
	// Copyright: Hiroshi Ichikawa <http://gimite.net/en/>
	// License: New BSD License
	// Reference: http://dev.w3.org/html5/websockets/
	// Reference: http://tools.ietf.org/html/rfc6455
	var initFlashWebSocket = function() {

		if (window.WEB_SOCKET_FORCE_FLASH) {
			// Keeps going.
		} else if (window.WebSocket) {
			return;
		} else if (window.MozWebSocket) {
			// Firefox.
			window.WebSocket = MozWebSocket;
			return;
		}

		//WEB_SOCKET_SWF_LOCATION = "WebSocketMain.swf";

		var logger;
		if (window.WEB_SOCKET_LOGGER) {
			logger = WEB_SOCKET_LOGGER;
		} else if (window.console && window.console.log && window.console.error) {
			// In some environment, console is defined but console.log or console.error is missing.
			logger = window.console;
		} else {
			logger = {log: function(){ }, error: function(){ }};
		}

		// swfobject.hasFlashPlayerVersion("10.0.0") doesn't work with Gnash.
		if (swfobject.getFlashPlayerVersion().major < 10) {
			logger.error("Flash Player >= 10.0.0 is required.");
			return;
		}
		if (location.protocol == "file:") {
			logger.error(
				"WARNING: web-socket-js doesn't work in file:///... URL " +
					"unless you set Flash Security Settings properly. " +
					"Open the page via Web server i.e. http://...");
		}

		/**
		 * Our own implementation of WebSocket class using Flash.
		 * @param {string} url
		 * @param {array or string} protocols
		 * @param {string} proxyHost
		 * @param {int} proxyPort
		 * @param {string} headers
		 */
		window.WebSocket = function(url, protocols, proxyHost, proxyPort, headers) {
			var self = this;
			self.__id = WebSocket.__nextId++;
			WebSocket.__instances[self.__id] = self;
			self.readyState = WebSocket.CONNECTING;
			self.bufferedAmount = 0;
			self.__events = {};
			if (!protocols) {
				protocols = [];
			} else if (typeof protocols == "string") {
				protocols = [protocols];
			}
			// Uses setTimeout() to make sure __createFlash() runs after the caller sets ws.onopen etc.
			// Otherwise, when onopen fires immediately, onopen is called before it is set.
			self.__createTask = setTimeout(function() {
				WebSocket.__addTask(function() {
					self.__createTask = null;
					WebSocket.__flash.create(
						self.__id, url, protocols, proxyHost || null, proxyPort || 0, headers || null);
				});
			}, 0);
		};

		/**
		 * Send data to the web socket.
		 * @param {string} data  The data to send to the socket.
		 * @return {boolean}  True for success, false for failure.
		 */
		WebSocket.prototype.send = function(data) {
			if (this.readyState == WebSocket.CONNECTING) {
				throw "INVALID_STATE_ERR: Web Socket connection has not been established";
			}
			// We use encodeURIComponent() here, because FABridge doesn't work if
			// the argument includes some characters. We don't use escape() here
			// because of this:
			// https://developer.mozilla.org/en/Core_JavaScript_1.5_Guide/Functions#escape_and_unescape_Functions
			// But it looks decodeURIComponent(encodeURIComponent(s)) doesn't
			// preserve all Unicode characters either e.g. "\uffff" in Firefox.
			// Note by wtritch: Hopefully this will not be necessary using ExternalInterface.  Will require
			// additional testing.
			var result = WebSocket.__flash.send(this.__id, encodeURIComponent(data));
			if (result < 0) { // success
				return true;
			} else {
				this.bufferedAmount += result;
				return false;
			}
		};

		/**
		 * Close this web socket gracefully.
		 */
		WebSocket.prototype.close = function() {
			if (this.__createTask) {
				clearTimeout(this.__createTask);
				this.__createTask = null;
				this.readyState = WebSocket.CLOSED;
				return;
			}
			if (this.readyState == WebSocket.CLOSED || this.readyState == WebSocket.CLOSING) {
				return;
			}
			this.readyState = WebSocket.CLOSING;
			WebSocket.__flash.close(this.__id);
		};

		/**
		 * Implementation of {@link <a href="http://www.w3.org/TR/DOM-Level-2-Events/events.html#Events-registration">DOM 2 EventTarget Interface</a>}
		 *
		 * @param {string} type
		 * @param {function} listener
		 * @param {boolean} useCapture
		 * @return void
		 */
		WebSocket.prototype.addEventListener = function(type, listener, useCapture) {
			if (!(type in this.__events)) {
				this.__events[type] = [];
			}
			this.__events[type].push(listener);
		};

		/**
		 * Implementation of {@link <a href="http://www.w3.org/TR/DOM-Level-2-Events/events.html#Events-registration">DOM 2 EventTarget Interface</a>}
		 *
		 * @param {string} type
		 * @param {function} listener
		 * @param {boolean} useCapture
		 * @return void
		 */
		WebSocket.prototype.removeEventListener = function(type, listener, useCapture) {
			if (!(type in this.__events)) return;
			var events = this.__events[type];
			for (var i = events.length - 1; i >= 0; --i) {
				if (events[i] === listener) {
					events.splice(i, 1);
					break;
				}
			}
		};

		/**
		 * Implementation of {@link <a href="http://www.w3.org/TR/DOM-Level-2-Events/events.html#Events-registration">DOM 2 EventTarget Interface</a>}
		 *
		 * @param {Event} event
		 * @return void
		 */
		WebSocket.prototype.dispatchEvent = function(event) {
			var events = this.__events[event.type] || [];
			for (var i = 0; i < events.length; ++i) {
				events[i](event);
			}
			var handler = this["on" + event.type];
			if (handler) handler.apply(this, [event]);
		};

		/**
		 * Handles an event from Flash.
		 * @param {Object} flashEvent
		 */
		WebSocket.prototype.__handleEvent = function(flashEvent) {

			if ("readyState" in flashEvent) {
				this.readyState = flashEvent.readyState;
			}
			if ("protocol" in flashEvent) {
				this.protocol = flashEvent.protocol;
			}

			var jsEvent;
			if (flashEvent.type == "open" || flashEvent.type == "error") {
				jsEvent = this.__createSimpleEvent(flashEvent.type);
			} else if (flashEvent.type == "close") {
				jsEvent = this.__createSimpleEvent("close");
				jsEvent.wasClean = flashEvent.wasClean ? true : false;
				jsEvent.code = flashEvent.code;
				jsEvent.reason = flashEvent.reason;
			} else if (flashEvent.type == "message") {
				var data = decodeURIComponent(flashEvent.message);
				jsEvent = this.__createMessageEvent("message", data);
			} else {
				throw "unknown event type: " + flashEvent.type;
			}

			this.dispatchEvent(jsEvent);

		};

		WebSocket.prototype.__createSimpleEvent = function(type) {
			if (document.createEvent && window.Event) {
				var event = document.createEvent("Event");
				event.initEvent(type, false, false);
				return event;
			} else {
				return {type: type, bubbles: false, cancelable: false};
			}
		};

		WebSocket.prototype.__createMessageEvent = function(type, data) {
			if (document.createEvent && window.MessageEvent && !window.opera) {
				var event = document.createEvent("MessageEvent");
				event.initMessageEvent("message", false, false, data, null, null, window, null);
				return event;
			} else {
				// IE and Opera, the latter one truncates the data parameter after any 0x00 bytes.
				return {type: type, data: data, bubbles: false, cancelable: false};
			}
		};

		/**
		 * Define the WebSocket readyState enumeration.
		 */
		WebSocket.CONNECTING = 0;
		WebSocket.OPEN = 1;
		WebSocket.CLOSING = 2;
		WebSocket.CLOSED = 3;

		WebSocket.__initialized = false;
		WebSocket.__flash = null;
		WebSocket.__instances = {};
		WebSocket.__tasks = [];
		WebSocket.__nextId = 0;

		/**
		 * Load a new flash security policy file.
		 * @param {string} url
		 */
		WebSocket.loadFlashPolicyFile = function(url){
			WebSocket.__addTask(function() {
				WebSocket.__flash.loadManualPolicyFile(url);
			});
		};

		/**
		 * Loads WebSocketMain.swf and creates WebSocketMain object in Flash.
		 */
		WebSocket.__initialize = function() {

			if (WebSocket.__initialized) return;
			WebSocket.__initialized = true;

			if (WebSocket.__swfLocation) {
				// For backword compatibility.
				window.WEB_SOCKET_SWF_LOCATION = WebSocket.__swfLocation;
			}
			if (!window.WEB_SOCKET_SWF_LOCATION) {
				logger.error("[WebSocket] set WEB_SOCKET_SWF_LOCATION to location of WebSocketMain.swf");
				return;
			}
			if (!window.WEB_SOCKET_SUPPRESS_CROSS_DOMAIN_SWF_ERROR &&
				!WEB_SOCKET_SWF_LOCATION.match(/(^|\/)WebSocketMainInsecure\.swf(\?.*)?$/) &&
				WEB_SOCKET_SWF_LOCATION.match(/^\w+:\/\/([^\/]+)/)) {
				var swfHost = RegExp.$1;
				if (location.host != swfHost) {
					logger.error(
						"[WebSocket] You must host HTML and WebSocketMain.swf in the same host " +
							"('" + location.host + "' != '" + swfHost + "'). " +
							"See also 'How to host HTML file and SWF file in different domains' section " +
							"in README.md. If you use WebSocketMainInsecure.swf, you can suppress this message " +
							"by WEB_SOCKET_SUPPRESS_CROSS_DOMAIN_SWF_ERROR = true;");
				}
			}
			var container = document.createElement("div");
			container.id = "webSocketContainer";
			// Hides Flash box. We cannot use display: none or visibility: hidden because it prevents
			// Flash from loading at least in IE. So we move it out of the screen at (-100, -100).
			// But this even doesn't work with Flash Lite (e.g. in Droid Incredible). So with Flash
			// Lite, we put it at (0, 0). This shows 1x1 box visible at left-top corner but this is
			// the best we can do as far as we know now.
			container.style.position = "absolute";
			if (WebSocket.__isFlashLite()) {
				container.style.left = "0px";
				container.style.top = "0px";
			} else {
				container.style.left = "-100px";
				container.style.top = "-100px";
			}
			var holder = document.createElement("div");
			holder.id = "webSocketFlash";
			container.appendChild(holder);
			document.body.appendChild(container);
			// See this article for hasPriority:
			// http://help.adobe.com/en_US/as3/mobile/WS4bebcd66a74275c36cfb8137124318eebc6-7ffd.html
			swfobject.embedSWF(
				WEB_SOCKET_SWF_LOCATION,
				"webSocketFlash",
				"1" /* width */,
				"1" /* height */,
				"10.0.0" /* SWF version */,
				null,
				null,
				{hasPriority: true, swliveconnect : true, allowScriptAccess: "always"},
				null,
				function(e) {
					if (!e.success) {
						logger.error("[WebSocket] swfobject.embedSWF failed");
					}
				}
			);

		};

		/**
		 * Called by Flash to notify JS that it's fully loaded and ready
		 * for communication.
		 */
		WebSocket.__onFlashInitialized = function() {
			// We need to set a timeout here to avoid round-trip calls
			// to flash during the initialization process.
			setTimeout(function() {
				WebSocket.__flash = document.getElementById("webSocketFlash");
				WebSocket.__flash.setCallerUrl(location.href);
				WebSocket.__flash.setDebug(!!window.WEB_SOCKET_DEBUG);
				for (var i = 0; i < WebSocket.__tasks.length; ++i) {
					WebSocket.__tasks[i]();
				}
				WebSocket.__tasks = [];
			}, 0);
		};

		/**
		 * Called by Flash to notify WebSockets events are fired.
		 */
		WebSocket.__onFlashEvent = function() {
			setTimeout(function() {
				try {
					// Gets events using receiveEvents() instead of getting it from event object
					// of Flash event. This is to make sure to keep message order.
					// It seems sometimes Flash events don't arrive in the same order as they are sent.
					var events = WebSocket.__flash.receiveEvents();
					for (var i = 0; i < events.length; ++i) {
						WebSocket.__instances[events[i].webSocketId].__handleEvent(events[i]);
					}
				} catch (e) {
					logger.error(e);
				}
			}, 0);
			return true;
		};

		// Called by Flash.
		WebSocket.__log = function(message) {
			logger.log(decodeURIComponent(message));
		};

		// Called by Flash.
		WebSocket.__error = function(message) {
			logger.error(decodeURIComponent(message));
		};

		WebSocket.__addTask = function(task) {
			if (WebSocket.__flash) {
				task();
			} else {
				WebSocket.__tasks.push(task);
			}
		};

		/**
		 * Test if the browser is running flash lite.
		 * @return {boolean} True if flash lite is running, false otherwise.
		 */
		WebSocket.__isFlashLite = function() {
			if (!window.navigator || !window.navigator.mimeTypes) {
				return false;
			}
			var mimeType = window.navigator.mimeTypes["application/x-shockwave-flash"];
			if (!mimeType || !mimeType.enabledPlugin || !mimeType.enabledPlugin.filename) {
				return false;
			}
			return mimeType.enabledPlugin.filename.match(/flashlite/i) ? true : false;
		};

		if (!window.WEB_SOCKET_DISABLE_AUTO_INITIALIZATION) {
			// NOTE:
			//   This fires immediately if web_socket.js is dynamically loaded after
			//   the document is loaded.
			swfobject.addDomLoadEvent(function() {
				WebSocket.__initialize();
			});
		}

	};

	var debugMode = false;
	var logStr = '';
	/**
	 * log to console if debugMode == true
	 */
	var log = function() {
		if ( debugMode ) {
			var d = new Date();
			var dd =  d.getFullYear() + '-' + (d.getMonth()<10?'0':'') + d.getMonth() + '-' + (d.getDate()<10?'0':'') + d.getDate();
			var t = (d.getHours()<10?'0':'') + d.getHours() + ':' + (d.getMinutes()<10?'0':'')+d.getMinutes() + ':' +  (d.getSeconds()<10?'0':'')+d.getSeconds() + ':' +
				(d.getMilliseconds() + 1000).toString().substr(1);
			logStr += dd +' '+ t + ' | ';
			args = ['Oktell.js ' + t + ' |']
			for ( var i = 0, j = arguments.length; i < j; i++ ) {
				logStr += (typeof arguments[i] == 'object' ? JSON.stringify(arguments[i]) : arguments[i]) + ' | ';
				args.push( arguments[i] );
			}
			logStr += "\n\n";
			try {
				console.log.apply( console, args || [] );
			} catch ( e ) {
				debugMode = false;
			}
		}
	};

	/**
	 * md5
	 * @param str target
	 * @return {String}
	 */
	var md5 = function (str) {
		var xl;

		var rotateLeft = function (lValue, iShiftBits) {
			return (lValue << iShiftBits) | (lValue >>> (32 - iShiftBits));
		};

		var addUnsigned = function (lX, lY) {
			var lX4, lY4, lX8, lY8, lResult;
			lX8 = (lX & 0x80000000);
			lY8 = (lY & 0x80000000);
			lX4 = (lX & 0x40000000);
			lY4 = (lY & 0x40000000);
			lResult = (lX & 0x3FFFFFFF) + (lY & 0x3FFFFFFF);
			if (lX4 & lY4) {
				return (lResult ^ 0x80000000 ^ lX8 ^ lY8);
			}
			if (lX4 | lY4) {
				if (lResult & 0x40000000) {
					return (lResult ^ 0xC0000000 ^ lX8 ^ lY8);
				} else {
					return (lResult ^ 0x40000000 ^ lX8 ^ lY8);
				}
			} else {
				return (lResult ^ lX8 ^ lY8);
			}
		};

		var _F = function (x, y, z) {
			return (x & y) | ((~x) & z);
		};
		var _G = function (x, y, z) {
			return (x & z) | (y & (~z));
		};
		var _H = function (x, y, z) {
			return (x ^ y ^ z);
		};
		var _I = function (x, y, z) {
			return (y ^ (x | (~z)));
		};

		var _FF = function (a, b, c, d, x, s, ac) {
			a = addUnsigned(a, addUnsigned(addUnsigned(_F(b, c, d), x), ac));
			return addUnsigned(rotateLeft(a, s), b);
		};

		var _GG = function (a, b, c, d, x, s, ac) {
			a = addUnsigned(a, addUnsigned(addUnsigned(_G(b, c, d), x), ac));
			return addUnsigned(rotateLeft(a, s), b);
		};

		var _HH = function (a, b, c, d, x, s, ac) {
			a = addUnsigned(a, addUnsigned(addUnsigned(_H(b, c, d), x), ac));
			return addUnsigned(rotateLeft(a, s), b);
		};

		var _II = function (a, b, c, d, x, s, ac) {
			a = addUnsigned(a, addUnsigned(addUnsigned(_I(b, c, d), x), ac));
			return addUnsigned(rotateLeft(a, s), b);
		};

		var convertToWordArray = function (str) {
			var lWordCount;
			var lMessageLength = str.length;
			var lNumberOfWords_temp1 = lMessageLength + 8;
			var lNumberOfWords_temp2 = (lNumberOfWords_temp1 - (lNumberOfWords_temp1 % 64)) / 64;
			var lNumberOfWords = (lNumberOfWords_temp2 + 1) * 16;
			var lWordArray = new Array(lNumberOfWords - 1);
			var lBytePosition = 0;
			var lByteCount = 0;
			while (lByteCount < lMessageLength) {
				lWordCount = (lByteCount - (lByteCount % 4)) / 4;
				lBytePosition = (lByteCount % 4) * 8;
				lWordArray[lWordCount] = (lWordArray[lWordCount] | (str.charCodeAt(lByteCount) << lBytePosition));
				lByteCount++;
			}
			lWordCount = (lByteCount - (lByteCount % 4)) / 4;
			lBytePosition = (lByteCount % 4) * 8;
			lWordArray[lWordCount] = lWordArray[lWordCount] | (0x80 << lBytePosition);
			lWordArray[lNumberOfWords - 2] = lMessageLength << 3;
			lWordArray[lNumberOfWords - 1] = lMessageLength >>> 29;
			return lWordArray;
		};

		var wordToHex = function (lValue) {
			var wordToHexValue = "",
				wordToHexValue_temp = "",
				lByte, lCount;
			for (lCount = 0; lCount <= 3; lCount++) {
				lByte = (lValue >>> (lCount * 8)) & 255;
				wordToHexValue_temp = "0" + lByte.toString(16);
				wordToHexValue = wordToHexValue + wordToHexValue_temp.substr(wordToHexValue_temp.length - 2, 2);
			}
			return wordToHexValue;
		};

		var x = [],
			k, AA, BB, CC, DD, a, b, c, d, S11 = 7,
			S12 = 12,
			S13 = 17,
			S14 = 22,
			S21 = 5,
			S22 = 9,
			S23 = 14,
			S24 = 20,
			S31 = 4,
			S32 = 11,
			S33 = 16,
			S34 = 23,
			S41 = 6,
			S42 = 10,
			S43 = 15,
			S44 = 21;

		// str = this.utf8_encode(str);
		x = convertToWordArray(str);
		a = 0x67452301;
		b = 0xEFCDAB89;
		c = 0x98BADCFE;
		d = 0x10325476;

		xl = x.length;
		for (k = 0; k < xl; k += 16) {
			AA = a;
			BB = b;
			CC = c;
			DD = d;
			a = _FF(a, b, c, d, x[k + 0], S11, 0xD76AA478);
			d = _FF(d, a, b, c, x[k + 1], S12, 0xE8C7B756);
			c = _FF(c, d, a, b, x[k + 2], S13, 0x242070DB);
			b = _FF(b, c, d, a, x[k + 3], S14, 0xC1BDCEEE);
			a = _FF(a, b, c, d, x[k + 4], S11, 0xF57C0FAF);
			d = _FF(d, a, b, c, x[k + 5], S12, 0x4787C62A);
			c = _FF(c, d, a, b, x[k + 6], S13, 0xA8304613);
			b = _FF(b, c, d, a, x[k + 7], S14, 0xFD469501);
			a = _FF(a, b, c, d, x[k + 8], S11, 0x698098D8);
			d = _FF(d, a, b, c, x[k + 9], S12, 0x8B44F7AF);
			c = _FF(c, d, a, b, x[k + 10], S13, 0xFFFF5BB1);
			b = _FF(b, c, d, a, x[k + 11], S14, 0x895CD7BE);
			a = _FF(a, b, c, d, x[k + 12], S11, 0x6B901122);
			d = _FF(d, a, b, c, x[k + 13], S12, 0xFD987193);
			c = _FF(c, d, a, b, x[k + 14], S13, 0xA679438E);
			b = _FF(b, c, d, a, x[k + 15], S14, 0x49B40821);
			a = _GG(a, b, c, d, x[k + 1], S21, 0xF61E2562);
			d = _GG(d, a, b, c, x[k + 6], S22, 0xC040B340);
			c = _GG(c, d, a, b, x[k + 11], S23, 0x265E5A51);
			b = _GG(b, c, d, a, x[k + 0], S24, 0xE9B6C7AA);
			a = _GG(a, b, c, d, x[k + 5], S21, 0xD62F105D);
			d = _GG(d, a, b, c, x[k + 10], S22, 0x2441453);
			c = _GG(c, d, a, b, x[k + 15], S23, 0xD8A1E681);
			b = _GG(b, c, d, a, x[k + 4], S24, 0xE7D3FBC8);
			a = _GG(a, b, c, d, x[k + 9], S21, 0x21E1CDE6);
			d = _GG(d, a, b, c, x[k + 14], S22, 0xC33707D6);
			c = _GG(c, d, a, b, x[k + 3], S23, 0xF4D50D87);
			b = _GG(b, c, d, a, x[k + 8], S24, 0x455A14ED);
			a = _GG(a, b, c, d, x[k + 13], S21, 0xA9E3E905);
			d = _GG(d, a, b, c, x[k + 2], S22, 0xFCEFA3F8);
			c = _GG(c, d, a, b, x[k + 7], S23, 0x676F02D9);
			b = _GG(b, c, d, a, x[k + 12], S24, 0x8D2A4C8A);
			a = _HH(a, b, c, d, x[k + 5], S31, 0xFFFA3942);
			d = _HH(d, a, b, c, x[k + 8], S32, 0x8771F681);
			c = _HH(c, d, a, b, x[k + 11], S33, 0x6D9D6122);
			b = _HH(b, c, d, a, x[k + 14], S34, 0xFDE5380C);
			a = _HH(a, b, c, d, x[k + 1], S31, 0xA4BEEA44);
			d = _HH(d, a, b, c, x[k + 4], S32, 0x4BDECFA9);
			c = _HH(c, d, a, b, x[k + 7], S33, 0xF6BB4B60);
			b = _HH(b, c, d, a, x[k + 10], S34, 0xBEBFBC70);
			a = _HH(a, b, c, d, x[k + 13], S31, 0x289B7EC6);
			d = _HH(d, a, b, c, x[k + 0], S32, 0xEAA127FA);
			c = _HH(c, d, a, b, x[k + 3], S33, 0xD4EF3085);
			b = _HH(b, c, d, a, x[k + 6], S34, 0x4881D05);
			a = _HH(a, b, c, d, x[k + 9], S31, 0xD9D4D039);
			d = _HH(d, a, b, c, x[k + 12], S32, 0xE6DB99E5);
			c = _HH(c, d, a, b, x[k + 15], S33, 0x1FA27CF8);
			b = _HH(b, c, d, a, x[k + 2], S34, 0xC4AC5665);
			a = _II(a, b, c, d, x[k + 0], S41, 0xF4292244);
			d = _II(d, a, b, c, x[k + 7], S42, 0x432AFF97);
			c = _II(c, d, a, b, x[k + 14], S43, 0xAB9423A7);
			b = _II(b, c, d, a, x[k + 5], S44, 0xFC93A039);
			a = _II(a, b, c, d, x[k + 12], S41, 0x655B59C3);
			d = _II(d, a, b, c, x[k + 3], S42, 0x8F0CCC92);
			c = _II(c, d, a, b, x[k + 10], S43, 0xFFEFF47D);
			b = _II(b, c, d, a, x[k + 1], S44, 0x85845DD1);
			a = _II(a, b, c, d, x[k + 8], S41, 0x6FA87E4F);
			d = _II(d, a, b, c, x[k + 15], S42, 0xFE2CE6E0);
			c = _II(c, d, a, b, x[k + 6], S43, 0xA3014314);
			b = _II(b, c, d, a, x[k + 13], S44, 0x4E0811A1);
			a = _II(a, b, c, d, x[k + 4], S41, 0xF7537E82);
			d = _II(d, a, b, c, x[k + 11], S42, 0xBD3AF235);
			c = _II(c, d, a, b, x[k + 2], S43, 0x2AD7D2BB);
			b = _II(b, c, d, a, x[k + 9], S44, 0xEB86D391);
			a = addUnsigned(a, AA);
			b = addUnsigned(b, BB);
			c = addUnsigned(c, CC);
			d = addUnsigned(d, DD);
		}

		var temp = wordToHex(a) + wordToHex(b) + wordToHex(c) + wordToHex(d);

		return temp.toLowerCase();
	}

	var utf8Decode = function(str_data) {
		// http://kevin.vanzonneveld.net
		// +   original by: Webtoolkit.info (http://www.webtoolkit.info/)
		// +      input by: Aman Gupta
		// +   improved by: Kevin van Zonneveld (http://kevin.vanzonneveld.net)
		// +   improved by: Norman "zEh" Fuchs
		// +   bugfixed by: hitwork
		// +   bugfixed by: Onno Marsman
		// +      input by: Brett Zamir (http://brett-zamir.me)
		// +   bugfixed by: Kevin van Zonneveld (http://kevin.vanzonneveld.net)
		// *     example 1: utf8_decode('Kevin van Zonneveld');
		// *     returns 1: 'Kevin van Zonneveld'
		var tmp_arr = [],
			i = 0,
			ac = 0,
			c1 = 0,
			c2 = 0,
			c3 = 0;

		str_data += '';

		while (i < str_data.length) {
			c1 = str_data.charCodeAt(i);
			if (c1 < 128) {
				tmp_arr[ac++] = String.fromCharCode(c1);
				i++;
			} else if (c1 > 191 && c1 < 224) {
				c2 = str_data.charCodeAt(i + 1);
				tmp_arr[ac++] = String.fromCharCode(((c1 & 31) << 6) | (c2 & 63));
				i += 2;
			} else {
				c2 = str_data.charCodeAt(i + 1);
				c3 = str_data.charCodeAt(i + 2);
				tmp_arr[ac++] = String.fromCharCode(((c1 & 15) << 12) | ((c2 & 63) << 6) | (c3 & 63));
				i += 3;
			}
		}

		return tmp_arr.join('');
	}

	var utf8DecodePass = function(aa) {
		var bb = '', c = 0;
		for (var i = 0; i < aa.length; i++) {
			c = aa.charCodeAt(i);
			if (c > 127) {
				if (c > 1024) {
					if (c == 1025) {
						c = 1016;
					} else if (c == 1105) {
						c = 1032;
					}
					bb += String.fromCharCode(c - 848);
				}
			} else {
				bb += aa.charAt(i);
			}
		}
		return bb;
	}

	var base64_decode = function base64_decode (data) {
		// http://kevin.vanzonneveld.net
		// +   original by: Tyler Akins (http://rumkin.com)
		// +   improved by: Thunder.m
		// +      input by: Aman Gupta
		// +   improved by: Kevin van Zonneveld (http://kevin.vanzonneveld.net)
		// +   bugfixed by: Onno Marsman
		// +   bugfixed by: Pellentesque Malesuada
		// +   improved by: Kevin van Zonneveld (http://kevin.vanzonneveld.net)
		// +      input by: Brett Zamir (http://brett-zamir.me)
		// +   bugfixed by: Kevin van Zonneveld (http://kevin.vanzonneveld.net)
		// -    depends on: utf8_decode
		// *     example 1: base64_decode('S2V2aW4gdmFuIFpvbm5ldmVsZA==');
		// *     returns 1: 'Kevin van Zonneveld'
		// mozilla has this native
		// - but breaks in 2.0.0.12!
		//if (typeof this.window['btoa'] == 'function') {
		//    return btoa(data);
		//}
		var b64 = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=";
		var o1, o2, o3, h1, h2, h3, h4, bits, i = 0,
			ac = 0,
			dec = "",
			tmp_arr = [];

		if (!data) {
			return data;
		}

		data += '';

		do { // unpack four hexets into three octets using index points in b64
			h1 = b64.indexOf(data.charAt(i++));
			h2 = b64.indexOf(data.charAt(i++));
			h3 = b64.indexOf(data.charAt(i++));
			h4 = b64.indexOf(data.charAt(i++));

			bits = h1 << 18 | h2 << 12 | h3 << 6 | h4;

			o1 = bits >> 16 & 0xff;
			o2 = bits >> 8 & 0xff;
			o3 = bits & 0xff;

			if (h3 == 64) {
				tmp_arr[ac++] = String.fromCharCode(o1);
			} else if (h4 == 64) {
				tmp_arr[ac++] = String.fromCharCode(o1, o2);
			} else {
				tmp_arr[ac++] = String.fromCharCode(o1, o2, o3);
			}
		} while (i < data.length);

		dec = tmp_arr.join('');
		dec = utf8Decode(dec);

		return dec;
	}

	/**
	 * Extending object
	 * @param obj
	 * @return {*}
	 */
	var extend = function(obj) {
		var args = Array.prototype.slice.call(arguments, 1);
		each(args, function(arg,kk){
			each(arg, function(a,prop){
				if ( arg.hasOwnProperty(prop) ) {
					obj[prop] = a;
				}
			});
		});
		return obj;
	};

	/**
	 * Check if target is array
	 * @param obj target
	 * @return {Boolean}
	 */
	var isArray = function(obj) {
		if ( Array.isArray ) {
			return Array.isArray(obj);
		} else {
			return Object.prototype.toString.call(obj) == '[object Array]';
		}
	}

	/**
	 * Object cloning (don't work with functions) TODO: throw error if circular links
	 * @param obj
	 * @param useJSON
	 * @return {*}
	 */
	var cloneObject = function( obj, useJSON ) { // don't work with functions as properties
		if ( useJSON ) {
			return JSON.parse(JSON.stringify(obj));
		} else {
			var c = {};
			for ( var i in obj ){
				if ( obj.hasOwnProperty(i) ) {
					if ( typeof obj[i] == 'object' ) {
						c[i] = cloneObject(obj[i],false);
					} else {
						c[i] = obj[i];
					}
				}
			}
			return c;
		}
	};

	/**
	 * Array's or object's size
	 * @param obj
	 * @return {*}
	 */
	var size = function(obj) {
		obj = obj || [];
		if ( isArray(obj) ) {
			return obj.length;
		} else if ( obj === Object(obj) ) {
			if ( Object.keys ){
				return Object.keys(obj).length;
			} else {
				var keysCount = 0;
				for (var key in obj) if ( Object.prototype.hasOwnProperty.call(obj, key) ) { keysCount++; }
				return keysCount;
			}
		}
		return false;
	};

	var breaker = {};
	/**
	 * foreach with callback
	 * @param obj
	 * @param fn
	 * @param context
	 */
	var each = function(obj, fn, context) {
		if (obj == null) return;
		if ( Array.prototype.forEach && obj.forEach === Array.prototype.forEach ) {
			obj.forEach(fn, context);
		} else if ( obj.length === +obj.length ) {
			for (var i = 0, l = obj.length; i < l; i++) {
				if (i in obj && fn.call(context, obj[i], i, obj) === breaker) return;
			}
		} else {
			for (var key in obj) {
				if ( Object.prototype.hasOwnProperty.call(obj, key) ) {
					if (fn.call(context, obj[key], key, obj) === breaker) return;
				}
			}
		}
	}

	var trim = function(val) {
		return val.replace(/^\s+/, '').replace(/\s+$/, '');
	}

	/**
	 * Format phone number
	 * @param value
	 * @return {String}
	 */
	var formatPhone = function ( value ) {
		if ( ! value ) { return '';}

		value = value.toString().split(';').join(',');

		var phones = value.split(',');

		for( var i = 0; i < phones.length; i++ ) {
			phones[i] = trim( phones[i] );
			var phone
				, country = ""
				, city = ""
				, extra = "";

			if ( phones[i] == "" ) { continue; }

			if ( phones[i].indexOf( '(' ) != -1 ) {

				var tmp = phones[i].split('(');
				country = trim( tmp[0] );

				tmp = tmp[1].split(')');
				city = trim( tmp[0] );

				var phone = trim( tmp[1] );
				phone = phone.replace( /(.?[0-9]) ([0-9].?)/ig, "$1-$2" );
				phone = phone.replace( /(.?[0-9]) ([0-9].?)/ig, "$1-$2" );

				if ( phone.indexOf('-') == -1 ) {

					tmp = [ phone.split(' ')[0], phone.split(' ').slice(1).join(' ') ];
					phone = trim( tmp[0] );
					extra = trim( tmp[1] );

					if ( phone.length == 5 ) { phone = phone.substr( 0, 3 ) + "-" + phone.substr( 3, 2 ); }
					if ( phone.length == 6 ) { phone = phone.substr( 0, 2 ) + "-" + phone.substr( 2, 2 ) + "-" + phone.substr( 4, 2 ); }
					if ( phone.length == 7 ) { phone = phone.substr( 0, 3 ) + "-" + phone.substr( 3, 2 ) + "-" + phone.substr( 5, 2 ); }

					if ( extra != "" ) { phone += ' ' + extra; }
				}

			} else {

				phone = phones[i].split('+').join('');
				phone = phone.replace( /(.?[0-9]) ([0-9].?)/ig, "$1-$2" );
				phone = phone.replace( /(.?[0-9]) ([0-9].?)/ig, "$1-$2" );

				var tmp = [ phone.split(' ')[0], phone.split(' ').slice(1).join(' ') ];
				phone = trim( tmp[0] );
				phone = phone.split('-').join('');
				phone = phone.split('—').join('');
				extra = trim( tmp[1] );

				if ( phone.length == 5 ) { phone = phone.substr( 0, 3 ) + "-" + phone.substr( 3, 2 ); }
				else if ( phone.length == 6 ) { phone = phone.substr( 0, 2 ) + "-" + phone.substr( 2, 2 ) + "-" + phone.substr( 4, 2 ); }
				else if ( phone.length == 7 ) { phone = phone.substr( 0, 3 ) + "-" + phone.substr( 3, 2 ) + "-" + phone.substr( 5, 2 ); }
				else if ( phone.length == 9 ) { city = phone.substr( 0, 3 ); phone = phone.substr( 3, 2 ) + "-" + phone.substr( 5, 2 ) + "-" + phone.substr( 7, 2 ); }
				else if ( phone.length == 10 ) { city = phone.substr( 0, 3 ); phone = phone.substr( 3, 3 ) + "-" + phone.substr( 6, 2 ) + "-" + phone.substr( 8, 2 ); }
				else if ( phone.length == 11 ) { country = phone.substr( 0, 1 ); city = phone.substr( 1, 3 ); phone = phone.substr( 4, 3 ) + "-" + phone.substr( 7, 2 ) + "-" + phone.substr( 9, 2 ); }
				else if ( phone.length == 12 ) { country = phone.substr( 0, 2 ); city = phone.substr( 2, 3 ); phone = phone.substr( 5, 3 ) + "-" + phone.substr( 8, 2 ) + "-" + phone.substr( 10, 2 ); }
				else if ( phone.length == 13 ) { country = phone.substr( 0, 3 ); city = phone.substr( 3, 3 ); phone = phone.substr( 6, 3 ) + "-" + phone.substr( 9, 2 ) + "-" + phone.substr( 11, 2 ); }
				else if ( phone.length == 14 ) { country = phone.substr( 0, 4 ); city = phone.substr( 4, 3 ); phone = phone.substr( 7, 3 ) + "-" + phone.substr( 10, 2 ) + "-" + phone.substr( 12, 2 ); }

				if ( extra != "" ) { phone += ' ' + extra; }
			}

			if ( country == "8" ) { country = "+7"; }
			if ( country[0] != "+" && country != "" ) { country = "+" + country; }

			if ( true ) { // collect
				var full = [];
				if ( country != "" ) { full.push( country ); }
				if ( city != "" ) { 	full.push( "(" + city + ")" ); }
				if ( phone != "" ) { 	full.push( phone ); }

				phones[i] = full.join(' ');
			}
		}

		value = phones.join(', ');
		return value;
	};

	/**
	 * create new guid
	 * @return {String}
	 */
	var newGuid = function () {
		return 'xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx'.replace(/[xy]/g, function(c) {
			var r = Math.random()*16|0, v = c == 'x' ? r : (r&0x3|0x8);
			return v.toString(16);
		});
	};

	var buildParams = function(obj) {
		if ( typeof obj == 'object' ) {
			var str = '';
			each(obj, function(v,k){
				str += '&' + k + '=' + v.toString()
			});
			return str;
		}
		return false
	};

	/**
	 * target is guid or not
	 * @param str
	 * @return {Boolean}
	 */
	var isGuid = function (str) {
		if ( typeof str == 'string' && ( str.match(/[a-zA-Z0-9]{8}-[a-zA-Z0-9]{4}-[a-zA-Z0-9]{4}-[a-zA-Z0-9]{4}-[a-zA-Z0-9]{12}/)) || ( str.length == 32 && str.match(/[a-zA-Z0-9]{32}/)) ) {
			return true;
		}
		return false;
	};

	/**
	 * call target if it is function
	 * @param fn
	 */
	var callFunc = function(fn) {
		if ( typeof fn == 'function' ) fn.apply(undefined, Array.prototype.slice.call( arguments, 1 ));
	}

	var dateToIso = function(dt) {
		if ( dt instanceof Date ) {
			return dt.getFullYear() + '-' + ( dt.getMonth() < 10 ? '0' + dt.getMonth() : dt.getMonth() ) + '-' + ( dt.getDate() < 10 ? '0' + dt.getDate() : dt.getDate() );
		}
		return false;
	}

	var cookie = function (key, value, options) {

		// key and at least value given, set cookie...
		if (arguments.length > 1 && String(value) !== "[object Object]") {
			options = extend({}, options);

			if (value === null || value === undefined) {
				options.expires = -1;
			}

			if (typeof options.expires === 'number') {
				var seconds = options.expires, t = options.expires = new Date();
				t.setSeconds(t.getSeconds() + seconds);
			}

			value = String(value);

			return (document.cookie = [
				encodeURIComponent(key), '=',
				options.raw ? value : encodeURIComponent(value),
				options.expires ? '; expires=' + options.expires.toUTCString() : '', // use expires attribute, max-age is not supported by IE
				options.path ? '; path=' + options.path : '',
				options.domain ? '; domain=' + options.domain : '',
				options.secure ? '; secure' : ''
			].join(''));
		}

		// key and possibly options given, get cookie...
		options = value || {};
		var result, decode = options.raw ? function (s) { return s; } : decodeURIComponent;
		return (result = new RegExp('(?:^|; )' + encodeURIComponent(key) + '=([^;]*)').exec(document.cookie)) ? decode(result[1]) : null;
	};

	var eventSplitter = /\s+/
	var normalizeEventNames = function(eventNames) {
		if ( typeof eventNames == 'string' ) {
			eventNames = eventNames.replace(/,/g, ' ').split(eventSplitter);
		} else if ( isArray(eventNames) && eventNames.length > 0 ) {
			var eventsArray = [];
			for (var i = 0; i < eventNames.length; i++) {
				var event = eventNames[i];
				if ( event && typeof event == 'string' ) {
					eventsArray.push(event);
				}
			}
			eventsNames = eventsArray;
		} else {
			return false;
		}
		return eventNames;
	}
	/**
	 * Events object. For extending other objects
	 * @type {Object}
	 */

	var Events = {
		/**
		 * Subscribe to events
		 * @param eventNames
		 * @param callback
		 * @param context
		 * @return {Boolean}
		 */
		on: function( eventNames, callback, context ) {
			eventNames = normalizeEventNames(eventNames);
			if ( ! eventNames || typeof callback != 'function' ) {
				return false;
			}

			var calls = this._callbacks || ( this._callbacks = {} );
			each( eventNames, function(event,key) {
				if ( typeof event != 'string' ) {
					return breaker;
				}
				var eventCalls = calls[ event ] || ( calls[ event ] = [] );
				eventCalls.push({
					callback: callback,
					context: context
				});
			});
			return true;
		},
		/**
		 * Unsubscribe
		 * @param eventNames to unsubscribe, if empty - unsubscribe from all events
		 * @param callback to unsubscribe, if empty - unsubscribe from all eventNames
		 * @return {Boolean}
		 */
		off: function( eventNames, callback ) {

			var calls = this._callbacks || ( this._callbacks = {} );

			if ( ! eventNames ) {
				calls = {};
			} else {
				eventNames = normalizeEventNames(eventNames);
				if ( ! eventNames ) {
					return false;
				}

				if ( typeof callback == 'function' ) {
					each(eventNames, function(event){
						if ( typeof event != 'string' ) { return; }
						each(calls[event], function(cl,i){
							if ( cl && cl.callback === callback ) {
								delete calls[ event ][i];
							}
						});
					});
				} else {
					each(eventNames, function(event){
						delete calls[ event ];
					});
				}
			}
			return true;
		},
		/**
		 * Trigger event with or without additional params
		 * @param eventNames
		 * @return {Boolean}
		 */
		trigger: function( eventNames ) {
			eventNames = normalizeEventNames(eventNames);
			var calls = this._callbacks || ( this._callbacks = {} );
			if ( ! eventNames ) {
				return false;
			}
			var realArgs = arguments;
			each( eventNames, function(event){
				var eventCalls = calls[ event ];
				if ( eventCalls ) {
					each(eventCalls, function(eventCall){
						if ( eventCall && typeof eventCall.callback == 'function' ) {
							eventCall.callback.apply( eventCall.context || undefined, Array.prototype.slice.call( realArgs, 1 ) );
						}
					});
				}
			});
			return true;
		}
	};

	/**
	 * class for connecting and working with browser's websocket API
	 * @param url адрес сервера
	 * @param openTimeout таймаут подключения
	 * @param onOpenCallback коллбэк
	 * @constructor
	 */
	var Server = function( url, openTimeout, onOpenCallback ) {
		var ws,
			wsArr = {},
			wsUrlRegexp = /^ws[s]{0,1}:\/\/\S+$/i,
			self = this,
			wsWasOpened = false,
			wsErrorConnection = false,
			callbacks = {},
			multiparts = {},
			oktellEventCallbacks = {},
			currentSessionSubscriptions = {},
			eventGroups = {
				'dynamic': ['executemethod', 'cancelmethod'],
				'dynamicwaitabort': ['executemethodwaitaborted'],
				'dlgcard': ['dlgcard_showreserve', 'dlgcard_showconfirm', 'dlgcard_showformstop', 'dlgcard_showformdialog', 'dlgcard_closeall', 'dlgcard_closereserve', 'dlgcard_closeformreturnvalues', 'dlgcard_closeformreturncomment']
			};


		var parseUrls = function(urls){
			if ( ! isArray(urls) ) {
				return false;
			}
			var needSecure = location.protocol == 'https:' ? true : false,
				defaultPort = 80,
				result = [];

			for ( var i, l = urls.length; i < l; i++ ) {
				if ( typeof urls[i] != 'string' ) {
					return false;
				}
				if ( wsUrlRegexp.text(urls[i]) ) {
					result.push(urls[i]);
				} else {
					var uArr = urls[i].split(':'),
						host = uArr[0],
						port = uArr[1];
					if ( ! port ) {
						port = defaultPort;
						result.push( host + ':' + '4066' ); //
					}
					if ( port == '443' ) { needSecure = true; }
					result.push( host + ':' + port );
				}
			}

			var prefix = needSecure ? 'wss://' : 'ws//';
			for ( var i, l = result.length; i < l; i++ ) {
				if ( ! wsUrlRegexp.text(urls[i]) ) {
					result[i] = prefix + result[i];
				}
			}

		}
		var n_onClose = function(a,b,c){}
		var n_onError = function(a,b,c){}
		var n_onError = function(a,b,c){}
		var n_wasConnected = false;
		var n_onConnect = function(wsObj) {
			if ( ! n_wasConnected ) {
				n_wasConnected = true;
				ws = wsObj;
				// send ping, wait pong, redirect to secure if need
				var qid = Math.random().toString();
				ws.onmessage = function ( evt ) {

					var data = JSON.parse( evt.data );

					var afterSuccessConnect = function(finalWs) {
						self.ws = finalWs;
						finalWs.onmessage = onMessage;
						finalWs.onclose = n_onClose;
						finalWs.onerror = n_onError;
						onOpen()
					}

					if ( data[0] == 'websocketredirect' ) {
						var wss = new WebSocket( wsObj.url.replace('ws://', 'wss://').replace(':4066', ':443'), 'json');
						wss.onopen = function() {
							afterSuccessConnect(wss);
						}
					} else if ( data[1] && data[1].qid == qid ) {
						afterSuccessConnect(wsObj);
					}
				}
				ws.send( JSON.stringify(['ping',{qid:qid}]));
			} else {
				wsObj.close();
			}
		}

		self.n_connect = function() {
			var wsArr = [];
			var urls = parseUrls(url);
			for ( var i, l = urls.length; i < l; i++ ) {
				setTimeout(function(){
					var ws = new WebSocket(urls[i], 'json');
					ws.onopen = function() {
						n_onConnect(ws);
					}
					ws.onerror = function() {

					}
					ws.onclose = function() {

					}
				},1);
			}
		}

		self.url = url;

		var errorConnection = function() {
			if ( ! wsErrorConnection ) {
				wsErrorConnection = true;
				self.trigger('errorConnection');
			}
		};

		var onOpen = function() {
			wsWasOpened = true;
			if ( typeof onOpenCallback == 'function' ) {
				log('success connect to ' + ws.url)
				onOpenCallback(ws.url);
			}
		}

		var onMessage = function ( evt ) {

			var data = JSON.parse( evt.data );

			triggerOktellEvent(data);

			var isFullMultiPart = false;
			if ( data[0] == 'multipart' ) {
				var msg = multiparts[ data[1]['message-id'] ];
				if ( !msg ) {
					msg = {
						packetcount:data[1]['packetcount'],
						content:[],
						value:''
					};
					multiparts[ data[1]['message-id'] ] = msg;
				}
				msg.content[ parseInt( data[1]['packetnumber'] ) ] = data[1]['content'].toString();
				if ( msg.content.length == msg.packetcount ) {
					for ( var i = 0; i < msg.content.length; i++ ) {
						msg.value = '' + msg.value + base64_decode( msg.content[i] );
					}
					isFullMultiPart = true;
				}
			}

			if ( data[0] != 'multipart' || ( data[0] == 'multipart' && isFullMultiPart ) ) {
				if ( isFullMultiPart ) {
					data = JSON.parse( multiparts[ data[1]['message-id'] ].value );
				}

				if ( typeof callbacks[data[1].qid] == 'function' ) {
					//debug('callback');
					var c = callbacks[data[1].qid];
					delete callbacks[data[1].qid];
					var d = data[1];
					if (d.result === undefined) {d.result = 1;}
					c( data[1] );
				}
			}
		};

		var onClose = function() {
			if ( wsWasOpened ) {
				if ( ! wsErrorConnection ) {
					self.trigger('connectionClose');
				}
			} else {
				errorConnection();
			}
			currentSessionSubscriptions = {};
		};

		self.multiConnect = function() {

			if ( ! isArray(url) ) {
				url = [url];
			}

			log('Multi connect start', url);

			var connectErrorsCount = 0;

			url = url.slice(0,10);
			each(url, function( curl, i) {

				setTimeout(function(){
					try {
						wsArr[curl] = new WebSocket( curl , 'json');
						log('trying to connect ' + curl);

						wsArr[curl].onopen = function() {
							wsArr[curl].wasOpened = true
							var qid = Math.random().toString();
							wsArr[curl].send( JSON.stringify(['ping',{qid:qid}]));
							wsArr[curl].onmessage = function ( evt ) {
								if ( wsWasOpened ) {
									//log('onopen return false for ' + curl);
									return false;
								}
								var data = JSON.parse( evt.data );

								var afterSuccessConnect = function() {
									self.url = curl;
									self.wsUrl =
										ws = wsArr[curl];
									ws.onmessage = onMessage
									ws.onclose = onClose;
									onOpen()
								}

								if ( data[0] == 'websocketredirect' ) {
									//if ( data[0] == 'pong' ) {
									var wssUrl = curl.replace(/^ws:\/\//, 'wss://').replace(/:[0-9]{1,5}/, ':443');
									log('redirect to secure websocket, trying to connect ' + wssUrl);
									wsArr[curl].close();
									curl = wssUrl;
									var wss = new WebSocket( curl, 'json');
									wss.onopen = function() {
										if ( wsWasOpened ) {
											//log('onopen return false for ' + curl);
											return false;
										}
										afterSuccessConnect()
									}
									wsArr[curl] = wss

								} else if ( data[1] && data[1].qid == qid ) {
									afterSuccessConnect()
								}
							}
						}

						setTimeout(function(){
							//log('timeout for ' + curl + ' ' + self.getWebSocketState(wsArr[curl]));
							if ( ( self.getWebSocketState(wsArr[curl]) != 1 && ! wsArr[curl].wasOpened ) || self.url != curl ) {
								//log('timeout2 for ' + curl);
								self.disconnect(wsArr[curl]);
								connectErrorsCount++;

								if ( connectErrorsCount == url.length ) {
									//log('errorConnection() for ' + curl);
									connectErrorsCount = -999;
									errorConnection();
								}
							}
						}, openTimeout);

					} catch (e) {
						//log('exception for ' + curl);
						connectErrorsCount++;

						if ( connectErrorsCount == url.length ) {
							//log('trigger errorConnection for ' + curl);
							connectErrorsCount = -999;
							self.trigger('errorConnection', e);
						}

						return breaker;
					}

				},1);

			});

		};

		self.connect = function() {
			wsErrorConnection = false;
			try {
				log('trying to connect ' + url);
				ws = new WebSocket( 'ws://'+url, 'json');

				setTimeout(function(){
					if ( self.getWebSocketState() == 0 ) {
						self.disconnect();
						errorConnection();
					}
				}, openTimeout);

			} catch (e) {
				self.trigger('errorConnection', e);
				return false;
			}


			ws.onopen = onOpen;
			ws.onmessage = onMessage;
			ws.onclose = onClose;
		}


		self.send = function ( data, id, callback ) {
			var d = JSON.parse(data);
			if ( typeof callback == 'function' ) {
				callbacks[id] = callback;
			}
			return ws.send( data );
		}

		self.sendOktell = function ( method, body, callback ) {
			body = body || {};
			var msg = new Array();
			msg.push( method );
			body.qid = Math.random().toString();
			msg.push( body );
			if ( self.send( JSON.stringify( msg ), msg[1].qid, callback ) === false ) {
				callFunc(callback,{result:0,errormsg:'websocket send error'});
			}
		}

		self.execProc = function ( procName, paramsObj, callback ) {
			var msg = [
				'execpredefineddbstoredproc',
				extend({
					qid:Math.random().toString(),
					procedure:procName
				}, paramsObj)
			];
			self.send( JSON.stringify( msg ), msg[1].qid, function(data){
				var items = [];
				if ( data.result == 1 && data.errorcode == 0 ) {
					for( var i = 0; i < data.dataset.length; i ++ ) {
						var d = [];
						items.push(d);
						var keys = [];
						for ( var k = 0; k < data.dataset[i][0].length; k ++ ){
							keys.push( data.dataset[i][0][k] );
						}
						for ( var j = 1; j < data.dataset[i].length; j++ ) {
							var item = {};
							for ( var f = 0; f < keys.length; f++ ) {
								item[ keys[f] ] = data.dataset[i][j][f];
							}
							d.push( item );
						}
					}
				} else {
					items = false;
				}
				callFunc(callback,items);
			});
		};

		self.bindOktellEvent = function( eventNames, callback ){
			eventNames = normalizeEventNames(eventNames);
			if ( ! eventNames || typeof callback != 'function' ) {return false;}

			each(eventNames, function(event){
				if ( ! oktellEventCallbacks[event] ) {
					oktellEventCallbacks[event] = [];
				}
				oktellEventCallbacks[event].push( callback );
			});

			self.sendOktellEventSubscription(eventNames);

			return true;
		};

		var triggerOktellEvent = function(data) {
			if ( oktellEventCallbacks && oktellEventCallbacks[ data[0] ] ) {
				log('<<< EVENT ' + data[0], data[1]);
				each( oktellEventCallbacks[ data[0] ], function(callback){
					callFunc(callback,data[1]);
				});
			}
		}

		self.sendOktellEventSubscription = function(eventNames, dontSend) {
			var self = this;
			eventNames = normalizeEventNames(eventNames)
			if ( ! eventNames ) {
				return false;
			}

			var toSend = [];

			each( eventNames, function(event){
				if ( ! currentSessionSubscriptions[ event ] ) {
					toSend.push(event)
					if ( isArray(eventGroups[event]) ) {
						self.sendOktellEventSubscription(eventGroups[event], true);
					}
				}
				if ( dontSend ) {
					currentSessionSubscriptions[ event ] = true;
				}
			});

			if ( ! dontSend && toSend.length ) {
				log ('===> Event subscription', toSend);
				self.sendOktell('subscribeevent', {eventmethod: toSend}, function(data){
					log('<=== Event subscribtion result: ' + data.result, toSend)
					each( toSend, function(ev){
						currentSessionSubscriptions[ ev ] = true;
					});
				});
			}
		};

		/**
		 * Unsubscribe from native event of oktell server
		 * @param eventNames
		 * @param callback
		 * @return {Boolean}
		 */
		self.unbindOktellEvent = function( eventNames, callback ) {
			if ( ! eventNames ) {
				oktellEventCallbacks = {};
			} else {
				eventNames = normalizeEventNames(eventNames);
				if ( ! eventNames ) { return false; }
				callback = typeof callback == 'function' ? callback : false;

				for (var i = 0; i < eventNames.length; i++) {
					var event = eventNames[i];
					if ( callback ) {
						each( oktellEventCallbacks[event], function(cb,i) {
							if ( cb === callback ) {
								delete oktellEventCallbacks[event][i];
							}
						});
					} else {
						delete oktellEventCallbacks[event];
					}
				}
			}
			return true;
		};

		self.reSendOktellEventSubscribtions = function() {

			var events = [];
			each( currentSessionSubscriptions, function(v,ev){
				if ( v ) {
					events.push(ev);
				}
			});

			if ( events.length ) {
				self.sendOktell('subscribeevent', {eventmethod: events}, function(data){

				});
			}
		};

		self.disconnect = function( websocket ) {
			websocket = websocket || ws;
			websocket.close();
			var status = self.getWebSocketState(websocket);
			if ( status == 3 || status == 2 ) {
				return true;
			} else {
				return false;
			}
		};

		self.getWebSocketState = function( websocket ) {
			websocket = websocket || ws;
			return websocket ? websocket.readyState : undefined;
		}
	};
	extend( Server.prototype , Events );

	var Abonent = function() {

	};

	var Oktell = function( options ) {
		var self = this,
			server,
			_oktellConnected = false,
			nativeEventsForBindAfterConnect = [],
			currentUrlIndex = 0,
			pingTimer,
			queueTimer,
			oktellOptions,
			oktellVoice,
			sipPhone,
			sipPnoneActive = false,
			oktellInfo = {
				redirectNumber: undefined,
				allowedProcedures: {}
			},
			methodVersions = {
				getmyuserinfo: {v:120327, critical: true},
				getversion: { v:120112, critical: true },
				pbxmakeflash: {v:120725},
				getextendedlineinfo: {v:120112, critical: true},
				getflashedabonentinfo: {v:120112, critical: true},
				saveredirectrules: {v:120725},
				deleteredirectrules: {v:120725},
				getredirectrules: {v:120725},
				pbxmaketransfer: {v:120725},
				triggercustomevent: {v:120725},
				getallusernumbers: {v:120920},
				cc_getlunchtypes: {v:130101}
			},
			httpQueryData = {},
			cookieSessionName = '___oktellsessionid',

			users = {},
			numbers = {},
			numbersById = {},
			connectionClosedByUser = false;

		var exportApi = function(name, fn, context) {
			if ( ! self[name] && typeof fn == 'function' ) {
				self[name] = function() {
					return fn.apply( context || self, arguments );
				}
			}
		}

		var oktellConnected = function(connected) {
			if ( connected !== undefined ) {
				if ( connected ) {
					_oktellConnected = true;
				} else {
					_oktellConnected = false;
				}
			}
			return _oktellConnected;
		}

		/**
		 * Events
		 * @type {*}
		 */
		var events = extend({}, Events);

		/**
		 * Return state of connection with websocket server
		 * @return {Boolean}
		 */
		var serverConnected = function() {
			if ( server && server.getWebSocketState() == 1 ) {
				return true;
			}
			return false;
		}

		/**
		 * Return name of state if state found, or false
		 * @param code of state
		 * @param states Object with states ( key is code, val is state name )
		 * @return {*}
		 */
		var getStateByCode = function( code, states ) {
			if ( code === undefined || ! size(states) ) {
				return false;
			}
			code = parseInt( code );
			var msg = '';
			each( states, function(scode, message){
				if ( scode == code ) {
					msg = message.toLowerCase();
				}
			});
			return msg;
		};

		/**
		 * Convert target to array of strings
		 * @param strings - string or array of string
		 * @return {*} array or false
		 */
		var toStringsArray = function(strings) {
			if ( ! strings || !(typeof strings == 'string' || typeof strings == 'number' || isArray(strings)) ) { return false; }
			if ( typeof strings == 'string' || typeof strings == 'number' ) {
				strings = [strings.toString()];
			}
			var result = true;
			each(strings, function(s){
				if( typeof s != 'string' ) { result = false; return breaker; }
			});
			if ( ! result ){ return false; } else { return strings }
		}

		/**
		 * Check oktell websocket method's version
		 * @param method name
		 * @return {Boolean} true if supported, false if not
		 */
		var isValidMethodVersion = function( method ) {
			if ( oktellInfo.oktellDated && methodVersions[method] && oktellInfo.oktellDated < methodVersions[method].v ) {
				return false;
			}
			return true;
		};

//		var connectErrors = {
//			10: 'error',
//			11: 'ws login method return error',
//			12: 'desktop client is connected now',
//			13: 'wrong login/pass combination',
//			14: 'session is not exist and no password param',
//			15: 'error loading phone state',
//			16: 'error loading user state',
//			17: 'error loading user info',
//			18: 'error loading version info',
//			19: 'bad url param'
//			20: 'max online users count reached'
//		}
//		var getConnectErrorObj = function(code, msg) {
//			return { errorCode: code, errorMessage: connectErrors[code] + ( msg ? ' ' + msg : '') }
//		}

		/**
		 * Possible disconnect reasons
		 * @type {Object}
		 */
		var disconnectReasons = {
			10: 'critical ws method not supported by this version of Oktell server',
			11: 'error loading version info',
			12: 'websocket connection closed',
			13: 'disconnected by user',
			14: "can't login using oktell.connect"
		};

		/**
		 * Return disconnect reason object
		 * @param code from disconnectReasons
		 * @param msg that will be concatenated to reason message
		 * @return {Object}
		 */
		var getDisconnectReasonObj = function(code,msg){
			return {
				code: code,
				message: ( disconnectReasons[code] + ' ' + (msg||'') ) || ''
			}
		};

		/**
		 * Possible errors
		 * @type {Object}
		 */
		var errorTypes = {
			// common
			1000: 'something goes wrong',
			// exec
			1101: 'method not supported by current Oktell version',
			1102: 'server didnt understand method or response timeout',
			1103: 'error execute method',
			1104: 'bad method for execute',
			1105: 'error execute stored procedure',
			1106: 'bad params',
			// connect
			1200: 'cant connect to server',
			1201: 'error websocket connection',
			1202: 'error login\pass',
			1203: 'oktell version too old',
			1204: 'using oktell desktop client',
			1205: 'error url',
			1206: 'error loading version info',
			1207: 'error loading phone state',
			1209: 'error loading user state',
			1210: 'error loading user info',
			1211: 'login failure',
			1212: 'error connect using session',
			1213: 'no password or session',
			1214: 'max online users count reached, license limitation',
			// call
			2001: 'user state - disconnected',
			2002: 'phone not connected',
			2101: 'user has hold call and is talking now',
			2102: 'user in conference now',
			2103: 'phone state not valid for call',
			2104: 'user state - busy',
			2105: 'calling number is talking with us',
			2106: 'bad number',
			2107: 'error autocall method call',
			2108: 'error user or phone state for call',
			// conference
			2201: 'no numbers to invite',
			2202: 'cant build conference from current call',
			2203: 'no number to create conference',
			2204: 'error conference method call',
			2205: 'bad user or phone state for creating conference',
			2206: 'cant invite hold abonent',
			2207: 'error inviting',
			2208: 'cant create conference while in callcenter in break',
			// transfer
			2301: 'error transfer method call',
			2302: 'bad user or phone state for transfer',
			2303: 'nothing to transfer',
			2304: 'bad number for transfer',
			// toggle
			2401: 'error toggle method executing',
			2402: 'nothing to toggle, no hold',
			// ghost modes
			2501: 'not in conference',
			2502: 'server retunred error while enabling ghost mode',
			2503: 'bad ghost mode',
			2504: 'bad userId or number',
			2505: 'error rigths',
			2506: 'user is not in ghost mode',
			2507: 'cant change ghost mode of this user',
			// flash
			2601: 'bad flash mode',
			2602: 'error while exec flash method',
			// queue
			2701: 'error while loading user queue'

		};

		/**
		 * Return error object
		 * @param code from errorTypes
		 * @param msg that will be added to errorMessage
		 * @param obj that will extend return object
		 * @return {*} error object
		 */
		var getErrorObj = function( code , msg, obj ) {
			code = parseInt(code);

			var errorObj = extend( obj || {},{
				result: false,
				errorCode: code,
				errorMessage: (errorTypes[code] ? errorTypes[code] : '' ) + ( msg ? msg.toString() : '' )
			});
			log ('ERROR ' + code + ' ' + errorObj.errorMessage, errorObj );
			return errorObj;
		};

		/**
		 * Return success object
		 * @param obj that will extend return object
		 * @return {*}
		 */
		var getSuccessObj = function(obj) {
			var sObj = extend( obj || {}, {result:true});
			log('SUCCESS ', sObj)
			return sObj;
		};

		/**
		 * Return object, that explain result of operation, error object or succec object
		 * @param result - if true than return success object, else return error object
		 * @param obj that will extend return object
		 * @param errorCode error code from errorTypes
		 * @param msg that concatenated to returning message
		 * @return {*}
		 */
		var getReturnObj = function( result, obj, errorCode, msg ) {
			if ( result ) {
				return getSuccessObj(obj);
			} else {
				return getErrorObj(errorCode, msg, obj);
			}
		};

		var bindOktellEvent = function(eventNames, callback){
			eventNames = normalizeEventNames(eventNames);
			evObjs = [];
			for (var i = 0; i < eventNames.length; i++) {
				var event = eventNames[i];
				var alreadyExist = false;
				for (var j = 0; j < nativeEventsForBindAfterConnect.length; j++) {
					var obj = nativeEventsForBindAfterConnect[j];
					if ( obj && obj.eventName == event && obj.callback === callback ) {
						alreadyExist = true;
						break;
					}
				}
				if ( alreadyExist ) {
					eventNames[i] = undefined;
				} else {
					var evObj = {eventName:event, callback: callback};
					nativeEventsForBindAfterConnect.push(evObj);
					evObjs.push(evObj);
				}
			}
			if ( oktellConnected() ) {
				for (var i = 0; i < evObjs.length; i++) {
					evObjs[i].binded = true;
				}
				server.bindOktellEvent( eventNames, callback );
			}
		}

		var unbindOktellEvent = function(eventNames, callback) {
			if ( ! eventNames ) {
				nativeEventsForBindAfterConnect = [];
			} else {
				eventNames = normalizeEventNames(eventNames);
				if ( ! eventNames ) { return false; }
				callback = typeof callback == 'function' ? callback : false;

				for (var i = 0; i < eventNames.length; i++) {
					var event = eventNames[i];
					for (var j = 0; j < nativeEventsForBindAfterConnect.length; j++) {
						var evObj = nativeEventsForBindAfterConnect[j];
						if ( evObj && evObj.eventName == event && ( ( callback && evObj.callback === callback ) || ! callback ) ) {
							nativeEventsForBindAfterConnect[j] = undefined;
						}
					}
				}
			}
			server.unbindOktellEvent( eventNames, callback );
		}

		/**
		 * Wrapper for server.sendOktell with userlogin setting
		 * @param method name from Oktell Websocket API
		 * @param params for method
		 * @param callback on oktell server answer
		 */
		var sendOktell = function(method, params, callback) {
			var callbackFn = typeof params == 'function' ? params : callback
			if ( serverConnected() ) {
				if ( isValidMethodVersion(method) ) {
					params = size(params) ? params : {};
					var params = extend({ userlogin: oktellInfo.login }, params );
					var errorTimer;
					if ( typeof callbackFn == 'function' ) {
						var errorTimer = setTimeout(function(){
							log('error timer for method ' + method);
							callFunc(callbackFn,getErrorObj(1102, ': ' + method));
						}, oktellOptions.queryTimeout);
					}
					server.sendOktell(method, params, function(data){
						clearTimeout(errorTimer);
						log('<<<< ' + method, data);
						callFunc(callbackFn,data);
					});
					log('>>>> ' + method, params);

				} else {
					callFunc(callbackFn,getErrorObj(1101, ' ' +method));
					if ( methodVersions[method].critical ) {
						disconnect( getDisconnectReasonObj(10), method );
					}
				}
			} else {
				callFunc(callbackFn,getErrorObj(1201));
			}
		};

		/**
		 * Call oktell websocket API method, that not return anything. sendOktell wrapper
		 * @param method name
		 * @param params for method
		 */
		var sendOktellWithoutBackData = function( method, params ) {
			if ( ! serverConnected() ) {
				return getErrorObj(1201);
			} else if ( ! isValidMethodVersion(method) ) {
				return getErrorObj(1101, ' ' + method);
			} else {
				sendOktell(method, params, null, true);
				return getSuccessObj();
			}
		};

		/**
		 * execute websocket api method or permitted stored procedure on oktell server's db
		 * @param method or procedure name
		 * @param params
		 * @param callback
		 */
		var exec = function(method, params, callback ) {
			var callbackFn = typeof params == 'function' ? params : callback;
			if ( ! method ) {
				callFunc(callbackFn,getErrorObj(1104));
			} else {
				if ( oktellInfo.allowedProcedures[method.toLowerCase()] ) {
					var p = {
						userid: oktellInfo.userid,
						userlogin: oktellInfo.login,
						inputparams: params || {}
					};
					log('>>>> ' + method, p);
					server.execProc(method, p, function(items){
						var resultdata = {
							result: false
						};
						if ( items ) {
							resultdata.result = true;
							resultdata.datasets = items;
						}
						log('<<<< ' + method, resultdata);
						callFunc(callbackFn, getReturnObj(resultdata.result, resultdata, 1105, ' ' + method));
					});
				} else {
					if ( ! callbackFn ) {
						sendOktell(method,params);
					} else {
						sendOktell(method,params,function(data){
							var r = data.errorCode ? getReturnObj(data.result,data, data.errorCode) : getReturnObj(data.result,data, 1103, ' ' + method);
							callFunc(callbackFn, r);
						});
					}
				}
			}
		};
		exportApi('exec', exec);

		/**
		 * Custom user events stuff
		 * @type {*}
		 */
		var customEvents = extend({
			/**
			 * Subscribe to all custom event on server
			 * @return {Boolean}
			 */
			sendCustomBinding: function() {
				if ( this._subscribed ) {
					return false;
				}
				this._subscribed = true;
				var that = this;
				server.bindOktellEvent('customevent', function(data){
					if ( data && data.eventname ) {
						that.trigger( data.eventname, data.eventparam );
					}
				});
			},
			/**
			 * Trigger custom event through oktell server
			 * @param eventName
			 * @param recipients userid's array
			 * @param data to send with event
			 * @param send back event or not, used only if recipients array defined
			 */
			triggerCustomEvent: function( eventName, recipientsArr, data, sendBack ) {
				sendOktell( 'triggercustomevent', {
					userid: oktellInfo.userid,
					userlogin: oktellInfo.login,
					eventname: eventName,
					eventparam: data,
					recipients: recipientsArr,
					sendback: sendBack ? 1 : "0"
				});
			}
		},Events);
		exportApi('triggerCustomEvent',customEvents.triggerCustomEvent, customEvents);
		exportApi('offCustomEvent',customEvents.off, customEvents);
		exportApi('onCustomEvent',customEvents.on, customEvents);

		/**
		 * Load users
		 * @param callback
		 */
		var loadUsers = function(callback){
			sendOktell('getallusernumbers', { fillsubordinates: true }, function(data){
				if ( data.result && data.users ) {
					each(data.users, function(u){
						users[ u.id ] = {
							id: u.id,
							name: u.name,
							number: u.main || undefined,
							numbers: u.nums || [],
							//controlMe: u.controlMe ? true : false,
							controlledByMe: u.sub ? true : false
						};
						users[ u.id ].numberObj = numbers[ users[ u.id ].number ] || undefined;
						if ( users[ u.id ].numberObj ) {
							users[ u.id ].numberObj.userid = u.id;
							users[ u.id ].numberObj.userObj = users[ u.id ];
						}
					});
					sendOktell("getalluserphotolink", {mode: "page"}, function(data){
						if ( data.result ) {
							var servPath = getWebServerLink();
							each(data.links, function(data){
								var user = data.id == oktellInfo.userid ? oktellInfo : users[data.id];
								if ( user ){
									user['avatarLink'] = data['link'] ? servPath + data['link32x32'] : oktellOptions.defaultAvatar || '';
									user['avatarLink32x32'] = data['link32x32'] ? servPath + data['link32x32'] : oktellOptions.defaultAvatar32x32 || '';
									user['avatarLink96x96'] = data['link96x96'] ? servPath + data['link96x96'] : oktellOptions.defaultAvatar64x64 || '';
								}
							});
						}

						callFunc(callback);
					});
				} else {
					callFunc(callback);
				}
			});
		};

		/**
		 * Is target user is controlled by me
		 * @param target
		 * @return {*}
		 */
		var userControlledByMe = function( target ) {
			if ( ! target ){
				return false;
			} else if ( (target = target.toString()) && users[target] && users[target].id ) {
				return users[target].controlledByMe;
			} else if  ( numbers[target] && numbers[target].userObj ) {
				return numbers[target].userObj.controlledByMe;
			} else {
				return false;
			}
		};

		/**
		 * Load number plan
		 * @param callback
		 */
		var loadPbxNumbers = function(callback) {
			sendOktell('getpbxnumbers', {mode:'full'}, function(data){
				if ( data.result && data.numbers ) {
					each(data.numbers, function(n){
						numbers[ n.number ] = n;
						numbersById[ n.id ] = numbers[ n.number ];
					});
				}
				callFunc(callback);
			});
		};

		/**
		 * Return url of oktell web server
		 * @return {*}
		 */
		var getWebServerLink = function() {
			if ( oktellInfo.currentUrl && oktellInfo.oktellWebServerPort ) {
				var protocol = oktellInfo.currentUrl.match(/^wss/) ? "https://" : "http://",
					host = oktellInfo.currentUrl.match(/wss?:\/\/([^\s\/:]+)/)[1];
					port = '';
				if ( ( protocol == 'https://' && self.getMyInfo().oktellWebServerPort != '443' ) || ( protocol == 'http://' && self.getMyInfo().oktellWebServerPort != '80' ) ) {
					port = ':' + self.getMyInfo().oktellWebServerPort;
				}
				return protocol + host + port;
			}
			return false;
		};

		/**
		 * Set callback for http query
		 * @param pass
		 * @param onResultsEvent
		 */
		var setHttpQueryCallback = function( pass, callback ) {
			var self = this;
			if ( pass ) {
				httpQueryData[pass] = {
					time: (new Date()).getTime(),
					callback: callback
				}
			}
		}
		//exportApi('setHttpQueryCallback',setHttpQueryCallback);

		/**
		 * Get password for http query
		 * @param callback
		 */
		var getHttpQueryPass = function( responsetowebsock, callback){
			sendOktell('gettemphttppass', {responsetowebsock: responsetowebsock ? true : false}, function(data){
				if ( data.result ) {
					callFunc(callback, getSuccessObj(data))
				} else {
					callFunc(callback, getErrorObj(1103, ' gettemphttppass', data))
				}
			});
		}
		//exportApi('getHttpQueryPass',getHttpQueryPass);

		/**
		 * Set up user avatar
		 * @param filepath
		 * @param callback
		 */
		var setUserAvatar = function( filepath, callback ) {
			if (! filepath) { return ;}

			var t = filepath.toString().split('.');
			if ( t.length < 2 || ['jpg','gif','png','jpeg'].indexOf(t[t.length-1]) == -1 ) {
				return;
			}

			sendOktell('setmyuserphoto', {filepath: filepath}, function(data){
				callFunc(callback, getReturnObj(data.result, {},1103,' setmyuserphoto'));
			});
		};
		exportApi('setUserAvatar', setUserAvatar);

		/**
		 * Load my avatar
		 * @param callback
		 */
		var loadUserAvatar = function(callback) {
			var self = this;
			sendOktell('getuserphoto', {mode: 'page'}, function(data){
				if ( data.result ) {
					var servPath = getWebServerLink();
					oktellInfo['avatarLink'] = data['link'] ? servPath + data['link32x32'] : oktellOptions.defaultAvatar || '';
					oktellInfo['avatarLink32x32'] = data['link32x32'] ? servPath + data['link32x32'] : oktellOptions.defaultAvatar32x32 || '';
					oktellInfo['avatarLink96x96'] = data['link96x96'] ? servPath + data['link96x96'] : oktellOptions.defaultAvatar64x64 || '';

					callFunc(callback, getSuccessObj({
						avatarLink: oktellInfo['avatarLink'], avatarLink32x32: oktellInfo['avatarLink32x32'], avatarLink96x96: oktellInfo['avatarLink96x96']
					}));
				} else {
					callFunc(callback, getErrorObj(1103, ' getuserphoto'));
				}
			});
		};
		exportApi('getUserAvatar',loadUserAvatar);

		/**
		 * Upload file to Oktell webserver. jQuery used if exist, else pure javascript version called
		 * @param storagemode - storage, temp, script or scriptplain
		 * @param pathmode - absolute or relative
		 * @param callback
		 * @return
		 */
		var uploadFile = function( options, callback, beforeRequest) {
			var $ = window.$ || window.jQuery || undefined;
			if ( ! $ ) {
				return uploadFilePure.apply(self, arguments);
			}

			var rid = Math.random().toString().replace('.',''),
				frameId = '_oktelljs_user_avatar_frame_' + rid,
				formId = '_oktelljs_user_avatar_form_' + rid,
				inputId = '_oktelljs_user_profile_select_file_' + rid;

			$('body').append('<iframe width="0" height="0" id="'+frameId+'" name="'+frameId+'"></iframe>');
			$('body').append('<form enctype="multipart/form-data" target="'+frameId+'" id="'+formId+'" action="" method="post">' +
				'<input style="visibility: hidden;" type="file" name="file" id="'+inputId+'" /></form>');

			$('#'+inputId).change(function(e){

				var file = $(e.currentTarget).val();

				if ( ! file ) {
					return;
				}

				var fileName = file.replace('/', '\\').split('\\');
				fileName = fileName[fileName.length-1];

				getHttpQueryPass( true, function(data){

					if ( data.result ) {

						$("#"+formId).attr("action", getWebServerLink() + "/upload?temppass="+ data.password + buildParams(options) );

						setHttpQueryCallback( data.password, function(data){
							var r = /uploadfilesresult count="1"[\s\S]+?path="([\s\S]+?)"/,
								path = r.exec(data);

							if ( !path || ! path[1] ) {
								return false
							}

							path = path[1].replace( /\\/g , '/');

							$('#'+formId).remove();
							$('#'+frameId).remove();

							callFunc(callback, getSuccessObj({path:path}));
						});

						callFunc(beforeRequest, getSuccessObj({fileName:fileName}));

						$('#'+formId).submit()
					}

				});
			});


			$('#'+inputId).click()


		};

		/**
		 * Upload file to Oktell webserver. Pure javascript version
		 * @param storagemode - storage, temp, script or scriptplain
		 * @param pathmode - absolute or relative
		 * @param callback
		 * @return
		 */
		var uploadFilePure = function( options, callback) {
			var rid = Math.random().toString().replace('.',''),
				frameId = '_oktelljs_user_avatar_frame_' + rid,
				formId = '_oktelljs_user_avatar_form_' + rid,
				inputId = '_oktelljs_user_profile_select_file_' + rid;

			var iframe = document.createElement('iframe');
			iframe.id = frameId;
			iframe.name = frameId;
			iframe.width = 0;
			iframe.height = 0;
			document.body.appendChild(iframe);

			var form = document.createElement('form');
			form.id = formId;
			form.style.display = 'none';
			form.target = frameId;
			form.enctype = "multipart/form-data";
			form.action = '';
			form.method = 'post';
			document.body.appendChild(form);

			var input = document.createElement('input');
			input.style.visibility = 'hidden';
			input.type = 'file';
			input.id = inputId
			input.name = 'file';
			form.appendChild(input);

			input.onchange = function() {
				var file = input.value;

				if ( ! file ) {
					return;
				}

				var fileName = file.replace('\\', '/').split('/');
				fileName = fileName[fileName.length-1];

				getHttpQueryPass( true, function(data){
					if ( data.result ) {
						form.action = getWebServerLink() + "/upload?temppass="+ data.password + '&' + buildParams(options);

						setHttpQueryCallback( data.password, function(data){
							var r = /uploadfilesresult count="1"[\s\S]+?path="([\s\S]+?)"/,
								path = r.exec(data);

							if ( !path || ! path[1] ) {
								return false
							}

							path = path[1].replace( /\\/g , '/');

							var elem;
							(elem=document.getElementById(frameId)).parentNode.removeChild(elem);
							(elem=document.getElementById(formId)).parentNode.removeChild(elem);

							callFunc(callback, getSuccessObj({path:path}));
						});

						callFunc(beforeRequest, getSuccessObj({fileName:fileName}));

						form.submit();
					}
				});
			}

			input.click();

		};
		exportApi('uploadFile', uploadFile);

		var DynamicMethods = (function(){
			function DynamicMethods(oktell, server){
				var self = this;
				self.oktell = oktell;
				self.server = server;
				self.currentMethods = {};
				self.methodTimers = {};
				self.onExecuteMethod = function(data){
					if ( ! data.executionid ) {
						return false;
					}
					self.currentMethods[data.executionid] = true;
					oktell.trigger('')
				};
				self.onCancelMethod = function(data){
					if ( ! data.executionid ) {
						return false;
					}
					delete self.currentMethods[data.executionid];
				};
				self.onExecuteMethodWaitAborted = function(data){
					if ( ! data.executionid ) {
						return false;
					}
					self.currentMethods[data.executionid] = true;
					self.methodTimers[data.executionid] = setTimeout(function(){
						delete self.currentMethods[data.executionid];
					}, data.waitresponsems );
				};
			};
			DynamicMethods.prototype.init = function(server){
				var self = this;
				self.server.bindOktellEvent('dynamic', function(){});
				self.server.bindOktellEvent('dynamicwaitabort', function(){});
				self.server.bindOktellEvent('executemethod', self.onExecuteMethod, self);
				self.server.bindOktellEvent('cancelmethod', self.onCancelMethod, self);
				self.server.bindOktellEvent('executemethodwaitaborted', self.onExecuteMethodWaitAborted, self);
			}
			DynamicMethods.prototype.sendMethodResult = function(executionId, data){
				var self = this;
				if ( self.currentMethods[executionId] ) {
					delete self.currentMethods[executionId];
					sendOktell('methodresult', {executionid: executionId, outputparameters: data || {}});
				} else {
					return false;
				}
			}
			DynamicMethods.prototype.reset = function(){
				var self = this;
				self.currentMethods = {};
				for ( var id in self.methodTimers ) {
					if ( self.methodTimers.hasOwnProperty(id) ) {
						clearTimeout(self.methodTimers[id]);
					}
				}
				self.server.unbindOktellEvent('executemethod', self.onExecuteMethod);
				self.server.unbindOktellEvent('cancelmethod', self.onCancelMethod);
				self.server.unbindOktellEvent('executemethodwaitaborted', self.onExecuteMethodWaitAborted);

			}
			return DynamicMethods;
		})();
		extend(DynamicMethods.prototype, Events);
		// TODO bindOktell or self.server.bindOktellEvent ?
		var dynamicMethods = new DynamicMethods()



		/**
		 * USER STATES
		 * @type {Object}
		 */
		var userStates = extend({},Events,{
			_stateId: 0,
			states: {
				DISCONNECTED: 0,
				READY: 1,
				BREAK: 2,
				OFF: 3,
				BUSY: 5,
				RESERVED: 6,
				NOPHONE: 7
			},
			webStates: {
				READY: 1, //'Ready for calls',
				DND: 2, //'DND',
				REDIRECT: 3, //'Redirect', not in callcenter
				BREAK: 4 // break, only in callcenter
			},
			onCallCenter: 0,
			_onRedirect: false,
			_status: 0,
			_webStateId: 0,
			onBreak: 0,
			breakReasons: {},

			loadBreakReasons: function(callback) {
				var that = this;
				sendOktell('cc_getlunchtypes', {}, function(data){
					if ( data.result ) {
						each( data.items, function(r){
							that.breakReasons[r.id.toString()] = r;
						});

					}
					callFunc(callback, getReturnObj(data.result, data, 1103, ' cc_getlunchtypes') );
				});
			},

			/**
			 * String name for state
			 * @param code
			 * @return {*}
			 */
			getStateStr: function( code ) {
				return getStateByCode( code === undefined ? this._stateId : parseInt(code), this.states );
			},

			/**
			 * String name for web state
			 * @param code
			 * @return {*}
			 */
			getWebStateStr: function( code ) {
				return getStateByCode( code === undefined ? this._webStateId : parseInt(code), this.webStates );
			},

			/**
			 * Получение состояния и локальное сохранение нового состояния
			 * Get or set current state
			 * @param newStateId
			 * @return {Number} current stateId
			 */
			state: function( newStateId ){
				newStateId = parseInt(newStateId);
				if ( this.getStateStr(newStateId) && this._stateId !== newStateId ) {
					log('SET USER STATE ' + newStateId + ' ' + this.getStateStr(newStateId) );
					this._stateId = newStateId;
					this.trigger('userStateChange', this._stateId);
				}
				return this._stateId;
			},

			/**
			 * Change states through change stateid on server or enabling redirect on server. Also save local states
			 * @param newWebState
			 * @param silent - if true, then event statusChange API event
			 * @param message - lunch reason message in callcenter
			 * @return {Boolean}
			 */
			changeStates: function( newWebState, silent, message ) {
				newWebState = this.webStates[newWebState.toString().toUpperCase()] || parseInt(newWebState);

				if ( ! this.getWebStateStr(newWebState) ) { return false; }

				if ( ( newWebState == this._webStateId && ! this.setAfterBusy ) || ! serverConnected() ) { return false; }
				var userState = this.state();
//				// set state, that was set while user was busy
//				if ( userState == this.states.BUSY && this.setAfterBusy && this.setAfterBusy != newWebState ) {
//					newWebState = this.setAfterBusy;
//					this.setAfterBusy = false;
//				}

				switch(newWebState) {
					case 1:
						if ( userState == this.states.BUSY ) {
							this.setAfterBusy = this.webStates.READY;
						} else {
							sendOktell('setuserstate', {userstateid: 1});
						}
						break;
					case 2:
						if ( userState == this.states.BUSY ) {
							this.setAfterBusy = this.webStates.DND;
						} else {
							if ( userState == this.states.READY || userState == this.states.BREAK || userState == this.states.OFF ) {
								sendOktell('setuserstate', {userstateid: 3} );
							}
						}
						break;
					case 3:
						if ( this.getRedirectNumber() ) {
							this.enableUserRedirectState( true );
						} else {
							return false;
						}
						break;
					case 4:
						if ( this.onCallCenter ) { //&& ( userState == this.states.READY || userState == this.states.BREAK || userState == this.states.OFF ) ) {
							var sObj = {userstateid: 2}, msg = '';
							if ( message ) {
								if ( this.breakReasons[message] ) {
									sObj.lunchreasonid = message;
								} else {
									sObj.lunchreasonmsg = message;
								}
							}
							sendOktell('setuserstate', sObj );
						}
						break;
				}

				this.webState(newWebState, silent);
				return true;
			},

			/**
			 * Save stateId local
			 * @param newStateId
			 * @param newStateId
			 * @param silent silent - if true, then event statusChange API event
			 * @return {Number}
			 */
			webState: function( newStateId, silent ) {
				if ( newStateId !== undefined && this.getWebStateStr(newStateId) && this._webStateId != newStateId ) {
					log('SET WEB STATE ' + this.getWebStateStr(newStateId));
					var oldStatus = this.getWebStateStr(this._webStateId);
					this._webStateId = newStateId;
					if ( ! silent ) {
						self.trigger('statusChange', this.getWebStateStr(this._webStateId), oldStatus );
					}
				}
				return this._webStateId;
			},

			/**
			 * Get redirect state or save redirect state locally
			 * @param newState новое состояние переадресации
			 * @return {Boolean} текущее состояние переадресации
			 */
			onRedirect: function(newState) {
				if ( newState !== undefined ) {
					newState = newState ? true : false;
					if ( this._onRedirect !== newState) {
						this._onRedirect = newState;
						events.trigger('userOnRedirectChanged', this._onRedirect);
					}
				}
				return this._onRedirect;
			},

			/**
			 * Load all states from server
			 */
			loadState: function(callback) {
				var that = this;
				sendOktell('getuserstate', {}, function(data){
					if ( data.result ) {
						that.saveStatesFromServer(data);
					}
					callFunc(callback, getReturnObj(data.result,data,1103,' getuserstate'));
				});
			},

			callCenterState: function(newState) {
				if ( newState !== undefined ) {
					newState = newState ? true : false;
					if ( this.onCallCenter !== newState ) {
						this.onCallCenter = newState;
						self.trigger('callCenterStateChange', this.onCallCenter );
					}
				}
				return this.onCallCenter;
			},

			/**
			 * Save and set all states locally
			 * @param data loaded from server {oncallcenter, onlunch, onredirect, userstateid}
			 */
			saveStatesFromServer: function(data) {
				this.callCenterState( data.oncallcenter );
				this.onBreak = data.onlunch;
				this.onRedirect(data.onredirect);

				var currentWebState = this.webState();
				var currentState = this.state();
				this.state( data.userstateid );
				if ( currentWebState == this.webStates.DND && this.setAfterBusy == this.webStates.DND && currentState == 5 && data.userstateid == 1 ) {
					this.setAfterBusy = false;
					this.changeStates(this.webStates.DND, true);
					return;
				}

				this.setWebStateFromUserState();
			},

			setUserStateBusy: function() {
				this.state(5);
			},

			/**
			 * Get redirect rule id for redirect state
			 * @return {String}
			 */
			getUserRedirectId: function() {
				return md5( oktellInfo.userid.toLocaleLowerCase() + oktellInfo.userid.toLocaleLowerCase() ).toLowerCase();
			},

			/**
			 * Get current redirect number
			 * @return {*} number or undefined
			 */
			getRedirectNumber: function() {
				return oktellInfo.redirectNumber ? oktellInfo.redirectNumber : undefined;
			},

			/**
			 * Set redirect number locally
			 * @param number
			 * @return {*} object like {number:'564'} or undefined
			 */
			setRedirectNumber: function( number ) {
				oktellInfo.redirectNumber =  number ? number : undefined;
				return oktellInfo.redirectNumber;
			},

			/**
			 * Load redirect number from server and set it locally
			 * @param callback
			 */
			checkUserRedirect: function(callback){
				var that = this;
				sendOktell("getredirectrules",{}, function(data){
					if ( data.result ) {
						var rule;
						if ( data.redirectrules && data.redirectrules.length > 0 ) { // ищем наше правило
							each( data.redirectrules, function(rule) {
								if ( rule.id.replace(/-/g,'').toLowerCase() == that.getUserRedirectId() ) {
									that.setRedirectNumber(rule.destinationnumber);
								}
							});
						}
					}
					callFunc(callback,getReturnObj(data.result,data,1103,' getredirectrules'));
				});
			},

			/**
			 * Save redirect number
			 * @param number or empty if need to cancel redirect
			 * @param callback
			 */
			saveUserRedirect: function(number,callback) {
				var that = this;
				if ( ! number ) {
					sendOktell("deleteredirectrules",{ ids: [ this.getUserRedirectId() ] }, function(data){
						if ( data.result ) {
							that.setRedirectNumber(undefined);
							if ( that.webState() == that.webStates.REDIRECT ) {
								that.changeStates( that.webStates.READY );
							}
						}
						callFunc(callback,getReturnObj(data.result,data,1103,' deleteredirectrules'));
					});

				} else {
					sendOktell("saveredirectrules",{
						redirectrule: {
							id: that.getUserRedirectId(),
							caption: 'Переадресация сохраненная из веб-октела. Действует постоянно.',
							description: 'Переадресация сохраненная из веб-октела. Действует постоянно.',
							priority: 1,
							userid: oktellInfo.userid,
							isenabled: true,
							allowcascade: true,
							state: 2,
							destinationnumber: number,
							onlyforredirectstate: true,
							definesources: false
						}
					}, function(data){
						if ( data.result ) {
							that.setRedirectNumber(number);
						}
						callFunc(callback,getReturnObj(data.result,data,1103,' saveredirectrules'));
					});
				}
				return true;
			},

			/**
			 * enable or disable redirect on server
			 * @param enable
			 */
			enableUserRedirectState: function( enable ) {
				sendOktell('setuserstate', { onredirect: enable ? true : false });
			},

			/**
			 * Set web state by stateId
			 */
			setWebStateFromUserState: function() {
				if ( ! this.onRedirect() ) {
					switch ( this.state() ) {
						case 1:
							this.webState( this.webStates.READY );
							break;
						case 2:
							this.webState( this.webStates.BREAK );
							break;
						case 3:
							this.webState( this.webStates.DND);
							break;
						case 5:
							if ( this.onBreak && this.onCallCenter ) {
								this.webState( this.webStates.BREAK );
							} else {
								this.webState( this.webStates.READY );
							}
							break;
						case 7:
							this.webState( this.webStates.READY );
							break;
					}
				} else {
					this.webState( this.webStates.REDIRECT );
				}
			}

		});
		exportApi('setRedirectNumber', userStates.saveUserRedirect, userStates);
		exportApi('getStatus', userStates.getWebStateStr, userStates);
		exportApi('setStatus', userStates.changeStates, userStates);
		exportApi('setUserStateBusy', userStates.setUserStateBusy, userStates);

		/**
		 * PHONE
		 * @type {Object}
		 */
		var phone = {

			_conferenceInfo: {},
			_holdNumber: false,
			_conferenceId: false,
			abonentList: {},
			queueList: {},
			_talkLength: 0,
			_talkTimer: false,
			sip: false,
			sipActive: false,
			states: {
				DISCONNECTED: -1,
				READY: 0,
				BACKCALL: 1,
				CALL: 2,
				RING: 3,
				BACKRING: 4,
				TALK: 5,
				//CALLWEBPHONE: 6
			},


			setSipphone: function(sip) {
				var that = this;
				that.sip = sip;
				that.sip.on('connect', function(){
					that.sipActive = true;
				});
				that.sip.on('disconnect', function(){
					that.sipActive = false;
				});
				that.sip.on('ringStart', function(number){

				});
				that.sip.on('ringStop', function(){

				});
				that.sip.on('callStart', function(number){

				});
				that.sip.on('callStop', function(){

				});
				that.sip.on('talkStart', function(number){

				});
				that.sip.on('talkStop', function(){

				});
				that.sip.on('sessionClose', function(){
					that.loadStates();
				});

			},

			answer: function() { if ( this.sipActive ) { this.sip.answer(); } },

			/**
			 * Set info about conference
			 * @param newInfoObj
			 */
			setConferenceInfo: function( newInfoObj ) {
				this._conferenceInfo = typeof newInfoObj == 'object' ? newInfoObj : {};
			},

			/**
			 * Get info about conference
			 * @return {*|Object}
			 */
			getConferenceInfo: function() {
				return this._conferenceInfo || {};
			},

			/**
			 * Clear hold info
			 * @return {Boolean}
			 */
			clearHold: function() {
				this.setHold(false);
				return true;
			},
			/**
			 * Set hold info
			 * @param info - phone number or conference id
			 * @return {Boolean} успех
			 */
			setHold: function( info ) {
				if ( info !== undefined && ( ( info.userid && info.userid != this._holdNumber ) || ( info.number && info.number != this._holdNumber ) || ( info.conferenceid && info.conferenceid != this._holdNumber ) ) ) {

					if ( this._holdAbonent ) {
						self.trigger('holdAbobnentLeave', cloneObject(this._holdAbonent) );
					}

					this._holdNumber = info.conferenceid ? info.conferenceid : ( info.userid ? info.userid : info.number );
					this._holdAbonent = info.conferenceid ? {
						isConference : true,
						conferenceId: info.conferenceid,
						conferenceName: info.conferencename,
						conferenceRoom: info.conferenceroom
					} : this.createAbonent(info);

					self.trigger('holdAbobnentEnter', cloneObject(this._holdAbonent));
					self.trigger('holdStateChange', cloneObject(this.getHoldInfo()));
					return true;
				} else if ( info === false ) {
					if ( this._holdAbonent ) {
						self.trigger('holdAbobnentLeave', cloneObject(this._holdAbonent));
					}
					this._holdAbonent = undefined;
					var oldHold = this._holdNumber;
					this._holdNumber = false;

					if ( oldHold !== this._holdNumber ) {
						self.trigger('holdStateChange', cloneObject(this.getHoldInfo()));
					}
				}
				return false;
			},
			/**
			 * Get hold info
			 * @return {Object}
			 */
			getHoldInfo: function() {
				var i = {
					hasHold: this._holdNumber ? true : false
				};
				if ( i.hasHold ) {
					if ( this._holdAbonent && this._holdAbonent.isConference ) {
						extend(i,cloneObject(this._holdAbonent));
					} else {
						i.isConference = false;
						i.abonent = cloneObject(this._holdAbonent);
					}
				}
				return i;
			},

			/**
			 * Set conference id
			 * @param newConferenceId
			 * @param notLoadConfAbonents boolean
			 * @return {Boolean}
			 */
			conferenceId: function( newConferenceId, notLoadConfAbonents ) {
				if ( newConferenceId !== undefined && newConferenceId != this._conferenceId ) {
					var oldConfId = this._conferenceId;
					this._conferenceId = newConferenceId;
					if ( oldConfId ) {
						sendOktell('confhandleevent', {
							conferenceid: oldConfId,
							eventtype: 'competitors',
							handle: false
						});
					}
					if ( this._conferenceId ) {

						sendOktell('confhandleevent', {
							conferenceid: this._conferenceId,
							eventtype: 'competitors',
							handle: true
						});

						if ( ! notLoadConfAbonents ) {
							this.loadConferenceInfo();
						}
					} else {
						this.setConferenceInfo(false);
					}
				}
				return this._conferenceId;
			},
			/**
			 * Set me as conference creator, or get
			 * @param newState
			 * @return {*}
			 */
			isConfCreator: function( newState ) {
				if ( newState !== undefined ) {
					this._isConfCreator = newState ? true : false;
				}
				return this._isConfCreator;
			},

			/**
			 * Return string description of phone state by state code
			 * @param code , if undefined, current code will be used
			 * @return {*}
			 */
			getStateStr: function( code ) {
				return getStateByCode( code === undefined ? this._stateId : parseInt(code), this.states );
			},

			/**
			 * Return string description of phone state for outside api calls. Replace BACKCALL to CALL
			 * @param code
			 * @return {*}
			 */
			apiGetStateStr: function(code) {
				var state = code === undefined ? this.state() : parseInt(code);
				if ( state == this.states.BACKCALL ) {
					state = this.states.CALL;
				}
				return this.getStateStr(state);
			},

			/**
			 * Set or get current state
			 * @param newStateId
			 * @return {*} current state id
			 */
			state: function( newStateId ) {
				newStateId = parseInt(newStateId);

				if ( this.getStateStr(newStateId) && newStateId != this._stateId ) {

//					var oldPhoneState = this.apiGetPhoneState(this._stateId);
					var oldState = this.apiGetStateStr(this._stateId);
					log('CHANGE STATE FROM ' + this.getStateStr(this._stateId) + ' TO ' + this.getStateStr(newStateId), this.getAbonents(true));
					switch ( this._stateId ) {
						case this.states.RING: self.trigger('ringStop', this.getAbonents(true)); break;
						case this.states.BACKRING: self.trigger('backRingStop', this.getAbonents(true)); break;
						case this.states.CALL: self.trigger('callStop', this.getAbonents(true) ); break;
						case this.states.BACKCALL: self.trigger('callStop', this.getAbonents(true)); break;
						case this.states.TALK: self.trigger('talkStop', this.getAbonents(true)); break;
					}

					this._stateId = newStateId;

					switch ( this._stateId ) {
						case this.states.RING: self.trigger('ringStart', this.getAbonents(true)); break;
						case this.states.BACKRING: self.trigger('backRingStart', this.getAbonents(true)); break;
						case this.states.CALL: self.trigger('callStart', this.getAbonents(true)); break;
						case this.states.BACKCALL: self.trigger('callStart', this.getAbonents(true)); break;
						case this.states.TALK: self.trigger('talkStart', this.getAbonents(true)); break;
						//case this.states.CALLWEBPHONE: self.trigger('webphoneCallStart', this.getAbonents(true)); break;
					}

//					var newPhoneState = this.apiGetPhoneState(this._stateId);
					var newState = this.apiGetStateStr(this._stateId);
//					if ( newPhoneState != oldPhoneState ) {
//						self.trigger('phoneStateChange', newPhoneState, oldPhoneState );
//
//					}
					if ( newState != oldState ) {
						self.trigger('stateChange', newState, oldState );
					}
				}

				if ( newStateId === this.states.READY || newStateId === this.states.DISCONNECTED ) {
					this.removeAbonents();
					this.conferenceId(false);
					this.isConfCreator(false);
					if ( newStateId === this.states.DISCONNECTED ) {
						this.clearHold();
					}
				}

				return this._stateId;
			},

			/**
			 * Load hold state
			 * @param callback
			 */
			loadFlashInfo: function(callback) {
				var that = this;
				sendOktell('getflashedabonentinfo', {}, function(data){
					if ( data.result ) {
						if ( data.containsflashed && data.abonent ) {
							that.setHold( data.abonent );
						} else {
							that.clearHold();
						}
					}
					callFunc(callback,getReturnObj(data.result,data,1103,' getflashedabonentinfo'));
				});
			},

			/**
			 * Load phone state
			 * @param callback
			 */
			loadStates: function(callback) {
				var that = this;
				//that.loadFlashInfo(function(data){
				if ( ! serverConnected() ) {
					return false;
				}

				sendOktell('getextendedlineinfo', {}, function(data) {
					var callCallback = function(){
						callFunc(callback,getReturnObj(data.result,data,1103,' getextendedlineinfo'));
					}

					if ( data.result ) {

						var oldState = that.state();

						var setStateFromResultData = function() {
							if ( data.abonent.isautocall ) {
								that.state( that.states.BACKCALL );
							} else if ( data.abonent.isringing ) {
								if ( data.abonent.direction == 'acm_callback' ) {
									that.state( that.states.BACKRING );
								} else {
									that.state( that.states.RING );
								}
							} else if ( data.abonent.iscommutated || data.abonent.iswaitinginflash || data.abonent.isconference ) {
								that.startTalkTimer(parseInt(data.timertalklensec) || 0);
								that.state( that.states.TALK );
							} else if ( data.abonent.extline || data.abonent.isivr || data.abonent.number ) { // peace of shit
								that.state( that.states.CALL );
							} else if ( data.linestatestr == 'lsDisconnected' ) {
								that.state( that.states.DISCONNECTED );
							} else {
								that.state( that.states.READY );
								if ( oldState !== that.state() && that.sipActive ) {
									that.sip.hangup();
								}
							}
						}

						if ( data.isflashing && data.flashed ) {
							that.setHold( data.flashed );
						} else {
							that.setHold(false);
						}

						if ( data.abonent ) {
							if ( ! data.abonent.conferenceid ) {
								that.setAbonent(data.abonent);
								that.conferenceId(false);
								setStateFromResultData();
								callCallback();
							} else {
								that.conferenceId(data.abonent.conferenceid, true);
								that.loadConferenceInfo(function(){
									setStateFromResultData();
									callCallback();
								});
							}
						} else {
							callCallback();
						}
					} else {
						callCallback();
					}

				});
				//});
			},

			/**
			 * Load current conference competitors
			 * @param callback
			 */
			loadConferenceInfo: function(callback) {
				var that = this;
				sendOktell('getconferenceinfo', { conferenceid: this.conferenceId() }, function(data){
					that.setConfAbonentList(data.competitors);
					that.setConferenceInfo( data.conference );
					callFunc(callback,getReturnObj(data.result,data,1103,' getconferencecompetitors'));
				});
			},

			/**
			 * Create abonent object from loaded data
			 * @param data
			 * @return {*}
			 */
			createAbonent: function(data) {
				var key = data.competitorid || data.number || data.userid || data.callerid;
				if ( key ) {
					var abonent = new Abonent();
					extend(abonent, {
						key: key,
						guid: data.competitorid || data.userid,

						isConferenceCompetitor: data.competitorid ? true : false,
						conferenceId : this.conferenceId(),
						isConferenceCreator: data.competitorid && data.iscreator ? true : undefined,
						isConferenceDirector: data.competitorid && data.isdirector ? true : undefined,
						isConferenceGhost: data.competitorid && data.isghost ? true : undefined,
						isConferenceGhostMajor: data.competitorid && data.isghostmajor ? true : undefined,
						isConferenceHidden: data.competitorid && data.ishidden ? true : undefined,
						isExternal: data.isextline ? true : false,

						phone: data.number ? data.number.toString() : ( data.calledid ? data.callerid.toString() : undefined ),
						phoneFormatted: data.number ? formatPhone( data.number.toString() ) : undefined,

						name: data.simplename || data.username || data.userlogin || data.number,

						isUser: data.userid ? true : false,
						user : {
							id: data.userid || undefined,
							name : data.username || undefined,
							login: data.userlogin || undefined,
							comment: data.comment || undefined
						},

						isClient: undefined,
						client : {
							id: undefined,
							name: undefined
						},
						line: {
							id: undefined,
							number: undefined
						}
					});
					return abonent;
				}
				return false;
			},

			/**
			 * Set current abonent (for simple calls)
			 * @param data - loaded info about abonent
			 * @return {*}
			 */
			setAbonent: function(data) {
				var oldKey;
				if ( size(this.abonentList) ) {
					each(this.abonentList, function(ab,key){
						oldKey = key;
					});
				}
				this.abonentList = {};
				var a = data ? this.createAbonent(data) : undefined;
				if ( a ) {
					this.abonentList[a.key] = a;
					if ( a.key != oldKey ) {
						self.trigger('abonentListChange', this.getAbonents() );
						self.trigger('abonentsChange', this.getAbonents(true) );
					}
				} else if ( oldKey ) {
					self.trigger('abonentListChange', this.getAbonents() );
					self.trigger('abonentsChange', this.getAbonents(true) );
				}
				return this.abonentList;
			},

			/**
			 * Set abonents list from loaded conference's competitors list
			 * @param abonents
			 * @return {Boolean}
			 */
			setConfAbonentList: function( abonents ){
				var newList = {},
					that = this;
				if ( abonents && isArray(abonents) ) {
					each( abonents, function(ab) {
						if ( ! that.getConferenceInfo().isghost || ( that.getConferenceInfo().isghost && ( ab.isghost || ab.userid == oktellInfo.userid || ab.number == oktellInfo.number ) ) ) {
							newList[ ab.competitorid ] = true;
							if ( ! that.abonentList[ ab.competitorid ] ) {
								var a = that.createAbonent(ab);
								that.abonentList[a.key] = a;
								if ( that.conferenceId() && that.state() == that.states.TALK ) {
									self.trigger('conferenceAbonentEnter', that.abonentList[a.key] );
								}
							}
						}
					})
				}
				var localList = that.getAbonents();
				each( localList, function(ab,id){
					if ( ! newList[id] ) {
						that.removeAbonents(id);
					}
				});
				self.trigger('abonentListChange', that.getAbonents() );
				self.trigger('abonentsChange', that.getAbonents(true) );
				return true;
			},

			/**
			 * Get current abonents list
			 * @return {Object}
			 */
			getAbonents: function( asArray ) {
				var list = asArray ? [] : {};
				each( this.abonentList, function(ab,i){
					if ( asArray ) {
						list.push( cloneObject( ab ) );
					} else {
						list[i] = cloneObject( ab );
					}
				});
				return list;
			},

			/**
			 * Check, target is current abonent or not
			 * @param number
			 * @return {Boolean}
			 */
			isAbonent: function( data, abonents ) {
				if ( ! data ) {
					return false;
				}
				abonents = abonents || this.getAbonents();
				if ( size(abonents) ) {
					if ( abonents.key ) {
						abonents = [abonents];
					}
					var curAb = false;
					each( abonents, function(ab){
						if (  ( ab.guid && ab.guid == data ) ||
							( ab.user && ab.user.id && ab.user.id == data ) ||
							( ab.client && ab.client.id && ab.client.id == data ) ||
							( ab.phone && ab.phone == data ) ) {
							curAb = cloneObject(ab);
							return breaker;
						}
					});
					return curAb;
				}
				return false;
			},

			/**
			 * Clear conference's abonents list
			 */
			removeConfAbonents: function() {
				var that = this;
				each( that.abonentList, function(ab,i){
					if ( that.conferenceId() && that.state() == that.states.TALK && ab.isConferenceCompetitor ) {
						self.trigger('conferenceAbonentLeave', ab);
					}
					delete that.abonentList[i];
				});
			},

			/**
			 * Remove abonent by number or id
			 * @param number
			 * @return {Boolean}
			 */
			removeAbonents: function(number) {
				var that = this;
				if ( number && that.abonentList[number] ) {
					if ( that.conferenceId() && that.state() == that.states.TALK && that.abonentList[number].isConferenceCompetitor ) {
						self.trigger('conferenceAbonentLeave', that.abonentList[number]);
					}
					delete that.abonentList[number];
					self.trigger('abonentListChange', that.getAbonents() );
					self.trigger('abonentsChange', that.getAbonents(true) );
				} else if ( number === undefined && size(that.abonentList) ) {
					each( that.abonentList, function(ab,i){
						if ( that.conferenceId() && that.state() == that.states.TALK && ab.isConferenceCompetitor ) {
							self.trigger('conferenceAbonentLeave', ab);
						}
						delete that.abonentList[i];
					});
					that.abonentList = {};
				} else {
					return false;
				}
				self.trigger('abonentListChange', that.getAbonents() );
				self.trigger('abonentsChange', that.getAbonents(true) );
				return true;
			},

			/**
			 * Back ring
			 * @param number
			 * @param callback
			 * @return {Boolean}
			 */
			makeCall: function(number, intercom, sequence, callback ) {
				var that = this;
				var error, msg = '';
				if ( ! number )  {
					error = 2106;
				}
				if ( userStates.state() == userStates.states.DISCONNECTED ) {
					error = 2001;
				}
				if ( that.state() == that.states.DISCONNECTED ) {
					error = 2002;
				}
				if ( that.getHoldInfo().hasHold && that.state() == that.states.TALK ) {
					error = 2101;
				}
				if ( that.conferenceId() ) {
					error = 2102;
				}
				if ( [ that.states.BACKCALL, that.states.BACKRING, that.states.CALL, that.states.RING ].indexOf(that.state()) != -1 ) {
					error = 2103;
					msg = ' (' + that.getStateStr() + ')';
				}
				if ( that.state() == that.states.READY && userStates.state() == userStates.states.BUSY && ! that.getHoldInfo().hasHold ) {
					error = 2104;
				}

				if ( error ) {
					callFunc(callback, getErrorObj(error));
					return false;
				}

				if ( that.isAbonent(number) ) {
					callFunc(callback, getErrorObj(2105));
					return false;
				} else if ( ( that.state() == that.states.READY  ) && that.sipActive && ! intercom ) {
					if ( that.state() == that.states.TALK ) {
						that.sip.hold();
					}
					that.sip.call(number);
					//that.state(that.states.CALLWEBPHONE);
					that.setAbonent({number:number});
					callFunc(callback, getSuccessObj());
				} else if ( that.state() == that.states.READY || that.state() == that.states.TALK ) {
					// обратный вызов
					// если TALK - текущий кладется в холд, и обратный вызов на number
					that.acmCall(number, intercom, sequence, function(data){
						callFunc(callback, getReturnObj(data.result,data,2107));
					});
				} else {
					// сюда никогда не придем (в теории)
					log('error call, unknown state');
					callFunc(callback, getErrorObj(2108));
					return false;
				}
			},

			/**
			 * Call server method for backcall
			 * @param number
			 * @param intercom - call in intercom mode
			 * @param callback
			 * @return {Boolean}
			 */
			acmCall: function( number, intercom, sequence, callback ) {
				var that = this;
				sequence = ['abonent', 'user'].indexOf(sequence) !== -1 ? sequence : 'user';
				if ( ! number ) {
					return false;
				}
				var params = {
					sequence: intercom ? 'user' : sequence,
					intercom: intercom ? true : undefined
				};
				params.number = number.toString();

				sendOktell( 'pbxautocallstart', params, function( data ) {
					that.loadStates(function(){
						callFunc(callback,data);
					});
				});
			},

			/**
			 * Switch current call and hold call
			 * @param callback
			 */
			toggleHold: function(callback) {
				var that = this;
				// TODO maybe it makes sense to load hold info from server before switch
				if ( that.getHoldInfo().hasHold ) {
					that.makeFlash('switch');
					callFunc(callback,getSuccessObj());
				} else {
					callFunc(callback,getErrorObj(2402));
				}
			},


			/**
			 * Call flash method
			 * @param mode тип
			 * @param callback
			 */
			makeFlash: function( mode ) {
				var that = this;
				var modeTypes = ['abort','switch','next'];
				sendOktell('pbxmakeflash',{ mode: modeTypes.indexOf(mode) != -1 ? mode : undefined });
			},

			/**
			 * Create conference or invite new competitor or make conference from current call
			 * @param numbers or number for inviting to conference
			 * @param callback
			 */
			conference: function( numbers, callback ) {
				var that = this;
				numbers = toStringsArray(numbers);

				if ( userStates.state() == userStates.states.BREAK ) {
					callFunc(callback,getErrorObj(2208));
				} else if ( that.state() == that.states.TALK ) {
					if ( that.conferenceId() && numbers ) {
						// invite
						that.inviteToConf(that.conferenceId(),numbers,callback);
					} else if ( ! that.conferenceId() ) {
						if ( ! numbers ) {
							that.callToConf(callback);
						} else {
							that.callToConf(function(data){
								if ( data.result ) {
									that.inviteToConf(that.conferenceId(),numbers,callback);
								} else {
									callFunc(callback, getErrorObj(2202));
								}
							});
						}
					}
				} else if ( that.state() == that.states.READY && ! that.conferenceId() && numbers ) {
					// new conf
					that.createConf( numbers, callback);
				} else {
					callFunc(callback,getErrorObj(2205))
				}
			},

			/**
			 * Call server method for creating conference from current call
			 * @param callback
			 */
			callToConf: function(callback) {
				var that = this;
				that.buildConfFromCommCallback = callback;
				that.buildConfFromCommTimer = setTimeout(function(){
					callFunc(that.buildConfFromCommCallback, getErrorObj(2202));
					that.buildConfFromCommCallback = undefined;
				},2000)
				sendOktell('buildconferencefromcommutation');
			},

			/**
			 * Call server method for creating conference
			 * @param numbers
			 * @param callback
			 */
			createConf: function( numbers, callback ) {
				var that = this;
				var confId = newGuid();
				var room = Math.round( Math.random() * 10000 );
				var numParam = [{ userlogin: oktellInfo.login }];
				numbers = toStringsArray(numbers);
				if ( isArray( numbers ) ) {
					each( numbers, function(n) {
						if ( isGuid(n) ) {
							numParam.push({ userid: n });
						} else {
							numParam.push({ intnumber: n });
						}
					});
				}

				if ( size(numParam) > 1 ) {
					sendOktell('createnewconference', {
						conference: {
							id: confId,
							room: room,
							name: "",
							description: "",
							accessmode: "free",
							isselector: false,
							record: true,
							recordrights: "selected",
							everyonecaninvite: true,
							canvieweachother: true
						},
						competitors: numParam
					} , function(data){
						if ( data.result == 1 ) {
							that.conferenceId(confId, true);
						} else {
							that.conferenceId(false);
						}
						callFunc(callback,getReturnObj(data.result, data, 2204));
					});
				} else {
					callFunc(callback, getErrorObj(2203));
				}
			},

			/**
			 * Call server method for inviting competitors to conference
			 * @param confId conference id
			 * @param numbers or number for invite
			 * @param callback
			 */
			inviteToConf: function( confId, numbers, callback ) {
				if ( ! confId ) {
					callFunc(callback,false);
				}
				var that = this;
				numbers = toStringsArray(numbers);
				var numParam = [];
				var fromHold;
				var holdAbonent = that.getHoldInfo().abonent || {};
				if ( isArray( numbers ) ) {
					each( numbers, function(n){
						if ( typeof n == 'string' && n !== '' ) {
							if ( that.isAbonent(n, holdAbonent) ) {
								fromHold = n;
							} else {
								if ( isGuid(n) ) {
									numParam.push({ userid: n });
								} else {
									numParam.push({ intnumber: n });
								}
							}
						}
					});
				}

				var sendInvites = function() {
					sendOktell('invitetoconference', { conferenceid: confId, competitors: numParam}, function(data){
						callFunc(callback, getReturnObj(data.result,data,2202));
					});
				}

				if ( size(numParam) == 0 && ! fromHold ) {
					callFunc(callback,getErrorObj(2201));
				} else if ( fromHold ) {
					if ( confId != that.conferenceId() ) {
						callFunc(callback, getErrorObj(2206));
						return;
					}
					sendOktell('checkcanconnecttogathertoconference', {}, function(data){
						if ( data.canconnecttogather ) {
							sendOktell('connecttogathertoconference');
							if ( size(numParam) != 0 ) {
								sendInvites();
							} else {
								callFunc(callback, getSuccessObj());
							}
						} else {
							callFunc(callback, getErrorObj(2206));
						}
					});
				} else if ( size(numParam) != 0 ) {
					sendInvites();
				} else {
					callFunc(callback, getErrorObj(2207));
				}
			},

			/**
			 * Stop call, dial, conference. Disconnection of conference competitor
			 * @param numbers or number for disconnect
			 */
			endCall: function( numbers ) {
				var that = this;
				numbers = toStringsArray(numbers);

				if ( that.getHoldInfo().hasHold ) {
					that.makeFlash('abort');
				} else {
					if ( that.state() == that.states.TALK ) {
						if ( that.conferenceId() ) {
							if ( numbers ) {
								// kick numbers from conf
								that.kickConfAbonent( that.conferenceId(), numbers);
							} else {
								// end conf
								that.exitConf(that.conferenceId());
							}
						} else {
							// abort call
							that.abortCall();
						}
					} else if ( that.state() == that.states.BACKCALL ) {
						// abort acm call
						that.abortAcmCall();
					} else if ( that.state() == that.states.CALL ) {
						that.abortCall();
					} else if ( that.state() == that.states.RING || that.state() == that.states.BACKRING ) {
						that.declineCall();
					}
				}
			},

			/**
			 * Call server method for disconnect current connection
			 */
			abortCall: function() {
				sendOktell('pbxabortcall');
			},

			/**
			 * Call server method for end commutation if exist, stop autocall if started
			 */
			declineCall: function() {
				sendOktell('pbxdeclinecall');
			},

			/**
			 * Call server method for disconnect conference competitor by number
			 * @param confId conference id
			 * @param numbers or number
			 */
			kickConfAbonent: function( confId, numbers ) {
				numbers = toStringsArray(numbers);
				var that = this;
				sendOktell('getconferencecompetitors', { conferenceid: confId }, function(data){
					var compsByNumber = {};
					var compsById = {};
					var iam = false;
					for ( var i = 0, l = data.competitorlist.length; i < l; i++ ) {
//						if ( data.competitorlist[i].number != oktellInfo.number ) {
//							compsByNumber[data.competitorlist[i].number] = data.competitorlist[i].competitorid;
//						} else {
//							iam = true;
//						}
//						if ( data.competitorlist[i].userid != oktellInfo.userid ) {
//							compsById[data.competitorlist[i].userid] = data.competitorlist[i].competitorid;
//						} else {
//							iam = true;
//						}
						compsByNumber[data.competitorlist[i].number] = data.competitorlist[i].competitorid;
						compsById[data.competitorlist[i].userid] = data.competitorlist[i].competitorid;
					}
					var n;
					each( numbers, function(num){
						if ( n = ( compsByNumber[num] || compsById[num] || '' ) ) {
							if ( num && ( num == oktellInfo.number || num == oktellInfo.userid ) ) {
								iam = true;
							} else {
								sendOktell('confdisconnectcompetitor', {conferenceid: confId, competitor: { competitorid: n } } );
							}
						}
					});
					if ( iam ) {
						that.exitConf(confId);
					}
				});
			},

			/**
			 * Call server method for stop back ring
			 * @param callback
			 */
			abortAcmCall: function(callback) {
				sendOktell('pbxautocallabort');
			},

			/**
			 * Call method for exit conference
			 * @param confId
			 */
			exitConf : function( confId ) {
				sendOktell('exitconference', {conferenceid:confId});
			},

			/**
			 * Call method for transfer call
			 * @param transferTo
			 * @param callback
			 */
			makeTransfer: function( transferTo, callback ) {
				sendOktell('pbxmaketransfer',{
					transferto: transferTo ? transferTo + '' : ""
				});
				callFunc(callback, getSuccessObj());
			},

			/**
			 * Transfer call
			 * @param number
			 * @param callback
			 */
			transfer: function( number, callback ) {
				var that = this;
				if ( ! number ) {
					callFunc(callback, getErrorObj(2304));
				}

				if ( that.state() == that.states.TALK ) {
					if ( that.getHoldInfo().hasHold ) {
						if ( ! number || that.isAbonent( number, that.getHoldInfo().abonent || {} ) ) {
							// connect B to A, we disconnect
							that.endCall(undefined);
							callFunc(callback,getSuccessObj());
						} else {
							// connect B to C, we connect to A
							that.makeTransfer(number, callback);
						}
					} else if ( number ) {
						// connect A to B, we disconnect
						that.makeTransfer( number, callback);
					} else {
						callFunc(callback, getErrorObj(2302));
					}
				} else {
					callFunc(callback, getErrorObj(2303));
				}
			},

			/**
			 * Connect for help or wiretapping, change connection type
			 * @param target
			 * @param mode
			 * @param callback
			 * @return {Boolean}
			 */
			ghost: function( target, mode, callback ) {
				var that = this;

				var fn = function(d) {
					that.loadConferenceInfo( callFunc(callback,d) );
				};

				target = ( users[target] && users[target].id ) || (numbers[target] && numbers[target].userid);
				if ( ! target ) {
					callFunc(fn, getErrorObj(2504));
					return false;
				}

				mode = mode || 'monitor';

				if ( ['monitor', 'conference', 'help'].indexOf(mode) == -1 ) {
					callFunc( fn, getErrorObj(2503));
					return false;
				}


				if ( that.state() == that.states.READY ) {

					sendOktell('attachasghost', { ghostedid: target }, function(data){
						if ( data.result ) {
							if ( mode && mode != 'monitor' ) {
								setTimeout(function(){
									if ( that.conferenceId() ) {
										that.changeGhostMode( mode, fn );
									}
								}, 500);
							} else {
								callFunc(fn, getSuccessObj());
							}
						} else {
							if ( data.error == 52710 ) {
								callFunc(fn, getErrorObj(2505));
							} else {
								callFunc(fn, getErrorObj(2502));
							}
						}
					});

				} else {

					var ab = that.isAbonent(oktellInfo.userid);
					var conferenceId = that.conferenceId();
					if ( ! ab || ! conferenceId || ! that.getConferenceInfo().isghost ) {
						callFunc( fn, getErrorObj(2506));
						return false;
					}

					var targetAbonent = that.isAbonent( target );
					if ( ! targetAbonent ) {
						callFunc( fn, getErrorObj(2507));
						return false;
					}

					if ( ! targetAbonent.isConferenceGhostMajor && ( mode == 'help' || mode == 'monitor' ) ) {

						sendOktell('confsetvoiceparams', {
							conferenceid: conferenceId,
							competitor: {
								competitorid: targetAbonent.guid,
								ghosthelp: mode == 'help' ? true : false
							}
						}, function(data){
							if ( data.result ) {

							}
							callFunc(fn,getReturnObj(data.result,{},2502));
						});

					} else {

						sendOktell('confsetghostmode', { conferenceid: conferenceId, ghostmode: mode }, function(data){
							if ( data.result ) {

							}
							callFunc(fn,getReturnObj(data.result,{},2502));
						});

					}
				}
			},

			/**
			 * Load waiting queue
			 * @param callback
			 */
			queue: function(callback) {
				var that = this;
				sendOktell('getcurrentqueue', {}, function(data){
					if ( data.result ) {
						var abonents = {},
							absArr = [],
							listChanged = false;
						if ( isArray( data.queue ) && size(data.queue) > 0 ) {
							each( data.queue, function(q) {
								ab = that.createAbonent(q)
								abonents[ab.key] = ab;
								absArr.push(ab);
								if ( ! that.queueList[ab.key] && ! that.isAbonent(ab.key) ) {
									that.queueList[ab.key] = ab;
									self.trigger('queueAbonentEnter', ab)
									listChanged = true;
								}
							});
						}
						each( that.queueList, function(ab, key){
							if ( ! abonents[key] ) {
								self.trigger('queueAbonentLeave', ab)
								delete that.queueList[key];
								listChanged = true;
							}
						});
						if ( listChanged ) {
							self.trigger('queueChange', absArr);
						}
						callFunc(callback, getSuccessObj({queue: absArr}));
					} else {
						callFunc(callback, getErrorObj(2701));
					}
				});
			},



			startTalkTimer: function(seconds) {
				var that = this;
				that.clearTalkTimer(true);
				that._talkLength = Date.now() - ( parseInt(seconds) || 0 ) * 1000;
				that.triggerTalkTimeEvent()
				that._talkTimer = setInterval(function(){
					that.triggerTalkTimeEvent()
				},1000);
			},

			triggerTalkTimeEvent: function() {
				var that = this;
				if ( that._talkLength !== false ) {
					var len = that.getCurrentTalkLength()
					self.trigger('talkTimer', len, that.formatTime(len) );
				} else {
					self.trigger('talkTimer', false );
				}
			},

			getCurrentTalkLength: function() {
				return Math.floor( (Date.now() - this._talkLength) / 1000 )
			},

			clearTalkTimer: function(silent) {
				clearInterval( this._talkTimer );
				this._talkLength = false
				if ( ! silent ) {
					this.triggerTalkTimeEvent()
				}
			},

			formatTime: function(sec) {
				var t = sec,
					h = Math.floor(t/3600),
					m = Math.floor(t/60) % 60,
					s = t%60;
				return ( h ? h + ':' : '' ) +
					( m < 10 ? '0' + m : m ) + ':' +
					( s < 10 ? '0' + s : s );
			},

			talkLength: function(format) {
				if ( this._talkLength === false ) {
					return '';
				}
				var sec = this.getCurrentTalkLength()
				if ( format ) {
					return this.formatTime(sec);
				} else {
					return sec;
				}
			},

			dtmf: function(code) {
				if ( ! this.sipActive || typeof code != 'string' || !code.match(/^[0-9\*#]{1}$/) ) {
					return false;
			}
				return this.sip.dtmf(code);
			},

			hold: function() {
				if ( this.sipActive ) { this.sip.hold(); }
			},

			resume: function() {
				if ( this.getHoldInfo().hasHold && this.sipActive ) { this.sip.resume(); }
			}
		};
		extend( phone, Events );
		exportApi('isAbonent', phone.isAbonent, phone);
		exportApi('conferenceId', phone.conferenceId, phone);
		exportApi('getHoldInfo', phone.getHoldInfo, phone);
		exportApi('endCall', phone.endCall, phone);
		exportApi('conference', phone.conference, phone);
		exportApi('transfer', phone.transfer, phone);
		exportApi('toggle', phone.toggleHold, phone);
		exportApi('getState', phone.apiGetStateStr, phone);
		exportApi('getQueue', phone.queue, phone);
		exportApi('getTalkLength', phone.talkLength, phone);
		exportApi('answer', phone.answer, phone);
		exportApi('dtmf', phone.dtmf, phone);
		exportApi('hold', phone.hold, phone);
		exportApi('resume', phone.resume, phone);
//		exportApi('getPhoneState', phone.apiGetPhoneState, phone);


		/**
		 * Possible actions for phone states
		 * @type {Object}
		 */
		var pa = {};
		pa['-'] = {}
		pa[phone.states.DISCONNECTED] = {};
		pa[phone.states.BACKCALL] = { endCall: 1 };
		pa[phone.states.BACKRING] = { endCall: 1 };
		pa[phone.states.CALL] = { endCall: 1, conference: 1, call: 1, intercom: 1, transfer: 1 };
		pa[phone.states.READY] = { conference: 1, call: 1, intercom: 1, ghostListen: 1, ghostHelp: 1, ghostConference: 1, transfer: 1, toggle: 1, endCall: 1, resume: 1 };
		pa[phone.states.RING] = { endCall: 1, answer: 1 };
		pa[phone.states.TALK] = { endCall: 1, conference: 1, call: 1, resume: 1, hold: 0, intercom: 1, toggle: 1, transfer: 1, ghostListen: 1, ghostHelp: 1, ghostConference: 1 };
		//pa[phone.states.CALLWEBPHONE] = { };

		/**
		 * Possible actions for user states
		 * @type {Object}
		 */
		var pau = {};
		pau['-'] = {}
		pau[userStates.states.DISCONNECTED] = {};
		pau[userStates.states.READY] = {endCall: 1, conference: 1, call: 1, intercom: 1, toggle: 1, transfer: 1, resume: 1, ghostListen: 1, ghostHelp: 1, ghostConference: 1, resume:1};
		pau[userStates.states.BREAK] = {endCall: 1, call: 1, intercom: 1, toggle: 1, transfer: 1, ghostListen: 1, resume: 1, ghostHelp: 1, ghostConference: 1};
		pau[userStates.states.OFF] = {endCall: 1, conference: 1, call: 1, intercom: 1, toggle: 1, transfer: 1, resume: 1, ghostListen: 1, ghostHelp: 1, ghostConference: 1};
		pau[userStates.states.BUSY] = {answer: 1, endCall: 1, conference: 1, call: 1, intercom: 1, toggle: 1, transfer: 1, resume: 1, hold: 0, ghostListen: 1, ghostHelp: 1, ghostConference: 1};
		pau[userStates.states.RESERVED] = {};
		pau[userStates.states.NOPHONE] = {};



		/**
		 * Phone actions class
		 * @constructor
		 */
		var PhoneActions = function() {
			var a = [];
			var s = phone.state();
			s = typeof s == 'number' ? s : '-';
			var us = userStates.state() || '-';
			us = typeof us == 'number' ? us : '-';
			this.push = function() {
				each( arguments, function(arg){
					if ( pa[s][arg] && pau[us][arg] ) {
						a.push(arg);
					}
				})
			};
			this.getActions = function(){
				return a;
			}
		}

		/**
		 * Return possible actions by phone number or userid
		 * @param data
		 * @return {*}
		 */
		var getPhoneActions = function( data ) {
			var a = new PhoneActions;
			if ( ! data || ! serverConnected() ) {
				return a.getActions();
			}

			var isMe = oktellInfo.userid == data || oktellInfo.number == data;
			var hold = phone.isAbonent(data, phone.getHoldInfo().abonent || {} );
			var obj = users[data] || numbers[data] || numbersById[data];
			if ( obj && obj.numberObj ) {
				obj = obj.numberObj;
			}
			var abonent = phone.isAbonent(data) || ( obj && obj.number && phone.isAbonent(obj.number) );
			var isInQueue = phone.isAbonent(data, phone.queueList) || ( obj && obj.number && phone.isAbonent(obj.number, phone.queueList) );
			var hasHold = phone.getHoldInfo().hasHold;
			var isConf = phone.conferenceId() ? true : false;
			var isConfCreator = isConf && abonent && abonent.isConferenceCreator;
			var iAmAbonent = isConf && phone.isAbonent( oktellInfo.userid );
			var iAmCreator = isConf && iAmAbonent && iAmAbonent.isConferenceCreator;
			var phoneState = phone.state();

			if ( isInQueue ) {

			} else if ( isMe ) {
				if ( phoneState != phone.states.DISCONNECTED && phoneState != phone.states.READY ) {
					if ( phone.sipActive ) {
						a.push('answer');
					}
					a.push('endCall');
				}
			} else if ( ! obj || ( obj && obj.state !== undefined && obj.state != 0 ) ) {
				if ( hold ) {
					if ( phone.sipActive && phoneState == phone.states.READY ) {
						a.push('resume');
					} else {
						a.push('toggle', 'endCall'); // toogle and connect current with hold, and disconnect myself
					}
				} else if ( ! abonent ) {
					if ( isConf ) {
						if ( ! ( obj && obj.state == 2 ) ) {
							a.push('conference');
						}
						a.push('transfer');
					} else {
						if ( ( ! hasHold && phoneState == phone.states.TALK ) || phoneState == phone.states.READY ) {
							a.push('call');
							if ( phoneState == phone.states.TALK ) {
								a.push('transfer');
							}
							if ( ! ( obj && obj.state == 2 ) ) {
								a.push('conference');
							}
							a.push('intercom');
						} else if ( hasHold && phoneState == phone.states.TALK ) {
							a.push('transfer');
						}
					}
					//log(phone.state() + userControlledByMe(data));
					if ( obj && obj.state == 5 && phoneState == phone.states.READY && userControlledByMe(data) ) {
						a.push('ghostListen', 'ghostHelp', 'ghostConference');
					}
				} else if ( abonent ) {
					if ( phoneState == phone.states.RING ) {
						a.push('answer');
					}
					if ( isConf ) {
						if ( iAmCreator ) {
							a.push('endCall');
						}
					} else {
						a.push('endCall');
						if ( phone.sipActive && ! hasHold ) {
							a.push('hold');
						}
						if ( ! ( obj && obj.state == 2 ) ) {
							a.push('conference');
						}
//						if ( hasHold ) {
//							a.push('transfer');
//						}
					}
					if ( phone.getConferenceInfo().isghost && userControlledByMe(data) ) {
						a.push('ghostListen', 'ghostHelp', 'ghostConference');
					}
				}
			}
			//log('Phone action for ' + data + ' ' + a.getActions());
			return a.getActions();
		};
		exportApi('getPhoneActions',getPhoneActions);

		/**
		 * connect with server
		 * @param options
		 * @param callback
		 * @return {Boolean}
		 */
		var connect = function( options, callback ) {

			self.trigger('connecting');

			oktellOptions = oktellOptions || {
				openTimeout: 10000,
				queryTimeout: 20000,
				queueInterval: 5000,
				oktellVoice: false,
				webSocketSwfLocation: "WebSocketMain.swf"
			};

			if ( serverConnected() ) {
				return true;
			}

			options = options || {};
			var loginError = false;

			extend( oktellOptions, options );
			debugMode = oktellOptions.debugMode;
			oktellVoice = false
			if ( oktellOptions.oktellVoice ) {
				if ( oktellOptions.oktellVoice.isOktellVoice === true ) {
					oktellVoice = oktellOptions.oktellVoice
				} else if ( window.oktellVoice && window.oktellVoice.isOktellVoice === true ) {
					oktellVoice = window.oktellVoice
				}
			}

			var sessionId = cookie(cookieSessionName) || ( localStorage && localStorage[cookieSessionName] );

			if ( ! sessionId && options.password !== undefined && options.password !== null ) {
				oktellOptions.password = md5( utf8DecodePass( options.password.toString().toLowerCase() ) );
				oktellOptions.Password = md5( utf8DecodePass( options.password.toString() ) );
			} else {
				oktellOptions.password = undefined;
			}


			var wsProtocolUrlRegExp = /^w[s]{1,2}:\/\/\S+$/,
				portRegExp = /:[0-9]{1,5}$/;
			var prepareUrl = function(urlStr) {
				if ( wsProtocolUrlRegExp.test(urlStr) ){
					return urlStr;
				} else {
					var useWss = location.protocol == 'https:',
						port = useWss ? ':443' : ':80',
						protocol = useWss ? 'wss://' : 'ws://';
					if ( portRegExp.test(urlStr) ) {
						return protocol + urlStr;
					} else {
						return protocol + urlStr + port;
					}
				}
				return false;
			}

			if ( typeof oktellOptions.url == 'string' ) {
				oktellOptions.url = [oktellOptions.url];
			}

			if ( isArray(oktellOptions.url) ) {
				var links = []
				for ( var i = 0, j = oktellOptions.url.length; i < j; i++ ) {
					if ( typeof oktellOptions.url[i] !== 'string') {
						continue;
					}
					links.push( prepareUrl(oktellOptions.url[i]) );
				}
				oktellOptions.url = links;
			} else {
				callFunc( oktellOptions.callback, getErrorObj(1205) );
				self.trigger('connectError', getErrorObj(1205) );
				return false;
			}

			WEB_SOCKET_SWF_LOCATION = oktellOptions.webSocketSwfLocation;

			if ( ! window.flashWebSocketInitialized ) {
				window.flashWebSocketInitialized = true;
				initFlashWebSocket();
			}

			oktellInfo.url = oktellOptions.url;
			oktellInfo.login = oktellOptions.login;
			oktellInfo.password = oktellOptions.password;
			oktellInfo.defaultAvatar = oktellOptions.defaultAvatar;
			oktellInfo.defaultAvatar32x32 = oktellOptions.defaultAvatar32x32;
			oktellInfo.defaultAvatar64x64 = oktellOptions.defaultAvatar64x64;

			var currentUrlIndex = 0;

			if ( ! sessionId && ( oktellOptions.password === undefined || oktellOptions.password === null ) ) {
				callFunc( oktellOptions.callback, getErrorObj(1213) );
				self.trigger('connectError', getErrorObj(1213) );
				return false;
			}

			var createServer = function() {
				server = new Server( oktellOptions.url, oktellOptions.openTimeout, function(url){
					//alert(url);
					loginError = false;
					oktellInfo.currentUrl = server.url; //oktellOptions.url[currentUrlIndex];
					sendOktell('login', {
						Password: oktellOptions.Password,
						password: oktellOptions.password,
						sessionid: sessionId || undefined,
						showid: 1,
						usewebrtc: oktellVoice ? true : false,
						workplace: oktellOptions.workplace || undefined,
						expires: oktellOptions.expires || undefined
					}, function(data){
						loginError = true;
						if ( data.error || data.errormsg ) {
							var errorCode = 1000;
							if ( data.error == 50093 ) {
								errorCode = 1204;
							} else if ( data.error == 50025 ) {
								errorCode = 1214;
							} else if( data.errormsg == "Wrong login/pass combination" ) {
								cookie(cookieSessionName, null);
								localStorage && (delete localStorage[cookieSessionName]);
								errorCode = 1202;
							} else if ( data.errormsg == 'Bad request. Session does not exist' || data.errormsg == 'Bad request. Invalid session user' ) {
								cookie(cookieSessionName, null);
								localStorage && (delete localStorage[cookieSessionName]);
								errorCode = 1212;
							}
							callFunc( oktellOptions.callback, getErrorObj(errorCode) );
							self.trigger('connectError', getErrorObj(errorCode) );
							disconnect(14);
						} else if (data.result == 1) {
							clearInterval(pingTimer);
							pingTimer = setInterval(function(){
								if ( serverConnected() ) {
									server.sendOktell('ping');
								}
							},15000);
							clearInterval(queueTimer);
							queueTimer = setInterval(function(){
								if ( serverConnected() ) {
									phone.queue()
								}
							}, oktellOptions.queueInterval)
							phone.queue();
							customEvents.sendCustomBinding();

							server.bindOktellEvent('userstatechanged', function(data){
								userStates.saveStatesFromServer(data);
							});

							if ( oktellVoice ) {
								setTimeout(function(){
									sipPhone = oktellVoice.connect({
										login: data.sipuser,
										password: data.sippass,
										server: url.replace(/w[s]{1,2}:\/\//, '').replace('/', '').split(':')[0] + ':' + data.sipport,
										debugMode: debugMode
									});
									sipPhone.on('connect', function(){
										sipPnoneActive = true;
										self.trigger('webphoneConnect');
									});
									sipPhone.on('all', function(event){
										log('Oktell webphone event: ' + event, arguments);
									});
									sipPhone.on('disconnect', function(){
										sipPnoneActive = true;
										self.trigger('webphoneDisconnect');
									});
									phone.setSipphone(sipPhone);
								}, 200);
							}
							oktellInfo.userid = data.userid;
							oktellInfo.sessionId = data.sessionid;
							if (oktellInfo.sessionId) {
								cookie(cookieSessionName, oktellInfo.sessionId, { expires: oktellOptions.expires });
								localStorage && (localStorage[cookieSessionName] = oktellInfo.sessionId);
							}

							sendOktell('getversion', {showalloweddbstoredprocs:1}, function(data){

								if ( data.result ) {
									oktellInfo.oktellBuild = data.version.build;
									oktellInfo.oktellDated = data.version.dated;
									oktellInfo.allowedProcedures = data.alloweddbstoredprocs || {};
									oktellInfo.oktellWebServerPort = data.version.webserverport;
									oktellInfo.oktellWebServerLink = getWebServerLink();
									sendOktell('getmyuserinfo', {}, function(data){
										if ( data.result ) {
											oktellInfo.number = data.mainpbxnumber;
											oktellInfo.username = data.username;
											oktellInfo.hasline = data.hasline;
											oktellInfo.lineid = data.lineid;
											oktellInfo.linenumber = data.linenumber;
											oktellInfo.isoperator = data.isoperator;
											userStates.loadBreakReasons(function(data){
												userStates.loadState(function(result){
													if ( result ) {
														userStates.checkUserRedirect(function(result){
															loadPbxNumbers(function(){

																server.bindOktellEvent( 'pbxnumberstatechanged', function( data ){
																	for( var i = 0; i < data.numbers.length; i++ ) {
																		var n = numbers[ data.numbers[i].num ];
																		if ( n ) {
																			n.state = data.numbers[i].numstateid;
																		}
																	}
																});

																loadUsers(function(){
																	phone.loadStates(function(result){
																		if ( result ) {
																			loginError = false;
																			events.trigger('login');
																			server.bindOktellEvent('httpresponsecopy',function(data){
																				var result = data.response;
																				if ( result == '200 OK') {
																					var pass = data.password;
																					var content = data.content;
																					if ( httpQueryData[pass] && typeof httpQueryData[pass].callback == 'function' ) {
																						httpQueryData[pass].callback(content);
																					}
																				}
																			});
																			callFunc( oktellOptions.callback, getSuccessObj() );
																			oktellConnected(true);

																			for (var i = 0; i < nativeEventsForBindAfterConnect.length; i++) {
																				var obj = nativeEventsForBindAfterConnect[i];
																				if ( obj && obj.eventName && obj.callback && ! obj.binded ) {
																					obj.binded = true;
																					server.bindOktellEvent(obj.eventName, obj.callback);
																				}
																			}

																			self.trigger('connect');
																		} else {
																			callFunc( oktellOptions.callback, getErrorObj(1207) );
																			self.trigger('connectError', getErrorObj(1207) );
																			disconnect(14);
																		}
																	});
																});
															});
														});
													} else {
														callFunc( oktellOptions.callback, getErrorObj(1209) );
														self.trigger('connectError', getErrorObj(1209) );
														disconnect(14);
													}
												});
											});
										} else {
											callFunc( oktellOptions.callback, getErrorObj(1210) );
											self.trigger('connectError', getErrorObj(1210) );
											disconnect(14);
										}
									});
								} else {
									callFunc( oktellOptions.callback, getErrorObj(1206 ) );
									self.trigger('connectError', getErrorObj(1206) );
									disconnect(11);
								}
							});


						} else {
							callFunc( oktellOptions.callback, getErrorObj(1211) );
							self.trigger('connectError', getErrorObj(1211) );
							disconnect(14);
						}
					});
				});
				server.on('errorConnection', function(data){
					self.trigger('connectError', getErrorObj(1200) );
					callFunc( oktellOptions.callback, getErrorObj(1200) );
				});
				server.on('connectionClose', function(){
					if ( connectionClosedByUser ) {
						connectionClosedByUser = false;
						disconnect(13);
					} else if ( ! loginError ) {
						disconnect(12);
					}
				});
				server.multiConnect();
				if ( debugMode ) {
					oktellInfo.server = server;
				}
			};

			createServer();
		};
		exportApi('connect', connect);

		/**
		 * disconnect from server
		 * @param reason code or reason object
		 * @param silent  - trigger outside 'disconnect' event or not
		 * @return {Boolean}
		 */
		var disconnect = function( reason, silent) {
			oktellConnected(false);
			for (var i = 0; i < nativeEventsForBindAfterConnect.length; i++) {
				var obj = nativeEventsForBindAfterConnect[i];
				obj.binded = false;
			}
			if ( sipPhone && sipPhone.disconnect ) {
				sipPhone.disconnect();
			}
			if ( ! serverConnected() ) {
				if ( typeof reason == 'number' ) {
					reason = getDisconnectReasonObj(reason);
				}
				if ( ! silent ) {
					self.trigger('disconnect', reason);
				}
			} else {
				cookie(cookieSessionName, null);
				localStorage && (delete localStorage[cookieSessionName]);
				connectionClosedByUser = true;
				userStates.state(0);
				phone.state( phone.states.DISCONNECTED );
				sendOktell('logout');
			}

			return true;
		};

		var removeUserSession = function() {
			cookie(cookieSessionName, null);
			return true;
		};
		exportApi('removeUserSession', removeUserSession);

		/**
		 * Chanhe number plan's states
		 */
		userStates.on('userStateChange', function(stateId){
			setTimeout(function(){ phone.loadStates(); }, 400);
			if ( stateId == 5 ) {

			} else if ( stateId == 7 ) {
				phone.state( phone.states.DISCONNECTED );
			} else {
				phone.state( phone.states.READY );
			}
		});

		/**
		 * Subscribe to stuff on login
		 */
		events.on('login', function(){

			server.bindOktellEvent('confcompositionchanged', function(data){
				if ( data.eventinfo.conferenceid == phone.conferenceId() ) {
					phone.setConfAbonentList(data.eventinfo.competitorlist);
					phone.loadStates();
				}
			});

			server.bindOktellEvent('phoneevent_acmcallstarted', function(data){
				phone.loadStates();
			});

			server.bindOktellEvent('phoneevent_acmcallstopped', function(data){
				phone.loadStates();
			});

			server.bindOktellEvent('phoneevent_ringstarted', function(data){
				phone.loadStates(function(result){
					if ( phone.conferenceId() ) {
						phone.loadConferenceInfo();
					}
				}, false);
			});

			server.bindOktellEvent('phoneevent_ringstopped', function(data){
				phone.loadStates();
			});

			server.bindOktellEvent('phoneevent_commstarted', function(data){
				phone.startTalkTimer(0);
				if ( data.isconference ) {
					if ( phone.buildConfFromCommCallback ) {
						phone.isConfCreator(true);
						clearTimeout(phone.buildConfFromCommTimer);
					}
					phone.conferenceId(data.confid);
					phone.loadConferenceInfo(function(){
						phone.loadStates(function(){
							if ( phone.buildConfFromCommCallback ) {
								callFunc(phone.buildConfFromCommCallback, getSuccessObj());
								phone.buildConfFromCommCallback = undefined;
							}
						});
					});
				} else {
					phone.loadStates();
				}
			});

			server.bindOktellEvent('phoneevent_commstopped', function(data){
				phone.clearTalkTimer();
				setTimeout(function(){
					phone.loadStates(function(){});
				}, 700);
			});

			userStates.loadBreakReasons();
		});

		//
		// API
		//

		//self.loadPhoneStates = function(callback){ phone.loadStates(callback); };

		/**
		 * API disconnect from server
		 * @param silent - trigger or not 'disconnect' event
		 * @return {*}
		 */
		self.disconnect = function(silent) {
			return disconnect( 13, silent);
		};

		/**
		 * API get current abonents list
		 * @return {Object}
		 */
		self.getAbonents = function() {
			return phone.getAbonents(true);
		};

		/**
		 * Call
		 * @param number
		 * @param callback
		 */
		self.call = function( number, sequence, callback ) {
			phone.makeCall(number, false, typeof sequence == 'string' ? sequence : '', typeof sequence == 'function' ? sequence : callback);
		};

		/**
		 * API Subscribe to server events
		 * @param eventName
		 * @param callback
		 */
		self.onNativeEvent = function( eventNames, callback) {
			bindOktellEvent(eventNames, callback);
		};

		/**
		 * API Unsubscribe from server events
		 * @param eventName
		 * @param callback
		 */
		self.offNativeEvent = function( eventNames, callback) {
			unbindOktellEvent( eventNames, callback );
		};

		/**
		 * API Get information about current connection and user
		 * @return {*}
		 */
		self.getMyInfo = function() {
			return cloneObject(oktellInfo);
		}

		/**
		 * API Call in intercom mode
		 * @param number
		 * @param callback
		 */
		self.intercom = function( number, callback ) {
			phone.makeCall(number, true, '', callback);
		};

		/**
		 * API Connect for wiretapping, or change mode for existing connection to wiretapping
		 * @param target - phone number or userid
		 * @param callback
		 */
		self.ghostListen = function( target, callback) {
			phone.ghost(target, 'monitor', callback);
		};
		/**
		 * API Connect for help , or change mode for existing connection to help
		 * @param target
		 * @param callback
		 */
		self.ghostHelp = function( target, callback) {
			phone.ghost(target, 'help', callback);
		};
		/**
		 * API Connect in conference mode, or change mode for existing connection to conference
		 * @param target номер телефона или id пользователя
		 * @param callback
		 */
		self.ghostConference = function( target, callback) {
			phone.ghost(target, 'conference', callback);
		};

		/**
		 * API Get users
		 * @return {Object}
		 */
		self.getUsers = function(){
			return users;
		};

		/**
		 * API Get numbers
		 * @return {Object}
		 */
		self.getNumbers = function(){
			return numbers;
		}

		/**
		 * API get lunch reasons
		 */
		self.getLunchReasons = self.getBreakReasons = function() {
			return cloneObject(userStates.breakReasons) || {}
		}

		self.getLog = function() {
			return logStr;
		}

		exportApi('formatPhone', formatPhone, undefined);

		self.inCallCenter = function() {
			return userStates.callCenterState();
		}

		self.webphoneIsActive = function() {
			return sipPnoneActive;
		}

		self.version = '1.5.3';

	};
	extend( Oktell.prototype , Events );

	return Oktell;
})();
window.oktell = new Oktell;
// moment.js
// version : 2.0.0
// author : Tim Wood
// license : MIT
// momentjs.com

(function (undefined) {

	/************************************
	 Constants
	 ************************************/

	var moment,
		VERSION = "2.0.0",
		round = Math.round, i,
	// internal storage for language config files
		languages = {},

	// check for nodeJS
		hasModule = (typeof module !== 'undefined' && module.exports),

	// ASP.NET json date format regex
		aspNetJsonRegex = /^\/?Date\((\-?\d+)/i,

	// format tokens
		formattingTokens = /(\[[^\[]*\])|(\\)?(Mo|MM?M?M?|Do|DDDo|DD?D?D?|ddd?d?|do?|w[o|w]?|W[o|W]?|YYYYY|YYYY|YY|a|A|hh?|HH?|mm?|ss?|SS?S?|X|zz?|ZZ?|.)/g,
		localFormattingTokens = /(\[[^\[]*\])|(\\)?(LT|LL?L?L?|l{1,4})/g,

	// parsing tokens
		parseMultipleFormatChunker = /([0-9a-zA-Z\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF]+)/gi,

	// parsing token regexes
		parseTokenOneOrTwoDigits = /\d\d?/, // 0 - 99
		parseTokenOneToThreeDigits = /\d{1,3}/, // 0 - 999
		parseTokenThreeDigits = /\d{3}/, // 000 - 999
		parseTokenFourDigits = /\d{1,4}/, // 0 - 9999
		parseTokenSixDigits = /[+\-]?\d{1,6}/, // -999,999 - 999,999
		parseTokenWord = /[0-9]*[a-z\u00A0-\u05FF\u0700-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF]+|[\u0600-\u06FF]+\s*?[\u0600-\u06FF]+/i, // any word (or two) characters or numbers including two word month in arabic.
		parseTokenTimezone = /Z|[\+\-]\d\d:?\d\d/i, // +00:00 -00:00 +0000 -0000 or Z
		parseTokenT = /T/i, // T (ISO seperator)
		parseTokenTimestampMs = /[\+\-]?\d+(\.\d{1,3})?/, // 123456789 123456789.123

	// preliminary iso regex
	// 0000-00-00 + T + 00 or 00:00 or 00:00:00 or 00:00:00.000 + +00:00 or +0000
		isoRegex = /^\s*\d{4}-\d\d-\d\d((T| )(\d\d(:\d\d(:\d\d(\.\d\d?\d?)?)?)?)?([\+\-]\d\d:?\d\d)?)?/,
		isoFormat = 'YYYY-MM-DDTHH:mm:ssZ',

	// iso time formats and regexes
		isoTimes = [
			['HH:mm:ss.S', /(T| )\d\d:\d\d:\d\d\.\d{1,3}/],
			['HH:mm:ss', /(T| )\d\d:\d\d:\d\d/],
			['HH:mm', /(T| )\d\d:\d\d/],
			['HH', /(T| )\d\d/]
		],

	// timezone chunker "+10:00" > ["10", "00"] or "-1530" > ["-15", "30"]
		parseTimezoneChunker = /([\+\-]|\d\d)/gi,

	// getter and setter names
		proxyGettersAndSetters = 'Month|Date|Hours|Minutes|Seconds|Milliseconds'.split('|'),
		unitMillisecondFactors = {
			'Milliseconds' : 1,
			'Seconds' : 1e3,
			'Minutes' : 6e4,
			'Hours' : 36e5,
			'Days' : 864e5,
			'Months' : 2592e6,
			'Years' : 31536e6
		},

	// format function strings
		formatFunctions = {},

	// tokens to ordinalize and pad
		ordinalizeTokens = 'DDD w W M D d'.split(' '),
		paddedTokens = 'M D H h m s w W'.split(' '),

		formatTokenFunctions = {
			M    : function () {
				return this.month() + 1;
			},
			MMM  : function (format) {
				return this.lang().monthsShort(this, format);
			},
			MMMM : function (format) {
				return this.lang().months(this, format);
			},
			D    : function () {
				return this.date();
			},
			DDD  : function () {
				return this.dayOfYear();
			},
			d    : function () {
				return this.day();
			},
			dd   : function (format) {
				return this.lang().weekdaysMin(this, format);
			},
			ddd  : function (format) {
				return this.lang().weekdaysShort(this, format);
			},
			dddd : function (format) {
				return this.lang().weekdays(this, format);
			},
			w    : function () {
				return this.week();
			},
			W    : function () {
				return this.isoWeek();
			},
			YY   : function () {
				return leftZeroFill(this.year() % 100, 2);
			},
			YYYY : function () {
				return leftZeroFill(this.year(), 4);
			},
			YYYYY : function () {
				return leftZeroFill(this.year(), 5);
			},
			a    : function () {
				return this.lang().meridiem(this.hours(), this.minutes(), true);
			},
			A    : function () {
				return this.lang().meridiem(this.hours(), this.minutes(), false);
			},
			H    : function () {
				return this.hours();
			},
			h    : function () {
				return this.hours() % 12 || 12;
			},
			m    : function () {
				return this.minutes();
			},
			s    : function () {
				return this.seconds();
			},
			S    : function () {
				return ~~(this.milliseconds() / 100);
			},
			SS   : function () {
				return leftZeroFill(~~(this.milliseconds() / 10), 2);
			},
			SSS  : function () {
				return leftZeroFill(this.milliseconds(), 3);
			},
			Z    : function () {
				var a = -this.zone(),
					b = "+";
				if (a < 0) {
					a = -a;
					b = "-";
				}
				return b + leftZeroFill(~~(a / 60), 2) + ":" + leftZeroFill(~~a % 60, 2);
			},
			ZZ   : function () {
				var a = -this.zone(),
					b = "+";
				if (a < 0) {
					a = -a;
					b = "-";
				}
				return b + leftZeroFill(~~(10 * a / 6), 4);
			},
			X    : function () {
				return this.unix();
			}
		};

	function padToken(func, count) {
		return function (a) {
			return leftZeroFill(func.call(this, a), count);
		};
	}
	function ordinalizeToken(func) {
		return function (a) {
			return this.lang().ordinal(func.call(this, a));
		};
	}

	while (ordinalizeTokens.length) {
		i = ordinalizeTokens.pop();
		formatTokenFunctions[i + 'o'] = ordinalizeToken(formatTokenFunctions[i]);
	}
	while (paddedTokens.length) {
		i = paddedTokens.pop();
		formatTokenFunctions[i + i] = padToken(formatTokenFunctions[i], 2);
	}
	formatTokenFunctions.DDDD = padToken(formatTokenFunctions.DDD, 3);


	/************************************
	 Constructors
	 ************************************/

	function Language() {

	}

	// Moment prototype object
	function Moment(config) {
		extend(this, config);
	}

	// Duration Constructor
	function Duration(duration) {
		var data = this._data = {},
			years = duration.years || duration.year || duration.y || 0,
			months = duration.months || duration.month || duration.M || 0,
			weeks = duration.weeks || duration.week || duration.w || 0,
			days = duration.days || duration.day || duration.d || 0,
			hours = duration.hours || duration.hour || duration.h || 0,
			minutes = duration.minutes || duration.minute || duration.m || 0,
			seconds = duration.seconds || duration.second || duration.s || 0,
			milliseconds = duration.milliseconds || duration.millisecond || duration.ms || 0;

		// representation for dateAddRemove
		this._milliseconds = milliseconds +
			seconds * 1e3 + // 1000
			minutes * 6e4 + // 1000 * 60
			hours * 36e5; // 1000 * 60 * 60
		// Because of dateAddRemove treats 24 hours as different from a
		// day when working around DST, we need to store them separately
		this._days = days +
			weeks * 7;
		// It is impossible translate months into days without knowing
		// which months you are are talking about, so we have to store
		// it separately.
		this._months = months +
			years * 12;

		// The following code bubbles up values, see the tests for
		// examples of what that means.
		data.milliseconds = milliseconds % 1000;
		seconds += absRound(milliseconds / 1000);

		data.seconds = seconds % 60;
		minutes += absRound(seconds / 60);

		data.minutes = minutes % 60;
		hours += absRound(minutes / 60);

		data.hours = hours % 24;
		days += absRound(hours / 24);

		days += weeks * 7;
		data.days = days % 30;

		months += absRound(days / 30);

		data.months = months % 12;
		years += absRound(months / 12);

		data.years = years;
	}


	/************************************
	 Helpers
	 ************************************/


	function extend(a, b) {
		for (var i in b) {
			if (b.hasOwnProperty(i)) {
				a[i] = b[i];
			}
		}
		return a;
	}

	function absRound(number) {
		if (number < 0) {
			return Math.ceil(number);
		} else {
			return Math.floor(number);
		}
	}

	// left zero fill a number
	// see http://jsperf.com/left-zero-filling for performance comparison
	function leftZeroFill(number, targetLength) {
		var output = number + '';
		while (output.length < targetLength) {
			output = '0' + output;
		}
		return output;
	}

	// helper function for _.addTime and _.subtractTime
	function addOrSubtractDurationFromMoment(mom, duration, isAdding) {
		var ms = duration._milliseconds,
			d = duration._days,
			M = duration._months,
			currentDate;

		if (ms) {
			mom._d.setTime(+mom + ms * isAdding);
		}
		if (d) {
			mom.date(mom.date() + d * isAdding);
		}
		if (M) {
			currentDate = mom.date();
			mom.date(1)
				.month(mom.month() + M * isAdding)
				.date(Math.min(currentDate, mom.daysInMonth()));
		}
	}

	// check if is an array
	function isArray(input) {
		return Object.prototype.toString.call(input) === '[object Array]';
	}

	// compare two arrays, return the number of differences
	function compareArrays(array1, array2) {
		var len = Math.min(array1.length, array2.length),
			lengthDiff = Math.abs(array1.length - array2.length),
			diffs = 0,
			i;
		for (i = 0; i < len; i++) {
			if (~~array1[i] !== ~~array2[i]) {
				diffs++;
			}
		}
		return diffs + lengthDiff;
	}


	/************************************
	 Languages
	 ************************************/


	Language.prototype = {
		set : function (config) {
			var prop, i;
			for (i in config) {
				prop = config[i];
				if (typeof prop === 'function') {
					this[i] = prop;
				} else {
					this['_' + i] = prop;
				}
			}
		},

		_months : "January_February_March_April_May_June_July_August_September_October_November_December".split("_"),
		months : function (m) {
			return this._months[m.month()];
		},

		_monthsShort : "Jan_Feb_Mar_Apr_May_Jun_Jul_Aug_Sep_Oct_Nov_Dec".split("_"),
		monthsShort : function (m) {
			return this._monthsShort[m.month()];
		},

		monthsParse : function (monthName) {
			var i, mom, regex, output;

			if (!this._monthsParse) {
				this._monthsParse = [];
			}

			for (i = 0; i < 12; i++) {
				// make the regex if we don't have it already
				if (!this._monthsParse[i]) {
					mom = moment([2000, i]);
					regex = '^' + this.months(mom, '') + '|^' + this.monthsShort(mom, '');
					this._monthsParse[i] = new RegExp(regex.replace('.', ''), 'i');
				}
				// test the regex
				if (this._monthsParse[i].test(monthName)) {
					return i;
				}
			}
		},

		_weekdays : "Sunday_Monday_Tuesday_Wednesday_Thursday_Friday_Saturday".split("_"),
		weekdays : function (m) {
			return this._weekdays[m.day()];
		},

		_weekdaysShort : "Sun_Mon_Tue_Wed_Thu_Fri_Sat".split("_"),
		weekdaysShort : function (m) {
			return this._weekdaysShort[m.day()];
		},

		_weekdaysMin : "Su_Mo_Tu_We_Th_Fr_Sa".split("_"),
		weekdaysMin : function (m) {
			return this._weekdaysMin[m.day()];
		},

		_longDateFormat : {
			LT : "h:mm A",
			L : "MM/DD/YYYY",
			LL : "MMMM D YYYY",
			LLL : "MMMM D YYYY LT",
			LLLL : "dddd, MMMM D YYYY LT"
		},
		longDateFormat : function (key) {
			var output = this._longDateFormat[key];
			if (!output && this._longDateFormat[key.toUpperCase()]) {
				output = this._longDateFormat[key.toUpperCase()].replace(/MMMM|MM|DD|dddd/g, function (val) {
					return val.slice(1);
				});
				this._longDateFormat[key] = output;
			}
			return output;
		},

		meridiem : function (hours, minutes, isLower) {
			if (hours > 11) {
				return isLower ? 'pm' : 'PM';
			} else {
				return isLower ? 'am' : 'AM';
			}
		},

		_calendar : {
			sameDay : '[Today at] LT',
			nextDay : '[Tomorrow at] LT',
			nextWeek : 'dddd [at] LT',
			lastDay : '[Yesterday at] LT',
			lastWeek : '[last] dddd [at] LT',
			sameElse : 'L'
		},
		calendar : function (key, mom) {
			var output = this._calendar[key];
			return typeof output === 'function' ? output.apply(mom) : output;
		},

		_relativeTime : {
			future : "in %s",
			past : "%s ago",
			s : "a few seconds",
			m : "a minute",
			mm : "%d minutes",
			h : "an hour",
			hh : "%d hours",
			d : "a day",
			dd : "%d days",
			M : "a month",
			MM : "%d months",
			y : "a year",
			yy : "%d years"
		},
		relativeTime : function (number, withoutSuffix, string, isFuture) {
			var output = this._relativeTime[string];
			return (typeof output === 'function') ?
				output(number, withoutSuffix, string, isFuture) :
				output.replace(/%d/i, number);
		},
		pastFuture : function (diff, output) {
			var format = this._relativeTime[diff > 0 ? 'future' : 'past'];
			return typeof format === 'function' ? format(output) : format.replace(/%s/i, output);
		},

		ordinal : function (number) {
			return this._ordinal.replace("%d", number);
		},
		_ordinal : "%d",

		preparse : function (string) {
			return string;
		},

		postformat : function (string) {
			return string;
		},

		week : function (mom) {
			return weekOfYear(mom, this._week.dow, this._week.doy);
		},
		_week : {
			dow : 0, // Sunday is the first day of the week.
			doy : 6  // The week that contains Jan 1st is the first week of the year.
		}
	};

	// Loads a language definition into the `languages` cache.  The function
	// takes a key and optionally values.  If not in the browser and no values
	// are provided, it will load the language file module.  As a convenience,
	// this function also returns the language values.
	function loadLang(key, values) {
		values.abbr = key;
		if (!languages[key]) {
			languages[key] = new Language();
		}
		languages[key].set(values);
		return languages[key];
	}

	// Determines which language definition to use and returns it.
	//
	// With no parameters, it will return the global language.  If you
	// pass in a language key, such as 'en', it will return the
	// definition for 'en', so long as 'en' has already been loaded using
	// moment.lang.
	function getLangDefinition(key) {
		if (!key) {
			return moment.fn._lang;
		}
		if (!languages[key] && hasModule) {
			require('./lang/' + key);
		}
		return languages[key];
	}


	/************************************
	 Formatting
	 ************************************/


	function removeFormattingTokens(input) {
		if (input.match(/\[.*\]/)) {
			return input.replace(/^\[|\]$/g, "");
		}
		return input.replace(/\\/g, "");
	}

	function makeFormatFunction(format) {
		var array = format.match(formattingTokens), i, length;

		for (i = 0, length = array.length; i < length; i++) {
			if (formatTokenFunctions[array[i]]) {
				array[i] = formatTokenFunctions[array[i]];
			} else {
				array[i] = removeFormattingTokens(array[i]);
			}
		}

		return function (mom) {
			var output = "";
			for (i = 0; i < length; i++) {
				output += typeof array[i].call === 'function' ? array[i].call(mom, format) : array[i];
			}
			return output;
		};
	}

	// format date using native date object
	function formatMoment(m, format) {
		var i = 5;

		function replaceLongDateFormatTokens(input) {
			return m.lang().longDateFormat(input) || input;
		}

		while (i-- && localFormattingTokens.test(format)) {
			format = format.replace(localFormattingTokens, replaceLongDateFormatTokens);
		}

		if (!formatFunctions[format]) {
			formatFunctions[format] = makeFormatFunction(format);
		}

		return formatFunctions[format](m);
	}


	/************************************
	 Parsing
	 ************************************/


		// get the regex to find the next token
	function getParseRegexForToken(token) {
		switch (token) {
			case 'DDDD':
				return parseTokenThreeDigits;
			case 'YYYY':
				return parseTokenFourDigits;
			case 'YYYYY':
				return parseTokenSixDigits;
			case 'S':
			case 'SS':
			case 'SSS':
			case 'DDD':
				return parseTokenOneToThreeDigits;
			case 'MMM':
			case 'MMMM':
			case 'dd':
			case 'ddd':
			case 'dddd':
			case 'a':
			case 'A':
				return parseTokenWord;
			case 'X':
				return parseTokenTimestampMs;
			case 'Z':
			case 'ZZ':
				return parseTokenTimezone;
			case 'T':
				return parseTokenT;
			case 'MM':
			case 'DD':
			case 'YY':
			case 'HH':
			case 'hh':
			case 'mm':
			case 'ss':
			case 'M':
			case 'D':
			case 'd':
			case 'H':
			case 'h':
			case 'm':
			case 's':
				return parseTokenOneOrTwoDigits;
			default :
				return new RegExp(token.replace('\\', ''));
		}
	}

	// function to convert string input to date
	function addTimeToArrayFromToken(token, input, config) {
		var a, b,
			datePartArray = config._a;

		switch (token) {
			// MONTH
			case 'M' : // fall through to MM
			case 'MM' :
				datePartArray[1] = (input == null) ? 0 : ~~input - 1;
				break;
			case 'MMM' : // fall through to MMMM
			case 'MMMM' :
				a = getLangDefinition(config._l).monthsParse(input);
				// if we didn't find a month name, mark the date as invalid.
				if (a != null) {
					datePartArray[1] = a;
				} else {
					config._isValid = false;
				}
				break;
			// DAY OF MONTH
			case 'D' : // fall through to DDDD
			case 'DD' : // fall through to DDDD
			case 'DDD' : // fall through to DDDD
			case 'DDDD' :
				if (input != null) {
					datePartArray[2] = ~~input;
				}
				break;
			// YEAR
			case 'YY' :
				datePartArray[0] = ~~input + (~~input > 68 ? 1900 : 2000);
				break;
			case 'YYYY' :
			case 'YYYYY' :
				datePartArray[0] = ~~input;
				break;
			// AM / PM
			case 'a' : // fall through to A
			case 'A' :
				config._isPm = ((input + '').toLowerCase() === 'pm');
				break;
			// 24 HOUR
			case 'H' : // fall through to hh
			case 'HH' : // fall through to hh
			case 'h' : // fall through to hh
			case 'hh' :
				datePartArray[3] = ~~input;
				break;
			// MINUTE
			case 'm' : // fall through to mm
			case 'mm' :
				datePartArray[4] = ~~input;
				break;
			// SECOND
			case 's' : // fall through to ss
			case 'ss' :
				datePartArray[5] = ~~input;
				break;
			// MILLISECOND
			case 'S' :
			case 'SS' :
			case 'SSS' :
				datePartArray[6] = ~~ (('0.' + input) * 1000);
				break;
			// UNIX TIMESTAMP WITH MS
			case 'X':
				config._d = new Date(parseFloat(input) * 1000);
				break;
			// TIMEZONE
			case 'Z' : // fall through to ZZ
			case 'ZZ' :
				config._useUTC = true;
				a = (input + '').match(parseTimezoneChunker);
				if (a && a[1]) {
					config._tzh = ~~a[1];
				}
				if (a && a[2]) {
					config._tzm = ~~a[2];
				}
				// reverse offsets
				if (a && a[0] === '+') {
					config._tzh = -config._tzh;
					config._tzm = -config._tzm;
				}
				break;
		}

		// if the input is null, the date is not valid
		if (input == null) {
			config._isValid = false;
		}
	}

	// convert an array to a date.
	// the array should mirror the parameters below
	// note: all values past the year are optional and will default to the lowest possible value.
	// [year, month, day , hour, minute, second, millisecond]
	function dateFromArray(config) {
		var i, date, input = [];

		if (config._d) {
			return;
		}

		for (i = 0; i < 7; i++) {
			config._a[i] = input[i] = (config._a[i] == null) ? (i === 2 ? 1 : 0) : config._a[i];
		}

		// add the offsets to the time to be parsed so that we can have a clean array for checking isValid
		input[3] += config._tzh || 0;
		input[4] += config._tzm || 0;

		date = new Date(0);

		if (config._useUTC) {
			date.setUTCFullYear(input[0], input[1], input[2]);
			date.setUTCHours(input[3], input[4], input[5], input[6]);
		} else {
			date.setFullYear(input[0], input[1], input[2]);
			date.setHours(input[3], input[4], input[5], input[6]);
		}

		config._d = date;
	}

	// date from string and format string
	function makeDateFromStringAndFormat(config) {
		// This array is used to make a Date, either with `new Date` or `Date.UTC`
		var tokens = config._f.match(formattingTokens),
			string = config._i,
			i, parsedInput;

		config._a = [];

		for (i = 0; i < tokens.length; i++) {
			parsedInput = (getParseRegexForToken(tokens[i]).exec(string) || [])[0];
			if (parsedInput) {
				string = string.slice(string.indexOf(parsedInput) + parsedInput.length);
			}
			// don't parse if its not a known token
			if (formatTokenFunctions[tokens[i]]) {
				addTimeToArrayFromToken(tokens[i], parsedInput, config);
			}
		}
		// handle am pm
		if (config._isPm && config._a[3] < 12) {
			config._a[3] += 12;
		}
		// if is 12 am, change hours to 0
		if (config._isPm === false && config._a[3] === 12) {
			config._a[3] = 0;
		}
		// return
		dateFromArray(config);
	}

	// date from string and array of format strings
	function makeDateFromStringAndArray(config) {
		var tempConfig,
			tempMoment,
			bestMoment,

			scoreToBeat = 99,
			i,
			currentDate,
			currentScore;

		while (config._f.length) {
			tempConfig = extend({}, config);
			tempConfig._f = config._f.pop();
			makeDateFromStringAndFormat(tempConfig);
			tempMoment = new Moment(tempConfig);

			if (tempMoment.isValid()) {
				bestMoment = tempMoment;
				break;
			}

			currentScore = compareArrays(tempConfig._a, tempMoment.toArray());

			if (currentScore < scoreToBeat) {
				scoreToBeat = currentScore;
				bestMoment = tempMoment;
			}
		}

		extend(config, bestMoment);
	}

	// date from iso format
	function makeDateFromString(config) {
		var i,
			string = config._i;
		if (isoRegex.exec(string)) {
			config._f = 'YYYY-MM-DDT';
			for (i = 0; i < 4; i++) {
				if (isoTimes[i][1].exec(string)) {
					config._f += isoTimes[i][0];
					break;
				}
			}
			if (parseTokenTimezone.exec(string)) {
				config._f += " Z";
			}
			makeDateFromStringAndFormat(config);
		} else {
			config._d = new Date(string);
		}
	}

	function makeDateFromInput(config) {
		var input = config._i,
			matched = aspNetJsonRegex.exec(input);

		if (input === undefined) {
			config._d = new Date();
		} else if (matched) {
			config._d = new Date(+matched[1]);
		} else if (typeof input === 'string') {
			makeDateFromString(config);
		} else if (isArray(input)) {
			config._a = input.slice(0);
			dateFromArray(config);
		} else {
			config._d = input instanceof Date ? new Date(+input) : new Date(input);
		}
	}


	/************************************
	 Relative Time
	 ************************************/


		// helper function for moment.fn.from, moment.fn.fromNow, and moment.duration.fn.humanize
	function substituteTimeAgo(string, number, withoutSuffix, isFuture, lang) {
		return lang.relativeTime(number || 1, !!withoutSuffix, string, isFuture);
	}

	function relativeTime(milliseconds, withoutSuffix, lang) {
		var seconds = round(Math.abs(milliseconds) / 1000),
			minutes = round(seconds / 60),
			hours = round(minutes / 60),
			days = round(hours / 24),
			years = round(days / 365),
			args = seconds < 45 && ['s', seconds] ||
				minutes === 1 && ['m'] ||
				minutes < 45 && ['mm', minutes] ||
				hours === 1 && ['h'] ||
				hours < 22 && ['hh', hours] ||
				days === 1 && ['d'] ||
				days <= 25 && ['dd', days] ||
				days <= 45 && ['M'] ||
				days < 345 && ['MM', round(days / 30)] ||
				years === 1 && ['y'] || ['yy', years];
		args[2] = withoutSuffix;
		args[3] = milliseconds > 0;
		args[4] = lang;
		return substituteTimeAgo.apply({}, args);
	}


	/************************************
	 Week of Year
	 ************************************/


		// firstDayOfWeek       0 = sun, 6 = sat
		//                      the day of the week that starts the week
		//                      (usually sunday or monday)
		// firstDayOfWeekOfYear 0 = sun, 6 = sat
		//                      the first week is the week that contains the first
		//                      of this day of the week
		//                      (eg. ISO weeks use thursday (4))
	function weekOfYear(mom, firstDayOfWeek, firstDayOfWeekOfYear) {
		var end = firstDayOfWeekOfYear - firstDayOfWeek,
			daysToDayOfWeek = firstDayOfWeekOfYear - mom.day();


		if (daysToDayOfWeek > end) {
			daysToDayOfWeek -= 7;
		}

		if (daysToDayOfWeek < end - 7) {
			daysToDayOfWeek += 7;
		}

		return Math.ceil(moment(mom).add('d', daysToDayOfWeek).dayOfYear() / 7);
	}


	/************************************
	 Top Level Functions
	 ************************************/

	function makeMoment(config) {
		var input = config._i,
			format = config._f;

		if (input === null || input === '') {
			return null;
		}

		if (typeof input === 'string') {
			config._i = input = getLangDefinition().preparse(input);
		}

		if (moment.isMoment(input)) {
			config = extend({}, input);
			config._d = new Date(+input._d);
		} else if (format) {
			if (isArray(format)) {
				makeDateFromStringAndArray(config);
			} else {
				makeDateFromStringAndFormat(config);
			}
		} else {
			makeDateFromInput(config);
		}

		return new Moment(config);
	}

	moment = function (input, format, lang) {
		return makeMoment({
			_i : input,
			_f : format,
			_l : lang,
			_isUTC : false
		});
	};

	// creating with utc
	moment.utc = function (input, format, lang) {
		return makeMoment({
			_useUTC : true,
			_isUTC : true,
			_l : lang,
			_i : input,
			_f : format
		});
	};

	// creating with unix timestamp (in seconds)
	moment.unix = function (input) {
		return moment(input * 1000);
	};

	// duration
	moment.duration = function (input, key) {
		var isDuration = moment.isDuration(input),
			isNumber = (typeof input === 'number'),
			duration = (isDuration ? input._data : (isNumber ? {} : input)),
			ret;

		if (isNumber) {
			if (key) {
				duration[key] = input;
			} else {
				duration.milliseconds = input;
			}
		}

		ret = new Duration(duration);

		if (isDuration && input.hasOwnProperty('_lang')) {
			ret._lang = input._lang;
		}

		return ret;
	};

	// version number
	moment.version = VERSION;

	// default format
	moment.defaultFormat = isoFormat;

	// This function will load languages and then set the global language.  If
	// no arguments are passed in, it will simply return the current global
	// language key.
	moment.lang = function (key, values) {
		var i;

		if (!key) {
			return moment.fn._lang._abbr;
		}
		if (values) {
			loadLang(key, values);
		} else if (!languages[key]) {
			getLangDefinition(key);
		}
		moment.duration.fn._lang = moment.fn._lang = getLangDefinition(key);
	};

	// returns language data
	moment.langData = function (key) {
		if (key && key._lang && key._lang._abbr) {
			key = key._lang._abbr;
		}
		return getLangDefinition(key);
	};

	// compare moment object
	moment.isMoment = function (obj) {
		return obj instanceof Moment;
	};

	// for typechecking Duration objects
	moment.isDuration = function (obj) {
		return obj instanceof Duration;
	};


	/************************************
	 Moment Prototype
	 ************************************/


	moment.fn = Moment.prototype = {

		clone : function () {
			return moment(this);
		},

		valueOf : function () {
			return +this._d;
		},

		unix : function () {
			return Math.floor(+this._d / 1000);
		},

		toString : function () {
			return this.format("ddd MMM DD YYYY HH:mm:ss [GMT]ZZ");
		},

		toDate : function () {
			return this._d;
		},

		toJSON : function () {
			return moment.utc(this).format('YYYY-MM-DD[T]HH:mm:ss.SSS[Z]');
		},

		toArray : function () {
			var m = this;
			return [
				m.year(),
				m.month(),
				m.date(),
				m.hours(),
				m.minutes(),
				m.seconds(),
				m.milliseconds()
			];
		},

		isValid : function () {
			if (this._isValid == null) {
				if (this._a) {
					this._isValid = !compareArrays(this._a, (this._isUTC ? moment.utc(this._a) : moment(this._a)).toArray());
				} else {
					this._isValid = !isNaN(this._d.getTime());
				}
			}
			return !!this._isValid;
		},

		utc : function () {
			this._isUTC = true;
			return this;
		},

		local : function () {
			this._isUTC = false;
			return this;
		},

		format : function (inputString) {
			var output = formatMoment(this, inputString || moment.defaultFormat);
			return this.lang().postformat(output);
		},

		add : function (input, val) {
			var dur;
			// switch args to support add('s', 1) and add(1, 's')
			if (typeof input === 'string') {
				dur = moment.duration(+val, input);
			} else {
				dur = moment.duration(input, val);
			}
			addOrSubtractDurationFromMoment(this, dur, 1);
			return this;
		},

		subtract : function (input, val) {
			var dur;
			// switch args to support subtract('s', 1) and subtract(1, 's')
			if (typeof input === 'string') {
				dur = moment.duration(+val, input);
			} else {
				dur = moment.duration(input, val);
			}
			addOrSubtractDurationFromMoment(this, dur, -1);
			return this;
		},

		diff : function (input, units, asFloat) {
			var that = this._isUTC ? moment(input).utc() : moment(input).local(),
				zoneDiff = (this.zone() - that.zone()) * 6e4,
				diff, output;

			if (units) {
				// standardize on singular form
				units = units.replace(/s$/, '');
			}

			if (units === 'year' || units === 'month') {
				diff = (this.daysInMonth() + that.daysInMonth()) * 432e5; // 24 * 60 * 60 * 1000 / 2
				output = ((this.year() - that.year()) * 12) + (this.month() - that.month());
				output += ((this - moment(this).startOf('month')) - (that - moment(that).startOf('month'))) / diff;
				if (units === 'year') {
					output = output / 12;
				}
			} else {
				diff = (this - that) - zoneDiff;
				output = units === 'second' ? diff / 1e3 : // 1000
					units === 'minute' ? diff / 6e4 : // 1000 * 60
						units === 'hour' ? diff / 36e5 : // 1000 * 60 * 60
							units === 'day' ? diff / 864e5 : // 1000 * 60 * 60 * 24
								units === 'week' ? diff / 6048e5 : // 1000 * 60 * 60 * 24 * 7
									diff;
			}
			return asFloat ? output : absRound(output);
		},

		from : function (time, withoutSuffix) {
			return moment.duration(this.diff(time)).lang(this.lang()._abbr).humanize(!withoutSuffix);
		},

		fromNow : function (withoutSuffix) {
			return this.from(moment(), withoutSuffix);
		},

		calendar : function () {
			var diff = this.diff(moment().startOf('day'), 'days', true),
				format = diff < -6 ? 'sameElse' :
					diff < -1 ? 'lastWeek' :
						diff < 0 ? 'lastDay' :
							diff < 1 ? 'sameDay' :
								diff < 2 ? 'nextDay' :
									diff < 7 ? 'nextWeek' : 'sameElse';
			return this.format(this.lang().calendar(format, this));
		},

		isLeapYear : function () {
			var year = this.year();
			return (year % 4 === 0 && year % 100 !== 0) || year % 400 === 0;
		},

		isDST : function () {
			return (this.zone() < moment([this.year()]).zone() ||
				this.zone() < moment([this.year(), 5]).zone());
		},

		day : function (input) {
			var day = this._isUTC ? this._d.getUTCDay() : this._d.getDay();
			return input == null ? day :
				this.add({ d : input - day });
		},

		startOf: function (units) {
			units = units.replace(/s$/, '');
			// the following switch intentionally omits break keywords
			// to utilize falling through the cases.
			switch (units) {
				case 'year':
					this.month(0);
				/* falls through */
				case 'month':
					this.date(1);
				/* falls through */
				case 'week':
				case 'day':
					this.hours(0);
				/* falls through */
				case 'hour':
					this.minutes(0);
				/* falls through */
				case 'minute':
					this.seconds(0);
				/* falls through */
				case 'second':
					this.milliseconds(0);
				/* falls through */
			}

			// weeks are a special case
			if (units === 'week') {
				this.day(0);
			}

			return this;
		},

		endOf: function (units) {
			return this.startOf(units).add(units.replace(/s?$/, 's'), 1).subtract('ms', 1);
		},

		isAfter: function (input, units) {
			units = typeof units !== 'undefined' ? units : 'millisecond';
			return +this.clone().startOf(units) > +moment(input).startOf(units);
		},

		isBefore: function (input, units) {
			units = typeof units !== 'undefined' ? units : 'millisecond';
			return +this.clone().startOf(units) < +moment(input).startOf(units);
		},

		isSame: function (input, units) {
			units = typeof units !== 'undefined' ? units : 'millisecond';
			return +this.clone().startOf(units) === +moment(input).startOf(units);
		},

		zone : function () {
			return this._isUTC ? 0 : this._d.getTimezoneOffset();
		},

		daysInMonth : function () {
			return moment.utc([this.year(), this.month() + 1, 0]).date();
		},

		dayOfYear : function (input) {
			var dayOfYear = round((moment(this).startOf('day') - moment(this).startOf('year')) / 864e5) + 1;
			return input == null ? dayOfYear : this.add("d", (input - dayOfYear));
		},

		isoWeek : function (input) {
			var week = weekOfYear(this, 1, 4);
			return input == null ? week : this.add("d", (input - week) * 7);
		},

		week : function (input) {
			var week = this.lang().week(this);
			return input == null ? week : this.add("d", (input - week) * 7);
		},

		// If passed a language key, it will set the language for this
		// instance.  Otherwise, it will return the language configuration
		// variables for this instance.
		lang : function (key) {
			if (key === undefined) {
				return this._lang;
			} else {
				this._lang = getLangDefinition(key);
				return this;
			}
		}
	};

	// helper for adding shortcuts
	function makeGetterAndSetter(name, key) {
		moment.fn[name] = moment.fn[name + 's'] = function (input) {
			var utc = this._isUTC ? 'UTC' : '';
			if (input != null) {
				this._d['set' + utc + key](input);
				return this;
			} else {
				return this._d['get' + utc + key]();
			}
		};
	}

	// loop through and add shortcuts (Month, Date, Hours, Minutes, Seconds, Milliseconds)
	for (i = 0; i < proxyGettersAndSetters.length; i ++) {
		makeGetterAndSetter(proxyGettersAndSetters[i].toLowerCase().replace(/s$/, ''), proxyGettersAndSetters[i]);
	}

	// add shortcut for year (uses different syntax than the getter/setter 'year' == 'FullYear')
	makeGetterAndSetter('year', 'FullYear');

	// add plural methods
	moment.fn.days = moment.fn.day;
	moment.fn.weeks = moment.fn.week;
	moment.fn.isoWeeks = moment.fn.isoWeek;

	/************************************
	 Duration Prototype
	 ************************************/


	moment.duration.fn = Duration.prototype = {
		weeks : function () {
			return absRound(this.days() / 7);
		},

		valueOf : function () {
			return this._milliseconds +
				this._days * 864e5 +
				this._months * 2592e6;
		},

		humanize : function (withSuffix) {
			var difference = +this,
				output = relativeTime(difference, !withSuffix, this.lang());

			if (withSuffix) {
				output = this.lang().pastFuture(difference, output);
			}

			return this.lang().postformat(output);
		},

		lang : moment.fn.lang
	};

	function makeDurationGetter(name) {
		moment.duration.fn[name] = function () {
			return this._data[name];
		};
	}

	function makeDurationAsGetter(name, factor) {
		moment.duration.fn['as' + name] = function () {
			return +this / factor;
		};
	}

	for (i in unitMillisecondFactors) {
		if (unitMillisecondFactors.hasOwnProperty(i)) {
			makeDurationAsGetter(i, unitMillisecondFactors[i]);
			makeDurationGetter(i.toLowerCase());
		}
	}

	makeDurationAsGetter('Weeks', 6048e5);


	/************************************
	 Default Lang
	 ************************************/


		// Set default language, other languages will inherit from English.
	moment.lang('en', {
		ordinal : function (number) {
			var b = number % 10,
				output = (~~ (number % 100 / 10) === 1) ? 'th' :
					(b === 1) ? 'st' :
						(b === 2) ? 'nd' :
							(b === 3) ? 'rd' : 'th';
			return number + output;
		}
	});


	/************************************
	 Exposing Moment
	 ************************************/


	// CommonJS module is defined
	if (hasModule) {
		module.exports = moment;
	}
	/*global ender:false */
	if (typeof ender === 'undefined') {
		// here, `this` means `window` in the browser, or `global` on the server
		// add `moment` as a global object via a string identifier,
		// for Closure Compiler "advanced" mode
		this['moment'] = moment;
	}
	/*global define:false */
	if (typeof define === "function" && define.amd) {
		define("moment", [], function () {
			return moment;
		});
	}
}).call(this);
try {
	if ( global && global._ ) {
		window._ = global._;
	}
} catch (e) {}

var log = function() {
	try{
		console.log.apply(console, arguments);
	} catch(e) {

	}
}

var logGroups = {}

var addLogGroup = function(group, css) {

	logGroups[group] = css

}

var logGroup = function(group) {

	if ( ! group && ! logGroups[group] ) {
		return log.apply(window,arguments);
	}

	var args = [ '%c'+group, logGroups[group] ].concat(Array.prototype.slice.call(arguments,1));
	return log.apply(window, args)

}

var callFunc = function(callback) {
	if ( typeof callback == 'function' ) {
		callback.apply(this, Array.prototype.slice.call( arguments, 1 ) );
	}
}


//var eventSplitter = /\s+/;
//var Events = {
//
//	// Bind one or more space separated events, `events`, to a `callback`
//	// function. Passing `"all"` will bind the callback to all events fired.
//	on: function(events, callback, context) {
//
//		var calls, event, node, tail, list;
//		if (!callback) return this;
//		events = events.split(eventSplitter);
//		calls = this._callbacks || (this._callbacks = {});
//
//		// Create an immutable callback list, allowing traversal during
//		// modification.  The tail is an empty object that will always be used
//		// as the next node.
//		while (event = events.shift()) {
//			list = calls[event];
//			node = list ? list.tail : {};
//			node.next = tail = {};
//			node.context = context;
//			node.callback = callback;
//			calls[event] = {tail: tail, next: list ? list.next : node};
//		}
//
//		return this;
//	},
//
//	// Remove one or many callbacks. If `context` is null, removes all callbacks
//	// with that function. If `callback` is null, removes all callbacks for the
//	// event. If `events` is null, removes all bound callbacks for all events.
//	off: function(events, callback, context) {
//		var event, calls, node, tail, cb, ctx;
//
//		// No events, or removing *all* events.
//		if (!(calls = this._callbacks)) return;
//		if (!(events || callback || context)) {
//			delete this._callbacks;
//			return this;
//		}
//
//		// Loop through the listed events and contexts, splicing them out of the
//		// linked list of callbacks if appropriate.
//		events = events ? events.split(eventSplitter) : _.keys(calls);
//		while (event = events.shift()) {
//			node = calls[event];
//			delete calls[event];
//			if (!node || !(callback || context)) continue;
//			// Create a new list, omitting the indicated callbacks.
//			tail = node.tail;
//			while ((node = node.next) !== tail) {
//				cb = node.callback;
//				ctx = node.context;
//				if ((callback && cb !== callback) || (context && ctx !== context)) {
//					this.on(event, cb, ctx);
//				}
//			}
//		}
//
//		return this;
//	},
//
//	// Trigger one or many events, firing all bound callbacks. Callbacks are
//	// passed the same arguments as `trigger` is, apart from the event name
//	// (unless you're listening on `"all"`, which will cause your callback to
//	// receive the true name of the event as the first argument).
//	trigger: function(events) {
//		var event, node, calls, tail, args, all, rest;
//		if (!(calls = this._callbacks)) return this;
//		all = calls.all;
//		events = events.split(eventSplitter);
//		rest = Array.prototype.slice.call(arguments, 1);
//
//		// For each event, walk through the linked list of callbacks twice,
//		// first to trigger the event, then to trigger any `"all"` callbacks.
//		while (event = events.shift()) {
//			if (node = calls[event]) {
//				tail = node.tail;
//				while ((node = node.next) !== tail) {
//					node.callback.apply(node.context || this, rest);
//				}
//			}
//			if (node = all) {
//				tail = node.tail;
//				args = [event].concat(rest);
//				while ((node = node.next) !== tail) {
//					node.callback.apply(node.context || this, args);
//				}
//			}
//		}
//
//		return this;
//	}
//
//};

// Backbone.Events
// ---------------

// Regular expression used to split event strings.
var eventSplitter = /\s+/;

// Implement fancy features of the Events API such as multiple event
// names `"change blur"` and jQuery-style event maps `{change: action}`
// in terms of the existing API.
var eventsApi = function(obj, action, name, rest) {
	if (!name) return true;
	if (typeof name === 'object') {
		for (var key in name) {
			obj[action].apply(obj, [key, name[key]].concat(rest));
		}
	} else if (eventSplitter.test(name)) {
		var names = name.split(eventSplitter);
		for (var i = 0, l = names.length; i < l; i++) {
			obj[action].apply(obj, [names[i]].concat(rest));
		}
	} else {
		return true;
	}
};

// Optimized internal dispatch function for triggering events. Tries to
// keep the usual cases speedy (most Backbone events have 3 arguments).
var triggerEvents = function(events, args) {
	var ev, i = -1, l = events.length;
	switch (args.length) {
		case 0: while (++i < l) (ev = events[i]).callback.call(ev.ctx);
			return;
		case 1: while (++i < l) (ev = events[i]).callback.call(ev.ctx, args[0]);
			return;
		case 2: while (++i < l) (ev = events[i]).callback.call(ev.ctx, args[0], args[1]);
			return;
		case 3: while (++i < l) (ev = events[i]).callback.call(ev.ctx, args[0], args[1], args[2]);
			return;
		default: while (++i < l) (ev = events[i]).callback.apply(ev.ctx, args);
	}
};

// A module that can be mixed in to *any object* in order to provide it with
// custom events. You may bind with `on` or remove with `off` callback
// functions to an event; `trigger`-ing an event fires all callbacks in
// succession.
//
//     var object = {};
//     _.extend(object, Backbone.Events);
//     object.on('expand', function(){ alert('expanded'); });
//     object.trigger('expand');
//
var Events = {

	// Bind one or more space separated events, or an events map,
	// to a `callback` function. Passing `"all"` will bind the callback to
	// all events fired.
	on: function(name, callback, context) {
		if (!(eventsApi(this, 'on', name, [callback, context]) && callback)) return this;
		this._events || (this._events = {});
		var list = this._events[name] || (this._events[name] = []);
		list.push({callback: callback, context: context, ctx: context || this});
		return this;
	},

	// Bind events to only be triggered a single time. After the first time
	// the callback is invoked, it will be removed.
	once: function(name, callback, context) {
		if (!(eventsApi(this, 'once', name, [callback, context]) && callback)) return this;
		var self = this;
		var once = _.once(function() {
			self.off(name, once);
			callback.apply(this, arguments);
		});
		once._callback = callback;
		this.on(name, once, context);
		return this;
	},

	// Remove one or many callbacks. If `context` is null, removes all
	// callbacks with that function. If `callback` is null, removes all
	// callbacks for the event. If `name` is null, removes all bound
	// callbacks for all events.
	off: function(name, callback, context) {
		var list, ev, events, names, i, l, j, k;
		if (!this._events || !eventsApi(this, 'off', name, [callback, context])) return this;
		if (!name && !callback && !context) {
			this._events = {};
			return this;
		}

		names = name ? [name] : _.keys(this._events);
		for (i = 0, l = names.length; i < l; i++) {
			name = names[i];
			if (list = this._events[name]) {
				events = [];
				if (callback || context) {
					for (j = 0, k = list.length; j < k; j++) {
						ev = list[j];
						if ((callback && callback !== ev.callback &&
							callback !== ev.callback._callback) ||
							(context && context !== ev.context)) {
							events.push(ev);
						}
					}
				}
				this._events[name] = events;
			}
		}

		return this;
	},

	// Trigger one or many events, firing all bound callbacks. Callbacks are
	// passed the same arguments as `trigger` is, apart from the event name
	// (unless you're listening on `"all"`, which will cause your callback to
	// receive the true name of the event as the first argument).
	trigger: function(name) {
		if (!this._events) return this;
		var args = Array.prototype.slice.call(arguments, 1);
		if (!eventsApi(this, 'trigger', name, args)) return this;
		var events = this._events[name];
		var allEvents = this._events.all;
		if (events) triggerEvents(events, args);
		if (allEvents) triggerEvents(allEvents, arguments);
		return this;
	},

	// An inversion-of-control version of `on`. Tell *this* object to listen to
	// an event in another object ... keeping track of what it's listening to.
	listenTo: function(obj, name, callback) {
		var listeners = this._listeners || (this._listeners = {});
		var id = obj._listenerId || (obj._listenerId = _.uniqueId('l'));
		listeners[id] = obj;
		obj.on(name, typeof name === 'object' ? this : callback, this);
		return this;
	},

	// Tell this object to stop listening to either specific events ... or
	// to every object it's currently listening to.
	stopListening: function(obj, name, callback) {
		var listeners = this._listeners;
		if (!listeners) return;
		if (obj) {
			obj.off(name, typeof name === 'object' ? this : callback, this);
			if (!name && !callback) delete listeners[obj._listenerId];
		} else {
			if (typeof name === 'object') callback = this;
			for (var id in listeners) {
				listeners[id].off(name, callback, this);
			}
			this._listeners = {};
		}
		return this;
	}
};



var md5 = function (str) {
	var xl;

	var rotateLeft = function (lValue, iShiftBits) {
		return (lValue << iShiftBits) | (lValue >>> (32 - iShiftBits));
	};

	var addUnsigned = function (lX, lY) {
		var lX4, lY4, lX8, lY8, lResult;
		lX8 = (lX & 0x80000000);
		lY8 = (lY & 0x80000000);
		lX4 = (lX & 0x40000000);
		lY4 = (lY & 0x40000000);
		lResult = (lX & 0x3FFFFFFF) + (lY & 0x3FFFFFFF);
		if (lX4 & lY4) {
			return (lResult ^ 0x80000000 ^ lX8 ^ lY8);
		}
		if (lX4 | lY4) {
			if (lResult & 0x40000000) {
				return (lResult ^ 0xC0000000 ^ lX8 ^ lY8);
			} else {
				return (lResult ^ 0x40000000 ^ lX8 ^ lY8);
			}
		} else {
			return (lResult ^ lX8 ^ lY8);
		}
	};

	var _F = function (x, y, z) {
		return (x & y) | ((~x) & z);
	};
	var _G = function (x, y, z) {
		return (x & z) | (y & (~z));
	};
	var _H = function (x, y, z) {
		return (x ^ y ^ z);
	};
	var _I = function (x, y, z) {
		return (y ^ (x | (~z)));
	};

	var _FF = function (a, b, c, d, x, s, ac) {
		a = addUnsigned(a, addUnsigned(addUnsigned(_F(b, c, d), x), ac));
		return addUnsigned(rotateLeft(a, s), b);
	};

	var _GG = function (a, b, c, d, x, s, ac) {
		a = addUnsigned(a, addUnsigned(addUnsigned(_G(b, c, d), x), ac));
		return addUnsigned(rotateLeft(a, s), b);
	};

	var _HH = function (a, b, c, d, x, s, ac) {
		a = addUnsigned(a, addUnsigned(addUnsigned(_H(b, c, d), x), ac));
		return addUnsigned(rotateLeft(a, s), b);
	};

	var _II = function (a, b, c, d, x, s, ac) {
		a = addUnsigned(a, addUnsigned(addUnsigned(_I(b, c, d), x), ac));
		return addUnsigned(rotateLeft(a, s), b);
	};

	var convertToWordArray = function (str) {
		var lWordCount;
		var lMessageLength = str.length;
		var lNumberOfWords_temp1 = lMessageLength + 8;
		var lNumberOfWords_temp2 = (lNumberOfWords_temp1 - (lNumberOfWords_temp1 % 64)) / 64;
		var lNumberOfWords = (lNumberOfWords_temp2 + 1) * 16;
		var lWordArray = new Array(lNumberOfWords - 1);
		var lBytePosition = 0;
		var lByteCount = 0;
		while (lByteCount < lMessageLength) {
			lWordCount = (lByteCount - (lByteCount % 4)) / 4;
			lBytePosition = (lByteCount % 4) * 8;
			lWordArray[lWordCount] = (lWordArray[lWordCount] | (str.charCodeAt(lByteCount) << lBytePosition));
			lByteCount++;
		}
		lWordCount = (lByteCount - (lByteCount % 4)) / 4;
		lBytePosition = (lByteCount % 4) * 8;
		lWordArray[lWordCount] = lWordArray[lWordCount] | (0x80 << lBytePosition);
		lWordArray[lNumberOfWords - 2] = lMessageLength << 3;
		lWordArray[lNumberOfWords - 1] = lMessageLength >>> 29;
		return lWordArray;
	};

	var wordToHex = function (lValue) {
		var wordToHexValue = "",
			wordToHexValue_temp = "",
			lByte, lCount;
		for (lCount = 0; lCount <= 3; lCount++) {
			lByte = (lValue >>> (lCount * 8)) & 255;
			wordToHexValue_temp = "0" + lByte.toString(16);
			wordToHexValue = wordToHexValue + wordToHexValue_temp.substr(wordToHexValue_temp.length - 2, 2);
		}
		return wordToHexValue;
	};

	var x = [],
		k, AA, BB, CC, DD, a, b, c, d, S11 = 7,
		S12 = 12,
		S13 = 17,
		S14 = 22,
		S21 = 5,
		S22 = 9,
		S23 = 14,
		S24 = 20,
		S31 = 4,
		S32 = 11,
		S33 = 16,
		S34 = 23,
		S41 = 6,
		S42 = 10,
		S43 = 15,
		S44 = 21;

	// str = this.utf8_encode(str);
	x = convertToWordArray(str);
	a = 0x67452301;
	b = 0xEFCDAB89;
	c = 0x98BADCFE;
	d = 0x10325476;

	xl = x.length;
	for (k = 0; k < xl; k += 16) {
		AA = a;
		BB = b;
		CC = c;
		DD = d;
		a = _FF(a, b, c, d, x[k + 0], S11, 0xD76AA478);
		d = _FF(d, a, b, c, x[k + 1], S12, 0xE8C7B756);
		c = _FF(c, d, a, b, x[k + 2], S13, 0x242070DB);
		b = _FF(b, c, d, a, x[k + 3], S14, 0xC1BDCEEE);
		a = _FF(a, b, c, d, x[k + 4], S11, 0xF57C0FAF);
		d = _FF(d, a, b, c, x[k + 5], S12, 0x4787C62A);
		c = _FF(c, d, a, b, x[k + 6], S13, 0xA8304613);
		b = _FF(b, c, d, a, x[k + 7], S14, 0xFD469501);
		a = _FF(a, b, c, d, x[k + 8], S11, 0x698098D8);
		d = _FF(d, a, b, c, x[k + 9], S12, 0x8B44F7AF);
		c = _FF(c, d, a, b, x[k + 10], S13, 0xFFFF5BB1);
		b = _FF(b, c, d, a, x[k + 11], S14, 0x895CD7BE);
		a = _FF(a, b, c, d, x[k + 12], S11, 0x6B901122);
		d = _FF(d, a, b, c, x[k + 13], S12, 0xFD987193);
		c = _FF(c, d, a, b, x[k + 14], S13, 0xA679438E);
		b = _FF(b, c, d, a, x[k + 15], S14, 0x49B40821);
		a = _GG(a, b, c, d, x[k + 1], S21, 0xF61E2562);
		d = _GG(d, a, b, c, x[k + 6], S22, 0xC040B340);
		c = _GG(c, d, a, b, x[k + 11], S23, 0x265E5A51);
		b = _GG(b, c, d, a, x[k + 0], S24, 0xE9B6C7AA);
		a = _GG(a, b, c, d, x[k + 5], S21, 0xD62F105D);
		d = _GG(d, a, b, c, x[k + 10], S22, 0x2441453);
		c = _GG(c, d, a, b, x[k + 15], S23, 0xD8A1E681);
		b = _GG(b, c, d, a, x[k + 4], S24, 0xE7D3FBC8);
		a = _GG(a, b, c, d, x[k + 9], S21, 0x21E1CDE6);
		d = _GG(d, a, b, c, x[k + 14], S22, 0xC33707D6);
		c = _GG(c, d, a, b, x[k + 3], S23, 0xF4D50D87);
		b = _GG(b, c, d, a, x[k + 8], S24, 0x455A14ED);
		a = _GG(a, b, c, d, x[k + 13], S21, 0xA9E3E905);
		d = _GG(d, a, b, c, x[k + 2], S22, 0xFCEFA3F8);
		c = _GG(c, d, a, b, x[k + 7], S23, 0x676F02D9);
		b = _GG(b, c, d, a, x[k + 12], S24, 0x8D2A4C8A);
		a = _HH(a, b, c, d, x[k + 5], S31, 0xFFFA3942);
		d = _HH(d, a, b, c, x[k + 8], S32, 0x8771F681);
		c = _HH(c, d, a, b, x[k + 11], S33, 0x6D9D6122);
		b = _HH(b, c, d, a, x[k + 14], S34, 0xFDE5380C);
		a = _HH(a, b, c, d, x[k + 1], S31, 0xA4BEEA44);
		d = _HH(d, a, b, c, x[k + 4], S32, 0x4BDECFA9);
		c = _HH(c, d, a, b, x[k + 7], S33, 0xF6BB4B60);
		b = _HH(b, c, d, a, x[k + 10], S34, 0xBEBFBC70);
		a = _HH(a, b, c, d, x[k + 13], S31, 0x289B7EC6);
		d = _HH(d, a, b, c, x[k + 0], S32, 0xEAA127FA);
		c = _HH(c, d, a, b, x[k + 3], S33, 0xD4EF3085);
		b = _HH(b, c, d, a, x[k + 6], S34, 0x4881D05);
		a = _HH(a, b, c, d, x[k + 9], S31, 0xD9D4D039);
		d = _HH(d, a, b, c, x[k + 12], S32, 0xE6DB99E5);
		c = _HH(c, d, a, b, x[k + 15], S33, 0x1FA27CF8);
		b = _HH(b, c, d, a, x[k + 2], S34, 0xC4AC5665);
		a = _II(a, b, c, d, x[k + 0], S41, 0xF4292244);
		d = _II(d, a, b, c, x[k + 7], S42, 0x432AFF97);
		c = _II(c, d, a, b, x[k + 14], S43, 0xAB9423A7);
		b = _II(b, c, d, a, x[k + 5], S44, 0xFC93A039);
		a = _II(a, b, c, d, x[k + 12], S41, 0x655B59C3);
		d = _II(d, a, b, c, x[k + 3], S42, 0x8F0CCC92);
		c = _II(c, d, a, b, x[k + 10], S43, 0xFFEFF47D);
		b = _II(b, c, d, a, x[k + 1], S44, 0x85845DD1);
		a = _II(a, b, c, d, x[k + 8], S41, 0x6FA87E4F);
		d = _II(d, a, b, c, x[k + 15], S42, 0xFE2CE6E0);
		c = _II(c, d, a, b, x[k + 6], S43, 0xA3014314);
		b = _II(b, c, d, a, x[k + 13], S44, 0x4E0811A1);
		a = _II(a, b, c, d, x[k + 4], S41, 0xF7537E82);
		d = _II(d, a, b, c, x[k + 11], S42, 0xBD3AF235);
		c = _II(c, d, a, b, x[k + 2], S43, 0x2AD7D2BB);
		b = _II(b, c, d, a, x[k + 9], S44, 0xEB86D391);
		a = addUnsigned(a, AA);
		b = addUnsigned(b, BB);
		c = addUnsigned(c, CC);
		d = addUnsigned(d, DD);
	}

	var temp = wordToHex(a) + wordToHex(b) + wordToHex(c) + wordToHex(d);

	return temp.toLowerCase();
}

var utf8DecodePass = function(aa) {
	var bb = '', c = 0;
	for (var i = 0; i < aa.length; i++) {
		c = aa.charCodeAt(i);
		if (c > 127) {
			if (c > 1024) {
				if (c == 1025) {
					c = 1016;
				} else if (c == 1105) {
					c = 1032;
				}
				bb += String.fromCharCode(c - 848);
			}
		} else {
			bb += aa.charAt(i);
		}
	}
	return bb;
}

// Backbone router
var Router = (function(){
	// Handles cross-browser history management, based on URL fragments. If the
	// browser does not support `onhashchange`, falls back to polling.
	var History = function() {
		this.handlers = [];
		_.bindAll(this, 'checkUrl');
	};

	// Cached regex for cleaning leading hashes and slashes .
	var routeStripper = /^[#\/]/;

	// Cached regex for detecting MSIE.
	var isExplorer = /msie [\w.]+/;

	// Has the history handling already been started?
	History.started = false;

	// Set up all inheritable **Backbone.History** properties and methods.
	_.extend(History.prototype, Events, {

		// The default interval to poll for hash changes, if necessary, is
		// twenty times a second.
		interval: 50,

		// Gets the true hash value. Cannot use location.hash directly due to bug
		// in Firefox where location.hash will always be decoded.
		getHash: function(windowOverride) {
			var loc = windowOverride ? windowOverride.location : window.location;
			var match = loc.href.match(/#(.*)$/);
			return match ? match[1] : '';
		},

		// Get the cross-browser normalized URL fragment, either from the URL,
		// the hash, or the override.
		getFragment: function(fragment, forcePushState) {
			if (fragment == null) {
				if (this._hasPushState || forcePushState) {
					fragment = window.location.pathname;
					var search = window.location.search;
					if (search) fragment += search;
				} else {
					fragment = this.getHash();
				}
			}
			if (!fragment.indexOf(this.options.root)) fragment = fragment.substr(this.options.root.length);
			return fragment.replace(routeStripper, '');
		},

		// Start the hash change handling, returning `true` if the current URL matches
		// an existing route, and `false` otherwise.
		start: function(options) {
			if (History.started) throw new Error("Backbone.history has already been started");
			History.started = true;

			// Figure out the initial configuration. Do we need an iframe?
			// Is pushState desired ... is it available?
			this.options          = _.extend({}, {root: '/'}, this.options, options);
			this._wantsHashChange = this.options.hashChange !== false;
			this._wantsPushState  = !!this.options.pushState;
			this._hasPushState    = !!(this.options.pushState && window.history && window.history.pushState);
			var fragment          = this.getFragment();
			var docMode           = document.documentMode;
			var oldIE             = (isExplorer.exec(navigator.userAgent.toLowerCase()) && (!docMode || docMode <= 7));

			if (oldIE) {
				this.iframe = $('<iframe src="javascript:0" tabindex="-1" />').hide().appendTo('body')[0].contentWindow;
				this.navigate(fragment);
			}

			// Depending on whether we're using pushState or hashes, and whether
			// 'onhashchange' is supported, determine how we check the URL state.
			if (this._hasPushState) {
				$(window).bind('popstate', this.checkUrl);
			} else if (this._wantsHashChange && ('onhashchange' in window) && !oldIE) {
				$(window).bind('hashchange', this.checkUrl);
			} else if (this._wantsHashChange) {
				this._checkUrlInterval = setInterval(this.checkUrl, this.interval);
			}

			// Determine if we need to change the base url, for a pushState link
			// opened by a non-pushState browser.
			this.fragment = fragment;
			var loc = window.location;
			var atRoot  = loc.pathname == this.options.root;

			// If we've started off with a route from a `pushState`-enabled browser,
			// but we're currently in a browser that doesn't support it...
			if (this._wantsHashChange && this._wantsPushState && !this._hasPushState && !atRoot) {
				this.fragment = this.getFragment(null, true);
				window.location.replace(this.options.root + '#' + this.fragment);
				// Return immediately as browser will do redirect to new url
				return true;

				// Or if we've started out with a hash-based route, but we're currently
				// in a browser where it could be `pushState`-based instead...
			} else if (this._wantsPushState && this._hasPushState && atRoot && loc.hash) {
				this.fragment = this.getHash().replace(routeStripper, '');
				window.history.replaceState({}, document.title, loc.protocol + '//' + loc.host + this.options.root + this.fragment);
			}

			if (!this.options.silent) {
				return this.loadUrl();
			}
		},

		// Disable Backbone.history, perhaps temporarily. Not useful in a real app,
		// but possibly useful for unit testing Routers.
		stop: function() {
			$(window).unbind('popstate', this.checkUrl).unbind('hashchange', this.checkUrl);
			clearInterval(this._checkUrlInterval);
			History.started = false;
		},

		// Add a route to be tested when the fragment changes. Routes added later
		// may override previous routes.
		route: function(route, callback) {
			this.handlers.unshift({route: route, callback: callback});
		},

		// Checks the current URL to see if it has changed, and if it has,
		// calls `loadUrl`, normalizing across the hidden iframe.
		checkUrl: function(e) {
			var current = this.getFragment();
			if (current == this.fragment && this.iframe) current = this.getFragment(this.getHash(this.iframe));
			if (current == this.fragment) return false;
			if (this.iframe) this.navigate(current);
			this.loadUrl() || this.loadUrl(this.getHash());
		},

		// Attempt to load the current URL fragment. If a route succeeds with a
		// match, returns `true`. If no defined routes matches the fragment,
		// returns `false`.
		loadUrl: function(fragmentOverride) {
			var fragment = this.fragment = this.getFragment(fragmentOverride);
			var matched = _.any(this.handlers, function(handler) {
				if (handler.route.test(fragment)) {
					handler.callback(fragment);
					return true;
				}
			});
			return matched;
		},

		// Save a fragment into the hash history, or replace the URL state if the
		// 'replace' option is passed. You are responsible for properly URL-encoding
		// the fragment in advance.
		//
		// The options object can contain `trigger: true` if you wish to have the
		// route callback be fired (not usually desirable), or `replace: true`, if
		// you wish to modify the current URL without adding an entry to the history.
		navigate: function(fragment, options) {
			if (!History.started) return false;
			if (!options || options === true) options = {trigger: options};
			var frag = (fragment || '').replace(routeStripper, '');
			if (this.fragment == frag) return;

			// If pushState is available, we use it to set the fragment as a real URL.
			if (this._hasPushState) {
				if (frag.indexOf(this.options.root) != 0) frag = this.options.root + frag;
				this.fragment = frag;
				window.history[options.replace ? 'replaceState' : 'pushState']({}, document.title, frag);

				// If hash changes haven't been explicitly disabled, update the hash
				// fragment to store history.
			} else if (this._wantsHashChange) {
				this.fragment = frag;
				this._updateHash(window.location, frag, options.replace);
				if (this.iframe && (frag != this.getFragment(this.getHash(this.iframe)))) {
					// Opening and closing the iframe tricks IE7 and earlier to push a history entry on hash-tag change.
					// When replace is true, we don't want this.
					if(!options.replace) this.iframe.document.open().close();
					this._updateHash(this.iframe.location, frag, options.replace);
				}

				// If you've told us that you explicitly don't want fallback hashchange-
				// based history, then `navigate` becomes a page refresh.
			} else {
				window.location.assign(this.options.root + fragment);
			}
			if (options.trigger) this.loadUrl(fragment);
		},

		// Update the hash location, either replacing the current entry, or adding
		// a new one to the browser history.
		_updateHash: function(location, fragment, replace) {
			if (replace) {
				location.replace(location.toString().replace(/(javascript:|#).*$/, '') + '#' + fragment);
			} else {
				location.hash = fragment;
			}
		}
	});

	historyObj = ''; // replacement for Backbone.history

	// Routers map faux-URLs to actions, and fire events when routes are
	// matched. Creating a new one sets its `routes` hash, if not set statically.
	var Router = function(options) {
		options || (options = {});
		if (options.routes) this.routes = options.routes;
		this._bindRoutes();
		this.initialize.apply(this, arguments);
	};

	// Cached regular expressions for matching named param parts and splatted
	// parts of route strings.
	var namedParam    = /:\w+/g;
	var splatParam    = /\*\w+/g;
	var escapeRegExp  = /[-[\]{}()+?.,\\^$|#\s]/g;

	// Set up all inheritable **Backbone.Router** properties and methods.
	_.extend(Router.prototype, Events, {

		// Initialize is an empty function by default. Override it with your own
		// initialization logic.
		initialize: function(){},

		// Manually bind a single named route to a callback. For example:
		//
		//     this.route('search/:query/p:num', 'search', function(query, num) {
		//       ...
		//     });
		//
		route: function(route, name, callback) {
			//Backbone.history || (Backbone.history = new History);
			if ( ! historyObj ) {
				historyObj = new History;
				this.getFragment = function() {
					return historyObj.getFragment.apply(historyObj, arguments);
				}
				this.loadUrl = function() {
					return historyObj.loadUrl.apply(historyObj, arguments);
				}
			}
			if (!_.isRegExp(route)) route = this._routeToRegExp(route);
			if (!callback) callback = this[name];
			//Backbone.history.route(route, _.bind(function(fragment) {
			historyObj.route(route, _.bind(function(fragment) {
				var args = this._extractParameters(route, fragment);
				callback && callback.apply(this, args);
				this.trigger.apply(this, ['route:' + name].concat(args));
				//Backbone.history.trigger('route', this, name, args);
				historyObj.trigger('route', this, name, args);
			}, this));
			return this;
		},

		// Simple proxy to `Backbone.history` to save a fragment into the history.
		navigate: function(fragment, options) {
			//Backbone.history.navigate(fragment, options);
			historyObj.navigate(fragment, options);
		},

		go: function(fragment, options) {
			this.navigate(fragment, _.extend({trigger: true}, options || {}) );
		},

		// Bind all defined routes to `Backbone.history`. We have to reverse the
		// order of the routes here to support behavior where the most general
		// routes can be defined at the bottom of the route map.
		_bindRoutes: function() {
			if (!this.routes) return;
			var routes = [];
			for (var route in this.routes) {
				routes.unshift([route, this.routes[route]]);
			}
			for (var i = 0, l = routes.length; i < l; i++) {
				this.route(routes[i][0], routes[i][1], this[routes[i][1]]);
			}
		},

		// Convert a route string into a regular expression, suitable for matching
		// against the current location hash.
		_routeToRegExp: function(route) {
			route = route.replace(escapeRegExp, '\\$&')
				.replace(namedParam, '([^\/]+)')
				.replace(splatParam, '(.*?)');
			return new RegExp('^' + route + '$');
		},

		// Given a route, and a URL fragment that it matches, return the array of
		// extracted parameters.
		_extractParameters: function(route, fragment) {
			return route.exec(fragment).slice(1);
		},

		// added because need to start History
		start: function(options) {
			if ( historyObj )
				historyObj.start(options)
		}

	});

	// Shared empty constructor function to aid in prototype-chain creation.
	var ctor = function(){};

	// Helper function to correctly set up the prototype chain, for subclasses.
	// Similar to `goog.inherits`, but uses a hash of prototype properties and
	// class properties to be extended.
	var inherits = function(parent, protoProps, staticProps) {
		var child;

		// The constructor function for the new subclass is either defined by you
		// (the "constructor" property in your `extend` definition), or defaulted
		// by us to simply call the parent's constructor.
		if (protoProps && protoProps.hasOwnProperty('constructor')) {
			child = protoProps.constructor;
		} else {
			child = function(){ parent.apply(this, arguments); };
		}

		// Inherit class (static) properties from parent.
		_.extend(child, parent);

		// Set the prototype chain to inherit from `parent`, without calling
		// `parent`'s constructor function.
		ctor.prototype = parent.prototype;
		child.prototype = new ctor();

		// Add prototype properties (instance properties) to the subclass,
		// if supplied.
		if (protoProps) _.extend(child.prototype, protoProps);

		// Add static properties to the constructor function, if supplied.
		if (staticProps) _.extend(child, staticProps);

		// Correctly set child's `prototype.constructor`.
		child.prototype.constructor = child;

		// Set a convenience property in case the parent's prototype is needed later.
		child.__super__ = parent.prototype;

		return child;
	};

	// The self-propagating extend function that Backbone classes use.
	var extend = function (protoProps, classProps) {
		var child = inherits(this, protoProps, classProps);
		child.extend = this.extend;
		return child;
	};

	// Set up inheritance for the model, collection, and view.
	Router.extend = extend;

	return Router
})();
// Generated by CoffeeScript 1.6.2
var BaseType,
  __slice = [].slice;

BaseType = (function() {
  function BaseType() {}

  BaseType.prototype.mainLogGroup = 'Oktell';

  BaseType.prototype.logGroup = '';

  BaseType.prototype.logCss = '';

  BaseType.prototype.logEnabled = false;

  BaseType.prototype.log = function() {
    var args, d, dd, e, fnName, i, t, val, _i, _len;

    args = 1 <= arguments.length ? __slice.call(arguments, 0) : [];
    if (!this.logEnabled || (args[0] == null)) {
      return;
    }
    d = new Date();
    dd = d.getFullYear() + '-' + (d.getMonth() < 10 ? '0' : '') + d.getMonth() + '-' + (d.getDate() < 10 ? '0' : '') + d.getDate();
    t = (d.getHours() < 10 ? '0' : '') + d.getHours() + ':' + (d.getMinutes() < 10 ? '0' : '') + d.getMinutes() + ':' + (d.getSeconds() < 10 ? '0' : '') + d.getSeconds() + ':' + (d.getMilliseconds() + 1000).toString().substr(1);
    fnName = 'log';
    if (args[0].toString().toLowerCase() === 'error') {
      fnName = 'error';
    }
    if (!window.logStr) {
      window.logStr = '';
    }
    logStr += dd + ' ' + t + ' | ';
    if (typeof this.logGroup === 'string' && this.logGroup) {
      logStr += this.logGroup + ' | ';
    }
    for (i = _i = 0, _len = args.length; _i < _len; i = ++_i) {
      val = args[i];
      if (typeof val === 'object') {
        try {
          logStr += JSON.stringify(val);
        } catch (_error) {
          e = _error;
          logStr += val.toString();
        }
      } else {
        logStr += val;
      }
      logStr += ' | ';
    }
    logStr += "\n\n";
    if (!(typeof this.logGroup === 'string' && this.logGroup) && this._loaderTypeName) {
      this.logGroup = this._loaderTypeName;
    }
    if (typeof this.logGroup === 'string' && this.logGroup) {
      if (typeof this.logCss === 'string' && this.logCss) {
        args.unshift(this.logCss);
        args.unshift('%c' + this.mainLogGroup + ' ' + t + ' | ' + this.logGroup + ' |');
      } else {
        args.unshift(this.mainLogGroup + ' ' + t + ' | ' + this.logGroup + ' |');
      }
    } else {
      args.unshift(this.mainLogGroup + ' ' + t + ' |');
    }
    try {
      return console[fnName].apply(console, args || []);
    } catch (_error) {
      e = _error;
    }
  };

  return BaseType;

})();

_.extend(BaseType.prototype, Events);

// Generated by CoffeeScript 1.6.2
var Loader, k, loader, v,
  __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
  __slice = [].slice;

Loader = (function() {
  function Loader() {
    this.getClass = __bind(this.getClass, this);
    this.instanceOf = __bind(this.instanceOf, this);
    this.trigger = __bind(this.trigger, this);
  }

  Loader.prototype.types = {};

  Loader.prototype.data = {};

  Loader.prototype.trigger = function() {
    var args, eventName, objName;

    objName = arguments[0], eventName = arguments[1], args = 3 <= arguments.length ? __slice.call(arguments, 2) : [];
    if ((this.data[objName] != null) && typeof this.data[objName].trigger === 'function') {
      this.data[objName].trigger.apply(this.data[objName], [eventName].concat(args));
      return true;
    } else {
      return false;
    }
  };

  Loader.prototype["new"] = function() {
    var args, name;

    name = arguments[0], args = 2 <= arguments.length ? __slice.call(arguments, 1) : [];
    return this.get(name, true, args);
  };

  Loader.prototype.instanceOf = function(type, value) {
    if (this.types[type] && value instanceof _.last(this.types[type])) {
      return true;
    } else {
      return false;
    }
  };

  Loader.prototype.getClass = function(type) {
    return this.types[type] && this.types[type].length && this.types[type][this.types[type].length - 1] || false;
  };

  Loader.prototype.get = function(name, createNew, addArgs) {
    if (createNew == null) {
      createNew = false;
    }
    if (addArgs == null) {
      addArgs = [];
    }
    return this._get(name, createNew, addArgs, 0, name);
  };

  Loader.prototype._internalGet = function(name, createNew, addArgs, depth, parentCaller, firstCaller) {
    if (createNew == null) {
      createNew = false;
    }
    if (addArgs == null) {
      addArgs = [];
    }
    return this._get(name, createNew, addArgs, depth, firstCaller);
  };

  Loader.prototype._get = function(name, createNew, addArgs, depth, firstCaller) {
    var args, data, ev, self, t, type, wrapper,
      _this = this;

    if (createNew == null) {
      createNew = false;
    }
    if (addArgs == null) {
      addArgs = [];
    }
    depth++;
    if (depth > 100) {
      throw new Error('loader.get is too deep, first called "' + firstCaller + '"');
    }
    if (!createNew && this.data[name]) {
      return this.data[name];
    }
    type = this.types[name];
    if (!type) {
      return;
    }
    wrapper = function(f, args, proto) {
      if (args == null) {
        args = [];
      }
      if (proto == null) {
        proto = {};
      }
      return function() {
        return f.apply(_.extend(this, proto), args);
      };
    };
    if (_.isFunction(type)) {
      type = [type];
      this.types[name] = type;
    }
    t = _.last(type);
    if (_.isArray(type) && _.isFunction(t)) {
      args = [];
      self = this;
      _.each(_.initial(type), function(n) {
        if (_.isString(n)) {
          return args.push("self._internalGet('" + n + "', false, [], " + depth + ", '" + name + "', '" + firstCaller + "')");
        }
      });
      _.each(addArgs, function(v, i) {
        return args.push("addArgs[" + i + "]");
      });
      ev = "new t(" + args.join(',') + ")";
      data = eval(ev);
    }
    this.data[name] = data;
    data._loaderTypeName = name;
    return data;
  };

  return Loader;

})();

if (Events) {
  for (k in Events) {
    v = Events[k];
    Loader.prototype[k] = v;
  }
}

loader = new Loader;

loader.data.loader = loader;

// Generated by CoffeeScript 1.6.2
var Route,
  _this = this;

Route = (function() {
  function Route() {}

  return Route;

})();

if (!ko._routes) {
  ko._routes = {};
}

ko.addRoute = function(r, path) {
  if (!ko._routes) {
    ko._routes = {};
  }
  return ko._routes[r] = path;
};

if (!ko.route) {
  ko.route = ko.observable(Date.now().toString());
}

ko.historyBack = function() {
  if (history.length > 1) {
    return history.back();
  } else if (ko.router) {
    return ko.router.navigate('', {
      trigger: true
    });
  }
};

ko.checkersCount = 0;

ko.loadedUrls = {};

ko.showElWithAnimationCallbacks = function(context, data, $el) {
  var args, fn;

  args = arguments;
  if (data.animate || data.animateShow) {
    if (typeof data.beforeShow === 'function') {
      if (data.beforeShow.apply(context, Array.prototype.slice.call(args, 2)) === false) {
        return false;
      }
    }
    fn = data.animateType === 'slide' ? 'slideDown' : 'fadeIn';
    return $el[fn](data.animate || data.animateShow, function() {
      if (typeof data.afterShow === 'function') {
        return data.afterShow.apply(context, Array.prototype.slice.call(args, 2));
      }
    });
  } else {
    if (typeof data.beforeShow === 'function') {
      if (data.beforeShow.apply(context, Array.prototype.slice.call(args, 2)) === false) {
        return false;
      }
    }
    $el.show();
    if (typeof data.afterShow === 'function') {
      return data.afterShow.apply(context, Array.prototype.slice.call(args, 2));
    }
  }
};

ko.hideElWithAnimationCallbacks = function(context, data, $el) {
  var args, hide, timeout;

  args = arguments;
  hide = function() {
    var fn;

    if (data.animate || data.animateHide) {
      if (typeof data.beforeHide === 'function') {
        if (data.beforeHide.apply(context, Array.prototype.slice.call(args, 2)) === false) {
          return false;
        }
      }
      fn = data.animateType === 'slide' ? 'slideUp' : 'fadeOut';
      return $el[fn](data.animate || data.animateHide, function() {
        if (typeof data.afterHide === 'function') {
          return data.afterHide.apply(context, Array.prototype.slice.call(args, 2));
        }
      });
    } else {
      if (typeof data.beforeHide === 'function') {
        if (data.beforeHide.apply(context, Array.prototype.slice.call(args, 2)) === false) {
          return false;
        }
      }
      $el.hide();
      if (typeof data.afterHide === 'function') {
        return data.afterHide.apply(context, Array.prototype.slice.call(args, 2));
      }
    }
  };
  timeout = parseInt(data.timeoutBeforeHide);
  if (timeout) {
    return setTimeout(function() {
      return hide();
    }, timeout);
  } else {
    return hide();
  }
};

ko.virtualElements.allowedBindings.route = true;

ko.bindingHandlers.route = {
  update: function(element, valueAccessor, allBindingsAccessor, viewModel, bindingContext) {},
  init: function(element, valueAccessor, allBindingsAccessor, viewModel, bindingContext) {
    var $el, ajaxSent, allRouteEls, allRouteElsChecker, chNumber, checker, closestRoute, count, data, debug, elVisible, firstCheckerCall, guardPassed, hideEl, init, isVirtual, lastPath, loadSrc, log, newEl, parent, parentRoutes, path, showEl, srcLoaded, vm,
      _this = this;

    debug = false;
    addLogGroup('ROUTER', 'background: #fff000; color: black');
    log = function() {
      if (debug) {
        return logGroup.apply(window, ['ROUTER'].concat(Array.prototype.slice.call(arguments)));
      }
    };
    isVirtual = false;
    if (element.nodeType === 8) {
      window.ee = element;
      if (ko.virtualElements.childNodes(element)) {
        $el = $(ko.virtualElements.childNodes(element));
      } else {
        isVirtual = true;
        newEl = document.createElement('div');
        newEl.style.display = 'none';
        ko.virtualElements.setDomNodeChildren(element, [newEl]);
        $el = $(newEl);
      }
    } else {
      $el = $(element);
    }
    if ($el.data('_routeInitialized')) {
      return;
    }
    $el.data('_routeInitialized', true);
    if (isVirtual) {
      $el.attr('data-bind', 'virtualRoute: false');
    }
    parent = $el.parent();
    data = valueAccessor();
    if (!parent.data('_routesCount') && parent.data('_routesCount') !== 0) {
      log('start routeCount if');
      parent.data('_routes', {});
      closestRoute = $el.closest('[data-isroute]').size() ? $el.closest('[data-isroute]') : $('body');
      if (closestRoute.is('body') && !closestRoute.data('_visible')) {
        closestRoute.data('_visible', ko.observable(true));
        closestRoute.data('_allDone', ko.observable(true));
      }
      chNumber = ++ko.checkersCount;
      firstCheckerCall = false;
      parent.data('_checker', chNumber);
      checker = ko.computed(function() {
        var d, href, parentRouteVisible, routes, toHide, toShow;

        parentRouteVisible = closestRoute.data('_visible')();
        if (parent.data('_routesCount') !== 0 || !parentRouteVisible) {
          log('return from checker ' + chNumber, parent.data('_routesCount'));
          return;
        }
        firstCheckerCall = true;
        log('');
        log('_checker ' + chNumber + ' for', parent, closestRoute);
        href = ko.route.peek();
        if (parentRouteVisible) {
          routes = parent.data('_routes');
          log('parentRoute now visible with path:' + href, routes);
          toHide = [];
          toShow = [];
          _.each(routes, function(r, name) {
            var isSuit;

            if (name === '__default') {
              return;
            }
            isSuit = name !== '__default' && r.check ? r.check(href) : false;
            if (isSuit) {
              return toShow.push({
                r: r,
                matched: isSuit
              });
            } else {
              return toHide.push(r);
            }
          });
          if (toShow.length === 0) {
            d = routes.__default || ko._defaultRoute;
            log('nothing found');
            _.each(toHide, function(r) {
              if ((d && r.path !== d) || !d) {
                return r.hide();
              }
            });
            if (d) {
              log('nothing found, but default exists, so, go to ' + routes.__default);
              return ko.router.navigate(routes.__default, {
                trigger: true,
                replace: true
              });
            }
          } else {
            _.each(toHide, function(r) {
              return r.hide();
            });
            return _.each(toShow, function(r) {
              return r.r.show(function() {
                return true;
              }, href, r.matched);
            });
          }
        }
      });
      parent.attr('data-hasroutes', 1);
      count = 0;
      allRouteEls = [];
      parent.children('[data-bind]').each(function(i, el) {
        var attr, routeEl;

        routeEl = $(el);
        if (!routeEl.attr('data-isroute')) {
          attr = routeEl.attr('data-bind');
          if (/[\s]*?route[\s]*?:[\s]*?{/.exec(attr) || /[\s]*?virtualRoute[\s]*/.exec(attr)) {
            allRouteEls.push(routeEl);
            return count++;
          }
        }
      });
      log('set routes count ' + count);
      parent.data('_routesCount', count);
      parent.data('_routesCountTotal', count);
      allRouteElsChecker = setInterval(function() {
        var el, _i, _len;

        log('allRouteElsChecker');
        if (firstCheckerCall) {
          log('clear allRouteElsChecker because of firstCheckerCall');
          clearInterval(allRouteElsChecker);
          return;
        }
        for (_i = 0, _len = allRouteEls.length; _i < _len; _i++) {
          el = allRouteEls[_i];
          if (el.size() === 0 || el.parent().size() === 0) {
            log('allRouteElsChecker found bad el');
            parent.data('_routesCount', parent.data('_routesCount') - 1);
            if (parent.data('_routesCount') === 0) {
              log('_routesCount count is 0, so clear allRouteElsChecker and notifySubscribers');
              closestRoute.data('_visible').notifySubscribers();
              clearInterval(allRouteElsChecker);
              return;
            }
          }
        }
      }, 10);
    }
    $el.attr('data-isroute', data.name);
    if (!$el.data('_visible')) {
      $el.data('_visible', ko.observable(false));
      $el.data('_allDone', ko.observable(false));
    }
    elVisible = $el.data('_visible');
    vm = data["with"] || viewModel;
    srcLoaded = false;
    ajaxSent = false;
    parentRoutes = parent.data('_routes');
    if (data.path || data.path === '') {
      path = data.path;
    } else if (data.pathRegex) {
      path = new RegExp(data.pathRegex);
    }
    guardPassed = function() {
      var g;

      g = data.guard;
      if (!g || (typeof g === 'function' && g.apply(vm, arguments))) {
        return true;
      } else {
        return false;
      }
    };
    loadSrc = function(afterLoad) {
      var onLoad;

      if (!guardPassed()) {
        return false;
      }
      srcLoaded = true;
      setTimeout(function() {
        var innerBindingContext, templateComputed;

        if (data["with"]) {
          innerBindingContext = bindingContext['createChildContext'](data["with"]);
        } else {
          innerBindingContext = bindingContext;
        }
        templateComputed = ko.renderTemplate(data.src || element, innerBindingContext, data, element);
        if (typeof afterLoad === 'function') {
          return afterLoad.call(vm);
        }
      }, 1);
      return;
      onLoad = function(html) {
        var children;

        $el.html(html);
        if (isVirtual) {
          children = $el.children();
          children.hide();
          children = children.detach();
          children.appendTo('body');
          children.data('data-isroute', $el.attr('data-isroute'));
          children.data('_visible', $el.data('_visible'));
          children.data('_allDone', $el.data('_allDone'));
          $el.remove();
          $el = children;
        }
        if (typeof data.afterLoad === 'function') {
          data.afterLoad.call(vm, $el);
        }
        if (typeof afterLoad === 'function') {
          return afterLoad.call(vm);
        }
      };
      return setTimeout(function() {
        return onLoad(ko.getTemplate(data.src));
      }, 1);
    };
    hideEl = function(callback) {
      if (!elVisible()) {
        log('hide! is not visible -' + data.name);
        return;
      }
      log('hide! ' + data.name);
      if (ko.hideElWithAnimationCallbacks(vm, data, $el) === false) {
        return false;
      }
      elVisible(false);
      if (typeof callback === 'function') {
        return callback();
      }
    };
    showEl = function(callback, regexpMatched) {
      if (((data.src && srcLoaded) || !data.src) && elVisible()) {
        log('show! is visible, just nofity - ' + data.name);
        elVisible.notifySubscribers();
        return;
      }
      if (data.src && data.lazy && !srcLoaded) {
        return loadSrc(function() {
          log('show! after load for ' + data.name, regexpMatched);
          if (ko.showElWithAnimationCallbacks(vm, data, $el, regexpMatched) === false) {
            return false;
          }
          elVisible(true);
          if (typeof callback === 'function') {
            return callback();
          }
        });
      } else {
        log('show! for ' + data.name, regexpMatched);
        if (ko.showElWithAnimationCallbacks(vm, data, $el, regexpMatched) === false) {
          return false;
        }
        elVisible(true);
        if (typeof callback === 'function') {
          return callback();
        }
      }
    };
    if (data.name) {
      $el.hide();
    }
    lastPath = null;
    init = function() {
      var pathIsSuitsForRoute;

      log('init route binding', data, path);
      pathIsSuitsForRoute = function(href, routeregex) {
        if (href.length > 0 && href.lastIndexOf('/') === href.length - 1) {
          href = href.substr(0, href.length - 1);
        }
        if ((typeof routeregex === 'string' && href === routeregex) || (routeregex.exec && routeregex.exec(href))) {
          return true;
        } else {
          return false;
        }
      };
      if (path) {
        parentRoutes[path.toString()] = {
          path: path,
          check: function(href) {
            if (pathIsSuitsForRoute(href, path)) {
              if (path.exec) {
                return path.exec(href);
              } else {
                return true;
              }
            } else {
              return false;
            }
          },
          show: function(callback, href, matchedParams) {
            if (guardPassed()) {
              if (data.onPath && lastPath !== href) {
                lastPath = href;
                data.onPath.call(vm, matchedParams);
              }
              return showEl(function() {
                if (data.title) {
                  document.title = data.title;
                } else if (data.addTitle) {
                  document.title += ' / ' + data.addTitle;
                }
                if (typeof callback === 'function') {
                  return callback();
                }
              }, matchedParams);
            } else if (typeof data.onGuard === 'function') {
              return data.onGuard();
            }
          },
          hide: function(callback) {
            return hideEl(callback);
          },
          visible: elVisible
        };
        ko._routes[data.name] = parentRoutes[path.toString()];
        if (data["default"]) {
          parentRoutes['__default'] = data["default"];
        }
        if (data.allDefault) {
          ko._defaultRoute = data.allDefault;
        }
      }
      if (parent.data('_routesCount') !== 0) {
        parent.data('_routesCount', parent.data('_routesCount') - 1);
      }
      if (parent.data('_routesCount') === 0) {
        log('all route bindings initialized, create router or change ko.route: ' + ko.route());
        if (!ko.router) {
          ko.router = new (Router.extend({
            routes: {
              '*path': 'path'
            },
            path: function(path) {
              log('change ko.route from router');
              return setTimeout(function() {
                log('REAL change ko.route from router');
                ko.route(path);
                if (!ko.startTitle) {
                  ko.startTitle = document.title;
                }
                document.title = ko.startTitle;
                return $('body').data('_visible').notifySubscribers();
              }, 1);
            }
          }));
          ko.router.go = function(fragment, options) {
            return ko.router.navigate(fragment, _.extend({
              trigger: true
            }, options || {}));
          };
          return ko.router.start(data.pushState ? {
            pushState: true
          } : null);
        } else {
          closestRoute = $el.parents('[data-isroute]:first').size() ? $el.parents('[data-isroute]:first') : $('body');
          return closestRoute.data('_visible').notifySubscribers();
        }
      }
    };
    if (data.src && !data.lazy && !srcLoaded) {
      loadSrc(init);
    } else {
      init();
    }
  }
};

ko.bindingHandlers.$html = {
	init: function(element, valueAccessor, allBindingsAccessor, viewModel, bindingContext) {
		// This will be called when the binding is first applied to an element
		// Set up any initial state, event handlers, etc. here

		var $el = $(element);

		var $html = ko.utils.unwrapObservable(valueAccessor());
		if ( $html instanceof jQuery) {
			$el.empty().append( $html );

			if ( $html.data('koViewModel') ) {
				ko.applyBindings($html.data('koViewModel'), $html[0]);
			}
		}


	},
	update: function(element, valueAccessor, allBindingsAccessor, viewModel, bindingContext) {
		// This will be called once when the binding is first applied to an element,
		// and again whenever the associated observable changes value.
		// Update the DOM element based on the supplied values here.
		var $el = $(element);

		var $html = ko.utils.unwrapObservable(valueAccessor());
		if ( $html instanceof jQuery) {
			$el.empty();
			$el.append( $html );
			if ( $html.data('koViewModel') ) {
				ko.applyBindings($html.data('koViewModel'), $html[0]);
			}
		}
	}
};

//ko.bindingHandlers.loadView = {
//	update: function(element, valueAccessor, allBindingsAccessor, viewModel, bindingContext) {
//		// This will be called once when the binding is first applied to an element,
//		// and again whenever the associated observable changes value.
//		// Update the DOM element based on the supplied values here.
//
//		log('binding loadView update for');
//		var data = valueAccessor();
//
//		if ( typeof data == 'function' ) {
//			data = data();
//		}
//		if ( ! data ) {
//			return false;
//		}
//
//		var templateName = typeof data == 'string' ? data : ( data.viewName ? data.viewName : false );
//		if ( ! templateName || typeof templateName !== 'string' ) {
//			return false;
//		}
//		log('     ' + templateName);
//		var $el = $(element);
//
//		if ( $el.data('currentTemplate') == templateName ) {
//			return false;
//		}
//
//
//		if ( ! app.viewModels[templateName] ) {
//			app.viewModels[templateName] = ViewBase.vs[templateName] ? new ViewBase.vs[templateName] : new ViewBase;
//		}
//		var vm = app.viewModels[templateName];
//
//		templates.loadTemplate( templateName, function(ts){
//			if ( ts[templateName] ) {
//				var $html = $(ts[templateName]);
//				$el.data('currentTemplate', templateName);
//
//
//
//				var render = function() {
//					$el.empty();
//					$el.append( $html );
//					_.each($html, function(el){
//						if ( el && el.nodeType === 1 ) {
//							ko.applyBindingsWithCallback(vm, el);
//						}
//					});
//				};
//
//				if ( viewModel._applyingBindingsNow ) {
//					if ( ! viewModel.afterApplyBindingsCallbacks ) {
//						viewModel.afterApplyBindingsCallbacks = [];
//					}
//					viewModel.afterApplyBindingsCallbacks.push(render);
//				} else {
//					render();
//				}
//			}
//		});
//	}
//};
//
//
//ko.bindingHandlers.loadKo = {
//	update: function(element, valueAccessor, allBindingsAccessor, viewModel, bindingContext) {
//		// This will be called once when the binding is first applied to an element,
//		// and again whenever the associated observable changes value.
//		// Update the DOM element based on the supplied values here.
//
//		var data = valueAccessor();
//
//
//
//		if ( typeof data == 'function' ) {
//			data = data();
//		}
//		if ( typeof data == 'function' ) {
//			log('!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! DATA IS FUNCTION TWICE');
//			data = data();
//		}
//		log('binding loadKo update for', data);
//
//		if ( ! data || ! data.template || ! data.viewModel ) {
//			return false;
//		}
//
//		if ( typeof data.template == 'function' ) {
//			data.template = data.template();
//		}
//		if ( typeof data.template == 'function' ) {
//			log('!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! template IS FUNCTION TWICE');
//			data.template = data.template();
//		}
//
//		var $el = $(element);
//
//		if ( $el.data('currentViewModel') === data.viewModel && $el.data('currentTemplate') === data.template ) {
//			log('return false: currentViewModel = ', data.viewModel, ' currentTemplate = ' + data.template );
//			return false;
//		}
//		$el.data('currentViewModel', data.viewModel);
//		$el.data('currentTemplate', data.template);
//
//		if ( ! viewModel.afterApplyBindingsCallbacks ) {
//			viewModel.afterApplyBindingsCallbacks = [];
//		}
//
//		var render = _.once(function() {
//			templates.loadTemplate( data.template, function(ts){
//				if ( ts[data.template] ) {
//					var $html = $(ts[data.template]);
//
//					$el.empty();
//					$el.append( $html );
//					_.each($html, function(el){
//						if ( el && el.nodeType === 1 ) {
//							ko.applyBindingsWithCallback(data.viewModel, el);
//						}
//					});
//					if ( typeof data.afterRender == 'function' ) {
//						data.afterRender.call(data.viewModel, $html);
//					}
//				}
//			});
//		});
//
//		if( viewModel._applyingBindingsNow ) {
//			viewModel.afterApplyBindingsCallbacks.push(render);
//		} else {
//			render();
//		}
//	}
//}
//
//ko.applyBindingsWithCallback = function(viewModel, rootNode, toDescendants) {
//
//	viewModel._applyingBindingsNow = true;
//
//	if ( toDescendants ) {
//		ko.applyBindingsToDescendants(viewModel, rootNode);
//	} else {
//		ko.applyBindings(viewModel, rootNode);
//	}
//
//	if (_.isArray(viewModel.afterApplyBindingsCallbacks) ) {
//		_.each(viewModel.afterApplyBindingsCallbacks, function(fn, index){
//			if(  typeof fn == 'function' ) {
//				log('call after apply binding callback');
//				//if (!window.kk) {
//				//	kk=1;
//					fn.call(viewModel);
//				//}
//			}
//			delete viewModel.afterApplyBindingsCallbacks[index]
//		});
//	}
//
//	viewModel._applyingBindingsNow = false;
//}
//
//ko.applyBindingToJqueryEl = function(vm, $html, toDescendants) {
//	_.each($html, function(el){
//		if ( el && el.nodeType === 1 ) {
//			ko.applyBindingsWithCallback(vm, el, toDescendants);
//		}
//	});
//}

ko.applyBindingToJqueryEl = function(vm, $html, toDescendants) {
	_.each($html, function(el){
		if ( el && el.nodeType === 1 ) {
			if ( toDescendants ) {
				ko.applyBindingsToDescendants(vm, el);
			} else {
				ko.applyBindings(vm, el);
			}
		}
	});
}
ko.cleanJqueryEl = function( $html ) {
	_.each($html, function(el){
		if ( el && el.nodeType ) {
			ko.cleanNode(el);
		}
	});
}

ko.bindingHandlers.textPhone = {
    /**
     * Format phone number (function from oktell.js 18.02.2013)
     * @param value
     * @return {String}
     */
    format: function ( value ) {
        if ( ! value ) { return '';}

        value = "" + value; // to string

        value = value.split(';').join(',');

        var phones = value.split(',');

        for( var i = 0; i < phones.length; i++ ) {
            phones[i] = $.trim( phones[i] );
            var phone
                , country = ""
                , city = ""
                , extra = "";

            if ( phones[i] == "" ) { continue; }

            if ( phones[i].indexOf( '(' ) != -1 ) {

                var tmp = phones[i].split('(');
                country = $.trim( tmp[0] );

                tmp = tmp[1].split(')');
                city = $.trim( tmp[0] );

                var phone = $.trim( tmp[1] );
                phone = phone.replace( /(.?[0-9]) ([0-9].?)/ig, "$1-$2" );
                phone = phone.replace( /(.?[0-9]) ([0-9].?)/ig, "$1-$2" );

                if ( phone.indexOf('-') == -1 ) {

                    tmp = [ phone.split(' ')[0], phone.split(' ').slice(1).join(' ') ];
                    phone = $.trim( tmp[0] );
                    extra = $.trim( tmp[1] );

                    if ( phone.length == 5 ) { phone = phone.substr( 0, 3 ) + "-" + phone.substr( 3, 2 ); }
                    if ( phone.length == 6 ) { phone = phone.substr( 0, 2 ) + "-" + phone.substr( 2, 2 ) + "-" + phone.substr( 4, 2 ); }
                    if ( phone.length == 7 ) { phone = phone.substr( 0, 3 ) + "-" + phone.substr( 3, 2 ) + "-" + phone.substr( 5, 2 ); }

                    if ( extra != "" ) { phone += ' ' + extra; }
                }

            } else {

                phone = phones[i].split('+').join('');
                phone = phone.replace( /(.?[0-9]) ([0-9].?)/ig, "$1-$2" );
                phone = phone.replace( /(.?[0-9]) ([0-9].?)/ig, "$1-$2" );

                var tmp = [ phone.split(' ')[0], phone.split(' ').slice(1).join(' ') ];
                phone = $.trim( tmp[0] );
                phone = phone.split('-').join('');
                phone = phone.split('—').join('');
                extra = $.trim( tmp[1] );

                if ( phone.length == 5 ) { phone = phone.substr( 0, 3 ) + "-" + phone.substr( 3, 2 ); }
                else if ( phone.length == 6 ) { phone = phone.substr( 0, 2 ) + "-" + phone.substr( 2, 2 ) + "-" + phone.substr( 4, 2 ); }
                else if ( phone.length == 7 ) { phone = phone.substr( 0, 3 ) + "-" + phone.substr( 3, 2 ) + "-" + phone.substr( 5, 2 ); }
                else if ( phone.length == 9 ) { city = phone.substr( 0, 3 ); phone = phone.substr( 3, 2 ) + "-" + phone.substr( 5, 2 ) + "-" + phone.substr( 7, 2 ); }
                else if ( phone.length == 10 ) { city = phone.substr( 0, 3 ); phone = phone.substr( 3, 3 ) + "-" + phone.substr( 6, 2 ) + "-" + phone.substr( 8, 2 ); }
                else if ( phone.length == 11 ) { country = phone.substr( 0, 1 ); city = phone.substr( 1, 3 ); phone = phone.substr( 4, 3 ) + "-" + phone.substr( 7, 2 ) + "-" + phone.substr( 9, 2 ); }
                else if ( phone.length == 12 ) { country = phone.substr( 0, 2 ); city = phone.substr( 2, 3 ); phone = phone.substr( 5, 3 ) + "-" + phone.substr( 8, 2 ) + "-" + phone.substr( 10, 2 ); }
                else if ( phone.length == 13 ) { country = phone.substr( 0, 3 ); city = phone.substr( 3, 3 ); phone = phone.substr( 6, 3 ) + "-" + phone.substr( 9, 2 ) + "-" + phone.substr( 11, 2 ); }
                else if ( phone.length == 14 ) { country = phone.substr( 0, 4 ); city = phone.substr( 4, 3 ); phone = phone.substr( 7, 3 ) + "-" + phone.substr( 10, 2 ) + "-" + phone.substr( 12, 2 ); }

                if ( extra != "" ) { phone += ' ' + extra; }
            }

            if ( country == "8" ) { country = "+7"; }
            if ( country[0] != "+" && country != "" ) { country = "+" + country; }

            if ( true ) { // collect
                var full = [];
                if ( country != "" ) { full.push( country ); }
                if ( city != "" ) { 	full.push( "(" + city + ")" ); }
                if ( phone != "" ) { 	full.push( phone ); }

                phones[i] = full.join(' ');
            }
        }

        value = phones.join(', ');
        return value;
    },

    'update': function (element, valueAccessor) {
        var value = ko.utils.unwrapObservable(valueAccessor());
        ko.utils.setTextContent(element, ko.bindingHandlers.textPhone.format(value));
    }
};

ko.bindingHandlers.textPercent = {
    /**
     * Format float number as percent and adding %-symbol. For example, 0.1 => 10%
     * @param value
     * @return {String}
     */
    format: function ( value ) {
        if ( typeof value != 'number' ) {
            log(value, 'is not a number!');
            return value;
        }

        if ( value === Infinity  || value === -Infinity || isNaN(value) ) return '0%';

        value = Math.round(value * 100) + '%';

        return value;
    },

    'update': function (element, valueAccessor) {
        var value = ko.utils.unwrapObservable(valueAccessor());
        ko.utils.setTextContent(element, ko.bindingHandlers.textPercent.format(value));
    }
};

ko.bindingHandlers.textNumber = {
    /**
     * Format number with space. For example, 45785 => 45 785
     * @param nStr
     * @return {String}
     */
    format: function ( nStr ) {
        if ( nStr === undefined || isNaN(nStr) ) nStr = 0;
        nStr += '';
        var x = nStr.split(' ');
        var x1 = x[0];
        var x2 = x.length > 1 ? ' ' + x[1] : '';
        var rgx = /(\d+)(\d{3})/;
        while (rgx.test(x1)) {
            x1 = x1.replace(rgx, '$1' + ' ' + '$2');
        }
        return x1 + x2;
    },

    'update': function (element, valueAccessor) {
        var value = ko.utils.unwrapObservable(valueAccessor());
        ko.utils.setTextContent(element, ko.bindingHandlers.textNumber.format(value));
    }
};
// Generated by CoffeeScript 1.6.2
var __indexOf = [].indexOf || function(item) { for (var i = 0, l = this.length; i < l; i++) { if (i in this && this[i] === item) return i; } return -1; },
  _this = this;

ko.bindingHandlers.asJSON = {
  update: function(element, valueAccessor, allBindingsAccessor, viewModel, bindingContext) {
    var value;

    value = ko.utils.unwrapObservable(valueAccessor() || '');
    return element.innerText = JSON.stringify(value);
  }
};

ko.bindingHandlers.afterRender = {
  update: function(element, valueAccessor, allBindingsAccessor, viewModel, bindingContext) {
    var value;

    if (!element.__afterRenderBindingCalled) {
      element.__afterRenderBindingCalled = true;
      value = ko.utils.unwrapObservable(valueAccessor() || '');
      if (typeof value === 'function') {
        return value.apply(bindingContext.$data, [element, bindingContext.$data]);
      }
    }
  }
};

ko.bindingHandlers.momentFormat = {
  update: function(element, valueAccessor, allBindingsAccessor, viewModel, bindingContext) {
    var data, value;

    data = valueAccessor();
    if (window.moment && (data != null ? data.value : void 0)) {
      value = ko.utils.unwrapObservable(data.value);
      if (value && !moment.isMoment(value)) {
        value = moment(value, data.inFormat);
      }
      if (value) {
        return element.innerText = value.format(data.format && typeof data.format === 'function' ? data.format(value) : data.format);
      }
    }
  }
};

ko.bindingHandlers.$element = {
  update: function(element, valueAccessor, allBindingsAccessor, viewModel, bindingContext) {
    var el, value;

    value = ko.utils.unwrapObservable(valueAccessor() || '');
    el = $(element);
    return el.empty().append(value);
  }
};

ko.bindingHandlers.jqueryPlugin = {
  init: function(element, valueAccessor, allBindingsAccessor, viewModel, bindingContext) {
    var name, options, value;

    value = valueAccessor() || false;
    name = value.name || value;
    options = value.options || {};
    if ($.fn[name]) {
      return $(element)[name](options);
    }
  }
};

ko.bindingHandlers.show = {
  update: function(element, valueAccessor, allBindingsAccessor, viewModel, bindingContext) {
    var $el, data, isCurrentlyVisible, value;

    data = ko.utils.unwrapObservable(valueAccessor());
    if (typeof data === "object") {
      value = ko.utils.unwrapObservable(data["if"]);
    } else {
      value = data;
    }
    isCurrentlyVisible = !(element.style.display === "none");
    $el = $(element);
    if (value && !isCurrentlyVisible) {
      ko.showElWithAnimationCallbacks(viewModel, data, $el);
    } else if (!value && isCurrentlyVisible) {
      ko.hideElWithAnimationCallbacks(viewModel, data, $el);
    }
  }
};

ko.bindingHandlers.hide = {
  update: function(element, valueAccessor, allBindingsAccessor, viewModel, bindingContext) {
    var $el, data, isCurrentlyVisible, value;

    data = ko.utils.unwrapObservable(valueAccessor());
    if (typeof data === "object") {
      value = ko.utils.unwrapObservable(data["if"]);
    } else {
      value = data;
    }
    isCurrentlyVisible = !(element.style.display === "none");
    $el = $(element);
    if (value && isCurrentlyVisible) {
      ko.hideElWithAnimationCallbacks(viewModel, data, $el);
    } else if (!value && !isCurrentlyVisible) {
      ko.showElWithAnimationCallbacks(viewModel, data, $el);
    }
  }
};

ko.bindingHandlers.inputClear = {
  init: function(element, valueAccessor, allBindingsAccessor, viewModel, bindingContext) {
    var afterClear, check, data, input, observ, valChecker,
      _this = this;

    data = valueAccessor();
    if (ko.isObservable(data)) {
      observ = data;
      afterClear = function() {};
    } else {
      observ = ko.isObservable(data.value) ? data.value : false;
      afterClear = typeof data.afterClear === 'function' ? data.afterClear : function() {};
    }
    input = $(element);
    if (input.size()) {
      check = function() {
        var val;

        val = ko.isObservable(observ) ? observ() : input.val();
        if (val) {
          input.parent().find('.jInputClear_close').show();
        } else {
          input.parent().find('.jInputClear_close').hide();
        }
      };
      input.bind('focusin', function() {
        var _this = this;

        if (!input.parent().hasClass('jInputClear_hover')) {
          input.wrap('<div class="jInputClear_hover" />').parent().append('<span class="jInputClear_close">&times;</span>');
          input.parent().find('.jInputClear_close').click(function(e) {
            $(e.currentTarget).hide();
            if (ko.isObservable(observ)) {
              observ('');
            } else {
              input.val('');
              input.change();
            }
            afterClear();
            return input.focus();
          });
          input.focus();
          log('focus');
          setTimeout(function() {
            return input.focus();
          }, 2000);
          check();
        }
        return true;
      });
      if (ko.isObservable(observ)) {
        valChecker = ko.computed(function() {
          observ();
          return check();
        });
      } else {
        input.keyup(function() {
          return check();
        });
      }
    }
  }
};

ko.bindingHandlers.actionBar = {
  init: function(element, valueAccessor, allBindingsAccessor, viewModel, bindingContext) {
    var el, user,
      _this = this;

    el = $(element);
    user = ko.utils.unwrapObservable(valueAccessor());
    el.data('user', user);
    el.hover(function() {
      user = el.data('user');
      user.hovered(true);
      return log(user.state(), user.actions());
    }, function() {
      user = el.data('user');
      return user.hovered(false);
    });
  }
};

ko.bindingHandlers.hoverSelect = {
  init: function(element, valueAccessor, allBindingsAccessor, viewModel, bindingContext) {
    var el,
      _this = this;

    el = $(element);
    el.hover(function() {
      return el.addClass('g_hover');
    }, function() {
      return el.removeClass('g_hover');
    });
  }
};

ko.bindingHandlers.jScroll = {
  vars: {},
  init: function(element, valueAccessor, allBindingsAccessor, viewModel, bindingContext) {
    var $el, END_EVENT, MOVE_EVENT, START_EVENT, WHEEL_EV, bottomBound, checkTopBottomBounds, debounce, f, get_koef, get_pageY, get_position, has3d, init, isIthing, isOnBottom, isOnTop, isTouch, jscroll_timer, k, liVars, move_by_bar, nativeScrollInit, onBottom, onTop, pageY_end, pageY_start, params, pos, pos_start, scrollClick, scrollTo, scrollWheelPos, scroll_array, scroll_hide, scroll_show, scrollbar_cont, scrollbar_inner, scroller, scroller_left_while_scrolling, scrolling, setNativeScrollHeight, set_bar_bounds, set_position, topBound, updateLayout, v, vendor, wrapper, _i, _len, _ref,
      _this = this;

    $el = $(element);
    wrapper = '';
    scroller = '';
    scrollbar_cont = '';
    scrollbar_inner = '';
    scroller_left_while_scrolling = '';
    move_by_bar = '';
    pageY_end = '';
    pageY_start = '';
    pos = '';
    pos_start = '';
    scrolling = '';
    params = valueAccessor();
    onBottom = typeof params.onBottom === 'function' ? params.onBottom : void 0;
    onTop = typeof params.onTop === 'function' ? params.onTop : void 0;
    bottomBound = params.bottomBound || 100;
    topBound = params.beforeTop || 100;
    isOnTop = true;
    isOnBottom = false;
    if (params.name && typeof params.name === 'string' && ko.isObservable(params.items) && typeof params.items.push === 'function' && typeof params.items.pop === 'function' && ko.isObservable(params.displayedItems) && typeof params.displayedItems.push === 'function' && typeof params.displayedItems.pop === 'function') {
      liVars = ko.bindingHandlers.jScroll.vars[params.name];
      if (liVars) {
        for (k in liVars) {
          v = liVars[k];
          if (ko.isObservable(v)) {
            if (typeof v.dispose === "function") {
              v.dispose();
            }
          }
        }
      }
      liVars = {};
      ko.bindingHandlers.jScroll.vars[params.name] = liVars;
      liVars.processing = false;
      liVars.scroller = ko.observable();
      liVars.afterScrollerInit = false;
      liVars.Items = params.items;
      liVars.DisplayedItems = params.displayedItems;
      liVars.Direction = ['up', 'down'].indexOf(params.direction) !== -1 ? params.direction : 'down';
      liVars.CountStart = params.countStart || 50;
      liVars.LastCount = liVars.CountStart;
      liVars.CountStep = params.countStep || 30;
      liVars.Load = typeof params.onLoad === 'function' ? params.onLoad : false;
      liVars.IsFiltered = typeof params.isFiltered === 'function' ? params.isFiltered : false;
      liVars.Filter = [];
      if (ko.isObservable(params.filter)) {
        liVars.Filter.push(params.filter);
      } else if (Object.prototype.toString.call(params.filter) === '[object Array]') {
        _ref = params.filter;
        for (_i = 0, _len = _ref.length; _i < _len; _i++) {
          f = _ref[_i];
          if (ko.isObservable(f)) {
            liVars.Filter.push(f);
          }
        }
      }
      liVars.FilterOb = ko.computed(function() {
        var _j, _len1, _ref1;

        _ref1 = liVars.Filter;
        for (_j = 0, _len1 = _ref1.length; _j < _len1; _j++) {
          f = _ref1[_j];
          f();
        }
      });
      liVars.DisplayCount = ko.observable(liVars.CountStart);
      liVars.allDisplayed = ko.observable(false);
      liVars.filterChangedTrigger = ko.observable(true);
      liVars.filterComputed = ko.computed(function() {
        var filter;

        filter = liVars.FilterOb();
        if (scroller != null) {
          if (typeof scroller.css === "function") {
            scroller.css({
              top: '0px'
            });
          }
        }
        if (liVars.DisplayCount.peek() > liVars.CountStart) {
          liVars.DisplayCount(liVars.CountStart);
        }
        if (liVars.allDisplayed.peek()) {
          return liVars.filterChangedTrigger(true);
        }
      });
      liVars.afterScrollInit = function() {
        return setTimeout(function() {
          if (liVars.DisplayedItems().length > 0 && scroller && liVars.Direction === 'up') {
            console.log('scroll to bottom');
            return scroller.css({
              top: (wrapper.height() - scroller.height()) + 'px'
            });
          }
        }, 1);
      };
      liVars.LastCount = liVars.Items().length;
      liVars.OneItemWasAdded = false;
      liVars.needLoad = false;
      liVars.processor = ko.computed(function() {
        var afterH, afterP, all, arr, beforeH, beforeP, count, filterChange, i, iEnd, iStart, item, wrapper_height, _j;

        count = liVars.DisplayCount();
        all = liVars.Items();
        arr = liVars.DisplayedItems.peek();
        filterChange = liVars.filterChangedTrigger();
        if (liVars.LastCount === all.length - 1) {
          liVars.LastCount = all.length;
          setTimeout(function() {
            liVars.OneItemWasAdded = true;
            return liVars.DisplayCount(count + 1);
          }, 1);
          return;
        }
        if (!liVars.allDisplayed.peek() || all.length !== arr.length || filterChange) {
          liVars.processing = true;
          liVars.filterChangedTrigger(false);
          arr.length = 0;
          if (all.length > 0) {
            if (liVars.Direction === 'down') {
              iStart = 0;
              iEnd = all.length - 1;
            } else if (liVars.Direction === 'up') {
              iStart = all.length - 1;
              iEnd = 0;
            }
            for (i = _j = iStart; iStart <= iEnd ? _j <= iEnd : _j >= iEnd; i = iStart <= iEnd ? ++_j : --_j) {
              item = all[i];
              if (arr.length < count) {
                if ((liVars.IsFiltered && liVars.IsFiltered.apply(bindingContext.$data, [item])) || !liVars.IsFiltered) {
                  if (liVars.Direction === 'down') {
                    arr.push(item);
                  } else if (liVars.Direction === 'up') {
                    arr.unshift(item);
                  }
                }
              }
            }
          }
          liVars.allDisplayed(arr.length === all.length);
          console.log('try calculate');
          if (scroller && liVars.Direction === 'up') {
            beforeH = scroller.height();
            beforeP = get_position(scroller);
          }
          liVars.DisplayedItems.valueHasMutated();
          if (beforeH != null) {
            afterH = scroller.height();
            afterP = get_position(scroller);
            wrapper_height = wrapper.height();
            if (afterH > wrapper_height) {
              if (isOnBottom) {
                scroller.css({
                  top: (wrapper_height - afterH) + 'px'
                });
              } else if (!liVars.OneItemWasAdded) {
                scroller.css({
                  top: (afterP - (afterH - beforeH)) + 'px'
                });
              }
            }
          }
          if (!liVars.allDisplayed.peek()) {
            setTimeout(function() {
              var scroller_height, scroller_position;

              scroller_position = get_position(scroller);
              wrapper_height = wrapper.height();
              scroller_height = scroller.height();
              if (scroller_height - wrapper_height + scroller_position < bottomBound && liVars.Direction === 'down' && liVars.DisplayedItems().length === liVars.DisplayCount()) {
                liVars.DisplayCount(liVars.DisplayCount() + liVars.CountStep);
              }
              if (-scroller_position < topBound && liVars.Direction === 'up' && liVars.DisplayedItems().length === liVars.DisplayCount()) {
                liVars.DisplayCount(liVars.DisplayCount() + liVars.CountStep);
              }
              return liVars.processing = false;
            }, 1);
          } else {
            liVars.processing = false;
          }
        }
        if (liVars.allDisplayed.peek() && count > arr.length) {
          setTimeout(function() {
            return liVars.Load.call(bindingContext.$data, liVars.DisplayedItems().length, liVars.DisplayedItems().length === 0 ? liVars.CountStart : liVars.CountStep);
          }, 1);
        }
        liVars.LastCount = all.length;
        return liVars.OneItemWasAdded = false;
      });
    }
    if (params && params["native"]) {
      $el.addClass('j_native_scroll_block');
    }
    nativeScrollInit = function(wrapper, scroller, scrollbar_cont, scrollbar_inner) {
      var body, nativeInner, nativeWrapper, ns;

      if (!wrapper.parent().is(".j_native_scroll_block:visible")) {
        return;
      }
      if (!$(".j_native_scroll").size()) {
        body = $("body");
        body.append('<div class="j_native_scroll"></div>');
        nativeWrapper = $(".j_native_scroll", body);
        nativeWrapper.append('<div class="j_native_scroll_inner">&nbsp;</div>');
        nativeInner = $(".j_native_scroll", nativeWrapper);
        nativeWrapper.css({
          "width": '18px',
          "height": "100%",
          "position": "fixed",
          "right": "0",
          "overflow-y": "auto",
          "overflow-x": "hidden",
          "z-index": "10000"
        });
        nativeInner.css({
          "height": "auto"
        });
      }
      ns = $(".j_native_scroll");
      $("html").unbind(WHEEL_EV + '.jscroll');
      $("html").bind(WHEEL_EV + '.jscroll', function(e) {
        pos = scrollWheelPos(e, wrapper, scroller, scrollbar_cont, scrollbar_inner);
        return ns.scrollTop(pos * -1);
      });
      console.log('scroll init');
      setNativeScrollHeight();
      wrapper.unbind('recalculateNative');
      wrapper.bind('recalculateNative', function() {
        return setNativeScrollHeight();
      });
      $(".j_native_scroll").unbind('scroll.jscroll');
      return $(".j_native_scroll").bind('scroll.jscroll', function() {
        return scrollTo(-1 * ns.scrollTop(), wrapper, scroller, scrollbar_cont, scrollbar_inner);
      });
    };
    scrollWheelPos = function(e, wrapper, scroller, scrollbar_cont, scrollbar_inner) {
      var deltaScale, deltaY, koef, wheelDeltaY;

      koef = get_koef(wrapper, scroller);
      deltaY = deltaScale = '';
      e = e.originalEvent;
      wheelDeltaY = e.detail ? e.detail * (-14) : e.wheelDelta / 3;
      pos_start = get_position(scroller);
      pageY_end = get_pageY(e);
      if (pos_start >= 0 && wheelDeltaY > 0 || (pos_start + wheelDeltaY) > 0) {
        wheelDeltaY = 0;
        pos_start = 0;
      }
      if ((pos_start <= (wrapper.height() - scroller.height())) && wheelDeltaY < 0 || (pos_start + wheelDeltaY) < wrapper.height() - scroller.height()) {
        pos_start = wrapper.height() - scroller.height();
        wheelDeltaY = 0;
      }
      pos = pos_start + wheelDeltaY;
      return pos;
    };
    scrollClick = function(e, wrapper, scroller, scrollbar_cont, scrollbar_inner) {
      var koef_bar, max_pos;

      if (e.type === START_EVENT) {
        if (params.noMoveMouse) {
          return;
        }
        pageY_start = get_pageY(e);
        pos_start = get_position(scroller);
        scrolling = true;
        return $('body').css({
          '-moz-user-select': 'none',
          '-ms-user-select': 'none',
          '-khtml-user-select': 'none',
          '-webkit-user-select': 'none',
          '-webkit-touch-callout': 'none',
          'user-select': 'none'
        });
      } else if (e.type === MOVE_EVENT) {
        if (!scrolling) {
          return;
        }
        if (isTouch) {
          scroll_show(scrollbar_inner);
        }
        koef_bar = get_koef(wrapper, scroller);
        pageY_end = get_pageY(e);
        if (move_by_bar) {
          pos = pos_start * koef_bar - (pageY_end - pageY_start);
          pos = pos / koef_bar;
        } else {
          pos = pos_start + (pageY_end - pageY_start);
        }
        if (pos >= 0) {
          pos_start = get_position(scroller);
          pageY_start = pageY_end;
          pos = 0;
        }
        max_pos = wrapper.height() - scroller.height();
        if (pos <= max_pos) {
          pos_start = get_position(scroller);
          pageY_start = pageY_end;
          pos = max_pos;
        }
        scrollTo(pos, wrapper, scroller, scrollbar_cont, scrollbar_inner);
        params.noMoveMouse = true;
        if (wrapper.parent().hasClass("j_native_scroll_block")) {
          return $(".j_native_scroll").scrollTop(pos * -1);
        }
      } else if (e.type === END_EVENT) {
        if (!scrolling) {
          return;
        }
        scrolling = false;
        move_by_bar = false;
        if (isTouch) {
          scroll_hide(scrollbar_inner);
        }
        $('body').css({
          '-moz-user-select': '',
          '-ms-user-select': '',
          '-khtml-user-select': '',
          '-webkit-user-select': '',
          '-webkit-touch-callout': '',
          'user-select': ''
        });
        if (scroller_left_while_scrolling) {
          return scroll_hide(scrollbar_inner);
        }
      } else {

      }
    };
    setNativeScrollHeight = function() {
      var cont, el, h, winH;

      winH = $(window).height();
      h = scroller.height() + winH - wrapper.height();
      el = $(".j_native_scroll_inner");
      cont = el.parent();
      el.css({
        height: h + 'px'
      });
      if (winH < h) {
        cont.css({
          zIndex: 10000
        });
        return typeof params.onNativeScrollShow === "function" ? params.onNativeScrollShow() : void 0;
      } else {
        cont.css({
          zIndex: 0
        });
        return typeof params.onNativeScrollHide === "function" ? params.onNativeScrollHide() : void 0;
      }
    };
    scrollTo = function(posTop, wrapper, scroller, scrollbar_cont, scrollbar_inner) {
      scroll_show(scrollbar_inner);
      set_position(scroller, posTop);
      return set_bar_bounds();
    };
    get_pageY = function(e) {
      if (isTouch) {
        return e.originalEvent.targetTouches[0].clientY;
      } else {
        return e.clientY;
      }
    };
    set_position = function(object, pos) {
      return object.css({
        'position': 'relative',
        'top': pos
      });
    };
    get_position = function(object) {
      var position;

      position = object.css('top');
      if (position === 'auto') {
        position = 0;
      }
      return parseInt(position);
    };
    get_koef = function(wrapper, scroller) {
      var koef, s_height, w_height;

      w_height = wrapper.height();
      s_height = scroller.height();
      koef = w_height / s_height;
      return koef;
    };
    scroll_show = function(scrollbar_inner) {
      scrollbar_inner.stop(true, true);
      return scrollbar_inner.fadeIn(100);
    };
    scroll_hide = function(scrollbar_inner) {
      scrollbar_inner.stop(true, true);
      return scrollbar_inner.fadeOut("slow");
    };
    set_bar_bounds = function() {
      var c_height, inner_height, koef, pos_koef, scroller_height, scroller_position, visibility, wrapper_height;

      c_height = scrollbar_cont.height();
      koef = get_koef(wrapper, scroller);
      inner_height = c_height * koef;
      if (koef >= 1) {
        visibility = 'hidden';
      } else {
        visibility = 'visible';
      }
      scrollbar_inner.css({
        'height': inner_height,
        'visibility': visibility
      });
      scroller_position = get_position(scroller);
      wrapper_height = wrapper.height();
      scroller_height = scroller.height();
      if (scroller_position <= 0 && scroller_position <= (wrapper_height - scroller_height)) {
        pos = wrapper_height - scroller_height;
        pos = Math.min(pos, 0);
        set_position(scroller, pos);
      }
      pos_koef = scroller_position / wrapper_height;
      pos = wrapper_height * pos_koef;
      set_position(scrollbar_inner, pos * koef * -1);
      return checkTopBottomBounds(scroller_position, wrapper_height, scroller_height);
    };
    checkTopBottomBounds = function(scroller_position, wrapper_height, scroller_height) {
      if (scroller_position == null) {
        scroller_position = get_position(scroller);
      }
      if (wrapper_height == null) {
        wrapper_height = wrapper.height();
      }
      if (scroller_height == null) {
        scroller_height = scroller.height();
      }
      if (scroller_height - wrapper_height + scroller_position < bottomBound) {
        if (isOnBottom === false) {
          isOnBottom = true;
          if (typeof onBottom === "function") {
            onBottom(true);
          }
          if (liVars && !liVars.processing && liVars.Direction === 'down' && liVars.DisplayedItems().length === liVars.DisplayCount()) {
            liVars.DisplayCount(liVars.DisplayCount() + liVars.CountStep);
          }
        }
      } else if (isOnBottom === true) {
        isOnBottom = false;
        if (typeof onBottom === "function") {
          onBottom(false);
        }
      }
      if (-scroller_position < topBound) {
        if (isOnTop === false) {
          isOnTop = true;
          if (typeof onTop === "function") {
            onTop(true);
          }
          if (liVars && !liVars.processing && liVars.Direction === 'up' && liVars.DisplayedItems().length === liVars.DisplayCount()) {
            liVars.DisplayCount(liVars.DisplayCount() + liVars.CountStep);
          }
        }
      } else if (isOnTop === true) {
        isOnTop = false;
        if (typeof onTop === "function") {
          onTop(false);
        }
      }
      return params.onScroll({
        wrapper: wrapper,
        scroller: scroller,
        position: scroller_position,
        length: scroller_height
      });
    };
    scrolling = false;
    move_by_bar = false;
    debounce = function(func, wait, immediate) {
      var args, delayed, result, thisArg, timeoutId,
        _this = this;

      args = null;
      result = null;
      thisArg = null;
      timeoutId = null;
      delayed = function() {
        timeoutId = null;
        if (!immediate) {
          return result = func.apply(thisArg, args);
        }
      };
      return function() {
        var isImmediate;

        isImmediate = immediate && !timeoutId;
        args = arguments;
        thisArg = _this;
        clearTimeout(timeoutId);
        timeoutId = setTimeout(delayed, wait);
        if (isImmediate) {
          result = func.apply(thisArg, args);
        }
        return result;
      };
    };
    params = $.extend({
      onScroll: function(opt) {},
      noMoveMouse: true
    }, params);
    scroll_array = new Array;
    vendor = /webkit/i.test(navigator.appVersion) ? 'webkit' : /firefox/i.test(navigator.userAgent) ? 'Moz' : __indexOf.call(window, 'opera') >= 0 ? 'O' : '';
    isIthing = /iphone|ipad/gi.test(navigator.appVersion);
    isTouch = typeof window['ontouchstart'] !== 'undefined';
    has3d = (window['WebKitCSSMatrix'] != null) && ((new window['WebKitCSSMatrix']())['m11'] != null);
    START_EVENT = isTouch ? 'touchstart' : 'mousedown';
    MOVE_EVENT = isTouch ? 'touchmove' : 'mousemove';
    END_EVENT = isTouch ? 'touchend' : 'mouseup';
    WHEEL_EV = vendor === 'Moz' ? 'DOMMouseScroll' : 'mousewheel';
    if (!isTouch && $('.jscroll_wrapper', $el).size()) {
      return;
    }
    init = function() {
      var myScroll, scrollbar_bar, scroller_inner;

      $el.wrapInner('<div class="jscroll_wrapper" />');
      wrapper = $(".jscroll_wrapper", $el);
      wrapper.attr("id", "jscroll_id" + Math.round(Math.random() * 10000000));
      scroller = wrapper.wrapInner('<div class="jscroll_scroller" />');
      scroller = $(".jscroll_scroller", wrapper);
      if (liVars != null) {
        if (typeof liVars.afterScrollInit === "function") {
          liVars.afterScrollInit();
        }
      }
      scrollbar_cont = $('<div class="jscroll_scrollbar_cont"></div>').insertAfter(scroller);
      scrollbar_cont.css({
        'position': 'absolute',
        'right': '0px',
        'width': '13px',
        'top': '3px',
        'bottom': '6px'
      });
      scrollbar_inner = $('<div class="jscroll_scrollbar_inner"></div>').appendTo(scrollbar_cont);
      scrollbar_inner.css({
        'position': 'relative',
        'width': '100%',
        'display': 'none',
        'opacity': '0.4',
        'cursor': 'pointer'
      });
      scrollbar_bar = $('<div class="jscroll_scrollbar_bar"></div>').appendTo(scrollbar_inner);
      scrollbar_bar.css({
        'position': 'relative',
        'background': 'black',
        'width': '5px',
        'margin': '0 auto',
        'border-radius': '3px',
        'height': '100%',
        '-webkit-border-radius': '3px'
      });
      wrapper.css({
        "position": "relative",
        "height": "100%",
        "overflow": "hidden"
      });
      scroller.css({
        "min-height": "100%",
        "overflow": "hidden"
      });
      if (isTouch) {
        scroller.after('<div class="jscroll_scroller_inner" />');
        scroller_inner = $(".jscroll_scroller_inner", wrapper);
        scroller_inner.appendTo('<div></div>');
        myScroll = new iScroll(wrapper.attr("id"), {
          hScrollbar: false,
          scrollbarClass: 'jscroll_scroller_inner',
          checkDOMChanges: true,
          bounceLock: true,
          onScrollMove: function() {
            params.onScroll();
            return true;
          },
          onScrollEnd: function() {
            params.onScroll();
            return true;
          }
        });
        return true;
      } else {
        return set_bar_bounds();
      }
    };
    init();
    if (isTouch) {
      return;
    }
    jscroll_timer = new Array;
    wrapper.bind('resize', function(e) {
      var timer_id;

      timer_id = wrapper.attr('id');
      if (typeof jscroll_timer[timer_id] !== 'undefined') {
        clearTimeout(jscroll_timer[timer_id]);
      }
      jscroll_timer[timer_id] = setTimeout(function() {
        set_bar_bounds();
        return delete jscroll_timer[timer_id];
      }, 100);
    });
    if (!isTouch) {
      wrapper.hover(function() {
        scroller_left_while_scrolling = false;
        set_bar_bounds();
        scroll_show(scrollbar_inner);
      }, function() {
        scroller_left_while_scrolling = true;
        if (scrolling) {
          return;
        }
        scroll_hide(scrollbar_inner);
      });
      updateLayout = debounce(function(e) {
        nativeScrollInit(wrapper, scroller, scrollbar_cont, scrollbar_inner);
      }, 500);
      wrapper.unbind('DOMNodeInserted', updateLayout);
      wrapper.unbind('DOMNodeRemoved', updateLayout);
      wrapper.bind('DOMNodeInserted', updateLayout);
      wrapper.bind('DOMNodeRemoved', updateLayout);
    }
    scrollbar_inner.bind(START_EVENT, function(e) {
      move_by_bar = true;
      params.noMoveMouse = false;
      return true;
    });
    wrapper.bind(START_EVENT, function(e) {
      scrollClick(e, wrapper, scroller, scrollbar_cont, scrollbar_inner);
      return true;
    });
    $(document).bind(MOVE_EVENT, function(e) {
      scrollClick(e, wrapper, scroller, scrollbar_cont, scrollbar_inner);
      return true;
    });
    $(document).bind(END_EVENT, function(e) {
      scrollClick(e, wrapper, scroller, scrollbar_cont, scrollbar_inner);
      return true;
    });
    return wrapper.on(WHEEL_EV, function(e) {
      var wheelPos;

      wheelPos = scrollWheelPos(e, wrapper, scroller, scrollbar_cont, scrollbar_inner);
      scrollTo(wheelPos, wrapper, scroller, scrollbar_cont, scrollbar_inner);
      if (!wrapper.parent().hasClass("j_native_scroll_block")) {
        return false;
      }
    });
  }
};

ko.bindingHandlers.loadingAnimation = {
  update: function(element, valueAccessor, allBindingsAccessor, viewModel, bindingContext) {
    var cont, data, defaults, el, loaderCont, options, val,
      _this = this;

    data = valueAccessor();
    el = $(element);
    val = data.value ? data.value : data;
    if (ko.isObservable(val)) {
      val = ko.utils.unwrapObservable(val);
    }
    if (((data.is != null) && val === data.is) || ((data.is == null) && val)) {
      defaults = {
        "wrClass": "",
        "image": "/img/loader.gif",
        "BG": "",
        "fadeInTime": 500,
        "fadeOutTime": 100,
        "text": "Загрузка...",
        "wrapper": "<div class='loadinganimation_hover'><div class='loadinganimation'><div class='loadinganimation_content'><div class='loadinganimation_content_fix'></div></div></div></div>"
      };
      options = $.extend(defaults, data.value ? data : {});
      if (el.children('.loadinganimation_hover').size()) {
        return false;
      }
      el.find(">*").animate({
        'opacity': 0
      }, options.fadeOutTime);
      el.append(options.wrapper);
      loaderCont = $(".loadinganimation_hover", el);
      if (options.BG) {
        loaderCont.css({
          'background': options.BG
        });
      }
      if (options.image) {
        $("<img src='" + options.image + "'><br>").appendTo($("div:last", loaderCont));
      }
      if (defaults.text) {
        $("<span>" + options.text + "</span>").appendTo($("div:last", loaderCont));
      }
      loaderCont.fadeIn(options.fadeInTime);
    } else {
      defaults = {
        "time": 200
      };
      options = $.extend(defaults, data.value ? data : {});
      loaderCont = $(".loadinganimation_hover", el);
      cont = loaderCont.parent();
      loaderCont.animate({
        opacity: 0
      }, options.time, function(e) {
        return loaderCont.remove();
      });
      cont.find(">*:not(.loadinganimation_hover)").animate({
        opacity: '1'
      }, options.time);
    }
  }
};

ko.bindingHandlers.phoneInput = {
  init: function(element, valueAccessor, allBindingsAccessor, viewModel, bindingContext) {
    var templatePath;

    templatePath = '/templates/phoneInput.html';
    loader.get('http').getAsync(templatePath, function(data) {
      var hidePopup, input, phoneButtons, phonePopup, showPopup, template, topchanged;

      $(document).on("click", function(e) {
        element = $(e.target);
        if (element.parents(".j_phone_popup_cloned").size() === 0 && element.parents(".h_phone_number_input").size() === 0) {
          $(".j_phone_popup_cloned").hide();
          return $(".i_phone_number_bg_active").removeClass("i_phone_number_bg_active");
        }
      });
      input = $(element);
      template = $(data);
      phonePopup = input.closest(".h_phone_number_bg").parent().find('div.b_phone_popup');
      phoneButtons = template.filter('div.i_phone_popup_button');
      input.before(phoneButtons);
      phonePopup.addClass('j_phone_popup_cloned');
      hidePopup = function() {
        phonePopup.hide();
        return input.closest(".h_phone_number_bg").removeClass("i_phone_number_bg_active");
      };
      topchanged = false;
      showPopup = function() {
        var inpitWidth;

        if (phonePopup.is(':visible')) {
          return;
        }
        inpitWidth = input.closest(".h_phone_number_bg").width() - 8;
        phonePopup.find('.l_column:last *').remove();
        phonePopup.css('width', inpitWidth);
        phonePopup.find('.b_actions_group_list').css('visibility', 'visible');
        phonePopup.fadeIn(200);
        if (!topchanged) {
          topchanged = true;
          phonePopup.offset({
            top: phonePopup.offset().top - 33
          });
        }
        input.closest(".h_phone_number_bg").addClass("i_phone_number_bg_active");
      };
      input.focusin(function() {
        return showPopup();
      });
      phoneButtons.click(function() {
        return showPopup();
      });
      phonePopup.on('click', '.b_actions_group_list li', function() {
        return hidePopup();
      });
      phonePopup.on('click', '.b_phone_panel li a', function(e) {
        e.preventDefault();
        input.val(input.val() + $(e.currentTarget).text());
        return input.keyup();
      });
      input.keyup(function(e) {
        phonePopup.find('.l_column:last *').remove();
        if (e.keyCode === 13) {
          phonePopup.find('.b_actions_group_list li:first').click();
          hidePopup();
          input.val('');
          return input.blur();
        }
      });
    });
  }
};

ko.bindingHandlers.appendTemplate = {
  init: function(element, valueAccessor, allBindingsAccessor, viewModel, bindingContext) {
    var data, url, vm;

    data = valueAccessor();
    if (!data) {
      return;
    }
    url = typeof data === 'string' ? data : typeof data.url === 'string' ? data.url : void 0;
    vm = data['with'] && typeof data['with'] === 'object' ? data['with'] : viewModel;
    return $.get(url, function(html) {
      var d;

      d = $(html);
      ko.virtualElements.setDomNodeChildren(element, d);
      if (!data.notApply) {
        return ko.applyBindingToJqueryEl(vm, d);
      }
    });
  }
};

ko.virtualElements.allowedBindings.appendTemplate = true;

ko.virtualElements.allowedBindings.oktellspa_isPopup = true;

ko.bindingHandlers.oktellspa_isPopup = {
  init: function(element, valueAccessor, allBindingsAccessor, viewModel, bindingContext) {
    var $el, $html, $popup, bindings, data, el, html, popupTemplate, popupTemplateName, vm;

    data = valueAccessor();
    if (data.src) {
      html = ko.getTemplate(data.src);
      $html = $(html);
      if (element.nodeType === 8) {
        ko.virtualElements.setDomNodeChildren(element, $html);
        el = ko.virtualElements.childNodes(element);
        $el = $(el);
      } else {
        $el = $(element);
        $el.append($html);
      }
    } else {
      if (element.nodeType === 8) {
        el = ko.virtualElements.childNodes(element);
        $el = $(el);
      } else {
        $el = $(element);
      }
    }
    $el.hide();
    popupTemplateName = '/oktellspa/templates/popup.html';
    popupTemplate = ko.getTemplate(popupTemplateName);
    popupTemplate = popupTemplate.replace(/>[\s]+?</g, '><');
    $popup = $(popupTemplate);
    bindings = $el.attr('data-popup-bind');
    $popup.hide();
    $popup.attr('data-bind', bindings);
    $el.wrapAll($popup);
    $el.show();
    $popup = $el.closest('.l_popup');
    vm = data["with"] || viewModel;
    if (typeof data.afterRender === 'function') {
      return data.afterRender.call(vm, $popup);
    }
  }
};

ko.loadedEls = {};

ko.getTemplate = function(template, templateDocument) {
  var elem;

  templateDocument = templateDocument || document;
  elem = ko.loadedEls[template] || templateDocument.getElementById(template);
  if (elem && !ko.loadedEls[template]) {
    ko.loadedEls[template] = elem;
    ko.loadedUrls[template] = elem.innerHTML;
  } else if (!elem && !ko.loadedEls[template]) {
    ko.loadedEls[template] = document.createElement('div');
    elem = ko.loadedEls[template];
    if (!ko.loadedUrls[template]) {
      $.ajax({
        url: template,
        type: 'get',
        cache: false,
        async: false,
        success: function(data) {
          return ko.loadedUrls[template] = data;
        }
      });
    }
    ko.loadedEls[template] = $('<script type="text/html">' + ko.loadedUrls[template] + '</script>')[0];
  }
  return ko.loadedUrls[template];
};

ko.getTemplateContainer = function(template, templateDocument) {
  ko.getTemplate(template, templateDocument);
  return ko.loadedEls[template];
};

ko.aload = function() {
  this['allowTemplateRewriting'] = false;
  this.loadedUrls = {};
  this.loadedEls = {};
};

ko.aload.prototype = new ko.templateEngine();

ko.aload.prototype['renderTemplateSource'] = function(templateSource, bindingContext, options) {
  var nodes, templateNodes, templateNodesFunc, templateText, useNodesIfAvailable;

  useNodesIfAvailable = !(ko.utils.ieVersion < 9);
  templateNodesFunc = useNodesIfAvailable ? templateSource['nodes'] : null;
  templateNodes = templateNodesFunc ? templateSource['nodes']() : null;
  if (templateNodes) {
    nodes = ko.utils.makeArray(templateNodes.cloneNode(true).childNodes);
  } else {
    templateText = templateSource['text']();
    nodes = ko.utils.parseHtmlFragment(templateText);
  }
  return nodes;
};

ko.aload.prototype['makeTemplateSource'] = function(template, templateDocument) {
  var elem, self;

  if (typeof template === "string") {
    self = this;
    elem = ko.getTemplateContainer(template, templateDocument);
    if (!elem) {
      throw new Error("Cannot find template with ID " + template);
    }
    return new ko.templateSources.domElement(elem);
  } else if (template.nodeType === 1 || template.nodeType === 8) {
    return new ko.templateSources.anonymousTemplate(template);
  } else {
    throw new Error("Unknown template type: " + template);
  }
};

ko.aload.instance = new ko.aload();

ko.setTemplateEngine(ko.aload.instance);

/**
 * jQuery Cookie plugin
 *
 * Copyright (c) 2010 Klaus Hartl (stilbuero.de)
 * Dual licensed under the MIT and GPL licenses:
 * http://www.opensource.org/licenses/mit-license.php
 * http://www.gnu.org/licenses/gpl.html
 *
 */
jQuery.cookie = function (key, value, options) {

    // key and at least value given, set cookie...
    if (arguments.length > 1 && String(value) !== "[object Object]") {
        options = jQuery.extend({}, options);

        if (value === null || value === undefined) {
            options.expires = -1;
        }

        if (typeof options.expires === 'number') {
            var days = options.expires, t = options.expires = new Date();
            t.setDate(t.getDate() + days);
        }

        value = String(value);

        return (document.cookie = [
            encodeURIComponent(key), '=',
            options.raw ? value : encodeURIComponent(value),
            options.expires ? '; expires=' + options.expires.toUTCString() : '', // use expires attribute, max-age is not supported by IE
            options.path ? '; path=' + options.path : '',
            options.domain ? '; domain=' + options.domain : '',
            options.secure ? '; secure' : ''
        ].join(''));
    }

    // key and possibly options given, get cookie...
    options = value || {};
    var result, decode = options.raw ? function (s) { return s; } : decodeURIComponent;
    return (result = new RegExp('(?:^|; )' + encodeURIComponent(key) + '=([^;]*)').exec(document.cookie)) ? decode(result[1]) : null;
};
// Generated by CoffeeScript 1.6.2
var __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; };

loader.types['languages'] = [
  (function() {
    function _Class() {
      this.setNodeItems = __bind(this.setNodeItems, this);
      var _this = this;

      this.selectedLanguage = false;
      this.languages = ko.observableArray([]);
      this.langsCount = ko.computed(function() {
        return _this.languages().length;
      });
      this.selectLanguage = function(langObj) {
        if (_this.selectedLanguage !== langObj) {
          _this.selectedLanguage = langObj;
          $.cookie('appLanguage', langObj.id, {
            path: '/',
            expires: 365
          });
          return location.reload();
        }
      };
      $.ajax({
        url: '/langs/langsList.json',
        dataType: 'json',
        async: false,
        success: function(data) {
          var l, lang, langObj, _i, _len;

          for (_i = 0, _len = data.length; _i < _len; _i++) {
            l = data[_i];
            _this.languages.push({
              id: l.id.toLowerCase(),
              file: l.file,
              name: l.name,
              css: 'flag-' + l.id.toLowerCase()
            });
          }
          lang = $.cookie('appLanguage') || navigator.language.split('-')[0] || 'en';
          langObj = _.find(_this.languages(), function(l) {
            return l.id.toLowerCase() === lang.toLowerCase();
          });
          if (!langObj) {
            langObj = _.find(_this.languages(), function(l) {
              return l.id.toLowerCase() === 'en';
            });
          }
          langObj.css += ' selected';
          $.cookie('appLanguage', langObj.id.toLowerCase(), {
            path: '/',
            expires: 365
          });
          _this.selectedLanguage = langObj;
          return _this.loadTranslations('/langs/' + _this.selectedLanguage.file);
        }
      });
    }

    _Class.prototype.setNodeItems = function(cache, node) {
      var $node, name, nodeCache,
        _this = this;

      $node = $(node);
      if ($node.is('languagefile')) {
        nodeCache = cache;
      } else {
        name = $node.attr('name');
        if (!name) {
          return;
        }
        nodeCache = cache[name] || (cache[name] = {});
      }
      $node.children('item').each(function(i, item) {
        var $item, itemName;

        $item = $(item);
        itemName = $item.attr('key');
        return nodeCache[itemName] = $item.text();
      });
      $node.children('node').each(function(i, childNode) {
        _this.setNodeItems(nodeCache, childNode);
      });
    };

    _Class.prototype.loadTranslations = function(url, callback) {
      var _this = this;

      return $.ajax({
        url: url,
        async: false,
        error: function() {
          $.cookie('appLanguage', 'en');
          return location.reload();
        },
        success: function(data) {
          var cache, xml;

          if (!data) {
            $.cookie('appLanguage', 'en');
            location.reload();
          }
          xml = $(data);
          cache = {};
          _this.setNodeItems(cache, xml.find('languagefile:first'));
          document.title = cache.menu.windowTitle;
          BaseType.prototype.langs = cache;
          window.langs = cache;
          return callFunc(callback);
        }
      });
    };

    return _Class;

  })()
];

// Generated by CoffeeScript 1.6.2
var Popup,
  __hasProp = {}.hasOwnProperty,
  __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; },
  _this = this;

Popup = (function(_super) {
  __extends(Popup, _super);

  function Popup() {
    var _this = this;

    Popup.__super__.constructor.apply(this, arguments);
    this.visible = ko.observable(false);
    this.visible.subscribe(function(val) {
      return _this.trigger(val ? 'show' : 'hide');
    });
  }

  Popup.prototype.hide = function() {
    return this.visible(false);
  };

  Popup.prototype.show = function() {
    return this.visible(true);
  };

  return Popup;

})(BaseType);

BaseType.prototype.setLogGroup = function(group, css) {
  addLogGroup(group, css);
  return function() {
    return logGroup.apply(window, [group].concat(Array.prototype.slice.call(arguments)));
  };
};

// Generated by CoffeeScript 1.6.2
var __hasProp = {}.hasOwnProperty,
  __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

loader.types['failPopup'] = [
  (function(_super) {
    __extends(_Class, _super);

    function _Class() {
      var defaultHeader, defaultMessage,
        _this = this;

      _Class.__super__.constructor.apply(this, arguments);
      defaultHeader = this.langs.popups.fail.defaultHeader;
      defaultMessage = this.langs.popups.fail.defaultMessage;
      this.onNextTryAgainClick = false;
      this.message = ko.observable('');
      this.header = ko.observable('');
      this.showTryAgain = ko.observable(true);
      this.show = function(header, message, showTryAgain, onNextTryAgainClick) {
        if (header == null) {
          header = defaultHeader;
        }
        if (message == null) {
          message = defaultMessage;
        }
        if (showTryAgain == null) {
          showTryAgain = true;
        }
        if (onNextTryAgainClick == null) {
          onNextTryAgainClick = false;
        }
        _this.header(header || '');
        _this.message(message || '');
        _this.showTryAgain(showTryAgain);
        _this.onNextTryAgainClick = onNextTryAgainClick;
        return _this.visible(true);
      };
      this.tryAgain = function() {
        var result;

        location.reload();
        return;
        if (typeof _this.onNextTryAgainClick === 'function') {
          result = _this.onNextTryAgainClick();
        }
        if (result === false) {
          return;
        }
        return _this.trigger('tryAgain');
      };
    }

    return _Class;

  })(Popup)
];

// Generated by CoffeeScript 1.5.0
var __hasProp = {}.hasOwnProperty,
  __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

loader.types['http'] = [
  (function(_super) {

    __extends(_Class, _super);

    function _Class() {
      _Class.__super__.constructor.apply(this, arguments);
    }

    _Class.prototype.cache = {};

    _Class.prototype.getAsync = function(url, callback, notUseCache) {
      var _this = this;
      if (notUseCache == null) {
        notUseCache = false;
      }
      if (this.cache[url] && !notUseCache) {
        return callFunc(callback, this.cache[url]);
      } else {
        return this.loadAsync(url, function(d) {
          _this.cache[url] = d;
          return callFunc(callback, _this.cache[url]);
        });
      }
    };

    _Class.prototype.get = function(url, notUseCache) {
      if (notUseCache == null) {
        notUseCache = false;
      }
      if (!this.cache[url] || notUseCache) {
        this.cache[url] = this.load(url);
      }
      return this.cache[url];
    };

    _Class.prototype.load = function(url) {
      var d;
      d = '';
      $.ajax({
        url: url,
        type: 'get',
        async: false,
        success: function(data) {
          return d = data;
        }
      });
      return d;
    };

    _Class.prototype.loadAsync = function(url, callback) {
      var d;
      d = '';
      $.ajax({
        url: url,
        type: 'get',
        async: true,
        success: function(data) {
          return callFunc(callback, data);
        }
      });
    };

    return _Class;

  })(BaseType)
];

// Generated by CoffeeScript 1.6.2
var MainMenu,
  __hasProp = {}.hasOwnProperty,
  __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

loader.types['mainMenu'] = [
  'app', 'localstorage', 'userProfile', 'oktell', 'stopPopup', 'breakPopup', 'dialog', MainMenu = (function(_super) {
    __extends(MainMenu, _super);

    function MainMenu(app, lStorage, userProfile, oktell, stopPopup, breakPopup, dialog) {
      var $menu, $statusInput, $statusMenu, loadCards,
        _this = this;

      MainMenu.__super__.constructor.apply(this, arguments);
      this.inCallCenter = ko.observable();
      this.cardIsActive = dialog.isActive;
      ko.computed(function() {
        if (dialog.isActive()) {
          return ko.router.go('card');
        }
      });
      this.test = function(info) {
        return app.testCard(info.formId + '_' + info.formCacheId);
      };
      this.removePanel = function() {
        return $('.j_panel').remove();
      };
      this.cards = ko.observableArray();
      loadCards = function(cards) {
        var info, k, v, _i, _len, _ref, _results;

        _results = [];
        for (_i = 0, _len = cards.length; _i < _len; _i++) {
          v = cards[_i];
          k = (_ref = v.match('[^_]+?_([^_]+?_.+)')) != null ? _ref[1] : void 0;
          if (k) {
            info = lStorage.get('showInfo_' + k);
            if (info) {
              _results.push(_this.cards.push(info));
            } else {
              _results.push(void 0);
            }
          } else {
            _results.push(void 0);
          }
        }
        return _results;
      };
      loadCards(app.cards);
      this.showCallPopup = function() {
        return app.showPopup('call');
      };
      this.loadCacheDump = function() {
        return $.ajax({
          url: '/dev/cardsCacheDump.json',
          dataType: 'json',
          success: function(data) {
            var k, v;

            if (data != null) {
              for (k in data) {
                v = data[k];
                lStorage.set(k, v);
              }
              app.cards = lStorage.get('formMetaData') || [];
              return loadCards(app.cards);
            }
          }
        });
      };
      this.testModeOff = function() {
        return window.testMode(false);
      };
      this.userName = ko.observable('');
      this.profileLink = ko.computed(function() {
        if (ko.route()) {
          return '#' + ko.route().split('/')[0] + '/profile';
        } else {
          return '#stats/profile';
        }
      });
      this.cardMenuItemVisible = ko.computed(function() {
        return dialog.isActive();
      });
      this.menuItems = ko.observableArray([
        {
          caption: this.langs.menu.items.stats,
          url: '#stats',
          cssClass: 'i_stats',
          active: ko.observable(false),
          visible: true
        }, {
          caption: this.langs.menu.items.schedule,
          url: '#schedule',
          cssClass: 'i_graph',
          active: ko.observable(false),
          visible: true
        }, {
          caption: this.langs.menu.items.journal,
          url: '#journal',
          cssClass: 'i_calls',
          active: ko.observable(false),
          visible: true
        }, {
          caption: this.langs.menu.items.card,
          url: '#card',
          cssClass: 'i_card',
          active: ko.observable(false),
          visible: this.cardMenuItemVisible
        }
      ]);
      ko.route.subscribe(function(val) {
        var m, _i, _len, _ref, _results;

        _ref = _this.menuItems();
        _results = [];
        for (_i = 0, _len = _ref.length; _i < _len; _i++) {
          m = _ref[_i];
          if (val.indexOf(m.url.substr(1)) === 0) {
            _results.push(m.active(true));
          } else {
            _results.push(m.active(false));
          }
        }
        return _results;
      });
      this.showUserProfile = function() {
        return userProfile.trigger('showPopup');
      };
      this.avatarPath = ko.observable('/img/noavatar.png');
      userProfile.userAvatarPath.subscribe(function(path) {
        path = path || userProfile.userAvatarPath();
        _this.avatarPath('/img/noavatar.png');
        return _this.avatarPath(path);
      });
      this.pos = {
        stop: ko.observable(lStorage.get('stopVisible')),
        "break": ko.observable(lStorage.get('breakVisible')),
        login: ko.observable(lStorage.get('loginVisible'))
      };
      this.pos.checker = ko.computed(function() {
        lStorage.set('stopVisible', _this.pos.stop());
        lStorage.set('breakVisible', _this.pos["break"]());
        return lStorage.set('loginVisible', _this.pos.login());
      });
      breakPopup.visible(this.pos["break"]());
      stopPopup.visible(this.pos.stop());
      this.showStopPopup = function() {
        return stopPopup.show('test');
      };
      this.showBreakPopup = function() {
        return breakPopup.visible(true);
      };
      this.disconnect = function() {
        app.showPopup('loading', '', true);
        app.startExit = true;
        lStorage.set('voiceparam', '');
        app.disconnect();
        return location.reload();
      };
      this.showLogin = function() {
        return app.showPopup('login');
      };
      this.statusMenuVisible = ko.observable(false);
      this.currentStatus = ko.observable();
      this.statusText = ko.computed(function() {
        var s;

        s = _this.currentStatus();
        if ((s != null) && (s.text != null)) {
          return s.text;
        } else {
          return '';
        }
      });
      this.statusCss = ko.computed(function() {
        var s;

        s = _this.currentStatus();
        if ((s != null) && (s.css != null)) {
          return s.css;
        } else {
          return '';
        }
      });
      this.showStatusMenu = function() {
        return _this.statusMenuVisible(true);
      };
      this.hideStatusMenu = function() {
        return _this.statusMenuVisible(false);
      };
      $menu = false;
      $statusInput = false;
      $statusMenu = false;
      this.statuses = ko.observableArray([]);
      this.stInCC = [
        {
          id: 'ready',
          css: 'm_ready',
          text: this.langs.menu.statuses.ready
        }, {
          id: 'break',
          css: 'm_busy',
          text: this.langs.menu.statuses["break"]
        }
      ];
      this.stOffCC = [
        {
          id: 'ready',
          css: 'm_ready',
          text: this.langs.menu.statuses.ready
        }, {
          id: 'dnd',
          css: 'm_away',
          text: this.langs.menu.statuses.dnd
        }, {
          id: 'redirect',
          css: 'm_forwarding',
          text: this.langs.menu.statuses.redirect
        }
      ];
      this.inCallCenter.subscribe(function(val) {
        _this.statuses(val ? _this.stInCC : _this.stOffCC);
        return _this.setStatus(oktell.getStatus(), true);
      });
      this.setStatusFromMenu = function(s) {
        return _this.setStatus(s);
      };
      this.setStatus = function(s, dontShowPopup) {
        if (typeof s === 'string') {
          s = _.find(_this.statuses(), function(o) {
            return o.id === s;
          });
        }
        if ((s == null) || (s.text == null) || (s.css == null) || (s.id == null)) {
          return;
        }
        _this.currentStatus(s);
        if (s.id === 'break' && !dontShowPopup) {
          breakPopup.show();
        } else if (oktell.getStatus() !== s.id) {
          oktell.setStatus(s.id);
        }
        return _this.hideStatusMenu();
      };
      oktell.on('statusChange', function(newStatus) {
        return _this.setStatus(newStatus, true);
      });
      oktell.on('oktellConnected', function() {
        breakPopup.reasons(_.toArray(oktell.getBreakReasons()) || []);
        _this.setStatus(oktell.getStatus(), true);
        return _this.userName(oktell.getMyInfo().login);
      });
      oktell.on('callCenterStateChange', function(inCallCenter) {
        return _this.inCallCenter(inCallCenter);
      });
      this.beforeStatusMenuShow = function(el) {
        var $el, hideTimer;

        $el = $(el);
        log($el);
        if (!$menu) {
          $menu = $('#mainMenu');
          $statusInput = $('#statusMenuInput');
          $statusMenu = $('#statusMenu');
          hideTimer = '';
          $statusMenu.mouseenter(function() {
            return clearTimeout(hideTimer);
          });
          $statusMenu.mouseleave(function() {
            return hideTimer = setTimeout(function() {
              return _this.statusMenuVisible(false);
            });
          });
          $statusInput.mouseenter(function() {
            return clearTimeout(hideTimer);
          });
          $statusInput.mouseleave(function() {
            return hideTimer = setTimeout(function() {
              return _this.statusMenuVisible(false);
            }, 500);
          });
        }
        return $el.css({
          top: $statusInput.offset().top - 25,
          left: $menu.offset().left + $menu.width()
        });
      };
      breakPopup.on('cancel', function() {
        return _this.setStatus(oktell.getStatus());
      });
      breakPopup.on('goBreak', function(reason) {
        var s;

        s = _.find(_this.statuses(), function(o) {
          return o.id === 'break';
        });
        _this.currentStatus(s);
        oktell.setStatus(s.id, false, reason);
        return _this.hideStatusMenu();
      });
    }

    return MainMenu;

  })(BaseType)
];

// Generated by CoffeeScript 1.6.2
var __hasProp = {}.hasOwnProperty,
  __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

loader.types['loginPopup'] = [
  'languages', 'localstorage', (function(_super) {
    __extends(_Class, _super);

    function _Class(languages, LS) {
      var _this = this;

      _Class.__super__.constructor.apply(this, arguments);
      this.languages = languages.languages;
      this.langsCount = languages.langsCount;
      this.selectLanguage = languages.selectLanguage;
      this.login = ko.observable(this.savedParam('login') || '');
      this.password = ko.observable('');
      this.server = ko.observable('');
      this.loginHasFocus = ko.observable(false);
      this.passHasFocus = ko.observable(false);
      setInterval(function() {
        return $(window).trigger('orientationchange');
      }, 2000);
      this.showBadPass = ko.observable(false);
      this.savePass = ko.observable(false);
      this.useVoice = ko.observable(this.savedParam('webrtc'));
      this.showUseVoice = ko.observable(window.chrome ? true : false);
      this.buttonHasFocus = ko.observable(false);
      this.buttonHasFocus.subscribe(function(val) {
        if (!val && _this.visible()) {
          return _this.loginHasFocus(true);
        }
      });
      this.show = function(showBadPass) {
        if (showBadPass == null) {
          showBadPass = false;
        }
        _this.showBadPass(showBadPass);
        _this.savePass(false);
        _this.password('');
        return _this.visible(true);
      };
      this.hide = function() {
        _this.visible(false);
        _this.passHasFocus(false);
        _this.buttonHasFocus(false);
        return _this.loginHasFocus(false);
      };
      this.goLogin = function() {
        var _this = this;

        if (window.webkitNotifications && window.webkitNotifications.checkPermission() !== 0) {
          this.trigger('webkitNotificationsPermissionRequestStart');
          webkitNotifications.requestPermission(function() {
            return _this.trigger('webkitNotificationsPermissionRequestEnd');
          });
        }
        return this.trigger('login', this.login(), this.password(), this.savePass(), this.server(), this.useVoice());
      };
      this.afterShow = function() {
        return setTimeout(function() {
          if (_this.login()) {
            return _this.passHasFocus(true);
          } else {
            return _this.loginHasFocus(true);
          }
        }, 300);
      };
    }

    _Class.prototype.savedParam = function(param, val) {
      if (!param) {
        return;
      }
      if (val === false) {
        $.cookie('__oktell' + param, null);
      } else if (val) {
        $.cookie('__oktell' + param, val, {
          path: '/',
          expires: 14
        });
      }
      return $.cookie('__oktell' + param);
    };

    return _Class;

  })(Popup)
];

// Generated by CoffeeScript 1.6.2
var __hasProp = {}.hasOwnProperty,
  __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

loader.types['loadingPopup'] = [
  (function(_super) {
    __extends(_Class, _super);

    function _Class() {
      _Class.__super__.constructor.apply(this, arguments);
      this.text = ko.observable('');
      this.buttonVisible = ko.observable(true);
    }

    _Class.prototype.cancel = function() {
      return this.trigger('cancel');
    };

    _Class.prototype.show = function(text, hideButton) {
      if (text == null) {
        text = this.langs.popups.loading.connecting;
      }
      this.text(text);
      this.buttonVisible(!Boolean(hideButton));
      return this.visible(true);
    };

    return _Class;

  })(Popup)
];

// Generated by CoffeeScript 1.6.2
var __hasProp = {}.hasOwnProperty,
  __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

loader.types['breakPopup'] = [
  (function(_super) {
    __extends(_Class, _super);

    function _Class() {
      var _this = this;

      _Class.__super__.constructor.apply(this, arguments);
      this.visible = ko.observable(false);
      this.reasons = ko.observableArray([]);
      this.reason = ko.observable('');
      this.customReason = ko.observable('');
      this.showedFromConfirm = ko.observable(false);
      this.customReasonFocus = ko.observable(false);
      this.customReasonFocus.subscribe(function(val) {
        if (val) {
          return _this.reason('custom');
        }
      });
      this.reason.subscribe(function(val) {
        if (val === 'custom') {
          return _this.customReasonFocus(true);
        }
      });
      this.validCustom = ko.computed(function() {
        return _this.reason() && _this.reason() !== 'custom' || _this.reason() === 'custom' && _this.customReason();
      });
      this.afterShow = function() {};
      this.show = function() {
        var _ref;

        _this.customReasonFocus(false);
        _this.customReason('');
        _this.reason((_ref = _this.reasons()[0]) != null ? _ref.id.toString() : void 0);
        _this.showedFromConfirm(false);
        return _this.visible(true);
      };
      this.afterRender = function(el) {
        var $el;

        return $el = $(el);
      };
      this.onScroll = function(opt) {
        return log(opt);
      };
      this.hide = function() {
        return _this.visible(false);
      };
      this.goBreak = function() {
        if (!_this.validCustom()) {
          return _this.customReasonFocus(true);
        } else {
          _this.trigger('goBreak', _this.reason() === 'custom' ? _this.customReason() : _this.reason());
          return _this.hide();
        }
      };
      this.cancel = function() {
        _this.trigger('cancel');
        return _this.hide();
      };
    }

    return _Class;

  })(Popup)
];

// Generated by CoffeeScript 1.6.2
var __hasProp = {}.hasOwnProperty,
  __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

loader.types['stopPopup'] = [
  'localstorage', (function(_super) {
    __extends(_Class, _super);

    function _Class(ls) {
      var setTimeCss,
        _this = this;

      _Class.__super__.constructor.apply(this, arguments);
      this.fDate = 'DD.MM.YYYY';
      this.fTime = 'HH:mm';
      this.fVal = 'YYYY-MM-DD HH:mm:ss';
      this.visible = ko.observable(false);
      this.nextAction = ko.observable('');
      this.userResult = ko.observable('');
      this.userResults = false;
      this.userResultsSuccessVisible = ko.observable(false);
      this.userResultsFailVisible = ko.observable(false);
      this.dateTimeVisible = ko.observable(false);
      this.resultSuccess = ko.observable(true);
      this.resultFail = ko.observable(false);
      ko.computed(function() {
        var nextAction, resultFail;

        resultFail = _this.resultFail();
        nextAction = _this.nextAction();
        if (!resultFail || nextAction !== 'redial') {
          return _this.dateTimeVisible(false);
        }
      });
      this.redialTimes = ko.observableArray([
        {
          text: this.langs.callcenter.popups.stop.redialTime.m15,
          time: 15,
          css: ko.observable(false)
        }, {
          text: this.langs.callcenter.popups.stop.redialTime.m30,
          time: 30,
          css: ko.observable(false)
        }, {
          text: this.langs.callcenter.popups.stop.redialTime.h1,
          time: 60,
          css: ko.observable(false)
        }, {
          text: this.langs.callcenter.popups.stop.redialTime.later,
          time: 'ds',
          css: ko.observable(false)
        }
      ]);
      this.redialTime = ko.observable('');
      this.newNumber = ko.observable('');
      this.comment = ko.observable('');
      this.dataVaild = ko.computed(function() {
        return true;
      });
      this.newNumberInputVisible = ko.observable(false);
      this.getInfoForSend = function() {
        if (_this.visible()) {
          return {
            idShow: _this.idShow,
            comment: _this.comment(),
            userResults: _this.userResults
          };
        } else {
          return false;
        }
      };
      this.setRedialTimeFromDateTimePicker = function() {
        return _this.redialTime(moment(_this.dateInput.val() + ' ' + _this.timeInput.val(), _this.fDate + ' ' + _this.fTime).format(_this.fVal));
      };
      this.afterRender = function(el) {
        var $el;

        $el = $(el);
        _this.el = $el;
        _this.dateInput = $el.find('input.j_recall_callendar');
        _this.dateInput.datepicker({
          format: 'dd.mm.yyyy'
        });
        _this.dateInput.datepicker().on('changeDate', function(e) {
          _this.dateInput.blur();
          return _this.closeDateTimeWidgets();
        });
        _this.dateInput.on('blur', function() {
          if (_this.dateTimeVisible()) {
            return _this.setRedialTimeFromDateTimePicker();
          }
        });
        _this.timeInput = $el.find('input.j_recall_time');
        _this.timeInput.timepicker({
          minuteStep: 1,
          defaultTime: false,
          showMeridian: false
        });
        _this.timeInput.on('change', function() {
          if (_this.dateTimeVisible()) {
            _this.setRedialTimeFromDateTimePicker();
          }
          return true;
        });
        _this.setDateTimeInputVals();
        _this.inputSuccess = _this.el.find('#stopFormUserResultComboSuccess');
        _this.inputFail = _this.el.find('#stopFormUserResultComboFail');
        _this.inputSuccess.on('change', function(e) {
          return _this.userResult(e.val);
        });
        return _this.inputFail.on('change', function(e) {
          return _this.userResult(e.val);
        });
      };
      this.setDateTimeInputVals = function() {
        if ((_this.dateInput.size != null) && _this.dateInput.size()) {
          _this.dateInput.datepicker('setValue', moment().format(_this.fDate));
        }
        if ((_this.timeInput.size != null) && _this.timeInput.size()) {
          return _this.timeInput.timepicker('setTime', moment().format(_this.fTime));
        }
      };
      this.closeDateTimeWidgets = function() {
        if ((_this.dateInput.size != null) && _this.dateInput.size()) {
          _this.dateInput.datepicker('hide');
        }
        if ((_this.timeInput.size != null) && _this.timeInput.size()) {
          return _this.timeInput.timepicker('hideWidget');
        }
      };
      this.visible.subscribe(function(val) {
        return _this.closeDateTimeWidgets();
      });
      this.onScroll = function(opt) {
        return log(opt);
      };
      this.hide = function() {
        _this.reset();
        return _this.visible(false);
      };
      this.show = function(data) {
        if (data === 'test') {
          data = ls.get('stopFormData');
        } else {
          ls.set('stopFormData', data);
        }
        if (!data) {
          return;
        }
        _this.reset();
        _this.idShow = data.idShow;
        _this.comment(data.comment);
        _this.userResults = data.userResults;
        _this.initUserResultSelects(_this.userResults);
        return _this.visible(true);
      };
      this.initUserResultSelects = function(userResults) {
        var fDefault, inputFail, inputSuccess, sDefault, uFailResults, uResults, uSuccessResults;

        uResults = ko.observableArray(userResults || []);
        _.each(uResults(), function(r) {
          return r.text = r.name;
        });
        uSuccessResults = _.filter(uResults(), function(r) {
          return r.issuccess;
        });
        uFailResults = _.filter(uResults(), function(r) {
          return !r.issuccess;
        });
        if (uSuccessResults.length) {
          _this.userResultsSuccessVisible(true);
        }
        if (uFailResults.length) {
          _this.userResultsFailVisible(true);
        }
        inputSuccess = _this.el.find('#stopFormUserResultComboSuccess');
        inputFail = _this.el.find('#stopFormUserResultComboFail');
        if (_this.selectsWasCreated) {
          inputSuccess.select2('destroy');
          inputFail.select2('destroy');
        }
        _this.selectsWasCreated = true;
        inputSuccess.select2({
          width: '100%',
          data: uSuccessResults,
          initSelection: function(element, callback) {
            var obj, val;

            val = element.val();
            obj = _.find(uSuccessResults, function(d) {
              return d.id.toString() === val.toString();
            });
            return callback(obj);
          }
        });
        inputFail.select2({
          width: '100%',
          data: uFailResults,
          initSelection: function(element, callback) {
            var obj, val;

            val = element.val();
            obj = _.find(uFailResults, function(d) {
              return d.id.toString() === val.toString();
            });
            return callback(obj);
          }
        });
        sDefault = _.find(uSuccessResults, function(r) {
          return r.isdefault;
        });
        fDefault = _.find(uFailResults, function(r) {
          return r.isdefault;
        });
        if (sDefault) {
          inputSuccess.select2('val', sDefault.id);
        }
        if (fDefault) {
          return inputFail.select2('val', fDefault.id);
        }
      };
      this.setResultFail = function() {
        _this.resultSuccess(false);
        return _this.resultFail(true);
      };
      this.setResultSuccess = function() {
        _this.resultFail(false);
        _this.resultSuccess(true);
        return _this.nextAction('excludeAbonent');
      };
      setTimeCss = function(time) {
        return _.each(_this.redialTimes(), function(t) {
          t.css(false);
          if (time && time === t.time) {
            t.css(true);
            return _this.nextAction('redial');
          }
        });
      };
      this.nextAction.subscribe(function(val) {
        if (val === 'redial') {
          return _this.setRedialTime(_this.redialTimes()[0]);
        } else {
          setTimeCss();
          return _this.redialTime(false);
        }
      });
      this.setRedialTime = function(t) {
        if (t.time === 'ds') {
          _this.setDateTimeInputVals();
          _this.setRedialTimeFromDateTimePicker();
          _this.dateTimeVisible(true);
        } else {
          _this.dateTimeVisible(false);
          _this.redialTime(t.time);
        }
        return setTimeCss(t.time);
      };
      this.reset = function() {
        _this.resultSuccess(true);
        _this.resultFail(false);
        _this.dateTimeVisible(false);
        _this.nextAction(false);
        _this.newNumber('');
        _this.comment('');
        _this.userResult('');
        _this.userResultsSuccessVisible(false);
        _this.userResultsFailVisible(false);
        _this.newNumberInputVisible(false);
        _this.nextAction('excludeAbonent');
        _this.setDateTimeInputVals();
        return _this.closeDateTimeWidgets();
      };
      this.afterShow = function() {};
      this.on('saveData', function(data) {
        return log('saveData', data);
      });
      this.saveData = function() {
        var data;

        if (!_this.dataVaild()) {
          return false;
        }
        data = {
          isSuccess: _this.resultSuccess(),
          comment: _this.comment()
        };
        if (!_this.resultSuccess()) {
          data.nextAction = _this.nextAction();
        }
        if (_this.newNumber()) {
          data.numbers = _.map(_this.newNumber().split(','), function(n) {
            return n.replace(/[ ]/g, '');
          });
        }
        if (_this.redialTime()) {
          if (typeof _this.redialTime() === 'number') {
            data.callAfterSec = _this.redialTime() * 60;
          } else {
            data.callAtDateTime = _this.redialTime();
          }
        }
        data.userResult = _this.userResult();
        _this.trigger('saveData', data);
        return _this.hide();
      };
      this.showNewNumberInput = function() {
        return _this.newNumberInputVisible(true);
      };
    }

    return _Class;

  })(Popup)
];

// Generated by CoffeeScript 1.5.0
var __hasProp = {}.hasOwnProperty,
  __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

loader.types['callPopup'] = [
  (function(_super) {

    __extends(_Class, _super);

    function _Class() {
      var _this = this;
      _Class.__super__.constructor.apply(this, arguments);
      this.callbacks = {};
      this.name = ko.observable('Вася Пупкин');
      this.number = ko.observable('89274513158');
      this.answerButtonVisible = ko.observable(false);
      this.actionAnswer = function() {
        callFunc(_this.callbacks.answer);
        return _this.hide();
      };
      this.actionReject = function() {
        callFunc(_this.callbacks.reject);
        return _this.hide();
      };
      this.actionHide = function() {
        callFunc(_this.callbacks.hide);
        return _this.hide();
      };
      this.show = function(name, number, onAnswer, onReject, onHide) {
        _this.callbacks = {};
        _this.name(name);
        _this.number(number !== name ? number : '');
        _this.callbacks.answer = onAnswer;
        _this.callbacks.reject = onReject;
        _this.callbacks.hide = onHide;
        return _this.visible(true);
      };
      this.hide = function() {
        _this.callbacks = {};
        _this.name('');
        _this.number('');
        return _this.visible(false);
      };
    }

    return _Class;

  })(Popup)
];

// Generated by CoffeeScript 1.6.2
var __hasProp = {}.hasOwnProperty,
  __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

loader.types['userProfile'] = [
  'oktell', (function(_super) {
    __extends(_Class, _super);

    function _Class(oktell) {
      var _this = this;

      this.popupVisible = ko.observable(false);
      this.username = ko.observable('');
      this.department = ko.observable('');
      this.number = ko.observable('');
      this.redirectNumber = ko.observable('');
      this.oldPass = ko.observable('');
      this.newPass = ko.observable('');
      this.showAvatarLoading = ko.observable(false);
      this.backgroundUrl = ko.observable('');
      this.userAvatarPath = ko.observable('/img/noavatar.png');
      this.inCallCenter = ko.observable(false);
      this.hidePopup = function() {
        _this.popupVisible(false);
        return ko.historyBack();
      };
      this.showPopup = function() {
        _this.reset();
        return _this.popupVisible(true);
      };
      this.on('showPopup', function() {
        return _this.showPopup();
      });
      oktell.on('oktellConnected', function() {
        var info;

        info = oktell.getMyInfo();
        _this.username(info.username || info.login);
        _this.number(info.number ? _this.langs.profile.userNumber + ': ' + info.number : '');
        _this.redirectNumber(info.redirectNumber || '');
        return _this.loadAvatar();
      });
      oktell.on('callCenterStateChange', function(inCallCenter) {
        return _this.inCallCenter(inCallCenter);
      });
      this.reset = function() {
        _this.redirectNumber(oktell.getMyInfo().redirectNumber || '');
        _this.oldPass('');
        return _this.newPass('');
      };
      this.afterShow = function() {};
      this.enableSaveRedirectButton = ko.computed(function() {
        var curr;

        curr = oktell.getMyInfo().redirectNumber || '';
        return _this.redirectNumber() !== curr;
      });
      this.saveRedirectNumber = function() {
        if (!_this.enableSaveRedirectButton()) {
          return;
        }
        oktell.setRedirectNumber(_this.redirectNumber(), function() {
          return _this.redirectNumber.notifySubscribers();
        });
        return false;
      };
      this.enableChangePassButton = ko.computed(function() {
        return _this.newPass() && _this.oldPass() !== _this.newPass() && _this.newPass().length >= 1 && md5(utf8DecodePass(_this.oldPass().toLowerCase())) === oktell.getMyInfo().password;
      });
      this.changePassword = function() {
        var newPassMd5, oldPassMd5;

        if (!_this.enableChangePassButton()) {
          return;
        }
        oldPassMd5 = md5(utf8DecodePass(_this.oldPass()));
        newPassMd5 = md5(utf8DecodePass(_this.newPass()));
        return oktell.exec('changepassword', {
          newpwdmd5: newPassMd5,
          oldpwdmd5: oldPassMd5
        }, function(data) {
          if (!data.result) {
            return alert(_this.langs.profile.passChangeError);
          } else {
            _this.oldPass('');
            return _this.newPass('');
          }
        });
      };
      this.selectAvatar = function(vm, event) {
        return oktell.uploadFile({
          storagemode: 'temp',
          pathmode: 'relative'
        }, function(data) {
          if (data.result) {
            return oktell.setUserAvatar(data.path, function() {
              return _this.loadAvatar();
            });
          }
        });
      };
      this.loadAvatar = function() {
        return oktell.getUserAvatar(function() {
          _this.backgroundUrl("url('" + oktell.getMyInfo().avatarLink96x96 + "')");
          _this.userAvatarPath(oktell.getMyInfo().avatarLink32x32 ? oktell.getMyInfo().avatarLink32x32 : "/img/noavatar.png");
          _this.backgroundUrl.notifySubscribers();
          return _this.userAvatarPath.notifySubscribers();
        });
      };
    }

    return _Class;

  })(BaseType)
];

// Generated by CoffeeScript 1.5.0
var __hasProp = {}.hasOwnProperty,
  __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

loader.types['localstorage'] = [
  (function(_super) {

    __extends(_Class, _super);

    function _Class() {
      _Class.__super__.constructor.apply(this, arguments);
      if (localStorage) {
        this.enabled = true;
      } else {
        this.enabled = false;
      }
    }

    _Class.prototype.get = function(key) {
      var obj;
      if (!this.enabled) {
        return;
      }
      try {
        obj = JSON.parse(localStorage.getItem(key));
      } catch (e) {
        obj = false;
      }
      return obj;
    };

    _Class.prototype.set = function(key, val) {
      if (!this.enabled) {
        return;
      }
      try {
        return localStorage.setItem(key, JSON.stringify(val));
      } catch (e) {
        return false;
      }
    };

    return _Class;

  })(BaseType)
];

loader.types['sessionstorage'] = [
  (function(_super) {

    __extends(_Class, _super);

    function _Class() {
      _Class.__super__.constructor.apply(this, arguments);
      if (sessionStorage) {
        this.enabled = true;
      } else {
        this.enabled = false;
      }
    }

    _Class.prototype.get = function(key) {
      var obj;
      if (!this.enabled) {
        return;
      }
      try {
        obj = JSON.parse(sessionStorage.getItem(key));
      } catch (e) {
        obj = false;
      }
      return obj;
    };

    _Class.prototype.set = function(key, val) {
      if (!this.enabled) {
        return;
      }
      try {
        return sessionStorage.setItem(key, JSON.stringify(val));
      } catch (e) {
        return false;
      }
    };

    return _Class;

  })(BaseType)
];

// Generated by CoffeeScript 1.6.2
var __hasProp = {}.hasOwnProperty,
  __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

loader.types['stats'] = [
  'oktell', (function(_super) {
    __extends(_Class, _super);

    function _Class(oktell) {
      var formatTime, formatTimeFull, loadInterval, log, oktellConnected,
        _this = this;

      _Class.__super__.constructor.apply(this, arguments);
      this.oktell = oktell;
      this.inCallCenter = ko.observable();
      this.isOperator = ko.observable(false);
      this.ccButtonsVisible = ko.computed(function() {
        return _this.inCallCenter() != null;
      });
      log = this.setLogGroup('STATS', 'background: #E626C7; color: yellow');
      this.fVal = 'YYYY-MM-DD HH:mm:ss';
      this.fTimeFull = 'H:mm:ss';
      this.fTimeM = 'mm:ss';
      this.fTimeH = 'H:mm:ss';
      oktellConnected = false;
      this.showBreakAndCount = ko.observable(false);
      this.tasks = ko.observableArray([]);
      this.currentState = ko.observable('');
      formatTimeFull = function(m) {
        if (!m) {
          return '';
        } else if (m.hours() > 0) {
          return m.format(_this.fTimeFull);
        } else {
          return m.format(_this.fTimeM);
        }
      };
      formatTime = function(m) {
        if (m) {
          return m.format(_this.fTimeH);
        } else {
          return '0:00:00';
        }
      };
      this.timeStr = ko.observable('from stat');
      this.currentStatus = ko.observable();
      this.currentStatus.subscribe(function(st) {
        var load;

        if (st === 'break') {
          log('0 1');
          _this.showBreakAndCount(true);
          _this.currentStatusTime(moment('1901-01-01 00:00:00', _this.fVal));
          load = function() {
            if (_this.loadData != null) {
              return _this.loadData(function(serverStatus) {
                if (serverStatus !== _this.currentStatus()) {
                  return setTimeout(load, 3000);
                }
              });
            } else {
              return setTimeout(load, 1000);
            }
          };
          setTimeout(load, 3000);
          return _this.checkCurrentCallIsTask(function(isTask) {
            if (isTask) {
              log('1 0');
              return _this.showBreakAndCount(false);
            } else {
              log('1 1');
              return _this.showBreakAndCount(true);
            }
          });
        } else {
          return _this.showBreakAndCount(false);
        }
      });
      this.currentStatusTime = ko.observable();
      setInterval(function() {
        var breakTime, curTime, showBreakAndCount, state, status, talkTime, workTime;

        curTime = _this.currentStatusTime();
        if (curTime) {
          curTime.add(1, 's');
        }
        _this.currentStatusTime.notifySubscribers();
        status = _this.currentStatus();
        state = _this.currentState();
        showBreakAndCount = _this.showBreakAndCount();
        breakTime = _this.breakTime();
        if (breakTime && status === 'break' && showBreakAndCount) {
          breakTime.add(1, 's');
          _this.breakTime.notifySubscribers();
        }
        workTime = _this.workTime();
        if (workTime && status !== 'dnd') {
          workTime.add(1, 's');
          _this.workTime.notifySubscribers();
        }
        talkTime = _this.talkTime();
        if (talkTime && state === 'talk') {
          talkTime.add('s', 1);
          return _this.talkTime.notifySubscribers();
        }
      }, 1000);
      this.currentStatusTimeFormetted = ko.computed(function() {
        return formatTimeFull(_this.currentStatusTime());
      });
      this.workTime = ko.observable();
      this.workTimeFormatted = ko.computed(function() {
        return formatTime(_this.workTime());
      });
      this.workTimeLeft = ko.observable();
      this.workTimeType = ko.observable();
      this.workTimeLeftFormatted = ko.computed(function() {
        var t, type;

        t = _this.workTimeLeft();
        type = parseInt(_this.workTimeType());
        if (type === 1) {
          return formatTime(_this.workTimeLeft());
        } else {
          return 'n/a';
        }
      });
      this.breakTime = ko.observable();
      this.breakTimeFormatted = ko.computed(function() {
        return formatTime(_this.breakTime());
      });
      this.breakTimeLast = ko.observable();
      this.breakTimeLastFormatted = ko.computed(function() {
        var t;

        t = _this.breakTimeLast();
        if (t && moment().diff(t, 'hours') < 12) {
          return t.format('H:mm');
        } else {
          return '—';
        }
      });
      this.talkTime = ko.observable();
      this.talkTimeFormatted = ko.computed(function() {
        return formatTime(_this.talkTime());
      });
      this.talkBusy = ko.computed(function() {
        var tt, wt;

        tt = _this.talkTime();
        wt = _this.workTime();
        if (tt && wt) {
          return Math.round((tt.hours() * 60 * 60 + tt.minutes() * 60 + tt.seconds()) / (wt.hours() * 60 * 60 + wt.minutes() * 60 + wt.seconds()) * 100) + '%';
        } else {
          return '0%';
        }
      });
      this.callsCount = ko.observable('—');
      this.callsSuccessCount = ko.observable('—');
      this.checkCurrentCallIsTask = function(callback) {
        return oktell.exec('getchaincontent', function(data) {
          var isTask, r, state, _ref;

          state = oktell.getState();
          isTask = ((data != null ? (_ref = data.content) != null ? _ref.trace : void 0 : void 0) != null) && _.find(data.content.trace, function(i) {
            return i.taskid;
          });
          r = state === 'talk' && isTask;
          return callFunc(callback, r);
        });
      };
      this.goWork = function() {
        return oktell.setStatus('ready');
      };
      this.beforeShow = function() {
        if (oktellConnected) {
          return _this.loadData();
        }
      };
      loadInterval = '';
      oktell.on('disconnect', function() {
        return oktellConnected = false;
      });
      oktell.on('oktellConnected', function() {
        var timer;

        oktellConnected = true;
        clearInterval(loadInterval);
        loadInterval = setInterval(function() {
          return _this.loadData();
        }, 15000);
        return timer = setInterval(function() {
          if (!oktellConnected) {
            return;
          }
          _this.loadData(function() {
            if (_this.currentStatus() !== 'off') {
              return clearInterval(timer);
            }
          });
          oktell.on('callCenterStateChange', function(inCallCenter) {
            return _this.inCallCenter(inCallCenter);
          });
          return _this.inCallCenter(oktell.inCallCenter());
        }, 1000);
      });
      oktell.on('statusChange', function(newStatus) {
        return _this.currentStatus(newStatus);
      });
      oktell.on('stateChange', function(newState, oldState) {
        _this.currentState(newState);
        if (newState === 'talk' && _this.currentStatus() === 'break') {
          return _this.checkCurrentCallIsTask(function(isTask) {
            if (isTask) {
              log('2 0');
              return _this.showBreakAndCount(false);
            } else {
              log('2 1');
              return _this.showBreakAndCount(true);
            }
          });
        } else if (oldState === 'talk' && _this.currentStatus() === 'break') {
          return _this.showBreakAndCount(true);
        }
      });
      this.loadData = function(callback) {
        var idOperator;

        if (!oktellConnected) {
          return false;
        }
        idOperator = oktell.getMyInfo().userid;
        return oktell.exec('W_CallCenter_Info_GetOperator', {
          '@operator': idOperator,
          '@getdate': moment().format(_this.fVal)
        }, function(data) {
          var d, serverStatus;

          if (data.result) {
            d = data.datasets[0][0];
            log('Operator info', d);
            serverStatus = d.StatusCurrent === 2 ? 'break' : d.StatusCurrent === 1 ? 'ready' : 'off';
            _this.currentStatusTime(_this.currentStatus() === 'break' ? moment(d.StartTimeCurrent, _this.fVal) : moment('1901-01-01 00:00:00', _this.fVal));
            _this.workTime(moment(d.TimeReady, _this.fVal));
            _this.workTimeLeft(moment(d.TimeReadyLeftOrOvertime, _this.fVal));
            _this.breakTime(moment(d.TimeRest, _this.fVal));
            _this.breakTimeLast(moment(d.TimeRestLast, _this.fVal));
            _this.talkTime(moment(d.TimeTalk, _this.fVal));
            _this.callsCount(d.CallsTotal || 0);
            _this.callsSuccessCount(d.CallsSuccess || 0);
          }
          return oktell.exec('W_CallCenter_Info_GetOperatorTasks', {
            '@operator': idOperator
          }, function(data) {
            if (data.result) {
              _this.tasks(data.datasets[0] || []);
            }
            _this.showBreakAndCount.notifySubscribers();
            return callFunc(callback, serverStatus);
          });
        });
      };
    }

    _Class.prototype.exitCallcenter = function() {
      return this.oktell.exec('exitcallcenter');
    };

    _Class.prototype.enterCallcenter = function() {
      this.log('enter callcenter');
      return this.oktell.exec('entercallcenter');
    };

    return _Class;

  })(BaseType)
];

// Generated by CoffeeScript 1.6.2
var __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
  __hasProp = {}.hasOwnProperty,
  __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; },
  __slice = [].slice;

loader.types['oktell'] = Oktell;

loader.types['app'] = [
  'oktell', 'localstorage', 'card', 'failPopup', 'loginPopup', 'loadingPopup', 'callPopup', (function(_super) {
    __extends(_Class, _super);

    _Class.prototype.logCss = 'background: #9DD9FF; color: black';

    function _Class(oktell, lStorage, card, failPopup, loginPopup, loadingPopup, callPopup) {
      this.createNotify = __bind(this.createNotify, this);
      var connectingAttempt, hidden, popups, ringNotify, state, visibilityChange,
        _this = this;

      _Class.__super__.constructor.apply(this, arguments);
      this.lStorage = lStorage;
      this.useVoice = ko.observable(false);
      connectingAttempt = 0;
      this.popup = ko.observable('');
      popups = {
        login: loginPopup,
        fail: failPopup,
        loading: loadingPopup,
        call: callPopup
      };
      this.showPopup = function() {
        var args, obj, p, popup, _results;

        popup = arguments[0], args = 2 <= arguments.length ? __slice.call(arguments, 1) : [];
        log('show popup ' + popup);
        _this.popup(popup);
        _results = [];
        for (p in popups) {
          obj = popups[p];
          if (p === popup && (obj.show != null)) {
            _results.push(obj.show.apply(obj, args));
          } else if (p !== popup && (obj.hide != null)) {
            _results.push(obj.hide.apply(obj, args));
          } else {
            _results.push(void 0);
          }
        }
        return _results;
      };
      failPopup.on('tryAgain', function() {
        return _this.showPopup('login');
      });
      loadingPopup.on('cancel', function() {
        $.cookie('___oktellsessionid', null);
        return location.reload();
      });
      loginPopup.on('login', function(login, password, savePass, server, useVoice) {
        var goConnect;

        _this.showPopup('loading');
        goConnect = function() {
          return _this.connect(login, password, savePass, server, useVoice, function(data) {
            if (data.result) {
              return _this.showPopup('');
            } else {
              switch (data.errorCode) {
                case 1202:
                  _this.showPopup('login', true);
                  return loginPopup.showBadPass(true);
                case 1204:
                  return _this.showPopup('fail', _this.langs.popups.fail.errors.usingOktellClient.header, _this.langs.popups.fail.errors.usingOktellClient.message, true);
                default:
                  return _this.showPopup('fail', _this.langs.popups.fail.errors["default"].header, _this.langs.popups.fail.errors["default"].message, true);
              }
            }
          });
        };
        if (useVoice) {
          return oktellVoice.createUserMedia(function() {
            return goConnect();
          }, function() {
            return _this.showPopup('fail', _this.langs.popups.fail.errors.mediaAccessRefused.header, _this.langs.popups.fail.errors.mediaAccessRefused.message, true);
          });
        } else {
          return goConnect();
        }
      });
      this.cards = lStorage.get('formMetaData') || [];
      this.testCard = function(idForm) {
        return card.test(idForm);
      };
      $('body').on('click', '.gritter-close', function(e) {
        var id, nId;

        id = $(e.currentTarget).parent().attr('id').replace('gritter-item-', '');
        $.gritter.remove(id);
        nId = _.find(_this.gritterNotifies, function(gritterId) {
          return gritterId.toString() === id.toString();
        });
        return delete _this.gritterNotifies[nId];
      });
      this.onPath = function() {
        return log('onPath');
      };
      this.tt = ko.observable('sf');
      this.gg = ko.observable(false);
      this.onGuard = function() {
        return alert('onGuard');
      };
      this.timeStr = ko.observable('');
      setInterval(function() {
        return _this.timeStr(moment().format('HH:mm:ss'));
      }, 10097);
      ko.route.subscribe(function() {
        return setTimeout(function() {
          return $('.jscroll_wrapper').trigger('recalculateNative');
        }, 50);
      });
      oktell.on('disconnect', function(reason) {
        log('on oktell DISCONNECT', reason);
        _this.oktellConnected = false;
        if (parseInt(reason.code) !== 13 && _this.popup() === '') {
          return _this.showPopup('fail', _this.langs.popups.fail.errors["default"].header, _this.langs.popups.fail.errors["default"].message, true);
        }
      });
      ringNotify = null;
      oktell.on('ringStart', function(data) {
        var name, phone, _ref, _ref1, _ref2;

        log('incoming call', data);
        name = (data != null ? (_ref = data[0]) != null ? _ref.name : void 0 : void 0) || (data != null ? (_ref1 = data[0]) != null ? _ref1.phone : void 0 : void 0) || _this.langs.popups.call.undefinedNumber;
        phone = (data != null ? (_ref2 = data[0]) != null ? _ref2.phone : void 0 : void 0) || _this.langs.popups.call.undefinedNumber;
        ringNotify = loader["new"]('notify', {
          title: _this.langs.popups.call.title,
          type: Notify.prototype.types.webkitIfPageInvisible,
          onClick: function() {
            return window.focus();
          }
        });
        if (!_this.useVoice()) {
          return _this.showPopup('call', name, phone, null, function() {
            return oktell.endCall();
          });
        }
      });
      oktell.on('ringStop', function(data) {
        return ringNotify != null ? typeof ringNotify.close === "function" ? ringNotify.close() : void 0 : void 0;
      });
      oktell.on('stateChange', function(newState, oldState) {
        if (_this.oktellConnected && !_this.startExit && newState !== 'ring' && newState !== 'backring') {
          return _this.showPopup('');
        }
      });
      oktell.onNativeEvent('shownotifymessage', function(data) {
        return _this.createNotify(data);
      });
      oktell.onCustomEvent('weboperatorsPing', function(data) {
        return oktell.triggerCustomEvent('weboperatorsPong', [oktell.getMyInfo().login], {
          k: data.k
        });
      });
      this.connect = function(login, password, savePass, server, useVoice, callback) {
        var attempt, url;

        _this.disconnect();
        _this.startExit = false;
        connectingAttempt++;
        attempt = connectingAttempt;
        localStorage.setItem('tempLogin', login);
        localStorage.setItem('tempPass', password);
        if (server) {
          url = server;
        } else {
          url = location.host;
        }
        _this.useVoice(useVoice);
        if (location.host.indexOf('airato.lan') !== -1 || location.host.indexOf('fomich.lan') !== -1 || location.host.indexOf('ramil.lan') !== -1) {
          url = ['wss://oktellserver.airato.lan:444', 'ws://oktellserver.airato.lan:4066'];
        }
        oktell.connect({
          url: url,
          login: login,
          password: password,
          debugMode: window.testMode(),
          openTimeout: 5000,
          queueInterval: window.testMode() ? 9999999 : 5000,
          oktellVoice: useVoice,
          expires: savePass ? 84600 : null,
          queryTimeout: 15000,
          webSocketSwfLocation: "/js/WebSocketMain.swf",
          callback: function(data) {
            if (connectingAttempt !== attempt) {
              log('callback on connect, that was canceled');
              return;
            }
            log('callback on connect');
            loginPopup.savedParam('login', login);
            loginPopup.savedParam('webrtc', useVoice);
            if (data.result) {
              oktell.exec('getmyuserinfo', function(userinfo) {
                if (oktell.getMyInfo().isoperator) {
                  oktell.exec('entercallcenter');
                }
                _this.oktellConnected = true;
                return oktell.trigger('oktellConnected');
              });
            }
            return typeof callback === "function" ? callback(data) : void 0;
          }
        });
      };
      this.reconnect = function() {
        var goConnect, login;

        login = loginPopup.savedParam('login');
        goConnect = function() {
          return _this.connect(login, null, true, '', loginPopup.savedParam('webrtc'), function(data) {
            if (!data.result) {
              loginPopup.savedParam('webrtc', false);
              return _this.showPopup('login');
            } else {
              return _this.showPopup('');
            }
          });
        };
        if (!login) {
          return _this.showPopup('login');
        } else {
          _this.showPopup('loading');
          if (loginPopup.savedParam('webrtc') && $.cookie('___oktellsessionid')) {
            return oktellVoice.createUserMedia(function() {
              return goConnect();
            }, function() {
              return _this.showPopup('fail', _this.langs.popups.fail.errors.mediaAccessRefused.header, _this.langs.popups.fail.errors.mediaAccessRefused.message, true);
            });
          } else {
            return goConnect();
          }
        }
      };
      this.disconnect = function() {
        loginPopup.savedParam('webrtc', false);
        _this.log('Disconnect');
        oktell.disconnect();
        return connectingAttempt++;
      };
      if (window.webkitNotifications && window.webkitNotifications.checkPermission() === 0) {
        this.useWebkitNotify = true;
      }
      loginPopup.on('webkitNotificationsPermissionRequestStart', function() {
        return _this.waitWebkitNotifyPermissionResponse = true;
      });
      loginPopup.on('webkitNotificationsPermissionRequestEnd', function() {
        var data, _i, _len, _ref, _results;

        _this.useWebkitNotify = window.webkitNotifications.checkPermission() === 0 ? true : false;
        if (_.isArray(_this.notifyQueue)) {
          _ref = _this.notifyQueue;
          _results = [];
          for (_i = 0, _len = _ref.length; _i < _len; _i++) {
            data = _ref[_i];
            _results.push(_this.createNotify(data));
          }
          return _results;
        }
      });
      this.pageInvisible = false;
      if (typeof document.hidden !== "undefined") {
        hidden = "hidden";
        visibilityChange = "visibilitychange";
        state = "visibilityState";
      } else if (typeof document.mozHidden !== "undefined") {
        hidden = "mozHidden";
        visibilityChange = "mozvisibilitychange";
        state = "mozVisibilityState";
      } else if (typeof document.msHidden !== "undefined") {
        hidden = "msHidden";
        visibilityChange = "msvisibilitychange";
        state = "msVisibilityState";
      } else if (typeof document.webkitHidden !== "undefined") {
        hidden = "webkitHidden";
        visibilityChange = "webkitvisibilitychange";
        state = "webkitVisibilityState";
      }
      if (visibilityChange) {
        this.pageInvisible = document[hidden] ? true : false;
        document.addEventListener(visibilityChange, function(e) {
          log('Page visibility', document[hidden]);
          if (document[hidden]) {
            return _this.pageInvisible = true;
          } else {
            return _this.pageInvisible = false;
          }
        }, false);
      }
      this.webkitNotifies = {};
      this.gritterNotifies = {};
      this.windowHasFocus = true;
      $(window).focus(function() {
        return _this.windowHasFocus = true;
      });
      $(window).blur(function() {
        return _this.windowHasFocus = false;
      });
      window.addEventListener('storage', function(evt) {
        var id, _ref;

        if (evt.key = 'idNotifyForClose') {
          id = lStorage.get('idNotifyForClose');
          log('CLOSE NOTIFY ' + id);
          if ((_ref = _this.webkitNotifies[id]) != null) {
            if (typeof _ref.close === "function") {
              _ref.close();
            }
          }
          if (_this.gritterNotifies[id]) {
            return $.gritter.remove(_this.gritterNotifies[id]);
          }
        }
      }, false);
      this.activeNotifies = 0;
    }

    _Class.prototype.createNotify = function(data) {
      var b, cleanText, color, customId, g, gritterId, href, k, notifyId, notifyQueue, r, textColor, wkNotify,
        _this = this;

      if (this.waitWebkitNotifyPermissionResponse && (this.useWebkitNotify == null)) {
        notifyQueue = this.notifyQueue || (this.notifyQueue = []);
        return notifyQueue.push(data);
      } else {
        notifyId = data.id || md5(JSON.stringify(data.dt + data.text + data.sender + data.type));
        if (this.pageInvisible && this.useWebkitNotify && this.lStorage.get('lastWkNotifyId') !== notifyId) {
          this.lStorage.set('lastWkNotifyId', notifyId);
          customId = Math.random().toString().replace('.', '');
          href = data.text.match(/<a.+?href=(.+?)('|"| )/);
          if ((href != null ? href[1] : void 0) != null) {
            href = href[1].replace(/('|")/g, '');
          } else {
            href = false;
          }
          cleanText = data.text.replace(/<.+?>/g, '');
          if (href) {
            $('body').append('<a style="display: none;" onclick="this.target=\'_blank\';" id="notifyLink_' + customId + '" href="' + href + '"></a>');
            $('#notifyLink_' + customId).click(function() {
              var _this = this;

              window.focus();
              setTimeout(function() {
                return $('#notifyLink_' + customId).remove();
              }, 10);
              return false;
            });
          }
          this.webkitNotifies[notifyId] = wkNotify = window.webkitNotifications.createNotification('favicon.ico', data.sender, cleanText);
          if (data.uniquekey) {
            wkNotify.tag = data.uniquekey;
          }
          wkNotify.show();
          wkNotify.onclick = function() {
            var args, e;

            e = arguments[0], args = 2 <= arguments.length ? __slice.call(arguments, 1) : [];
            log('CLICK', e, args);
            _this.lStorage.set('idNotifyForClose', notifyId);
            if (href) {
              $('#notifyLink_' + customId).click();
            } else {
              $(window).focus();
            }
            return wkNotify.close();
          };
          wkNotify.onclose = function() {
            return delete _this.webkitNotifies[notifyId];
          };
          if (data.autohide) {
            setTimeout(function() {
              return wkNotify.close();
            }, 7000);
          }
        }
        color = data.backcolor.substr(2, 6);
        r = color.substr(0, 2);
        g = color.substr(2, 2);
        b = color.substr(4, 2);
        k = 0.8;
        textColor = parseInt(r, 16) + parseInt(g, 16) + parseInt(b, 16) > 127 * 3 ? 'black' : 'white';
        r = Math.round(parseInt(r, 16) * k);
        g = Math.round(parseInt(g, 16) * k);
        b = Math.round(parseInt(b, 16) * k);
        return this.gritterNotifies[notifyId] = gritterId = $.gritter.add({
          title: data.sender,
          text: data.text.replace(/<a /g, '<a target="_blank" '),
          sticky: !data.autohide,
          color: '#' + data.backcolor.substr(2, 6),
          borderColor: 'rgb( ' + r + ',' + g + ',' + b + ')',
          textColor: textColor,
          before_close: function() {
            var _ref;

            _this.lStorage.set('idNotifyForClose', notifyId);
            if ((_ref = _this.webkitNotifies[notifyId]) != null) {
              if (typeof _ref.close === "function") {
                _ref.close();
              }
            }
            return delete _this.gritterNotifies[notifyId];
          }
        });
      }
    };

    return _Class;

  })(BaseType)
];

// Generated by CoffeeScript 1.6.2
var __hasProp = {}.hasOwnProperty,
  __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; },
  __slice = [].slice;

loader.types['card'] = [
  'oktell', 'localstorage', (function(_super) {
    __extends(_Class, _super);

    _Class.prototype.logCss = 'background: #77dd77; color: black';

    function _Class(oktell, ss) {
      var currentSelectedCell, dlgEvents, setCurrentShowInfo,
        _this = this;

      _Class.__super__.constructor.apply(this, arguments);
      dlgEvents = ['dlgcard_closeall', 'dlgcard_closereserve', 'dlgcard_closeformreturnvalues', 'dlgcard_showreserve', 'dlgcard_showconfirm', 'dlgcard_showformstop', 'dlgcard_showformdialog'];
      this.currentShowInfo = ko.observable(false);
      setCurrentShowInfo = function(data) {
        var info;

        info = {
          idShow: data.idshow,
          taskId: data.taskId,
          taskName: data.textdir,
          comment: data.comment,
          topmost: data.topmost,
          allowStop: data.allowstop,
          abonentInfo: data.abonentinfo,
          formId: data.formdata.formid,
          formCacheId: data.formdata.cacheid
        };
        _this.currentShowInfo(info);
        return info;
      };
      this.on('all', function() {
        var args, eventname;

        eventname = arguments[0], args = 2 <= arguments.length ? __slice.call(arguments, 1) : [];
        return _this.log('TRIGGERED ' + eventname, args);
      });
      this.confirmResult = function(result) {
        if (result === 'ok' || result === 'skip' || result === 'delete') {
          _this.log('hide confirm');
          _this.trigger('confirmHide');
          oktell.exec('dlgcard_confirmresult', {
            result: result
          }, '', true);
          return oktell.triggerCustomEvent('close_сonfirm', [oktell.getMyInfo().login], {
            fromIdApp: loader.idApp
          });
        }
      };
      this.loadFormMetaData = function(formId, callback) {
        return oktell.exec('dlgcard_getmetadata', {
          formid: formId
        }, function(data) {
          return callFunc(callback, data.metadata);
        });
      };
      this.getGroupValues = function(key, callback) {
        return oktell.exec('dlgcard_getcachedvalues', {
          key: 'G_' + key
        }, function(data) {
          if (data.result) {
            return callFunc(callback, data.values);
          }
        });
      };
      this.dialogGoNext = function(idShow, comment, values) {
        oktell.exec('dlgcard_setresultonnext', {
          idshow: idShow,
          comment: comment,
          values: values
        });
        return oktell.triggerCustomEvent('close_dialog', [oktell.getMyInfo().login], {
          fromIdApp: loader.idApp
        });
      };
      this.sendValuesOnClose = function(comment, values) {
        return oktell.exec('dlgcard_setvaluesonclose', {
          comment: comment,
          values: values
        });
      };
      this.dialogStop = function(idShow, comment) {
        oktell.exec('dlgcard_setresultonstop', {
          idshow: idShow,
          comment: comment
        });
        return oktell.triggerCustomEvent('close_dialog', [oktell.getMyInfo().login], {
          fromIdApp: loader.idApp
        });
      };
      this.stopFormSubmit = function(idShow, isSuccess, userResult, comment, nextAction, callAtDateTime, callAfterSec, anotherNumbers) {
        var nextCallType;

        nextCallType = 'none';
        switch (nextAction) {
          case 'excludeAbonent':
            nextCallType = 'abonentnone';
            break;
          case 'excludeNumber':
            nextCallType = 'numbernone';
            break;
          case 'redial':
            if (callAtDateTime) {
              nextCallType = 'numberdatetime';
              callAfterSec = null;
            } else if (callAfterSec) {
              nextCallType = 'numberafter';
              callAtDateTime = null;
            }
        }
        if (anotherNumbers != null ? anotherNumbers.length : void 0) {
          nextCallType = 'changenumber';
        }
        if (nextAction !== 'redial') {
          callAtDateTime = null;
          callAfterSec = null;
        }
        if (nextCallType !== 'abonentafter' && nextCallType !== 'abonentdatetime' && nextCallType !== 'abonentnone' && nextCallType !== 'numberafter' && nextCallType !== 'numberdatetime' && nextCallType !== 'numbernone' && nextCallType !== 'changenumber' && nextCallType !== 'none') {
          return false;
        }
        return oktell.exec('dlgcard_setstopformresult', {
          idshow: idShow,
          issuccess: isSuccess,
          userresult: userResult,
          comment: comment,
          nextcalltype: nextCallType,
          callatdatetime: callAtDateTime,
          callaftersec: callAfterSec,
          anothernumbers: anotherNumbers
        });
      };
      this.formMetaData = function(formId, cacheId, metaData) {
        var allKey, cache, formKey, i, key, keysCache, newKeysCache, v, _i, _len;

        _this.log('formMetaData ' + formId + ' ' + cacheId, metaData);
        allKey = 'formMetaData';
        formKey = allKey + '_' + formId;
        key = formKey + '_' + cacheId;
        keysCache = ss.get(allKey) || [];
        cache = ss.get(key) || false;
        if (metaData != null) {
          cache = metaData;
          ss.set(key, cache);
          newKeysCache = [];
          for (i = _i = 0, _len = keysCache.length; _i < _len; i = ++_i) {
            v = keysCache[i];
            newKeysCache.push(v);
          }
          keysCache = newKeysCache;
          keysCache.push(key);
          ss.set(allKey, keysCache);
        }
        return cache;
      };
      this.transferTo = function(number) {
        return oktell.transfer(number);
      };
      this.dumpStorage = function() {
        var d, k, v, _i, _len, _ref;

        d = {};
        d['formValss'] = ss.get('formValss');
        for (k in d['formValss']) {
          d[k] = ss.get(k);
        }
        d['showInfos'] = ss.get('showInfos');
        for (k in d['showInfos']) {
          d[k] = ss.get(k);
        }
        d['loadedValsForms'] = ss.get('loadedValsForms');
        for (k in d['loadedValsForms']) {
          d[k] = ss.get(k);
        }
        d['formMetaData'] = ss.get('formMetaData');
        _ref = d['formMetaData'];
        for (_i = 0, _len = _ref.length; _i < _len; _i++) {
          v = _ref[_i];
          d[v] = ss.get(v);
        }
        return d;
      };
      this.test = function(idForm) {
        var g, idf, metadata, showInfo, vals, _i, _len;

        idf = _.find(ss.get('formMetaData'), function(f) {
          return f.indexOf(idForm) !== -1;
        });
        if (idf) {
          metadata = ss.get(idf);
          showInfo = ss.get('showInfo_' + idForm);
          vals = ss.get('formVals_' + idForm);
          for (_i = 0, _len = metadata.length; _i < _len; _i++) {
            g = metadata[_i];
            _.extend(vals, ss.get('loadedVals_' + idForm + '_' + g.index) || {});
            g.isexpanded = true;
          }
          return _this.trigger('dialogShow', showInfo, metadata, vals);
        }
      };
      window.selectedCell = ko.observable({});
      window.selectedControlObservables = ko.observableArray([]);
      currentSelectedCell = '';
      ko.computed(function() {
        var c, k, v, vals, vvals;

        if (!window.testMode()) {
          return;
        }
        c = window.selectedCell();
        vals = [];
        if (c && currentSelectedCell !== c) {
          window.c = c;
          _this.log('selected control ' + (c.typeName && c.typeName.toUpperCase()));
          _this.log(c.json);
          if (c._values) {
            vvals = c.getValues() || {};
            for (k in vvals) {
              v = vvals[k];
              _this.log(k + ' : ' + c._values[k] + ' now ' + v);
            }
          }
          currentSelectedCell = c;
          for (k in c) {
            v = c[k];
            if (ko.isObservable(v)) {
              vals.push({
                isbool: typeof v() === 'boolean',
                arr: currentSelectedCell[k + 'Arr'],
                v: v,
                name: k
              });
            }
          }
          return window.selectedControlObservables(vals);
        }
      });
      this.testReserve = function() {
        return _this.trigger('reserveShow', ss.get('formReserve'));
      };
      this.testConfirm = function() {
        return _this.trigger('confirmShow', ss.get('formConfirm'));
      };
      this.startEditingControl = function(idShow, index) {
        return oktell.triggerCustomEvent('card_control_start_edit', [oktell.getMyInfo().login], {
          idShow: idShow,
          controlIndex: index,
          fromIdApp: loader.idApp
        });
      };
      this.stopEditingControl = function(idShow, index, vals) {
        return oktell.triggerCustomEvent('card_control_stop_edit', [oktell.getMyInfo().login], {
          idShow: idShow,
          controlIndex: index,
          vals: vals,
          fromIdApp: loader.idApp
        });
      };
      this.setControlVal = function(idShow, index, vals) {
        return oktell.triggerCustomEvent('card_control_set_val', [oktell.getMyInfo().login], {
          idShow: idShow,
          controlIndex: index,
          vals: vals,
          fromIdApp: loader.idApp
        });
      };
      this.sendCurrentCard = function(info, toIdApp) {
        return oktell.triggerCustomEvent('card_current', [oktell.getMyInfo().login], {
          info: info,
          fromIdApp: loader.idApp,
          toIdApp: toIdApp
        });
      };
      oktell.onCustomEvent('card_control_start_edit', function(data) {
        if (data.fromIdApp !== loader.idApp) {
          return _this.trigger('controlStartEditing', data.idShow, data.controlIndex);
        }
      });
      oktell.onCustomEvent('card_control_stop_edit', function(data) {
        if (data.fromIdApp !== loader.idApp) {
          return _this.trigger('controlStopEditing', data.idShow, data.controlIndex, data.vals);
        }
      });
      oktell.onCustomEvent('card_control_set_val', function(data) {
        if (data.fromIdApp !== loader.idApp) {
          return _this.trigger('controlSetValues', data.idShow, data.controlIndex, data.vals);
        }
      });
      oktell.onCustomEvent('card_need_current', function(data) {
        if (data.fromIdApp !== loader.idApp) {
          return _this.trigger('needSendCurrentDialog', data.fromIdApp);
        }
      });
      oktell.onCustomEvent('card_current', function(data) {
        if (data.fromIdApp !== loader.idApp && data.toIdApp === loader.idApp) {
          return _this.trigger('setCurrentDialog', data.info);
        }
      });
      oktell.onCustomEvent('close_сonfirm', function(data) {
        if (data.fromIdApp !== loader.idApp) {
          return _this.trigger('confirmHide');
        }
      });
      oktell.onCustomEvent('close_dialog', function(data) {
        if (data.fromIdApp !== loader.idApp) {
          return _this.trigger('dialogHide');
        }
      });
      oktell.onNativeEvent('dlgcard', function() {});
      oktell.onNativeEvent('dlgcard_closeall', function(data) {
        _this.log('EVENT dlgcard_closeall', data);
        return _this.trigger('reserveHide confirmHide dialogHide stopFormHide');
      });
      oktell.onNativeEvent('dlgcard_closereserve', function(data) {
        _this.trigger('reserveHide');
        return _this.log('EVENT dlgcard_closereserve', data);
      });
      oktell.onNativeEvent('dlgcard_showreserve', function(data) {
        ss.set('formReserve', data);
        _this.trigger('reserveShow', data);
        return _this.log('EVENT dlgcard_showreserve', data);
      });
      oktell.onNativeEvent('dlgcard_showconfirm', function(data) {
        ss.set('formConfirm', data);
        _this.log('EVENT dlgcard_showconfirm', data);
        _this.trigger('confirmShow', data);
        return oktell.exec('dlgcard_confirmgot', {}, '', true);
      });
      oktell.onNativeEvent('dlgcard_closeformreturnvalues', function(data) {
        _this.log('EVENT dlgcard_closeformreturnvalues', data);
        return _this.trigger('sendValuesOnClose');
      });
      oktell.onNativeEvent('dlgcard_showformstop', function(data) {
        _this.log('EVENT dlgcard_showformstop event', data);
        oktell.exec('dlgcard_showformdone', {});
        return _this.trigger('showStopForm', data);
      });
      oktell.onNativeEvent('dlgcard_showformdialog', function(data) {
        var formIdCache, metaData, showInfo, values, vvv;

        _this.log('EVENT dlgcard_showformdialog', data);
        formIdCache = data.formdata.formid + '_' + data.formdata.cacheid;
        metaData = _this.formMetaData(data.formdata.formid, data.formdata.cacheid);
        values = data.formdata.values;
        showInfo = setCurrentShowInfo(data);
        vvv = {};
        vvv['formVals_' + formIdCache] = true;
        ss.set('formValss', _.extend(ss.get('formValss') || {}, vvv));
        ss.set('formVals_' + formIdCache, values);
        vvv = {};
        vvv['showInfo_' + formIdCache] = true;
        ss.set('showInfos', _.extend(ss.get('showInfos') || {}, vvv));
        ss.set('showInfo_' + formIdCache, showInfo);
        if (metaData) {
          _this.trigger('dialogShow', showInfo, metaData, values);
        } else {
          _this.loadFormMetaData(data.formdata.formid, function(data) {
            metaData = _this.formMetaData(data.formid, data.cacheid, data.groups);
            return _this.trigger('dialogShow', showInfo, metaData, values);
          });
        }
        return oktell.exec('dlgcard_showformdone', {}, '', true);
      });
      oktell.on('oktellConnected', function() {
        oktell.exec('dlgcard_setsupported', {
          supported: true
        }, function() {});
        return oktell.triggerCustomEvent('card_need_current', [oktell.getMyInfo().login], {
          fromIdApp: loader.idApp
        });
      });
    }

    return _Class;

  })(BaseType)
];

// Generated by CoffeeScript 1.5.0
var __hasProp = {}.hasOwnProperty,
  __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

loader.types['confirmPopup'] = [
  'card', 'breakPopup', (function(_super) {

    __extends(_Class, _super);

    function _Class(card, breakPopup) {
      var _this = this;
      _Class.__super__.constructor.apply(this, arguments);
      this.visible = ko.observable(false);
      this.message = ko.observable('');
      this.show = function(data) {
        _this.message(data.message.replace(/(\r\n|\n)/g, '<br>'));
        return _this.visible(true);
      };
      this.actionOk = function() {
        return card.confirmResult('ok');
      };
      this.actionSkip = function() {
        return card.confirmResult('skip');
      };
      this.actionDelete = function() {
        return card.confirmResult('delete');
      };
      breakPopup.on('goBreak', function() {
        if (breakPopup.showedFromConfirm()) {
          return _this.visible(false);
        }
      });
      breakPopup.on('cancel', function() {
        if (breakPopup.showedFromConfirm()) {
          return _this.visible(true);
        }
      });
      this.actionGoBreak = function() {
        _this.visible(false);
        breakPopup.show();
        return breakPopup.showedFromConfirm(true);
      };
      card.on('confirmShow', function(data) {
        return _this.show(data);
      });
      card.on('confirmHide', function() {
        return _this.visible(false);
      });
      this.afterShow = function($el) {};
      this.getInfoForSend = function() {
        if (_this.visible()) {
          return {
            message: _this.message()
          };
        } else {
          return false;
        }
      };
    }

    return _Class;

  })(BaseType)
];

// Generated by CoffeeScript 1.5.0
var __hasProp = {}.hasOwnProperty,
  __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

loader.types['reservePopup'] = [
  'card', (function(_super) {

    __extends(_Class, _super);

    function _Class(card) {
      var _this = this;
      _Class.__super__.constructor.apply(this, arguments);
      this.visible = ko.observable(false);
      this.message = ko.observable('');
      this.show = function(data) {
        _this.message(data.message.replace(/(\r\n|\n)/g, '<br>'));
        return _this.visible(true);
      };
      card.on('reserveShow', function(data) {
        return _this.show(data);
      });
      card.on('reserveHide', function() {
        return _this.visible(false);
      });
      this.afterShow = function($el) {};
      this.getInfoForSend = function() {
        if (_this.visible()) {
          return {
            message: _this.message()
          };
        } else {
          return false;
        }
      };
    }

    return _Class;

  })(BaseType)
];

// Generated by CoffeeScript 1.5.0
var __hasProp = {}.hasOwnProperty,
  __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

loader.types['afterNextPopup'] = [
  'oktell', (function(_super) {

    __extends(_Class, _super);

    function _Class(oktell) {
      var _this = this;
      _Class.__super__.constructor.apply(this, arguments);
      this.visible = ko.observable(false);
      this.show = function() {
        return _this.visible(true);
      };
      this.hide = function() {
        return _this.visible(false);
      };
      this.click = function() {
        _this.hide();
        return oktell.endCall();
      };
    }

    return _Class;

  })(BaseType)
];

// Generated by CoffeeScript 1.6.2
var __hasProp = {}.hasOwnProperty,
  __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

loader.types['dialog'] = [
  'card', 'stopPopup', 'afterNextPopup', 'confirmPopup', 'reservePopup', (function(_super) {
    __extends(_Class, _super);

    function _Class(card, stopPopup, afterNextPopup, confirmPopup, reservePopup) {
      var $el, $scroller, $wrapper, isLoaded, log,
        _this = this;

      _Class.__super__.constructor.apply(this, arguments);
      this.tt = [1, 2, 3];
      $el = false;
      $scroller = false;
      $wrapper = false;
      this.setEl = function(el) {
        $el = $(el);
        return _this.elRigthCss = $el.parent().css('right');
      };
      this.getEl = function() {
        return $el;
      };
      log = this.setLogGroup('DIALOG', 'background: #ffff00; color: black');
      this.taskName = ko.observable('');
      this.comment = ko.observable('');
      this.isActive = ko.observable(false);
      this.formIsReady = false;
      this.allowStop = ko.observable(false);
      this.metaData = false;
      this.setDialogInfo = function(info) {
        _this.taskName(info.taskName);
        _this.idShow = info.idShow;
        _this.comment(info.comment);
        _this.formId = info.formId;
        _this.formCacheId = info.formCacheId;
        return _this.allowStop(info.allowStop);
      };
      this.getDialogInfo = function() {
        return {
          taskName: _this.taskName(),
          idShow: _this.idShow,
          comment: _this.comment(),
          formId: _this.formId,
          formCacheId: _this.formCacheId,
          allowStop: _this.allowStop
        };
      };
      this.groups = ko.observableArray([]);
      window.allgroups = this.groups;
      this.addAll = function() {
        var g, r, _i, _len, _ref, _results;

        _ref = _this.groups();
        _results = [];
        for (_i = 0, _len = _ref.length; _i < _len; _i++) {
          g = _ref[_i];
          _results.push((function() {
            var _j, _len1, _ref1, _results1;

            _ref1 = g.rows();
            _results1 = [];
            for (_j = 0, _len1 = _ref1.length; _j < _len1; _j++) {
              r = _ref1[_j];
              _results1.push(r.addAll());
            }
            return _results1;
          })());
        }
        return _results;
      };
      this.expandAll = function() {
        var g, _i, _len, _ref, _results;

        _ref = _this.groups();
        _results = [];
        for (_i = 0, _len = _ref.length; _i < _len; _i++) {
          g = _ref[_i];
          _results.push(g.isExpanded(true));
        }
        return _results;
      };
      this.collapseAll = function() {
        var g, _i, _len, _ref, _results;

        _this.getEl().find('.jscroll_scroller').animate({
          top: '0px'
        }, 200);
        _ref = _this.groups();
        _results = [];
        for (_i = 0, _len = _ref.length; _i < _len; _i++) {
          g = _ref[_i];
          if (!g.isRestrictedCloseUp()) {
            _results.push(g.isExpanded(false));
          } else {
            _results.push(void 0);
          }
        }
        return _results;
      };
      isLoaded = false;
      this.recalculateNative = function() {};
      this.afterRender = function(el) {
        _this.setEl(el);
        isLoaded = true;
        _this.recalculateNative = _.debounce(function() {
          return setTimeout(function() {
            return _this.getEl().find('.jscroll_wrapper').trigger('recalculateNative');
          }, 500);
        }, 50);
        return _this.getEl().bind('resize', _this.recalculateNative);
      };
      this.guard = function() {
        if (_this.isActive() || !isLoaded) {
          return true;
        } else {
          ko.router.go('stats', {
            replace: true
          });
          return false;
        }
      };
      this.readyToSave = ko.computed(function() {
        var g, groups, ready, _i, _len;

        groups = _this.groups();
        ready = true;
        for (_i = 0, _len = groups.length; _i < _len; _i++) {
          g = groups[_i];
          if (!g.readyToSave()) {
            ready = false;
          }
        }
        return ready;
      });
      this.buildForm = function(metaData, values) {
        var el, rs;

        log('build form', metaData, values);
        _this.metaData = metaData;
        el = _this.getEl().find('.j_dialog_form');
        rs = [];
        _this.groups.removeAll();
        _.each(metaData, function(g, i) {
          var group, needLoad, vals;

          if ((values != null ? values[g.index] : void 0) && typeof values[g.index] !== 'string') {
            needLoad = false;
            vals = values[g.index];
          } else {
            needLoad = !g.isexpanded;
            vals = values;
          }
          group = loader["new"]('control.group', _this, g, vals, needLoad);
          group.isExpanded.subscribe(function() {
            return _this.recalculateNative();
          });
          return rs.push(group);
        });
        _this.groups(rs);
        return _this.formIsReady = true;
      };
      this.afterRenderGroups = function(elements, group) {
        return group.rendered(true);
      };
      this.getValues = function() {
        var c, g, i, r, v, vals, vs, _i, _j, _k, _len, _len1, _len2, _ref, _ref1, _ref2;

        vals = {};
        _ref = _this.groups();
        for (_i = 0, _len = _ref.length; _i < _len; _i++) {
          g = _ref[_i];
          _ref1 = g.rows();
          for (_j = 0, _len1 = _ref1.length; _j < _len1; _j++) {
            r = _ref1[_j];
            _ref2 = r.cells();
            for (_k = 0, _len2 = _ref2.length; _k < _len2; _k++) {
              c = _ref2[_k];
              if (c.index) {
                vs = c.getValues();
                for (i in vs) {
                  v = vs[i];
                  vals[i] = v;
                }
              }
            }
          }
        }
        return vals;
      };
      card.on('dialogShow', function(info, data, values) {
        _this.isActive(true);
        ko.router.go('card');
        _this.setDialogInfo(info);
        return _this.buildForm(data, values);
      });
      card.on('dialogHide', function(data) {
        return _this.closeDialog();
      });
      card.on('stopFormHide', function() {
        return stopPopup.hide();
      });
      card.on('showStopForm', function(data) {
        return stopPopup.show({
          idShow: data.idshow,
          comment: data.comment,
          userResults: data.userresults
        });
      });
      card.on('sendValuesOnClose', function() {
        card.sendValuesOnClose(_this.comment(), _this.getValues());
        return _this.closeDialog();
      });
      this.closeDialog = function() {
        _this.isActive(false);
        _this.formIsReady = false;
        if (ko.route().indexOf('card') === 0) {
          return ko.router.go('stats');
        }
      };
      this.goNext = function() {
        var firstNotReadyControl, g, _i, _len, _ref;

        _ref = _this.groups();
        for (_i = 0, _len = _ref.length; _i < _len; _i++) {
          g = _ref[_i];
          g.nextWasClicked(true);
        }
        if (_this.readyToSave()) {
          card.dialogGoNext(_this.idShow, _this.comment(), _this.getValues());
          return _this.closeDialog();
        } else {
          firstNotReadyControl = '';
          _.find(_this.groups(), function(g) {
            return _.find(g.rows(), function(r) {
              return _.find(r.cells(), function(c) {
                if (ko.isObservable(c.readyToSave) && !c.readyToSave()) {
                  return firstNotReadyControl = c;
                }
              });
            });
          });
          if (firstNotReadyControl) {
            if (!firstNotReadyControl.row.group.isExpanded()) {
              firstNotReadyControl.row.group.expand();
              return setTimeout(function() {
                _this.scrollToControl(firstNotReadyControl);
                return firstNotReadyControl.focus();
              }, 200);
            } else {
              _this.scrollToControl(firstNotReadyControl);
              return firstNotReadyControl.focus();
            }
          }
        }
      };
      this.scrollToControl = function(control) {
        var cellEl, elH, elTop, scTop, wrH, wrTop, x;

        if ((control.el == null) || (control.el.size == null) || !control.el.size()) {
          return;
        }
        if (!$scroller) {
          $scroller = _this.getEl().find('.jscroll_scroller');
        }
        if (!$wrapper) {
          $wrapper = _this.getEl().find('.jscroll_wrapper');
        }
        if (!($scroller != null ? typeof $scroller.size === "function" ? $scroller.size() : void 0 : void 0) || !($wrapper != null ? typeof $wrapper.size === "function" ? $wrapper.size() : void 0 : void 0)) {
          return false;
        }
        cellEl = control.el.closest('.ctrl_cell');
        elTop = cellEl.offset().top;
        elH = cellEl.height();
        wrTop = $wrapper.offset().top;
        wrH = $wrapper.height();
        scTop = $scroller.offset().top;
        if (elTop < wrTop) {
          x = scTop - elTop + wrTop + 10;
          $scroller.css({
            top: (x - wrTop) + 'px'
          });
          _this.recalculateNative();
          return true;
        } else if (elTop + elH > wrTop + wrH) {
          x = scTop - (elTop + elH - wrTop - wrH) - 20;
          $scroller.offset({
            top: x
          });
          _this.recalculateNative();
          return true;
        } else {
          return false;
        }
      };
      this.stop = function() {
        _this.closeDialog();
        return card.dialogStop(_this.idShow, _this.comment());
      };
      this.on('all', function(a, b, c) {
        return log('DIALOG EVENT ' + a, b, c);
      });
      this.controlStartEdit = function(controlIndex) {
        return card.startEditingControl(_this.idShow, controlIndex);
      };
      this.controlStopEdit = function(controlIndex, vals) {
        return card.stopEditingControl(_this.idShow, controlIndex, vals);
      };
      this.controlValueChange = function(controlIndex, valuesObj) {
        return card.setControlVal(_this.idShow, controlIndex, valuesObj);
      };
      this.cardControlsStates = {};
      this.saveControlSate = function(idShow, index, disabled, vals) {
        var c, controls;

        controls = _this.cardControlsStates[idShow] || (_this.cardControlsStates[idShow] = {});
        c = controls[index] || (controls[index] = {});
        c.index = index;
        if (disabled != null) {
          c.disabled = disabled;
        }
        if (vals) {
          return c.vals = vals;
        }
      };
      card.on('controlStartEditing', function(idShow, index) {
        if (_this.formIsReady && _this.idShow === idShow) {
          return _this.trigger('disableControl', index);
        } else {
          return _this.saveControlSate(idShow, index, true);
        }
      });
      card.on('controlStopEditing', function(idShow, index, vals) {
        if (_this.formIsReady && _this.idShow === idShow) {
          return _this.trigger('enableControl', index, vals);
        } else {
          return _this.saveControlSate(idShow, index, false, vals);
        }
      });
      card.on('controlSetValues', function(idShow, index, vals) {
        if (_this.formIsReady && _this.idShow === idShow) {
          return _this.trigger('setValue', index, vals);
        } else {
          return _this.saveControlSate(idShow, index, null, vals);
        }
      });
      card.on('needSendCurrentDialog', function(toIdApp) {
        var confirmPopupInfo, dataToSend, reservePopupInfo, stopPopupInfo;

        log('EVENT needSendCurrentDialog');
        reservePopupInfo = reservePopup.getInfoForSend();
        confirmPopupInfo = confirmPopup.getInfoForSend();
        stopPopupInfo = stopPopup.getInfoForSend();
        dataToSend = false;
        if (_this.isActive()) {
          dataToSend = _this.getInfoForSendCard();
        } else if (reservePopupInfo) {
          dataToSend = {
            reservePopup: reservePopupInfo
          };
        } else if (confirmPopupInfo) {
          dataToSend = {
            confirmPopup: confirmPopupInfo
          };
        } else if (stopPopupInfo) {
          dataToSend = {
            stopPopup: stopPopupInfo
          };
        }
        if (dataToSend) {
          return card.sendCurrentCard(dataToSend, toIdApp);
        }
      });
      this.getInfoForSendCard = function() {
        var controlVals, g, groupVals, index, info, k, v, _i, _len, _ref, _ref1;

        controlVals = _this.getValues() || {};
        groupVals = {};
        _ref = _this.groups();
        for (_i = 0, _len = _ref.length; _i < _len; _i++) {
          g = _ref[_i];
          index = g.index();
          groupVals[index] = g.vals;
          if (groupVals[index]) {
            _ref1 = groupVals[index];
            for (k in _ref1) {
              v = _ref1[k];
              if (controlVals[k] != null) {
                groupVals[index][k] = controlVals[k];
              }
            }
          }
        }
        info = _.extend({
          metaData: card.formMetaData(_this.formId, _this.formCacheId),
          groupVals: groupVals
        }, _this.getDialogInfo());
        return info;
      };
      card.on('setCurrentDialog', function(info) {
        var metaData;

        log('EVENT setCurrentDialog', info);
        if (info.reservePopup) {
          reservePopup.show(info.reservePopup);
          return;
        } else if (info.confirmPopup) {
          confirmPopup.show(info.confirmPopup);
          return;
        } else if (info.stopPopup) {
          stopPopup.show(info.stopPopup);
          return;
        }
        if (_this.isActive()) {
          return;
        }
        _this.isActive(true);
        ko.router.go('card');
        _this.setDialogInfo(info);
        metaData = info.metaData;
        return _this.buildForm(metaData, info.groupVals);
      });
      stopPopup.on('saveData', function(data) {
        _this.closeDialog();
        return card.stopFormSubmit(stopPopup.idShow, data.isSuccess, data.userResult, data.comment, data.nextAction, data.callAtDateTime, data.callAfterSec, data.numbers);
      });
      this.onNativeScrollShow = function() {
        var _ref;

        if ((_ref = _this.getEl()) != null) {
          _ref.parent().css('right', parseInt(_this.elRigthCss) + 17 + 'px');
        }
        return window.onNativeScrollShow();
      };
      this.onNativeScrollHide = function() {
        var _ref;

        if ((_ref = _this.getEl()) != null) {
          _ref.parent().css('right', _this.elRigthCss);
        }
        return window.onNativeScrollHide();
      };
    }

    return _Class;

  })(BaseType)
];

// Generated by CoffeeScript 1.6.2
var Notify,
  __hasProp = {}.hasOwnProperty,
  __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; },
  __slice = [].slice;

loader.types['notify'] = [
  'app', Notify = (function(_super) {
    __extends(Notify, _super);

    Notify.prototype.types = {
      auto: 0,
      webkit: 1,
      webkitIfPageInvisible: 2,
      html: 3
    };

    Notify.prototype.error = false;

    Notify.prototype.defaultOptions = {
      title: false,
      autoHide: 0,
      text: '',
      type: 0,
      onClick: false,
      group: null
    };

    function Notify(app, opts) {
      var type;

      Notify.__super__.constructor.apply(this, arguments);
      opts = _.extend({}, this.defaultOptions, opts);
      if (!(typeof opts.title === 'string' && opts.title)) {
        this.error = false;
        return;
      }
      if (opts.type === this.types.auto) {
        if (app.pageInvisible && window.webkitNotifications) {
          type = this.types.webkit;
        } else {
          type = this.types.html;
        }
      }
      if (window.webkitNotifications && opts.type === this.types.webkit || (app.pageInvisible && opts.type === this.types.webkitIfPageInvisible)) {
        this.createWebkitNotify(opts.title, opts.text, opts.autoHide, opts.group, opts.onClick);
      } else if (opts.type === this.types.HTML) {
        this.createWebkitNotify(opts.title, opts.text, opts.autoHide, opts.group, opts.onClick);
      }
    }

    Notify.prototype.createHtmlNotify = function(title, text, autoHide, group, onClick) {};

    Notify.prototype.createWebkitNotify = function(title, text, autoHide, group, onClick) {
      var notify,
        _this = this;

      notify = window.webkitNotifications.createNotification('favicon.ico', title, message || '');
      if (group) {
        notify.tag = group;
      }
      notify.show();
      autoHide = parseInt(autoHide);
      if (autoHide) {
        setTimeout(function() {
          return notify.close();
        }, autoHide * 1000);
      }
      notify.onclick = function() {
        var args, e;

        e = arguments[0], args = 2 <= arguments.length ? __slice.call(arguments, 1) : [];
        if (typeof window.focus === "function") {
          window.focus();
        }
        notify.close();
        if (typeof onClick === 'function') {
          return onClick.apply(window, []);
        }
      };
      return this.close = function() {
        return notify != null ? typeof notify.close === "function" ? notify.close() : void 0 : void 0;
      };
    };

    return Notify;

  })(BaseType)
];

// Generated by CoffeeScript 1.6.2
var __hasProp = {}.hasOwnProperty,
  __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

loader.types['control.group'] = [
  'loader', 'card', 'localstorage', (function(_super) {
    __extends(_Class, _super);

    function _Class(loader, card, ss, dialog, metaData, vals, needLoad) {
      var log, newRow, r, rows, _i, _len, _ref,
        _this = this;

      _Class.__super__.constructor.apply(this, arguments);
      log = this.setLogGroup('GROUP', 'background: #FFCDCA; color: black');
      rows = [];
      this.vals = vals || false;
      _ref = metaData.rows;
      for (_i = 0, _len = _ref.length; _i < _len; _i++) {
        r = _ref[_i];
        newRow = loader["new"]('control.row', dialog, r, vals);
        newRow.group = this;
        rows.push(newRow);
      }
      this.readyToSave = ko.computed(function() {
        var ready, _j, _len1;

        ready = true;
        for (_j = 0, _len1 = rows.length; _j < _len1; _j++) {
          r = rows[_j];
          if (!r.readyToSave()) {
            ready = false;
          }
        }
        return ready;
      });
      this.nextWasClicked = ko.observable(false);
      this.nextWasClicked.subscribe(function(val) {
        var _j, _len1, _results;

        if (val) {
          _results = [];
          for (_j = 0, _len1 = rows.length; _j < _len1; _j++) {
            r = rows[_j];
            _results.push(r.nextWasClicked(true));
          }
          return _results;
        }
      });
      this.rows = ko.observableArray(rows);
      this.rendered = ko.observable(false);
      this.number = metaData.number;
      this.name = ko.observable(metaData.caption);
      this.index = ko.observable(metaData.index);
      this.isExpanded = ko.observable(metaData.isexpanded);
      this.isRestrictedCloseUp = ko.observable(metaData.isrestrictedcloseup);
      this.expand = function() {
        if (!_this.isRestrictedCloseUp()) {
          return _this.isExpanded(!_this.isExpanded());
        }
      };
      if (needLoad) {
        log('start time for loading group');
        setTimeout(function() {
          return card.getGroupValues(_this.index(), function(loadedVals) {
            var vvv, _j, _len1, _ref1, _results;

            log('loaded group values for ' + _this.index(), loadedVals);
            if (window.testMode()) {
              if (loadedVals) {
                vvv = {};
                vvv['loadedVals_' + dialog.formId + '_' + _this.index()] = true;
                ss.set('loadedValsForms', _.extend(ss.get('loadedValsForms') || {}, vvv));
                ss.set('loadedVals_' + dialog.formId + '_' + _this.index(), loadedVals);
              } else {
                loadedVals = ss.get('loadedVals_' + dialog.formId + '_' + _this.index());
              }
            }
            if (loadedVals) {
              _this.vals = loadedVals;
              _ref1 = _this.rows();
              _results = [];
              for (_j = 0, _len1 = _ref1.length; _j < _len1; _j++) {
                r = _ref1[_j];
                _results.push(r.setVals(loadedVals));
              }
              return _results;
            }
          });
        }, 1000);
      }
      this.selectCell = function(control) {
        window.selectedCell(control);
        return true;
      };
      this.openCss = ko.observable(this.isExpanded());
      this.beforeShow = function($el) {
        return _this.openCss(true);
      };
      this.afterHide = function($el) {
        return _this.openCss(false);
      };
    }

    return _Class;

  })(BaseType)
];

// Generated by CoffeeScript 1.6.2
var __hasProp = {}.hasOwnProperty,
  __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

loader.types['control.row'] = [
  'loader', (function(_super) {
    __extends(_Class, _super);

    function _Class(loader, dialog, data, vals) {
      var cells, controlsByIndex, types,
        _this = this;

      _Class.__super__.constructor.apply(this, arguments);
      types = {
        0: 'select',
        100: 'null',
        101: 'label',
        102: 'textBox',
        103: 'comboBox',
        104: 'checkBox',
        105: 'dateTime',
        106: 'spin',
        107: 'radioGroup',
        108: 'line',
        109: 'checkBoxGroup',
        110: 'image',
        111: 'grid',
        112: 'button'
      };
      cells = [];
      controlsByIndex = {};
      _.each(data.cells, function(c, i) {
        var control, controlObj;

        control = c.control;
        if ((control != null) || ((control == null) && i < data.cells.length - 1)) {
          if ((control != null) && types[control.type]) {
            control.typeName = types[control.type];
            controlObj = loader["new"]('control.' + control.typeName, control, vals);
          } else {
            if (control == null) {
              control = {};
              control.isEmpty = true;
            }
            controlObj = loader["new"]('control.base', control, vals);
          }
          if (controlObj && controlObj.index && controlObj.canMultipleEdit) {
            controlObj.row = _this;
            controlsByIndex[controlObj.index] = controlObj;
            controlObj.on('startEdit', function() {
              return dialog.controlStartEdit(controlObj.index);
            });
            controlObj.on('stopEdit', function(vals) {
              return dialog.controlStopEdit(controlObj.index, vals);
            });
            controlObj.on('valueChange', function(vals) {
              return dialog.controlValueChange(controlObj.index, vals);
            });
          }
          return cells.push(controlObj);
        }
      });
      dialog.on('enableControl', function(index, vals) {
        if (controlsByIndex[index]) {
          if (vals) {
            controlsByIndex[index].setValuesObj(vals);
          }
          return controlsByIndex[index].canEdit(true);
        }
      });
      dialog.on('disableControl', function(index) {
        if (controlsByIndex[index]) {
          return controlsByIndex[index].canEdit(false);
        }
      });
      dialog.on('setValue', function(index, vals) {
        if (controlsByIndex[index]) {
          return controlsByIndex[index].setValuesObj(vals);
        }
      });
      this.readyToSave = ko.computed(function() {
        var c, ready, _i, _len;

        ready = true;
        for (_i = 0, _len = cells.length; _i < _len; _i++) {
          c = cells[_i];
          if (c && ko.isObservable(c.readyToSave) && !c.readyToSave()) {
            ready = false;
          }
        }
        return ready;
      });
      this.nextWasClicked = ko.observable(false);
      this.nextWasClicked.subscribe(function(val) {
        var c, _i, _len, _ref, _results;

        if (val) {
          _ref = _this.cells();
          _results = [];
          for (_i = 0, _len = _ref.length; _i < _len; _i++) {
            c = _ref[_i];
            _results.push(c.nextWasClicked(true));
          }
          return _results;
        }
      });
      if (cells.length > 1) {
        _.last(cells).isLast = true;
      }
      this.allCells = ko.observableArray([]);
      this.cells = ko.observableArray(cells);
      this.width = (100 / this.cells().length).toFixed(2) + '%';
      this.add = function(cell) {
        if (!_.find(_this.allCells(), function(c) {
          return c === cell;
        })) {
          return _this.allCells.push(cell);
        }
      };
      this.addAll = function() {
        var cell, _i, _len, _ref, _results;

        _ref = _this.cells();
        _results = [];
        for (_i = 0, _len = _ref.length; _i < _len; _i++) {
          cell = _ref[_i];
          if (!_.find(_this.allCells(), function(c) {
            return c === cell;
          })) {
            _results.push(_this.allCells.push(cell));
          } else {
            _results.push(void 0);
          }
        }
        return _results;
      };
      this.remove = function(cell) {
        return _this.allCells.remove(cell);
      };
      this.log = function(cell) {
        window.c = cell;
        return log(c);
      };
      this.setVals = function(vals) {
        var c, _i, _len, _ref, _results;

        if (vals) {
          _ref = _this.cells();
          _results = [];
          for (_i = 0, _len = _ref.length; _i < _len; _i++) {
            c = _ref[_i];
            _results.push(c.setValues(vals));
          }
          return _results;
        }
      };
    }

    return _Class;

  })(BaseType)
];

// Generated by CoffeeScript 1.6.2
var controlBase,
  __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
  __hasProp = {}.hasOwnProperty,
  __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

controlBase = (function(_super) {
  __extends(controlBase, _super);

  function controlBase(card, data, values) {
    this.setValuesObj = __bind(this.setValuesObj, this);
    this.getValuesObj = __bind(this.getValuesObj, this);
    this.getValues = __bind(this.getValues, this);
    this.setValues = __bind(this.setValues, this);
    this.parseListItems = __bind(this.parseListItems, this);
    this.computeStyles = __bind(this.computeStyles, this);
    this.afterRender = __bind(this.afterRender, this);
    this.focus = __bind(this.focus, this);
    var lastSentVals, throttledTrigger,
      _this = this;

    controlBase.__super__.constructor.apply(this, arguments);
    data = data || {};
    this.json = data;
    window.dd = this;
    this.typeName = data.typeName;
    this.index = data.index;
    this.isEmpty = false;
    this.template = '/templates/controls/' + (this.typeName || 'base') + '.html';
    if (data.isEmpty) {
      this.isEmpty = true;
      this.typeName = 'empty';
    }
    this.canEdit = ko.observable(true);
    this.isActive = ko.observable(false);
    this.nextWasClicked = ko.observable(false);
    window.tt = window.tt || {};
    window.tt[this.typeName] = window.tt[this.typeName] || {};
    window.tt[this.typeName] = _.extend(window.tt[this.typeName], data);
    this.float = 'left';
    this.hasCheckbox = ko.observable(false);
    this.comment = ko.observable('');
    this.fullWidth = ko.observable(false);
    this.title = ko.observable('');
    this.titlePosArr = ['top', 'left'];
    this.titlePos = ko.observable('top');
    this.left = ko.observable(0);
    this.leftTypeArr = ['fix', 'after'];
    this.leftType = ko.observable('after');
    this.text = ko.observable('');
    this.noWrap = ko.observable(true);
    this.isChecked = ko.observable(false);
    this.width = ko.observable(0);
    this.widthTypeArr = ['stretch', 'fix'];
    this.widthType = ko.observable('fix');
    ko.computed(function() {
      var wt;

      wt = _this.widthType();
      if (wt === 'fix') {
        return _this.fullWidth(false);
      } else if (wt === 'stretch') {
        return _this.fullWidth(true);
      }
    });
    this.titleStyle = ko.computed(function() {
      return _this.computeStyles(_this.titlePos(), _this.leftType(), _this.left()).title;
    });
    this.contentStyle = ko.computed(function() {
      return _this.computeStyles(_this.titlePos(), _this.leftType(), _this.left(), _this.widthType(), _this.width()).content;
    });
    this.checkboxStyle = ko.computed(function() {
      return _this.computeStyles(_this.titlePos(), _this.leftType(), _this.left()).checkbox;
    });
    this.enabled = ko.computed(function() {
      if (!_this.canEdit()) {
        return false;
      } else if (_this.hasCheckbox()) {
        return _this.isChecked();
      } else {
        return true;
      }
    });
    this.cellCss = ko.computed(function() {
      var css, nexWasClicked;

      css = ['ctrl_type_' + _this.typeName];
      if (!_this.enabled()) {
        css.push('disabled');
      }
      if (_this.titlePos() === 'top') {
        css.push('ctrl_cell_title_top');
      }
      if (_this.noWrap()) {
        css.push('ctrl_nowrap');
      }
      if (_this.isActive()) {
        css.push('selected');
      }
      nexWasClicked = _this.nextWasClicked();
      if (ko.isObservable(_this.readyToSave) && !_this.readyToSave()) {
        if (nexWasClicked) {
          css.push('error');
        } else {
          css.push('required');
        }
      }
      if (!_this.canEdit()) {
        css.push('anotherEditor');
      }
      return css.join(' ');
    });
    this.number = ko.observable(0);
    this.value = ko.observable('');
    this.subscription = ko.observable('');
    this.data = ko.observable('');
    this.isEditable = ko.observable(this.json.iseditable ? true : false);
    this.isRequired = ko.observable(this.json.isrequired ? true : false);
    this.realTimeSendChangesPeriod = false;
    this.sendAllVals = function() {
      return _this.trigger('valueChange', _this.getValuesObj(true));
    };
    if (this.init) {
      this.init();
    }
    if (this.canMultipleEdit) {
      this.on('all', function(a, b, c) {
        return log('CONTROL EVENT ' + a, b, c);
      });
      lastSentVals = '';
      this.isActive.subscribe(function(val) {
        var vals;

        if (val) {
          return _this.trigger('startEdit');
        } else {
          vals = _this.getValuesObj();
          if (_.isEqual(vals, lastSentVals)) {
            vals = null;
          } else {
            lastSentVals = vals;
          }
          return _this.trigger('stopEdit', vals);
        }
      });
      if (this.realTimeSendChangesPeriod !== false) {
        throttledTrigger = _.throttle(function(vals) {
          if (!_.isEqual(vals, lastSentVals)) {
            lastSentVals = vals;
            return _this.trigger('valueChange', vals);
          }
        }, this.realTimeSendChangesPeriod);
      }
      ko.computed(function() {
        var vals;

        vals = _this.getValuesObj();
        if (_this._wasSetFromWs) {
          _this._wasSetFromWs = false;
          return;
        }
        if (_this.valuesWasSet && _this.realTimeSendChangesPeriod !== false && typeof throttledTrigger === 'function') {
          return throttledTrigger(vals);
        }
      });
      if (ko.isObservable(this.isChecked) && (this.getValuesObj().c != null)) {
        ko.computed(function() {
          var c;

          c = _this.isChecked();
          if (_this.valuesWasSet && _this.realTimeSendChangesPeriod === false) {
            return _this.sendAllVals();
          }
        });
      }
    }
    if (values) {
      this.setValues(values);
    }
  }

  controlBase.prototype.focus = function() {};

  controlBase.prototype.afterRender = function(el) {
    return this.el = $(el);
  };

  controlBase.prototype.computeStyles = function(titlePos, leftType, left, withType, contentWidth) {
    var ch, cs, hc, p, ts;

    left = left || 0;
    ts = {
      width: '',
      maxWidth: ''
    };
    cs = {
      paddingLeft: '',
      width: ''
    };
    ch = {
      paddingLeft: ''
    };
    hc = this.hasCheckbox();
    if (withType === 'fix') {
      cs.maxWidth = contentWidth + 'px';
      cs.width = '100%';
    }
    if (titlePos === 'top') {
      if (leftType === 'fix') {
        if (hc) {
          if (left <= 23) {
            cs.maxWidth = (contentWidth - 23) + 'px';
          } else {
            ch = {
              paddingLeft: Math.max(left, 23) - 23 + 'px'
            };
          }
        } else {
          p = left <= 23 ? 0 : left;
          cs.paddingLeft = p + 'px';
        }
      }
    } else if (titlePos === 'left') {
      if (leftType === 'fix') {
        if (hc) {
          ts = {
            width: (Math.max(left, 38) - 23) + 'px',
            maxWidth: (Math.max(left, 38) - 23) + 'px'
          };
        } else {
          ts = {
            width: Math.max(left, 38) + 'px',
            maxWidth: Math.max(left, 38) + 'px'
          };
        }
      } else if (leftType === 'after') {
        ts = {
          width: '',
          maxWidth: ''
        };
      }
    }
    if (cs.maxWidth === '0px') {
      cs.width = 'auto';
      cs.maxWidth = '';
    }
    return {
      title: ts,
      content: cs,
      checkbox: ch
    };
  };

  controlBase.prototype.parseListItems = function(itemsJson) {
    var i, item, items, itemsRaw, _i, _len;

    itemsRaw = JSON.parse(itemsJson || '[]');
    items = [];
    for (i = _i = 0, _len = itemsRaw.length; _i < _len; i = ++_i) {
      item = itemsRaw[i];
      if (_.isArray(item)) {
        items.push({
          name: item[1],
          value: item[0],
          id: item[0],
          text: item[1]
        });
      } else {
        items.push({
          name: item,
          value: item,
          id: item,
          text: item
        });
      }
    }
    return items;
  };

  controlBase.prototype.setValues = function(values) {
    if (!values) {
      return;
    }
    this._values = values;
    if (this.json.width != null) {
      this.width(this.json.width);
    }
    if ((this.json.commentid != null) && (values[this.json.commentid] != null)) {
      this.comment(values[this.json.commentid]);
    }
    this.hasCheckbox(this.json.hascheck || false);
    if (this.widthTypeArr.indexOf(this.json.widthtype) !== -1) {
      this.widthType(this.json.widthtype);
    }
    this.title(values[this.json.titleid] || '');
    if (this.titlePosArr.indexOf(this.json.titlepos) !== -1) {
      this.titlePos(this.json.titlepos);
    }
    this.left(this.json.left || 0);
    if (this.leftTypeArr.indexOf(this.json.lefttype) !== -1) {
      this.leftType(this.json.lefttype);
    }
    if ((this.json.textid != null) && (values[this.json.textid] != null)) {
      this.text(values[this.json.textid]);
    }
    this.isChecked(values[this.json.checkid] ? true : false);
    if ((this.json.numberid != null) && (values[this.json.numberid] != null)) {
      this.number(values[this.json.numberid]);
    }
    if ((this.json.valueid != null) && (values[this.json.valueid] != null)) {
      this.value(values[this.json.valueid]);
    }
    if ((this.json.subscriptionid != null) && (values[this.json.subscriptionid] != null)) {
      this.subscription(values[this.json.subscriptionid]);
    }
    if ((this.json.dataid != null) && (values[this.json.dataid] != null)) {
      this.data(values[this.json.dataid]);
    }
    if (this.json.wrap != null) {
      return this.noWrap(!this.json.wrap);
    }
  };

  controlBase.prototype.getValues = function() {
    return {};
  };

  controlBase.prototype.getValuesObj = function(peek) {};

  controlBase.prototype.setValuesObj = function(vals) {
    return this._wasSetFromWs = true;
  };

  return controlBase;

})(BaseType);

loader.types['control.base'] = ['card', controlBase];

// Generated by CoffeeScript 1.5.0
var __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
  __hasProp = {}.hasOwnProperty,
  __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

loader.types['control.textBox'] = [
  'card', (function(_super) {

    __extends(_Class, _super);

    function _Class(card, data, values) {
      this.setValuesObj = __bind(this.setValuesObj, this);
      this.getValuesObj = __bind(this.getValuesObj, this);
      this.getValues = __bind(this.getValues, this);
      this.setValues = __bind(this.setValues, this);
      this.afterRender = __bind(this.afterRender, this);
      this.init = __bind(this.init, this);      _Class.__super__.constructor.apply(this, arguments);
    }

    _Class.prototype.init = function() {
      var _this = this;
      this.rowCount = ko.observable(1);
      this.canMultipleEdit = true;
      this.realTimeSendChangesPeriod = 500;
      return this.readyToSave = ko.computed(function() {
        var hasCheckbox, hasValue, isChecked, isRequired;
        hasCheckbox = _this.hasCheckbox();
        isChecked = _this.isChecked();
        hasValue = (_this.text() != null) && _this.text() !== '';
        isRequired = _this.isRequired();
        if (!isRequired || (hasCheckbox && isChecked && hasValue) || (hasCheckbox && !isChecked) || (!hasCheckbox && hasValue)) {
          return true;
        } else {
          return false;
        }
      });
    };

    _Class.prototype.afterRender = function(el) {
      var _this = this;
      _Class.__super__.afterRender.apply(this, arguments);
      this.textarea = this.el.find('textarea');
      this.textarea.bind('mousewheel', function(e) {
        var up;
        if (e.currentTarget.scrollHeight <= e.currentTarget.offsetHeight) {
          return true;
        }
        up = e.originalEvent.wheelDelta > 0;
        if (up && e.currentTarget.scrollTop !== 0) {
          return e.stopPropagation();
        } else if (!up && e.currentTarget.scrollHeight + e.currentTarget.scrollTop < e.currentTarget.offsetHeight) {
          return e.stopPropagation();
        } else {
          return true;
        }
      });
      this.el.find(':input').blur(function() {
        _this.isActive(false);
        return true;
      });
      return this.el.find(':input').focus(function() {
        _this.isActive(true);
        return true;
      });
    };

    _Class.prototype.focus = function() {
      $('body').blur();
      return this.el.find(':input:visible:first').focus();
    };

    _Class.prototype.setValues = function(values) {
      _Class.__super__.setValues.apply(this, arguments);
      this.rowCount(this.json.rowcount);
      return this.valuesWasSet = true;
    };

    _Class.prototype.getValues = function() {
      var v;
      v = {};
      if (this.hasCheckbox()) {
        v[this.json.checkid] = this.isChecked() ? 1 : 0;
      }
      if (!(this.hasCheckbox() && !this.isChecked())) {
        v[this.json.textid] = this.text();
      }
      return v;
    };

    _Class.prototype.getValuesObj = function(peek) {
      if (peek) {
        return {
          c: this.isChecked.peek(),
          t: this.text.peek()
        };
      } else {
        return {
          c: this.isChecked(),
          t: this.text()
        };
      }
    };

    _Class.prototype.setValuesObj = function(vals) {
      _Class.__super__.setValuesObj.apply(this, arguments);
      this.isChecked(vals.c);
      return this.text(vals.t);
    };

    return _Class;

  })(loader.getClass('control.base'))
];

// Generated by CoffeeScript 1.5.0
var __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
  __hasProp = {}.hasOwnProperty,
  __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

loader.types['control.image'] = [
  'card', (function(_super) {

    __extends(_Class, _super);

    function _Class(card, data, values) {
      this.setValues = __bind(this.setValues, this);
      this.computeSize = __bind(this.computeSize, this);
      this.init = __bind(this.init, this);      _Class.__super__.constructor.apply(this, arguments);
    }

    _Class.prototype.init = function() {
      var _this = this;
      this.image = ko.observable('');
      this.widthTypeArr = ['original', 'stretch', 'fixedwidth', 'fixedheight', 'fixed'];
      this.widthType = ko.observable('original');
      this.height = ko.observable('');
      this.cWidth = ko.computed(function() {
        return _this.computeSize(_this.widthType(), _this.width(), _this.height.peek()).w;
      });
      return this.cHeight = ko.computed(function() {
        return _this.computeSize(_this.widthType(), _this.width.peek(), _this.height()).h;
      });
    };

    _Class.prototype.computeSize = function(wtype, w, h) {
      this.fullWidth(false);
      switch (wtype) {
        case 'original':
          w = h = '';
          break;
        case 'stretch':
          this.fullWidth(true);
          w = '100%';
          h = '';
          break;
        case 'fixedwidth':
          h = '';
          break;
        case 'fixedheight':
          w = '';
      }
      return {
        w: w,
        h: h
      };
    };

    /*
    	type
       typestr
       index
       titlepos (top,left)
       lefttype (fix,after)
       left
       widthtype (original,stretch,fixedwidth,fixedheight,fixed)
       width
       height
       wrap
       imageid
       titleid?
       commentid?
    */


    _Class.prototype.setValues = function(values) {
      _Class.__super__.setValues.apply(this, arguments);
      if ((this.json.imageid != null) && (values[this.json.imageid] != null)) {
        this.image(values[this.json.imageid]);
      }
      return this.height(this.json.height);
    };

    return _Class;

  })(loader.getClass('control.base'))
];

// Generated by CoffeeScript 1.5.0
var __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
  __hasProp = {}.hasOwnProperty,
  __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

loader.types['control.label'] = [
  'card', (function(_super) {

    __extends(_Class, _super);

    function _Class(card, data, values) {
      this.setValues = __bind(this.setValues, this);      _Class.__super__.constructor.apply(this, arguments);
    }

    _Class.prototype.setValues = function(values) {
      return _Class.__super__.setValues.apply(this, arguments);
    };

    return _Class;

  })(loader.getClass('control.base'))
];

// Generated by CoffeeScript 1.5.0
var __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
  __hasProp = {}.hasOwnProperty,
  __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

loader.types['control.button'] = [
  'card', (function(_super) {

    __extends(_Class, _super);

    function _Class(card, data, values) {
      this.setValues = __bind(this.setValues, this);
      this.init = __bind(this.init, this);
      var _this = this;
      _Class.__super__.constructor.apply(this, arguments);
      this.onClick = function() {
        return card.transferTo(_this.number());
      };
    }

    _Class.prototype.init = function() {};

    _Class.prototype.setValues = function(values) {
      return _Class.__super__.setValues.apply(this, arguments);
    };

    return _Class;

  })(loader.getClass('control.base'))
];

// Generated by CoffeeScript 1.5.0
var __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
  __hasProp = {}.hasOwnProperty,
  __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

loader.types['control.checkBox'] = [
  'card', (function(_super) {

    __extends(_Class, _super);

    function _Class(card, data, values) {
      this.setValuesObj = __bind(this.setValuesObj, this);
      this.getValuesObj = __bind(this.getValuesObj, this);
      this.getValues = __bind(this.getValues, this);
      this.setValues = __bind(this.setValues, this);
      this.init = __bind(this.init, this);      _Class.__super__.constructor.apply(this, arguments);
    }

    _Class.prototype.init = function() {
      var _this = this;
      this.value = ko.observable(false);
      this.canMultipleEdit = true;
      return this.value.subscribe(function(val) {
        if (_this.valuesWasSet && !_this._wasSetFromWs) {
          return _this.sendAllVals();
        }
      });
    };

    _Class.prototype.setValues = function(values) {
      _Class.__super__.setValues.apply(this, arguments);
      this.value(this.isChecked());
      return this.valuesWasSet = true;
    };

    _Class.prototype.getValues = function() {
      var v;
      v = {};
      v[this.json.checkid] = this.value() ? 1 : 0;
      return v;
    };

    _Class.prototype.getValuesObj = function(peek) {
      if (peek) {
        return {
          v: this.value.peek()
        };
      } else {
        return {
          v: this.value()
        };
      }
    };

    _Class.prototype.setValuesObj = function(vals) {
      _Class.__super__.setValuesObj.apply(this, arguments);
      return this.value(vals.v);
    };

    return _Class;

  })(loader.getClass('control.base'))
];

// Generated by CoffeeScript 1.5.0
var __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
  __hasProp = {}.hasOwnProperty,
  __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

loader.types['control.checkBoxGroup'] = [
  'card', (function(_super) {

    __extends(_Class, _super);

    function _Class(card, data, values) {
      this.setValuesObj = __bind(this.setValuesObj, this);
      this.getValuesObj = __bind(this.getValuesObj, this);
      this.getValues = __bind(this.getValues, this);
      this.setValues = __bind(this.setValues, this);
      this.init = __bind(this.init, this);      _Class.__super__.constructor.apply(this, arguments);
    }

    _Class.prototype.init = function() {
      var _this = this;
      this.columnCount = ko.observable(1);
      this.items = ko.observableArray([]);
      this.fullWidth(true);
      this.elWidth = ko.computed(function() {
        return {
          width: Math.floor(100 / _this.columnCount()) + '%'
        };
      });
      this.readyToSave = ko.computed(function() {
        var hasCheckbox, isChecked, isRequired, item, items, val, _i, _len;
        items = _this.items();
        val = false;
        for (_i = 0, _len = items.length; _i < _len; _i++) {
          item = items[_i];
          if (item.checked()) {
            val = true;
          }
        }
        hasCheckbox = _this.hasCheckbox();
        isChecked = _this.isChecked();
        isRequired = _this.isRequired();
        if (!isRequired || (hasCheckbox && isChecked && val) || (hasCheckbox && !isChecked) || (!hasCheckbox && val)) {
          return true;
        } else {
          return false;
        }
      });
      this.canMultipleEdit = true;
      return this.realTimeSendChangesPeriod = 100;
    };

    _Class.prototype.setValues = function(values) {
      var i, item, items, itemsRaw, _i, _len;
      _Class.__super__.setValues.apply(this, arguments);
      this.columnCount(this.json.columncount);
      items = [];
      if (values) {
        itemsRaw = JSON.parse(values[this.json.itemsid] || []);
        for (i = _i = 0, _len = itemsRaw.length; _i < _len; i = ++_i) {
          item = itemsRaw[i];
          items.push({
            number: i + 1,
            name: item,
            checked: ko.observable(false)
          });
        }
      }
      this.items(items);
      return this.valuesWasSet = true;
    };

    _Class.prototype.getValues = function() {
      var v,
        _this = this;
      v = {};
      v[this.json.valueid] = _.map(this.items(), function(i) {
        if (i.checked()) {
          return 1;
        } else {
          return 0;
        }
      }).join('');
      return v;
    };

    _Class.prototype.getValuesObj = function(peek) {
      var c, v, _i, _len, _ref;
      if (peek) {
        v = {
          c: this.isChecked.peek()
        };
      } else {
        v = {
          c: this.isChecked()
        };
      }
      v.ch = {};
      _ref = this.items();
      for (_i = 0, _len = _ref.length; _i < _len; _i++) {
        c = _ref[_i];
        if (peek) {
          v.ch[c.number] = c.checked.peek();
        } else {
          v.ch[c.number] = c.checked();
        }
      }
      return v;
    };

    _Class.prototype.setValuesObj = function(vals) {
      var c, _i, _len, _ref, _results;
      _Class.__super__.setValuesObj.apply(this, arguments);
      this.isChecked(vals.c);
      _ref = this.items();
      _results = [];
      for (_i = 0, _len = _ref.length; _i < _len; _i++) {
        c = _ref[_i];
        if (vals.ch[c.number] != null) {
          _results.push(c.checked(vals.ch[c.number]));
        } else {
          _results.push(void 0);
        }
      }
      return _results;
    };

    return _Class;

  })(loader.getClass('control.base'))
];

// Generated by CoffeeScript 1.5.0
var __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
  __hasProp = {}.hasOwnProperty,
  __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

loader.types['control.comboBox'] = [
  'card', (function(_super) {

    __extends(_Class, _super);

    function _Class(card, data, values) {
      this.setValuesObj = __bind(this.setValuesObj, this);
      this.getValuesObj = __bind(this.getValuesObj, this);
      this.afterRender = __bind(this.afterRender, this);
      this.createCombo = __bind(this.createCombo, this);
      this.getValues = __bind(this.getValues, this);
      this.setValues = __bind(this.setValues, this);
      this.focus = __bind(this.focus, this);
      this.init = __bind(this.init, this);      _Class.__super__.constructor.apply(this, arguments);
    }

    _Class.prototype.init = function() {
      var _this = this;
      this.value = ko.observable('');
      this.comboWidth = ko.observable(this.width());
      ko.computed(function() {
        var cs;
        cs = _this.contentStyle();
        return _this.comboWidth(cs.width);
      });
      this.cWidth = ko.computed(function() {
        var w, wt;
        wt = _this.widthType();
        w = _this.comboWidth();
        if (wt === 'fix') {
          return {
            width: w
          };
        } else if (wt === 'stretch') {
          return {
            width: '100%'
          };
        } else {
          return {
            width: '100px'
          };
        }
      });
      this.items = ko.observableArray([]);
      this.readyToSave = ko.computed(function() {
        var hasCheckbox, isChecked, isRequired, value;
        hasCheckbox = _this.hasCheckbox();
        isChecked = _this.isChecked();
        value = _this.value();
        isRequired = _this.isRequired();
        if (!isRequired || (hasCheckbox && isChecked && value) || (hasCheckbox && !isChecked) || (!hasCheckbox && value)) {
          return true;
        } else {
          return false;
        }
      });
      return this.canMultipleEdit = true;
    };

    _Class.prototype.focus = function() {
      if (this.enabled()) {
        return this.selectEl.select2('open');
      }
    };

    _Class.prototype.setValues = function(values) {
      _Class.__super__.setValues.apply(this, arguments);
      if (values) {
        this.items(this.parseListItems(values[this.json.itemsid]));
        this.createCombo(this.items());
        if (values[this.json.textid] != null) {
          this.value(values[this.json.textid]);
        }
      }
      return this.valuesWasSet = true;
    };

    _Class.prototype.getValues = function() {
      var v;
      v = {};
      if (this.hasCheckbox()) {
        v[this.json.checkid] = this.isChecked() ? 1 : 0;
      }
      if (!(this.hasCheckbox() && !this.isChecked())) {
        v[this.json.textid] = this.value();
      }
      return v;
    };

    _Class.prototype.createCombo = function(data) {
      var select,
        _this = this;
      if (!this.selectEl || !this.selectEl.size()) {
        return;
      }
      select = this.selectEl;
      if (this.select2created) {
        select.select2('destroy');
      }
      this.select2created = true;
      select.select2({
        data: data,
        createSearchChoice: function(term, data) {
          if (_this.isEditable() && $(data).filter(function() {
            return this.text.localeCompare(term) === 0;
          }).length === 0) {
            return {
              id: term,
              text: term
            };
          }
        },
        initSelection: function(element, callback) {
          var obj, val;
          val = element.val();
          obj = _.find(_this.items(), function(d) {
            return d.id === val;
          });
          if (!obj) {
            obj = {
              id: val,
              name: val,
              value: val,
              text: val
            };
          }
          return callback(obj);
        }
      });
      select.select2('val', this.value());
      select.select2('container').find('.select2-container').bind('touchend', function(e) {
        return e.stopPropagation();
      });
      select.select2('container').find('.select2-drop').bind('mousewheel', function(e) {
        return e.stopPropagation();
      });
      if (!this.enabled()) {
        return select.select2('disable');
      }
    };

    _Class.prototype.afterRender = function(el) {
      var $el, closer, data, filtered, select,
        _this = this;
      _Class.__super__.afterRender.apply(this, arguments);
      $el = $(el);
      filtered = $el.filter('input');
      select = filtered.size() ? filtered : $el.find('input');
      this.selectEl = select;
      data = this.items();
      this.createCombo(data);
      select.on('change', function(e) {
        _this.value(e.val);
        return _this.isActive(false);
      });
      this.value.subscribe(function(val) {
        if (select.select2('val') !== val) {
          return select.select2('val', val);
        }
      });
      select.on('open', function() {
        return _this.isActive(true);
      });
      select.on('close', function() {
        _this.value(select.select2('val'));
        return _this.isActive(false);
      });
      if (window.allSelect2s == null) {
        window.allSelect2Containers = $();
        window.allSelect2s = $();
      }
      window.allSelect2s = window.allSelect2s.add(select);
      window.allSelect2Containers = window.allSelect2Containers.add(select.select2('container'));
      if (!$('html').data('__select2closer') && typeof window.ontouchstart === 'undefined') {
        $('html').data('__select2closer', true);
        closer = _.throttle(function() {
          if (window.allSelect2Containers.filter('.select2-dropdown-open').size()) {
            return window.allSelect2s.select2('close');
          }
        }, 100);
        $('html').bind('mousewheel', closer);
      }
      this.cWidth.subscribe(function(w) {
        return select.select2('container').css({
          width: w.width
        });
      });
      return this.enabled.subscribe(function(enabled) {
        if (enabled) {
          return select.select2('enable');
        } else {
          return select.select2('disable');
        }
      });
    };

    _Class.prototype.getValuesObj = function(peek) {
      if (peek) {
        return {
          c: this.isChecked.peek(),
          v: this.value.peek()
        };
      } else {
        return {
          c: this.isChecked(),
          v: this.value()
        };
      }
    };

    _Class.prototype.setValuesObj = function(vals) {
      _Class.__super__.setValuesObj.apply(this, arguments);
      this.isChecked(vals.c);
      return this.value(vals.v);
    };

    return _Class;

  })(loader.getClass('control.base'))
];

// Generated by CoffeeScript 1.6.2
var controlDateTime,
  __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
  __hasProp = {}.hasOwnProperty,
  __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

controlDateTime = (function(_super) {
  __extends(controlDateTime, _super);

  function controlDateTime(card, data, values) {
    this.setValuesObj = __bind(this.setValuesObj, this);
    this.getValuesObj = __bind(this.getValuesObj, this);
    this.afterRender = __bind(this.afterRender, this);
    this.setValues = __bind(this.setValues, this);
    this.getValues = __bind(this.getValues, this);
    this.init = __bind(this.init, this);    controlDateTime.__super__.constructor.apply(this, arguments);
  }

  controlDateTime.prototype.init = function() {
    var _this = this;

    this.contentStyle = '';
    this.modeArr = ['time', 'timeperiod', 'date', 'dateperiod'];
    this.mode = ko.observable('date');
    this.value1 = ko.observable('');
    this.value2 = ko.observable('');
    this.valueDate1 = ko.observable('');
    this.valueDate2 = ko.observable('');
    this.valueTime1 = ko.observable('');
    this.valueTime2 = ko.observable('');
    this.d1Focus = ko.observable(false);
    this.d2Focus = ko.observable(false);
    this.t1Focus = ko.observable(false);
    this.t2Focus = ko.observable(false);
    this.fDate = 'DD.MM.YYYY';
    this.fTime = 'HH:mm';
    this.fVal = 'YYYY-MM-DD HH:mm:ss';
    this.readyToSave = ko.computed(function() {
      var hasCheckbox, isChecked, isRequired, mode, v, vd1, vd2, vt1, vt2;

      hasCheckbox = _this.hasCheckbox();
      isChecked = _this.isChecked();
      v = '';
      vd1 = _this.valueDate1();
      vd2 = _this.valueDate2();
      vt1 = _this.valueTime1();
      vt2 = _this.valueTime2();
      mode = _this.mode();
      switch (mode) {
        case 'date':
          v = vd1;
          break;
        case 'time':
          v = vt1;
          break;
        case 'dateperiod':
          v = vd1 && vd2 ? true : false;
          break;
        case 'timeperiod':
          v = vt1 && vt2 ? true : false;
      }
      isRequired = _this.isRequired();
      if (!isRequired || (hasCheckbox && isChecked && v) || (hasCheckbox && !isChecked) || (!hasCheckbox && v)) {
        return true;
      } else {
        return false;
      }
    });
    return this.canMultipleEdit = true;
  };

  controlDateTime.prototype.getValues = function() {
    var v;

    v = {};
    if (this.hasCheckbox()) {
      v[this.json.checkid] = this.isChecked() ? 1 : 0;
    }
    if (!(this.hasCheckbox() && !this.isChecked())) {
      if (this.json.valueid != null) {
        if (this.mode() === 'date') {
          v[this.json.valueid] = moment(this.valueDate1(), this.fDate).format(this.fVal);
        } else {
          v[this.json.valueid] = moment(this.valueTime1(), this.fTime).format(this.fVal);
        }
      } else if (this.json.value1id != null) {
        if (this.mode() === 'dateperiod') {
          v[this.json.value1id] = moment(this.valueDate1(), this.fDate).format(this.fVal);
          v[this.json.value2id] = moment(this.valueDate2(), this.fDate).format(this.fVal);
        } else {
          v[this.json.value1id] = moment(this.valueTime1(), this.fTime).format(this.fVal);
          v[this.json.value2id] = moment(this.valueTime2(), this.fTime).format(this.fVal);
        }
      }
    }
    return v;
  };

  controlDateTime.prototype.setValues = function(values) {
    var m, val, val1, val2;

    controlDateTime.__super__.setValues.apply(this, arguments);
    if (this.modeArr.indexOf(this.json.mode) !== -1) {
      this.mode(this.json.mode);
    }
    if (this.json.value1id != null) {
      val1 = values[this.json.value1id];
      if (val1 === '0001-01-01 00:00:00') {
        val1 = moment().format(this.fVal);
      }
    }
    if (this.json.value1id != null) {
      val2 = values[this.json.value1id];
      if (val2 === '0001-01-01 00:00:00') {
        val2 = moment().format(this.fVal);
      }
    }
    if (this.value() === '0001-01-01 00:00:00') {
      this.value(moment().format(this.fVal));
    }
    if (this.value()) {
      this.valueDate1(this.value().substr(0, 10));
    }
    if (val1) {
      this.value1(val1);
    }
    val = this.value1() || this.value();
    if (val) {
      m = moment(val, this.fVal);
      this.valueDate1(m.format(this.fDate));
      this.valueTime1(m.format(this.fTime));
    }
    if (val2) {
      this.value2(val2);
      m = moment(this.value2(), this.fVal);
      this.valueDate2(m.format(this.fDate));
      this.valueTime2(m.format(this.fTime));
    }
    return this.valuesWasSet = true;
  };

  controlDateTime.prototype.afterRender = function(el) {
    var closer, dateInputs, di1, di2, ti1, ti2, timeInputs,
      _this = this;

    controlDateTime.__super__.afterRender.apply(this, arguments);
    dateInputs = this.el.find('input:even');
    timeInputs = this.el.find('input:odd');
    if (window.allDatePickers == null) {
      window.allDatePickers = $();
      window.allTimePickers = $();
      window.allDatePickerMenus = $();
      window.allTimePickerMenus = $();
    }
    di1 = '';
    di2 = '';
    ti1 = '';
    ti2 = '';
    dateInputs.each(function(i, el) {
      var input;

      input = $(el);
      window.allDatePickers = window.allDatePickers.add(input);
      input.datepicker({
        format: 'dd.mm.yyyy'
      });
      input.datepicker().on('changeDate', function(ev) {
        input.datepicker('hide');
        return input.blur();
      });
      input.datepicker().on('show', function(ev) {
        return _this.isActive(true);
      });
      _this.canEdit.subscribe(function(val) {
        if (!val) {
          return input.datepicker('hide');
        }
      });
      if (!di1) {
        di1 = input;
        return di1.datepicker('setValue', _this.valueDate1());
      } else {
        di2 = input;
        return di2.datepicker('setValue', _this.valueDate2());
      }
    });
    di1.datepicker().on('changeDate', function(ev) {
      return _this.valueDate1(moment(ev.date).format(_this.fDate));
    });
    this.valueDate1.subscribe(function(val) {
      if (di1.val() !== val) {
        return di1.datepicker('setValue', val);
      }
    });
    di1.datepicker().on('hide', function(ev) {
      _this.valueDate1(di1.val());
      return _this.isActive(false);
    });
    di2.datepicker().on('changeDate', function(ev) {
      return _this.valueDate2(moment(ev.date).format(_this.fDate));
    });
    this.valueDate2.subscribe(function(val) {
      if (di2.val() !== val) {
        return di2.datepicker('setValue', val);
      }
    });
    di2.datepicker().on('hide', function(ev) {
      _this.valueDate2(di2.val());
      return _this.isActive(false);
    });
    timeInputs.each(function(i, el) {
      var input;

      input = $(el);
      if (!ti1) {
        ti1 = input;
        ti1.val(_this.valueTime1() || '11:11');
      } else {
        ti2 = input;
        ti2.val(_this.valueTime2() || '11:11');
      }
      window.allTimePickers = window.allTimePickers.add(input);
      input.timepicker({
        minuteStep: 1,
        defaultTime: false,
        showMeridian: false
      });
      input.timepicker().on('show.timepicker', function(ev) {
        return _this.isActive(true);
      });
      return _this.canEdit.subscribe(function(val) {
        if (!val) {
          input.timepicker('hideWidget');
          return input.blur();
        }
      });
    });
    ti1.on('change', function(ev) {
      return _this.valueTime1(ti1.val());
    });
    ti1.timepicker().on('hide.timepicker', function(ev) {
      _this.valueTime1(ti1.val());
      return _this.isActive(false);
    });
    this.valueTime1.subscribe(function(val) {
      if (ti1.val() !== val) {
        return ti1.timepicker('setTime', val);
      }
    });
    ti2.on('change', function(ev) {
      return _this.valueTime2(ti2.val());
    });
    ti2.timepicker().on('hide.timepicker', function(ev) {
      _this.valueTime2(ti2.val());
      return _this.isActive(false);
    });
    this.valueTime2.subscribe(function(val) {
      if (ti2.val() !== val) {
        return ti2.timepicker('setTime', val);
      }
    });
    window.allDatePickerMenus = $('body .datepicker.dropdown-menu');
    window.allTimePickerMenus = $('body .bootstrap-timepicker.dropdown-menu');
    if (!$('html').data('__datetimepickerscloser')) {
      $('html').data('__datetimepickerscloser', true);
      closer = _.throttle(function() {
        if (window.allDatePickerMenus.filter(':visible').size()) {
          window.allDatePickers.datepicker('hide');
          window.allDatePickers.blur();
        }
        if (window.allTimePickerMenus.filter('.open')) {
          window.allTimePickers.timepicker('hideWidget');
          return window.allTimePickers.blur();
        }
      }, 100);
      return $('html').bind('mousewheel', closer);
    }
  };

  controlDateTime.prototype.getValuesObj = function(peek) {
    controlDateTime.__super__.getValuesObj.apply(this, arguments);
    if (peek) {
      return {
        c: this.isChecked.peek(),
        d1: this.valueDate1.peek(),
        d2: this.valueDate2.peek(),
        t1: this.valueTime1.peek(),
        t2: this.valueTime2.peek()
      };
    } else {
      return {
        c: this.isChecked(),
        d1: this.valueDate1(),
        d2: this.valueDate2(),
        t1: this.valueTime1(),
        t2: this.valueTime2()
      };
    }
  };

  controlDateTime.prototype.setValuesObj = function(vals) {
    controlDateTime.__super__.setValuesObj.apply(this, arguments);
    this.isChecked(vals.c);
    this.valueDate1(vals.d1);
    this.valueDate2(vals.d2);
    this.valueTime1(vals.t1);
    return this.valueTime2(vals.t2);
  };

  return controlDateTime;

})(controlBase);

loader.types['control.dateTime'] = ['card', controlDateTime];

// Generated by CoffeeScript 1.5.0
var __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
  __hasProp = {}.hasOwnProperty,
  __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

loader.types['control.grid'] = [
  'card', (function(_super) {

    __extends(_Class, _super);

    function _Class(card, data, values) {
      this.setValues = __bind(this.setValues, this);
      this.init = __bind(this.init, this);      _Class.__super__.constructor.apply(this, arguments);
    }

    _Class.prototype.init = function() {
      this.fields = ko.observableArray([]);
      this.height = ko.observable();
      this.rows = ko.observableArray([]);
      this.cellCss = this.cellCss + ' b_operators_table';
      return this.data = ko.observable();
    };

    _Class.prototype.setValues = function(values) {
      var d, f, fields, i, r, row, rows, v, _i, _j, _k, _len, _len1, _len2, _ref, _ref1;
      _Class.__super__.setValues.apply(this, arguments);
      this.data(this.data() && JSON.parse(this.data()) || false);
      if (this.json.height != null) {
        this.height(this.json.height);
      }
      fields = [];
      rows = [];
      d = this.data();
      if (d) {
        _ref = d.fields;
        for (i = _i = 0, _len = _ref.length; _i < _len; i = ++_i) {
          f = _ref[i];
          fields.push({
            name: f,
            style: {
              width: d.width && (d.width[i] + 'px') || ''
            }
          });
        }
        _ref1 = d.rows;
        for (_j = 0, _len1 = _ref1.length; _j < _len1; _j++) {
          r = _ref1[_j];
          row = [];
          for (i = _k = 0, _len2 = r.length; _k < _len2; i = ++_k) {
            v = r[i];
            row.push({
              value: v,
              style: fields[i].style
            });
          }
          rows.push(row);
        }
      }
      this.fields(fields);
      return this.rows(rows);
    };

    return _Class;

  })(loader.getClass('control.base'))
];

// Generated by CoffeeScript 1.5.0
var __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
  __hasProp = {}.hasOwnProperty,
  __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

loader.types['control.line'] = [
  'card', (function(_super) {

    __extends(_Class, _super);

    function _Class(card, data, values) {
      this.setValues = __bind(this.setValues, this);      _Class.__super__.constructor.apply(this, arguments);
    }

    _Class.prototype.setValues = function(values) {
      return _Class.__super__.setValues.apply(this, arguments);
    };

    return _Class;

  })(loader.getClass('control.base'))
];

// Generated by CoffeeScript 1.5.0
var __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
  __hasProp = {}.hasOwnProperty,
  __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

loader.types['control.radioGroup'] = [
  'card', (function(_super) {

    __extends(_Class, _super);

    function _Class(card, data, values) {
      this.setValuesObj = __bind(this.setValuesObj, this);
      this.getValuesObj = __bind(this.getValuesObj, this);
      this.getValues = __bind(this.getValues, this);
      this.setValues = __bind(this.setValues, this);
      this.init = __bind(this.init, this);      _Class.__super__.constructor.apply(this, arguments);
    }

    _Class.prototype.init = function() {
      var _this = this;
      this.columnCount = ko.observable(1);
      this.fullWidth(true);
      this.elWidth = ko.computed(function() {
        return {
          width: Math.floor(100 / _this.columnCount()) + '%'
        };
      });
      this.items = ko.observableArray([]);
      this.readyToSave = ko.computed(function() {
        var hasCheckbox, isChecked, isRequired, val;
        val = _this.value();
        hasCheckbox = _this.hasCheckbox();
        isChecked = _this.isChecked();
        isRequired = _this.isRequired();
        if (!isRequired || (hasCheckbox && isChecked && val) || (hasCheckbox && !isChecked) || (!hasCheckbox && val)) {
          return true;
        } else {
          return false;
        }
      });
      this.canMultipleEdit = true;
      return this.realTimeSendChangesPeriod = 500;
    };

    _Class.prototype.setValues = function(values) {
      _Class.__super__.setValues.apply(this, arguments);
      this.columnCount(this.json.columncount);
      this.items(this.parseListItems(values[this.json.itemsid]));
      return this.valuesWasSet = true;
    };

    _Class.prototype.getValues = function() {
      var v;
      v = {};
      if (this.hasCheckbox()) {
        v[this.json.checkid] = this.isChecked() ? 1 : 0;
      }
      if (!(this.hasCheckbox() && !this.isChecked())) {
        v[this.json.valueid] = this.value();
      }
      return v;
    };

    _Class.prototype.getValuesObj = function(peek) {
      if (peek) {
        return {
          c: this.isChecked.peek(),
          v: this.value.peek()
        };
      } else {
        return {
          c: this.isChecked(),
          v: this.value()
        };
      }
    };

    _Class.prototype.setValuesObj = function(vals) {
      _Class.__super__.setValuesObj.apply(this, arguments);
      this.isChecked(vals.c);
      return this.value(vals.v);
    };

    return _Class;

  })(loader.getClass('control.base'))
];

// Generated by CoffeeScript 1.5.0
var __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
  __hasProp = {}.hasOwnProperty,
  __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

loader.types['control.select'] = [
  'card', (function(_super) {

    __extends(_Class, _super);

    function _Class(card, data, values) {
      this.setValues = __bind(this.setValues, this);      _Class.__super__.constructor.apply(this, arguments);
    }

    _Class.prototype.setValues = function(values) {
      return _Class.__super__.setValues.apply(this, arguments);
    };

    return _Class;

  })(loader.getClass('control.base'))
];

// Generated by CoffeeScript 1.5.0
var __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
  __hasProp = {}.hasOwnProperty,
  __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

loader.types['control.spin'] = [
  'card', (function(_super) {

    __extends(_Class, _super);

    function _Class(card, data, values) {
      this.getValues = __bind(this.getValues, this);
      this.setValues = __bind(this.setValues, this);
      this.init = __bind(this.init, this);      _Class.__super__.constructor.apply(this, arguments);
      this.template = '/templates/controls/textBox.html';
    }

    _Class.prototype.init = function() {
      var minMaxChecker,
        _this = this;
      _Class.__super__.init.apply(this, arguments);
      this.max = ko.observable(false);
      this.min = ko.observable(false);
      minMaxChecker = ko.computed(function() {
        var max, min, val;
        min = _this.min();
        max = _this.max();
        val = parseInt(_this.text());
        if (!val) {
          val = 0;
        }
        if (max !== false && val > max) {
          val = max;
        } else if (min !== false && val < min) {
          val = min;
        }
        return _this.text(val);
      });
      return this.eBlur = function() {
        return _this.isActive(false);
      };
    };

    _Class.prototype.setValues = function(values) {
      _Class.__super__.setValues.apply(this, arguments);
      if ((this.json.maxid != null) && (values[this.json.maxid] != null)) {
        this.max(values[this.json.maxid]);
      }
      if ((this.json.minid != null) && (values[this.json.minid] != null)) {
        this.min(values[this.json.minid]);
      }
      this.text(this.value() || 0);
      return _Class.__super__.setValues.apply(this, arguments);
    };

    _Class.prototype.getValues = function() {
      var v;
      v = {};
      if (this.hasCheckbox()) {
        v[this.json.checkid] = this.isChecked() ? 1 : 0;
      }
      if (!(this.hasCheckbox() && !this.isChecked())) {
        v[this.json.valueid] = this.text();
      }
      return v;
    };

    return _Class;

  })(loader.getClass('control.textBox'))
];

// Generated by CoffeeScript 1.6.2
loader.get('languages');

$(function() {
  var h, oldLog,
    _this = this;

  loader.idApp = Math.random();
  window.testMode = ko.observable(false);
  h = location.host;
  if (h.indexOf('airato.lan') !== -1 || h.indexOf('fomich.lan') !== -1 || h.indexOf('ramil.lan') !== -1) {
    window.testMode(true);
  }
  oldLog = window.log;
  window.log = function() {
    if (window.testMode()) {
      return oldLog.apply(window, arguments);
    }
  };
  window.app = loader.get('app');
  window.d = loader.data;
  ko.startTitle = window.app.langs.menu.windowTitle;
  ko.applyBindings(window.app);
  window.app.reconnect();
  delete window.oktell;
  $.oktellPanel({
    oktell: loader.get('oktell'),
    oktellVoice: window.oktellVoice,
    dynamic: true,
    position: 'right',
    debug: window.testMode(),
    lang: $.cookie('appLanguage') || navigator.language || 'en',
    useNotifies: false
  });
  window.onNativeScrollShow = function() {
    return $('.oktell_panel').css({
      paddingRight: '17px'
    });
  };
  return window.onNativeScrollHide = function() {
    return $('.oktell_panel').css({
      paddingRight: '0px'
    });
  };
});

/* Oktell-panel.js 0.1.2 http://js.oktell.ru/webpanel */

/*! Copyright (c) 2013 Brandon Aaron (http://brandonaaron.net)
 * Licensed under the MIT License (LICENSE.txt).
 *
 * Thanks to: http://adomas.org/javascript-mouse-wheel/ for some pointers.
 * Thanks to: Mathias Bank(http://www.mathias-bank.de) for a scope bug fix.
 * Thanks to: Seamus Leahy for adding deltaX and deltaY
 *
 * Version: 3.1.3
 *
 * Requires: 1.2.2+
 */

(function (factory) {
	if ( typeof define === 'function' && define.amd ) {
		// AMD. Register as an anonymous module.
		define(['jquery'], factory);
	} else if (typeof exports === 'object') {
		// Node/CommonJS style for Browserify
		module.exports = factory;
	} else {
		// Browser globals
		factory(jQuery);
	}
}(function ($) {

	var toFix = ['wheel', 'mousewheel', 'DOMMouseScroll', 'MozMousePixelScroll'];
	var toBind = 'onwheel' in document || document.documentMode >= 9 ? ['wheel'] : ['mousewheel', 'DomMouseScroll', 'MozMousePixelScroll'];
	var lowestDelta, lowestDeltaXY;

	if ( $.event.fixHooks ) {
		for ( var i = toFix.length; i; ) {
			$.event.fixHooks[ toFix[--i] ] = $.event.mouseHooks;
		}
	}

	$.event.special.oktellPanelMousewheel = {
		setup: function() {
			if ( this.addEventListener ) {
				for ( var i = toBind.length; i; ) {
					this.addEventListener( toBind[--i], handler, false );
				}
			} else {
				this.onmousewheel = handler;
			}
		},

		teardown: function() {
			if ( this.removeEventListener ) {
				for ( var i = toBind.length; i; ) {
					this.removeEventListener( toBind[--i], handler, false );
				}
			} else {
				this.onmousewheel = null;
			}
		}
	};

	$.fn.extend({
		oktellPanelMousewheel: function(fn) {
			return fn ? this.bind("oktellPanelMousewheel", fn) : this.trigger("oktellPanelMousewheel");
		},

		unOktellPanelMousewheel: function(fn) {
			return this.unbind("oktellPanelMousewheel", fn);
		}
	});


	function handler(event) {
		var orgEvent = event || window.event,
			args = [].slice.call(arguments, 1),
			delta = 0,
			deltaX = 0,
			deltaY = 0,
			absDelta = 0,
			absDeltaXY = 0,
			fn;
		event = $.event.fix(orgEvent);
		event.type = "oktellPanelMousewheel";

		// Old school scrollwheel delta
		if ( orgEvent.wheelDelta ) { delta = orgEvent.wheelDelta; }
		if ( orgEvent.detail )     { delta = orgEvent.detail * -1; }

		// New school wheel delta (wheel event)
		if ( orgEvent.deltaY ) {
			deltaY = orgEvent.deltaY * -1;
			delta  = deltaY;
		}
		if ( orgEvent.deltaX ) {
			deltaX = orgEvent.deltaX;
			delta  = deltaX * -1;
		}

		// Webkit
		if ( orgEvent.wheelDeltaY !== undefined ) { deltaY = orgEvent.wheelDeltaY; }
		if ( orgEvent.wheelDeltaX !== undefined ) { deltaX = orgEvent.wheelDeltaX * -1; }

		// Look for lowest delta to normalize the delta values
		absDelta = Math.abs(delta);
		if ( !lowestDelta || absDelta < lowestDelta ) { lowestDelta = absDelta; }
		absDeltaXY = Math.max(Math.abs(deltaY), Math.abs(deltaX));
		if ( !lowestDeltaXY || absDeltaXY < lowestDeltaXY ) { lowestDeltaXY = absDeltaXY; }

		// Get a whole value for the deltas
		fn = delta > 0 ? 'floor' : 'ceil';
		delta  = Math[fn](delta / lowestDelta);
		deltaX = Math[fn](deltaX / lowestDeltaXY);
		deltaY = Math[fn](deltaY / lowestDeltaXY);

		// Add event and delta to the front of the arguments
		args.unshift(event, delta, deltaX, deltaY);

		return ($.event.dispatch || $.event.handle).apply(this, args);
	}

}));

/**
 * @author trixta
 * @version 1.2
 */
(function($){

	var mwheelI = {
			pos: [-260, -260]
		},
		minDif 	= 3,
		doc 	= document,
		root 	= doc.documentElement,
		body 	= doc.body,
		longDelay, shortDelay
		;

	function unsetPos(){
		if(this === mwheelI.elem){
			mwheelI.pos = [-260, -260];
			mwheelI.elem = false;
			minDif = 3;
		}
	}

	$.event.special.oktellPanelMwheelIntent = {
		setup: function(){
			var jElm = $(this).bind('oktellPanelMousewheel', $.event.special.oktellPanelMwheelIntent.handler);
			if( this !== doc && this !== root && this !== body ){
				jElm.bind('mouseleave', unsetPos);
			}
			jElm = null;
			return true;
		},
		teardown: function(){
			$(this)
				.unbind('oktellPanelMousewheel', $.event.special.oktellPanelMwheelIntent.handler)
				.unbind('mouseleave', unsetPos)
			;
			return true;
		},
		handler: function(e, d){
			var pos = [e.clientX, e.clientY];
			if( this === mwheelI.elem || Math.abs(mwheelI.pos[0] - pos[0]) > minDif || Math.abs(mwheelI.pos[1] - pos[1]) > minDif ){
				mwheelI.elem = this;
				mwheelI.pos = pos;
				minDif = 250;

				clearTimeout(shortDelay);
				shortDelay = setTimeout(function(){
					minDif = 10;
				}, 200);
				clearTimeout(longDelay);
				longDelay = setTimeout(function(){
					minDif = 3;
				}, 1500);
				e = $.extend({}, e, {type: 'oktellPanelMwheelIntent'});
				return ($.event.dispatch || $.event.handle).apply(this, arguments);
			}
		}
	};
	$.fn.extend({
		oktellPanelMwheelIntent: function(fn) {
			return fn ? this.bind("oktellPanelMwheelIntent", fn) : this.trigger("oktellPanelMwheelIntent");
		},

		unOktellPanelMwheelIntent: function(fn) {
			return this.unbind("oktellPanelMwheelIntent", fn);
		}
	});

	$(function(){
		body = doc.body;
		//assume that document is always scrollable, doesn't hurt if not
		$(doc).bind('oktellPanelMwheelIntent.mwheelIntentDefault', $.noop);
	});
})(jQuery);

/*!
 * jScrollPane - v2.0.14 - 2013-05-01
 * http://jscrollpane.kelvinluck.com/
 *
 * Copyright (c) 2010 Kelvin Luck
 * Dual licensed under the MIT or GPL licenses.
 */

// Script: jScrollPane - cross browser customisable scrollbars
//
// *Version: 2.0.14, Last updated: 2013-05-01*
//
// Project Home - http://jscrollpane.kelvinluck.com/
// GitHub       - http://github.com/vitch/jScrollPane
// Source       - http://github.com/vitch/jScrollPane/raw/master/script/jquery.jscrollpane.js
// (Minified)   - http://github.com/vitch/jScrollPane/raw/master/script/jquery.jscrollpane.min.js
//
// About: License
//
// Copyright (c) 2013 Kelvin Luck
// Dual licensed under the MIT or GPL Version 2 licenses.
// http://jscrollpane.kelvinluck.com/MIT-LICENSE.txt
// http://jscrollpane.kelvinluck.com/GPL-LICENSE.txt
//
// About: Examples
//
// All examples and demos are available through the jScrollPane example site at:
// http://jscrollpane.kelvinluck.com/
//
// About: Support and Testing
//
// This plugin is tested on the browsers below and has been found to work reliably on them. If you run
// into a problem on one of the supported browsers then please visit the support section on the jScrollPane
// website (http://jscrollpane.kelvinluck.com/) for more information on getting support. You are also
// welcome to fork the project on GitHub if you can contribute a fix for a given issue.
//
// jQuery Versions - tested in 1.4.2+ - reported to work in 1.3.x
// Browsers Tested - Firefox 3.6.8, Safari 5, Opera 10.6, Chrome 5.0, IE 6, 7, 8
//
// About: Release History
//
// 2.0.14 - (2013-05-01) Updated to most recent mouse wheel plugin (see #106) and related changes for sensible scroll speed
// 2.0.13 - (2013-05-01) Switched to semver compatible version name
// 2.0.0beta12 - (2012-09-27) fix for jQuery 1.8+
// 2.0.0beta11 - (2012-05-14)
// 2.0.0beta10 - (2011-04-17) cleaner required size calculation, improved keyboard support, stickToBottom/Left, other small fixes
// 2.0.0beta9 - (2011-01-31) new API methods, bug fixes and correct keyboard support for FF/OSX
// 2.0.0beta8 - (2011-01-29) touchscreen support, improved keyboard support
// 2.0.0beta7 - (2011-01-23) scroll speed consistent (thanks Aivo Paas)
// 2.0.0beta6 - (2010-12-07) scrollToElement horizontal support
// 2.0.0beta5 - (2010-10-18) jQuery 1.4.3 support, various bug fixes
// 2.0.0beta4 - (2010-09-17) clickOnTrack support, bug fixes
// 2.0.0beta3 - (2010-08-27) Horizontal mousewheel, mwheelIntent, keyboard support, bug fixes
// 2.0.0beta2 - (2010-08-21) Bug fixes
// 2.0.0beta1 - (2010-08-17) Rewrite to follow modern best practices and enable horizontal scrolling, initially hidden
//							 elements and dynamically sized elements.
// 1.x - (2006-12-31 - 2010-07-31) Initial version, hosted at googlecode, deprecated

(function($,window,undefined){

	$.fn.oktellPanelJScrollPane = function(settings)
	{
		// JScrollPane "class" - public methods are available through $('selector').data('jsp')
		function JScrollPane(elem, s)
		{
			var settings, jsp = this, pane, paneWidth, paneHeight, container, contentWidth, contentHeight,
				percentInViewH, percentInViewV, isScrollableV, verticalDrag, verticalDragInner, dragMaxY,
				verticalDragPosition, dragMaxX,
				verticalBar, verticalTrack, scrollbarWidth, verticalTrackHeight, verticalDragHeight, arrowUp, arrowDown,
				arrowLeft, arrowRight,
				originalPadding, originalPaddingTotalWidth, previousContentWidth,
				wasAtTop = true, wasAtLeft = true, wasAtBottom = false, wasAtRight = false,
				originalElement = elem.clone(false, false).empty(),
				mwEvent = $.fn.oktellPanelMwheelIntent ? 'oktellPanelMwheelIntent.jsp' : 'oktellPanelMousewheel.jsp';

			originalPadding = elem.css('paddingTop') + ' ' +
				elem.css('paddingRight') + ' ' +
				elem.css('paddingBottom') + ' ' +
				elem.css('paddingLeft');
			originalPaddingTotalWidth = (parseInt(elem.css('paddingLeft'), 10) || 0) +
				(parseInt(elem.css('paddingRight'), 10) || 0);

			function initialise(s)
			{

				var /*firstChild, lastChild, */isMaintainingPositon, lastContentX, lastContentY,
					hasContainingSpaceChanged, originalScrollTop, originalScrollLeft,
					maintainAtBottom = false, maintainAtRight = false;

				settings = s;

				if (pane === undefined) {
					originalScrollTop = elem.scrollTop();
					originalScrollLeft = elem.scrollLeft();

					elem.css(
						{
							overflow: 'hidden',
							padding: 0
						}
					);
					// TODO: Deal with where width/ height is 0 as it probably means the element is hidden and we should
					// come back to it later and check once it is unhidden...
					paneWidth = elem.innerWidth() + originalPaddingTotalWidth;
					paneHeight = elem.innerHeight();

					elem.width(paneWidth);

					pane = $('<div class="jspPane" />').css('padding', originalPadding).append(elem.children());
					container = $('<div class="jspContainer" />')
						.css({
							'width': paneWidth + 'px',
							'height': paneHeight + 'px'
						}
					).append(pane).appendTo(elem);

					/*
					 // Move any margins from the first and last children up to the container so they can still
					 // collapse with neighbouring elements as they would before jScrollPane
					 firstChild = pane.find(':first-child');
					 lastChild = pane.find(':last-child');
					 elem.css(
					 {
					 'margin-top': firstChild.css('margin-top'),
					 'margin-bottom': lastChild.css('margin-bottom')
					 }
					 );
					 firstChild.css('margin-top', 0);
					 lastChild.css('margin-bottom', 0);
					 */
				} else {
					elem.css('width', '');

					maintainAtBottom = settings.stickToBottom && isCloseToBottom();
					maintainAtRight  = settings.stickToRight  && isCloseToRight();

					hasContainingSpaceChanged = elem.innerWidth() + originalPaddingTotalWidth != paneWidth || elem.outerHeight() != paneHeight;

					if (hasContainingSpaceChanged) {
						paneWidth = elem.innerWidth() + originalPaddingTotalWidth;
						paneHeight = elem.innerHeight();
						container.css({
							width: paneWidth + 'px',
							height: paneHeight + 'px'
						});
					}

					// If nothing changed since last check...
					if (!hasContainingSpaceChanged && previousContentWidth == contentWidth && pane.outerHeight() == contentHeight) {
						elem.width(paneWidth);
						return;
					}
					previousContentWidth = contentWidth;

					pane.css('width', '');
					elem.width(paneWidth);

					container.find('>.jspVerticalBar').remove().end();
				}

				pane.css('overflow', 'auto');
				if (s.contentWidth) {
					contentWidth = s.contentWidth;
				} else {
					contentWidth = pane[0].scrollWidth;
				}
				contentHeight = pane[0].scrollHeight;
				pane.css('overflow', '');

				percentInViewH = contentWidth / paneWidth;
				percentInViewV = contentHeight / paneHeight;
				isScrollableV = percentInViewV > 1;

				//console.log(paneWidth, paneHeight, contentWidth, contentHeight, percentInViewH, percentInViewV, isScrollableH, isScrollableV);

				if (!isScrollableV) {
					elem.removeClass('jspScrollable');
					pane.css({
						top: 0,
						width: container.width() - originalPaddingTotalWidth
					});
					removeMousewheel();
					removeClickOnTrack();
				} else {
					elem.addClass('jspScrollable');

					isMaintainingPositon = settings.maintainPosition && verticalDragPosition;
					if (isMaintainingPositon) {
						lastContentY = contentPositionY();
					}

					initialiseVerticalScroll();
					resizeScrollbars();

					if (isMaintainingPositon) {
						scrollToY(maintainAtBottom ? (contentHeight - paneHeight) : lastContentY, false);
					}

					initMousewheel();
					initTouch();

					if (settings.clickOnTrack) {
						initClickOnTrack();
					}
				}

				originalScrollTop && elem.scrollTop(0) && scrollToY(originalScrollTop, false);

				elem.trigger('jsp-initialised', [isScrollableV]);
			}

			function initialiseVerticalScroll()
			{
				if (isScrollableV) {

					container.append(
						$('<div class="jspVerticalBar" />').append(
							$('<div class="jspCap jspCapTop" />'),
							$('<div class="jspTrack" />').append(
								$('<div class="jspDrag" />').append(
									$('<div class="jspDragTop" />'),
									$('<div class="jspDragBottom" />'),
									$('<div class="jspDragInner" />')
								)
							),
							$('<div class="jspCap jspCapBottom" />')
						)
					);

					verticalBar = container.find('>.jspVerticalBar');
					verticalTrack = verticalBar.find('>.jspTrack');
					verticalDrag = verticalTrack.find('>.jspDrag');
					verticalDragInner = verticalDrag.find('>.jspDragInner');


					container.unbind('mouseenter.jspInner');
					container.unbind('mouseleave.jspInner');
					if ( settings.dragInnerAnimation ) {
						container.bind('mouseenter.jspInner', function(){
							verticalDragInner.stop(true,true);
							verticalDragInner.fadeIn(100);
							return true;
						});
						container.bind('mouseleave.jspInner', function(){
							verticalDragInner.stop(true,true);
							verticalDragInner.fadeOut(500);
						});
					}

					if (settings.showArrows) {
						arrowUp = $('<a class="jspArrow jspArrowUp" />').bind(
							'mousedown.jsp', getArrowScroll(0, -1)
						).bind('click.jsp', nil);
						arrowDown = $('<a class="jspArrow jspArrowDown" />').bind(
							'mousedown.jsp', getArrowScroll(0, 1)
						).bind('click.jsp', nil);
						if (settings.arrowScrollOnHover) {
							arrowUp.bind('mouseover.jsp', getArrowScroll(0, -1, arrowUp));
							arrowDown.bind('mouseover.jsp', getArrowScroll(0, 1, arrowDown));
						}

						appendArrows(verticalTrack, settings.verticalArrowPositions, arrowUp, arrowDown);
					}



					verticalTrackHeight = paneHeight;
					container.find('>.jspVerticalBar>.jspCap:visible,>.jspVerticalBar>.jspArrow').each(
						function()
						{
							verticalTrackHeight -= $(this).outerHeight();
						}
					);


					verticalDrag.hover(
						function()
						{
							verticalDrag.addClass('jspHover');
						},
						function()
						{
							verticalDrag.removeClass('jspHover');
						}
					).bind(
						'mousedown.jsp',
						function(e)
						{
							// Stop IE from allowing text selection
							$('html').bind('dragstart.jsp selectstart.jsp', nil);

							verticalDrag.addClass('jspActive');

							var startY = e.pageY - verticalDrag.position().top;

							$('html').bind(
								'mousemove.jsp',
								function(e)
								{
									positionDragY(e.pageY - startY, false);
								}
							).bind('mouseup.jsp mouseleave.jsp', cancelDrag);
							return false;
						}
					);
					sizeVerticalScrollbar();
				}
			}

			function sizeVerticalScrollbar()
			{
				verticalTrack.height(verticalTrackHeight + 'px');
				verticalDragPosition = 0;
				scrollbarWidth = settings.verticalGutter + verticalTrack.outerWidth();

				// Make the pane thinner to allow for the vertical scrollbar
				pane.width(paneWidth - scrollbarWidth - originalPaddingTotalWidth);

				// Add margin to the left of the pane if scrollbars are on that side (to position
				// the scrollbar on the left or right set it's left or right property in CSS)
				try {
					if (verticalBar.position().left === 0) {
						pane.css('margin-left', scrollbarWidth + 'px');
					}
				} catch (err) {
				}
			}

			function resizeScrollbars()
			{
				// reflow content
				contentHeight = pane.outerHeight();
				percentInViewV = contentHeight / paneHeight;

				if (isScrollableV) {
					verticalDragHeight = Math.ceil(1 / percentInViewV * verticalTrackHeight);
					if (verticalDragHeight > settings.verticalDragMaxHeight) {
						verticalDragHeight = settings.verticalDragMaxHeight;
					} else if (verticalDragHeight < settings.verticalDragMinHeight) {
						verticalDragHeight = settings.verticalDragMinHeight;
					}
					verticalDrag.height(verticalDragHeight + 'px');
					dragMaxY = verticalTrackHeight - verticalDragHeight;
					_positionDragY(verticalDragPosition); // To update the state for the arrow buttons
				}
			}

			function initClickOnTrack()
			{
				removeClickOnTrack();
				if (isScrollableV) {
					verticalTrack.bind(
						'mousedown.jsp',
						function(e)
						{
							if (e.originalTarget === undefined || e.originalTarget == e.currentTarget) {
								var clickedTrack = $(this),
									offset = clickedTrack.offset(),
									direction = e.pageY - offset.top - verticalDragPosition,
									scrollTimeout,
									isFirst = true,
									doScroll = function()
									{
										var offset = clickedTrack.offset(),
											pos = e.pageY - offset.top - verticalDragHeight / 2,
											contentDragY = paneHeight * settings.scrollPagePercent,
											dragY = dragMaxY * contentDragY / (contentHeight - paneHeight);
										if (direction < 0) {
											if (verticalDragPosition - dragY > pos) {
												jsp.scrollByY(-contentDragY);
											} else {
												positionDragY(pos);
											}
										} else if (direction > 0) {
											if (verticalDragPosition + dragY < pos) {
												jsp.scrollByY(contentDragY);
											} else {
												positionDragY(pos);
											}
										} else {
											cancelClick();
											return;
										}
										scrollTimeout = setTimeout(doScroll, isFirst ? settings.initialDelay : settings.trackClickRepeatFreq);
										isFirst = false;
									},
									cancelClick = function()
									{
										scrollTimeout && clearTimeout(scrollTimeout);
										scrollTimeout = null;
										$(document).unbind('mouseup.jsp', cancelClick);
									};
								doScroll();
								$(document).bind('mouseup.jsp', cancelClick);
								return false;
							}
						}
					);
				}
			}

			function removeClickOnTrack()
			{
				if (verticalTrack) {
					verticalTrack.unbind('mousedown.jsp');
				}
			}

			function cancelDrag()
			{
				$('html').unbind('dragstart.jsp selectstart.jsp mousemove.jsp mouseup.jsp mouseleave.jsp');

				if (verticalDrag) {
					verticalDrag.removeClass('jspActive');
				}
			}

			function positionDragY(destY, animate)
			{
				if (!isScrollableV) {
					return;
				}
				if (destY < 0) {
					destY = 0;
				} else if (destY > dragMaxY) {
					destY = dragMaxY;
				}

				// can't just check if(animate) because false is a valid value that could be passed in...
				if (animate === undefined) {
					animate = settings.animateScroll;
				}
				if (animate) {
					jsp.animate(verticalDrag, 'top', destY,	_positionDragY);
				} else {
					verticalDrag.css('top', destY);
					_positionDragY(destY);
				}

			}

			function _positionDragY(destY)
			{
				if (destY === undefined) {
					destY = verticalDrag.position().top;
				}

				container.scrollTop(0);
				verticalDragPosition = destY;

				var isAtTop = verticalDragPosition === 0,
					isAtBottom = verticalDragPosition == dragMaxY,
					percentScrolled = destY/ dragMaxY,
					destTop = -percentScrolled * (contentHeight - paneHeight);

				if (wasAtTop != isAtTop || wasAtBottom != isAtBottom) {
					wasAtTop = isAtTop;
					wasAtBottom = isAtBottom;
					elem.trigger('jsp-arrow-change', [wasAtTop, wasAtBottom, wasAtLeft, wasAtRight]);
				}

				updateVerticalArrows(isAtTop, isAtBottom);
				pane.css('top', destTop);
				elem.trigger('jsp-scroll-y', [-destTop, isAtTop, isAtBottom]).trigger('scroll');
			}

			function updateVerticalArrows(isAtTop, isAtBottom)
			{
				if (settings.showArrows) {
					arrowUp[isAtTop ? 'addClass' : 'removeClass']('jspDisabled');
					arrowDown[isAtBottom ? 'addClass' : 'removeClass']('jspDisabled');
				}
			}

			function scrollToY(destY, animate)
			{
				var percentScrolled = destY / (contentHeight - paneHeight);
				positionDragY(percentScrolled * dragMaxY, animate);
			}

			function contentPositionY()
			{
				return -pane.position().top;
			}

			function isCloseToBottom()
			{
				var scrollableHeight = contentHeight - paneHeight;
				return (scrollableHeight > 20) && (scrollableHeight - contentPositionY() < 10);
			}

			function initMousewheel()
			{
				container.unbind(mwEvent).bind(
					mwEvent,
					function (event, delta, deltaX, deltaY) {
						var dY = verticalDragPosition;
						jsp.scrollByY(-deltaY * settings.mouseWheelSpeed, false);
						// return true if there was no movement so rest of screen can scroll
						if ( settings.onScroll ){
							settings.onScroll();
						}
						return false; //dY == verticalDragPosition;
					}
				);
			}

			function removeMousewheel()
			{
				container.unbind(mwEvent);
			}

			function nil()
			{
				return false;
			}

			// Init touch on iPad, iPhone, iPod, Android
			function initTouch()
			{
				var startY,
					touchStartY,
					moved,
					moving = false;

				container.unbind('touchstart.jsp touchmove.jsp touchend.jsp click.jsp-touchclick').bind(
					'touchstart.jsp',
					function(e)
					{
						var touch = e.originalEvent.touches[0];
						startY = contentPositionY();
						touchStartY = touch.pageY;
						moved = false;
						moving = true;
					}
				).bind(
					'touchmove.jsp',
					function(ev)
					{
						if(!moving) {
							return;
						}

						var touchPos = ev.originalEvent.touches[0],
							dY = verticalDragPosition;

						jsp.scrollToY(startY + touchStartY - touchPos.pageY);

						moved = moved || Math.abs(touchStartY - touchPos.pageY) > 5;

						if ( settings.onScroll ){
							settings.onScroll();
						}

						// return true if there was no movement so rest of screen can scroll
						return false; //dY == verticalDragPosition;
					}
				).bind(
					'touchend.jsp',
					function(e)
					{
						moving = false;
						/*if(moved) {
						 return false;
						 }*/
					}
				).bind(
					'click.jsp-touchclick',
					function(e)
					{
						if(moved) {
							moved = false;
							return false;
						}
					}
				);
			}

			function destroy(){
				var currentY = contentPositionY();
				elem.removeClass('jspScrollable').unbind('.jsp');
				elem.replaceWith(originalElement.append(pane.children()));
				originalElement.scrollTop(currentY);
			}

			// Public API
			$.extend(
				jsp,
				{
					// Reinitialises the scroll pane (if it's internal dimensions have changed since the last time it
					// was initialised). The settings object which is passed in will override any settings from the
					// previous time it was initialised - if you don't pass any settings then the ones from the previous
					// initialisation will be used.
					reinitialise: function(s)
					{
						s = $.extend({}, settings, s);
						initialise(s);
					},
					// Scrolls the pane so that the specified co-ordinate within the content is at the top of the
					// viewport. animate is optional and if not passed then the value of animateScroll from the settings
					// object this jScrollPane was initialised with is used.
					scrollToY: function(destY, animate)
					{
						scrollToY(destY, animate);
					},
					// Scrolls the pane to the specified percentage of its maximum vertical scroll position. animate
					// is optional and if not passed then the value of animateScroll from the settings object this
					// jScrollPane was initialised with is used.
					scrollToPercentY: function(destPercentY, animate)
					{
						scrollToY(destPercentY * (contentHeight - paneHeight), animate);
					},
					// Scrolls the pane by the specified amount of pixels. animate is optional and if not passed then
					// the value of animateScroll from the settings object this jScrollPane was initialised with is used.
					scrollByY: function(deltaY, animate)
					{
						var destY = contentPositionY() + Math[deltaY<0 ? 'floor' : 'ceil'](deltaY),
							percentScrolled = destY / (contentHeight - paneHeight);
						positionDragY(percentScrolled * dragMaxY, animate);
					},
					// Positions the vertical drag at the specified y position (and updates the viewport to reflect
					// this). animate is optional and if not passed then the value of animateScroll from the settings
					// object this jScrollPane was initialised with is used.
					positionDragY: function(y, animate)
					{
						positionDragY(y, animate);
					},
					// This method is called when jScrollPane is trying to animate to a new position. You can override
					// it if you want to provide advanced animation functionality. It is passed the following arguments:
					//  * ele          - the element whose position is being animated
					//  * prop         - the property that is being animated
					//  * value        - the value it's being animated to
					//  * stepCallback - a function that you must execute each time you update the value of the property
					// You can use the default implementation (below) as a starting point for your own implementation.
					animate: function(ele, prop, value, stepCallback)
					{
						var params = {};
						params[prop] = value;
						ele.animate(
							params,
							{
								'duration'	: settings.animateDuration,
								'easing'	: settings.animateEase,
								'queue'		: false,
								'step'		: stepCallback
							}
						);
					},
					// Returns the current y position of the viewport with regards to the content pane.
					getContentPositionY: function()
					{
						return contentPositionY();
					},
					// Returns the width of the content within the scroll pane.
					getContentWidth: function()
					{
						return contentWidth;
					},
					// Returns the height of the content within the scroll pane.
					getContentHeight: function()
					{
						return contentHeight;
					},
					// Returns the vertical position of the viewport within the pane content.
					getPercentScrolledY: function()
					{
						return contentPositionY() / (contentHeight - paneHeight);
					},
					// Returns whether or not this scrollpane has a vertical scrollbar.
					getIsScrollableV: function()
					{
						return isScrollableV;
					},
					// Gets a reference to the content pane. It is important that you use this method if you want to
					// edit the content of your jScrollPane as if you access the element directly then you may have some
					// problems (as your original element has had additional elements for the scrollbars etc added into
					// it).
					getContentPane: function()
					{
						return pane;
					},
					// Scrolls this jScrollPane down as far as it can currently scroll. If animate isn't passed then the
					// animateScroll value from settings is used instead.
					scrollToBottom: function(animate)
					{
						positionDragY(dragMaxY, animate);
					},
					// Removes the jScrollPane and returns the page to the state it was in before jScrollPane was
					// initialised.
					destroy: function()
					{
						destroy();
					}
				}
			);

			initialise(s);
		}

		// Pluginifying code...
		settings = $.extend({}, $.fn.oktellPanelJScrollPane.defaults, settings);

		// Apply default speed
		$.each(['arrowButtonSpeed', 'trackClickSpeed', 'keyboardSpeed'], function() {
			settings[this] = settings[this] || settings.speed;
		});

		return this.each(
			function()
			{
				var elem = $(this), jspApi = elem.data('jsp');
				if (jspApi) {
					jspApi.reinitialise(settings);
				} else {
					$("script",elem).filter('[type="text/javascript"],:not([type])').remove();
					jspApi = new JScrollPane(elem, settings);
					elem.data('jsp', jspApi);
				}
			}
		);
	};

	$.fn.oktellPanelJScrollPane.defaults = {
		showArrows					: false,
		maintainPosition			: true,
		stickToBottom				: false,
		stickToRight				: false,
		clickOnTrack				: true,
		autoReinitialise			: false,
		autoReinitialiseDelay		: 500,
		verticalDragMinHeight		: 0,
		verticalDragMaxHeight		: 99999,
		contentWidth				: undefined,
		animateScroll				: false,
		animateDuration				: 300,
		animateEase					: 'linear',
		hijackInternalLinks			: false,
		verticalGutter				: 4,
		mouseWheelSpeed				: 3,
		arrowButtonSpeed			: 0,
		arrowRepeatFreq				: 50,
		arrowScrollOnHover			: false,
		trackClickSpeed				: 0,
		trackClickRepeatFreq		: 70,
		verticalArrowPositions		: 'split',
		enableKeyboardNavigation	: true,
		hideFocus					: false,
		keyboardSpeed				: 0,
		initialDelay                : 300,        // Delay before starting repeating
		speed						: 30,		// Default speed when others falsey
		scrollPagePercent			: .8,		// Percent of visible area scrolled when pageUp/Down or track area pressed
		dragInnerAnimation			: true,		//
		onScroll					: null
	};

})(jQuery,this);


var __slice = [].slice,
	__bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
	__hasProp = {}.hasOwnProperty,
	__indexOf = [].indexOf || function(item) { for (var i = 0, l = this.length; i < l; i++) { if (i in this && this[i] === item) return i; } return -1; };

(function($) {
	var CUser, Department, Error, List, Notify, PermissionsPopup, Popup, actionButtonContainerClass, actionButtonHtml, actionListEl, actionListHtml, addActionButtonToEl, afterOktellConnect, checkCssAnimationSupport, cookie, debounce, defaultOptions, departmentTemplateHtml, error, errorHtml, escapeHtml, getOptions, hasTouch, initActionButtons, initButtonOnElement, initPanel, isAndroid, isIDevice, isTouchPad, langs, list, loadTemplate, log, logStr, newGuid, oktell, oktellConnected, options, panelHtml, panelWasInitialized, permissionsPopup, permissionsPopupHtml, popup, popupHtml, templates, userTemplateHtml, usersTableHtml,
		_this = this;

	if (!$) {
		throw new Error('Error init oktell panel, jQuery ( $ ) is not defined');
	}
	debounce = function(func, wait, immediate) {
		var timeout;

		timeout = '';
		return function() {
			var args, callNow, context, later, result;

			context = this;
			args = arguments;
			later = function() {
				var result;

				timeout = null;
				if (!immediate) {
					return result = func.apply(context, args);
				}
			};
			callNow = immediate && !timeout;
			clearTimeout(timeout);
			timeout = setTimeout(later, wait);
			if (callNow) {
				result = func.apply(context, args);
			}
			return result;
		};
	};
	escapeHtml = function(string) {
		return ('' + string).replace(/&/g, '&amp;').replace(/</g, '&lt;').replace(/>/g, '&gt;').replace(/"/g, '&quot;').replace(/'/g, '&#x27;').replace(/\//g, '&#x2F;');
	};
	log = function() {
		var e;

		try {
			return console.log.apply(console, arguments);
		} catch (_error) {
			e = _error;
		}
	};
	cookie = function(key, value, options) {
		var decode, result, seconds, t;

		if (arguments.length > 1 && String(value) !== "[object Object]") {
			options = $.extend({}, options);
			if (value == null) {
				options.expires = -1;
			}
			if (typeof options.expires === 'number') {
				seconds = options.expires;
				t = options.expires = new Date();
				t.setSeconds(t.getSeconds() + seconds);
			}
			value = String(value);
			return document.cookie = [encodeURIComponent(key), '=', options.raw ? value : encodeURIComponent(value), options.expires ? '; expires=' + options.expires.toUTCString() : '', options.path ? '; path=' + options.path : '', options.domain ? '; domain=' + options.domain : '', options.secure ? '; secure' : ''].join('');
		}
		options = value || {};
		result = '';
		if (options.raw) {
			decode = function(s) {
				return s;
			};
		} else {
			decode = decodeURIComponent;
		}
		if ((result = new RegExp('(?:^|; )' + encodeURIComponent(key) + '=([^;]*)').exec(document.cookie))) {
			return decode(result[1]);
		} else {
			return null;
		}
	};
	newGuid = function() {
		return 'xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx'.replace(/[xy]/g, function(c) {
			var r, v;

			r = Math.random() * 16 | 0;
			v = c === 'x' ? r : r & 0x3 | 0x8;
			return v.toString(16);
		});
	};
	Notify = (function() {
		function Notify(title, autoHide, message, group, onClick) {
			var notify,
				_this = this;

			if (autoHide == null) {
				autoHide = 0;
			}
			if (!(typeof title === 'string' && title) || window.webkitNotifications.checkPermission() !== 0) {
				return;
			}
			if (typeof message === 'function') {
				onClick = message;
				message = '';
				group = null;
			} else if (typeof group === 'function') {
				onClick = group;
				group = null;
			}
			notify = window.webkitNotifications.createNotification('favicon.ico', title, message || '');
			if (group) {
				notify.tag = group;
			}
			notify.show();
			autoHide = parseInt(autoHide);
			if (autoHide) {
				setTimeout(function() {
					return notify.close();
				}, autoHide * 1000);
			}
			notify.onclick = function() {
				var args, e;

				e = arguments[0], args = 2 <= arguments.length ? __slice.call(arguments, 1) : [];
				if (typeof window.focus === "function") {
					window.focus();
				}
				notify.close();
				if (typeof onClick === 'function') {
					return onClick.apply(window, []);
				}
			};
			this.close = function() {
				return notify != null ? typeof notify.close === "function" ? notify.close() : void 0 : void 0;
			};
		}

		return Notify;

	})();
	Department = (function() {
		Department.prototype.logGroup = 'Department';

		function Department(id, name) {
			this.usersVisibilityCss = 'invisibleDep';
			this.lastFilteredUsers = [];
			this.isSorted = false;
			this.visible = true;
			this.users = [];
			this.id = id && id !== '00000000-0000-0000-0000-000000000000' ? id : this.withoutDepName;
			this.name = this.id === this.withoutDepName || !name ? this.langs.panel.withoutDepartment : name;
			this.isOpen = this.config().departmentVisibility[this.id] != null ? this.config().departmentVisibility[this.id] : true;
		}

		Department.prototype.getEl = function(usersVisible) {
			if (!this.el) {
				this.el = $(this.template.replace(/\{\{department}\}/g, escapeHtml(this.name)));
			}
			if (usersVisible) {
				this._oldIsOpen = this.isOpen;
				this.showUsers(true, true);
			} else {
				this.showUsers(this._oldIsOpen != null ? this._oldIsOpen : this.isOpen);
			}
			this.el.data('department', this);
			return this.el;
		};

		Department.prototype.getContainer = function() {
			return this.el.find('tbody');
		};

		Department.prototype.showUsers = function(val, notSave) {
			var c;

			if (typeof val === 'undefined') {
				val = !this.isOpen;
			}
			if (!this.hideEl) {
				this.hideEl = this.el.find('table');
			}
			this.hideEl.stop(true, true);
			if (!notSave) {
				this.isOpen = val;
				c = this.config();
				c.departmentVisibility[this.id] = this.isOpen;
				this.config(c);
			}
			if (val) {
				this.el.toggleClass(this.usersVisibilityCss, false);
				return this.hideEl.show();
			} else {
				this.el.toggleClass(this.usersVisibilityCss, true);
				return this.hideEl.hide();
			}
		};

		Department.prototype.getInfo = function() {
			return this.name + ' ' + this.id;
		};

		Department.prototype.clearUsers = function() {
			return this.users = [];
		};

		Department.prototype.show = function(withAnimation) {
			if (!this.el || this.visible) {
				return;
			}
			if (withAnimation) {
				this.el.slideDown(200);
			} else {
				this.el.show();
			}
			return this.visible = true;
		};

		Department.prototype.hide = function(withAnimation) {
			if (!this.el || !this.visible) {
				return;
			}
			if (withAnimation) {
				this.el.slideUp(200);
			} else {
				this.el.hide();
			}
			return this.visible = false;
		};

		Department.prototype.getUsers = function(filter, showOffline, filterLang) {
			var exactMatch, u, users, _i, _j, _k, _len, _len1, _len2, _ref, _ref1, _ref2;

			if (!this.isSorted) {
				this.sortUsers();
			}
			users = [];
			exactMatch = false;
			if (filter === '') {
				if (showOffline) {
					_ref = this.users;
					for (_i = 0, _len = _ref.length; _i < _len; _i++) {
						u = _ref[_i];
						u.setSelection();
						users.push(u);
					}
				} else {
					_ref1 = this.users;
					for (_j = 0, _len1 = _ref1.length; _j < _len1; _j++) {
						u = _ref1[_j];
						if (u.state !== 0) {
							u.setSelection();
							users.push(u);
						}
					}
				}
			} else {
				_ref2 = this.users;
				for (_k = 0, _len2 = _ref2.length; _k < _len2; _k++) {
					u = _ref2[_k];
					if (u.isFiltered(filter, showOffline, filterLang)) {
						users.push(u);
						if (u.number === filter && !exactMatch) {
							exactMatch = u;
						}
					}
				}
			}
			this.lastFilteredUsers = users;
			return [users, exactMatch];
		};

		Department.prototype.sortUsers = function() {
			return this.users.sort(this.sortFn);
		};

		Department.prototype.sortFn = function(a, b) {
			if (a.nameLower > b.nameLower) {
				return 1;
			} else if (a.nameLower < b.nameLower) {
				return -1;
			} else {
				if (a.number > b.number) {
					return 1;
				} else if (a.number < b.number) {
					return -1;
				} else {
					return 0;
				}
			}
		};

		Department.prototype.addUser = function(user) {
			if (user.number) {
				return this.users.push(user);
			}
		};

		return Department;

	})();
	CUser = (function() {
		CUser.prototype.logGroup = 'User';

		function CUser(data) {
			this.doAction = __bind(this.doAction, this);      this.state = false;
			this.hasHover = false;
			this.buttonLastAction = '';
			this.firstLiCssPrefix = 'm_button_action_';
			this.noneActionCss = '';
			this.els = $();
			this.buttonEls = $();
			this.init(data);
		}

		CUser.prototype.init = function(data) {
			var lastHtml, ns, _ref, _ref1, _ref2, _ref3, _ref4, _ref5, _ref6, _ref7, _ref8, _ref9;

			this.id = (_ref = data.id) != null ? _ref.toString().toLowerCase() : void 0;
			this.isFantom = data.isFantom || false;
			this.number = ((_ref1 = data.number) != null ? _ref1.toString() : void 0) || '';
			if (!this.number) {
				this.invisible = true;
			}
			this.numberFormatted = ((_ref2 = data.numberFormatted) != null ? _ref2.toString() : void 0) || this.number;
			this.numberHtml = escapeHtml(this.numberFormatted);
			this.name = ((_ref3 = data.name) != null ? _ref3.toString() : void 0) || '';
			this.nameLower = this.name.toLowerCase();
			this.letter = ((_ref4 = this.name[0]) != null ? _ref4.toUpperCase() : void 0) || ((_ref5 = this.number) != null ? _ref5[0].toString().toLowerCase() : void 0);
			this.nameHtml = data.name && data.name.toString() !== this.number ? escapeHtml(data.name) : this.numberHtml;
			if (this.numberHtml === this.nameHtml) {
				this.numberHtml = '';
			}
			ns = this.nameHtml.split(/\s+/);
			if (ns.length > 1 && data.name.toString() !== this.number) {
				this.nameHtml1 = ns[0];
				this.nameHtml2 = ' ' + ns.splice(1).join('');
			} else {
				this.nameHtml1 = this.nameHtml;
				this.nameHtml2 = '';
			}
			lastHtml = this.elNumberHtml;
			this.elNumberHtml = this.numberHtml !== this.nameHtml ? this.numberHtml : '';
			if (this.elNumberHtml !== lastHtml && (this.el != null)) {
				this.el.find('.o_number').text(this.elNumberHtml);
			}
			if ((_ref6 = this.el) != null) {
				_ref6.find('.b_contact_title wrapword a').text(this.nameHtml);
			}
			this.avatarLink32x32 = data.avatarLink32x32 || this.defaultAvatar32 || '';
			this.defaultAvatarCss = this.avatarLink32x32 ? '' : 'm_default';
			this.departmentId = (data != null ? (_ref7 = data.numberObj) != null ? _ref7.departmentid : void 0 : void 0) && (data != null ? data.numberObj.departmentid : void 0) !== '00000000-0000-0000-0000-000000000000' ? data != null ? data.numberObj.departmentid : void 0 : this.withoutDepName;
			this.department = this.departmentId === 'www_without' ? this.langs.panel.withoutDepartment : data != null ? (_ref8 = data.numberObj) != null ? _ref8.department : void 0 : void 0;
			if (((_ref9 = data.numberObj) != null ? _ref9.state : void 0) != null) {
				this.setState(data.numberObj.state);
			} else if (data.state != null) {
				this.setState(data.state);
			} else {
				this.setState(1);
			}
			return this.loadActions();
		};

		CUser.prototype.regexps = {
			name1: /\{\{name1\}\}/,
			name2: /\{\{name2\}\}/,
			number: /\{\{number\}\}/,
			dtmf: /\{\{dtmf\}\}/,
			avatarLink32x32: /\{\{avatarLink32x32\}\}/,
			css: /\{\{css\}\}/,
			letter: /\{\{letter\}\}/
		};

		CUser.prototype.setState = function(state) {
			var _this = this;

			state = parseInt(state);
			if (state === this.state) {
				return;
			}
			this.state = state;
			this.setStateCss();
			if (this.buttonEls.length) {
				this.loadActions();
				return setTimeout(function() {
					return _this.loadActions();
				}, 100);
			}
		};

		CUser.prototype.setStateCss = function() {
			if (this.els.length) {
				if (this.state === 0) {
					return this.els.removeClass('m_busy').addClass('m_offline');
				} else if (this.state === 5) {
					return this.els.removeClass('m_offline').addClass('m_busy');
				} else {
					return this.els.removeClass('m_offline').removeClass('m_busy');
				}
			}
		};

		CUser.prototype.getInfo = function() {
			return '"' + this.number + '" ' + this.state + ' ' + this.name;
		};

		CUser.prototype.isFiltered = function(filter, showOffline, lang) {
			var fl;

			if ((!filter || typeof filter !== 'string') && (showOffline || (!showOffline && this.state !== 0))) {
				this.setSelection();
				return true;
			}
			if (showOffline || (!showOffline && this.state !== 0)) {
				if ((this.number && this.number.indexOf(filter) !== -1) || (' ' + this.name).toLowerCase().indexOf(filter) !== -1) {
					this.setSelection(filter);
					return true;
				}
				if (lang === 'en' && (fl = this.toRu(filter)) && (' ' + this.name).toLowerCase().indexOf(fl) !== -1) {
					this.setSelection(fl);
					return true;
				}
				if (lang === 'ru' && (fl = this.toEn(filter)) && (' ' + this.name).toLowerCase().indexOf(fl) !== -1) {
					this.setSelection(fl);
					return true;
				}
				return false;
			}
			return false;
		};

		CUser.prototype.showLetter = function(show) {
			var _ref;

			return (_ref = this.el) != null ? _ref.find('.b_capital_letter span').text(show ? this.letter : '') : void 0;
		};

		CUser.prototype.getEl = function(createIndependent) {
			var $el, str;

			if (!this.el || createIndependent) {
				str = this.template.replace(this.regexps.name1, this.nameHtml1).replace(this.regexps.name2, this.nameHtml2).replace(this.regexps.number, this.numberHtml).replace(this.regexps.dtmf, this.langs.panel.dtmf).replace(this.regexps.avatarLink32x32, this.avatarLink32x32).replace(this.regexps.css, this.defaultAvatarCss);
				$el = $(str);
				$el.data('user', this);
				this.initButtonEl($el.find('.oktell_button_action'));
				this.els = this.els.add($el);
				this.setStateCss();
				if (!this.el) {
					this.el = $el;
					this.elName = this.el.find('.b_contact_name b');
					this.elName2 = this.el.find('.b_contact_name span');
					this.elNumber = this.el.find('.o_number');
					this.elDtmf = this.el.find('.o_dtmf');
				}
			}
			$el = $el || this.el;
			return $el;
		};

		CUser.prototype.setSelection = function(str) {
			var rx;

			if (this.el != null) {
				if (!str) {
					if (this.elHasSelection) {
						this.elName.text(this.nameHtml1);
						this.elName2.text(this.nameHtml2);
						this.elNumber.text(this.numberHtml);
						return this.elHasSelection = false;
					}
				} else {
					rx = new RegExp('(' + str + ')', 'gi');
					this.elName.html(this.nameHtml1.replace(rx, '<span class="selected_text">$1</span>'));
					this.elName2.html(this.nameHtml2.replace(rx, '<span class="selected_text">$1</span>'));
					this.elNumber.html(this.numberHtml.replace(rx, '<span class="selected_text">$1</span>'));
					return this.elHasSelection = true;
				}
			}
		};

		CUser.prototype.initButtonEl = function($el) {
			var _this = this;

			this.buttonEls = this.buttonEls.add($el);
			$el.data('user', this);
			$el.children(':first').bind('click', function() {
				return _this.doAction(_this.buttonLastAction);
			});
			if (this.buttonLastAction) {
				return $el.removeClass(this.noneActionCss).addClass(this.firstLiCssPrefix + this.buttonLastAction.toLowerCase());
			} else {
				return $el.addClass(this.noneActionCss);
			}
		};

		CUser.prototype.getButtonEl = function() {
			var $el;

			$el = $(this.buttonTemplate);
			this.initButtonEl($el);
			return $el;
		};

		CUser.prototype.isHovered = function(isHovered) {
			if (this.hasHover === isHovered) {
				return;
			}
			this.hasHover = isHovered;
			if (this.hasHover) {
				return this.loadActions(true);
			}
		};

		CUser.prototype.loadOktellActions = function() {
			var actions;

			actions = this.oktell.getPhoneActions(this.id || this.number);
			return actions;
		};

		CUser.prototype.loadActions = function() {
			var action, actions;

			actions = this.loadOktellActions();
			action = (actions != null ? actions[0] : void 0) || '';
			if (this.buttonLastAction === action) {
				return actions;
			}
			if (this.buttonLastAction) {
				this.buttonEls.removeClass(this.firstLiCssPrefix + this.buttonLastAction.toLowerCase());
			}
			if (action) {
				this.buttonLastAction = action;
				this.buttonEls.removeClass(this.noneActionCss).addClass(this.firstLiCssPrefix + this.buttonLastAction.toLowerCase());
			} else {
				this.buttonLastAction = '';
				this.buttonEls.addClass(this.noneActionCss);
			}
			return actions;
		};

		CUser.prototype.doAction = function(action) {
			var target, _base, _base1, _base2;

			if (!action) {
				return;
			}
			target = this.number;
			if (typeof this.beforeAction === "function") {
				this.beforeAction(action);
			}
			switch (action) {
				case 'call':
					return this.oktell.call(target);
				case 'conference':
					return this.oktell.conference(target);
				case 'intercom':
					return this.oktell.intercom(target);
				case 'transfer':
					return this.oktell.transfer(target);
				case 'toggle':
					return this.oktell.toggle();
				case 'ghostListen':
					return this.oktell.ghostListen(target);
				case 'ghostHelp':
					return this.oktell.ghostHelp(target);
				case 'ghostConference':
					return this.oktell.ghostConference(target);
				case 'endCall':
					return this.oktell.endCall(target);
				case 'hold':
					return typeof (_base = this.oktell).hold === "function" ? _base.hold() : void 0;
				case 'resume':
					return typeof (_base1 = this.oktell).resume === "function" ? _base1.resume() : void 0;
				case 'answer':
					return typeof (_base2 = this.oktell).answer === "function" ? _base2.answer() : void 0;
			}
		};

		CUser.prototype.doLastFirstAction = function() {
			if (this.buttonLastAction) {
				this.doAction(this.buttonLastAction);
				return true;
			} else {
				return false;
			}
		};

		CUser.prototype.letterVisibility = function(show) {
			if (this.el && this.el.length) {
				if (show) {
					return this.el.find('.b_capital_letter span').text(this.letter);
				} else {
					return this.el.find('.b_capital_letter span').text('');
				}
			}
		};

		CUser.prototype.replacerToRu = {
			"q": "й",
			"w": "ц",
			"e": "у",
			"r": "к",
			"t": "е",
			"y": "н",
			"u": "г",
			"i": "ш",
			"o": "щ",
			"p": "з",
			"[": "х",
			"]": "ъ",
			"a": "ф",
			"s": "ы",
			"d": "в",
			"f": "а",
			"g": "п",
			"h": "р",
			"j": "о",
			"k": "л",
			"l": "д",
			";": "ж",
			"'": "э",
			"z": "я",
			"x": "ч",
			"c": "с",
			"v": "м",
			"b": "и",
			"n": "т",
			"m": "ь",
			",": "б",
			".": "ю",
			"/": "."
		};

		CUser.prototype.replacerToEn = {
			"й": "q",
			"ц": "w",
			"у": "e",
			"к": "r",
			"е": "t",
			"н": "y",
			"г": "u",
			"ш": "i",
			"щ": "o",
			"з": "p",
			"х": "[",
			"ъ": "]",
			"ф": "a",
			"ы": "s",
			"в": "d",
			"а": "f",
			"п": "g",
			"р": "h",
			"о": "j",
			"л": "k",
			"д": "l",
			"ж": ";",
			"э": "'",
			"я": "z",
			"ч": "x",
			"с": "c",
			"м": "v",
			"и": "b",
			"т": "n",
			"ь": "m",
			"б": ",",
			"ю": ".",
			".": "/"
		};

		CUser.prototype.toRu = function(str) {
			var _this = this;

			return str.replace(/[A-z\/,.;\'\]\[]/g, function(x) {
				if (x === x.toLowerCase()) {
					return _this.replacerToRu[x];
				} else {
					return _this.replacerToRu[x.toLowerCase()].toUpperCase();
				}
			});
		};

		CUser.prototype.toEn = function(str) {
			var _this = this;

			return str.replace(/[А-яёЁ]/g, function(x) {
				if (x === x.toLowerCase()) {
					return _this.replacerToEn[x];
				} else {
					return _this.replacerToEn[x.toLowerCase()].toUpperCase();
				}
			});
		};

		return CUser;

	})();
	List = (function() {
		List.prototype.logGroup = 'List';

		function List(oktell, panelEl, dropdownEl, afterOktellConnect, options, debugMode) {
			this.onPbxNumberStateChange = __bind(this.onPbxNumberStateChange, this);
			var debouncedSetFilter, debouncedSetHeight, dropdownHideTimer, oktellConnected, ringNotify, self,
				_this = this;

			this.defaultConfig = {
				departmentVisibility: {},
				showDeps: true,
				showOffline: false
			};
			this.jScrollPaneParams = {
				mouseWheelSpeed: 50,
				hideFocus: true,
				verticalGutter: -13,
				onScroll: function() {
					if (_this.oktellConnected) {
						return _this.processStickyHeaders.apply(_this);
					}
				}
			};
			this.allActions = {
				answer: {
					icon: '/img/icons/action/call.png',
					iconWhite: '/img/icons/action/white/call.png',
					text: this.langs.actions.answer
				},
				call: {
					icon: '/img/icons/action/call.png',
					iconWhite: '/img/icons/action/white/call.png',
					text: this.langs.actions.call
				},
				conference: {
					icon: '/img/icons/action/confinvite.png',
					iconWhite: '/img/icons/action/white/confinvite.png',
					text: this.langs.actions.conference
				},
				transfer: {
					icon: '/img/icons/action/transfer.png',
					text: this.langs.actions.transfer
				},
				toggle: {
					icon: '/img/icons/action/toggle.png',
					text: this.langs.actions.toggle
				},
				intercom: {
					icon: '/img/icons/action/intercom.png',
					text: this.langs.actions.intercom
				},
				endCall: {
					icon: '/img/icons/action/endcall.png',
					iconWhite: '/img/icons/action/white/endcall.png',
					text: this.langs.actions.endCall
				},
				ghostListen: {
					icon: '/img/icons/action/ghost_monitor.png',
					text: this.langs.actions.ghostListen
				},
				ghostHelp: {
					icon: '/img/icons/action/ghost_help.png',
					text: this.langs.actions.ghostHelp
				},
				hold: {
					icon: '/img/icons/action/ghost_help.png',
					text: this.langs.actions.hold
				},
				resume: {
					icon: '/img/icons/action/ghost_help.png',
					text: this.langs.actions.resume
				}
			};
			this.actionCssPrefix = 'i_';
			this.lastDropdownUser = false;
			self = this;
			CUser.prototype.beforeAction = function(action) {
				return self.beforeUserAction(this, action);
			};
			this.departments = [];
			this.departmentsById = {};
			this.simpleListEl = $(this.usersTableTemplate);
			this.filterFantomUserNumber = false;
			this.userWithGeneratedButtons = {};
			this.debugMode = debugMode;
			this.dropdownPaddingBottomLeft = 3;
			this.dropdownOpenedOnPanel = false;
			this.regexps = {
				actionText: /\{\{actionText\}\}/,
				action: /\{\{action\}\}/,
				css: /\{\{css\}\}/,
				dep: /\{\{department}\}/g
			};
			oktellConnected = false;
			this.options = options;
			this.usersByNumber = {};
			this.me = false;
			this.oktell = oktell;
			this.panelUsers = [];
			this.panelUsersFiltered = [];
			this.abonents = {};
			this.hold = {};
			this.queue = {};
			this.oktell = oktell;
			CUser.prototype.oktell = oktell;
			this.filter = false;
			this.panelEl = panelEl;
			this.dtmfEl = this.panelEl.find('.i_extension');
			this.dropdownEl = dropdownEl;
			this.dropdownElLiTemplate = this.dropdownEl.html();
			this.dropdownEl.empty();
			this.keypadEl = this.panelEl.find('.j_phone_keypad');
			this.keypadIsVisible = false;
			this.usersListBlockEl = this.panelEl.find('.j_main_list');
			this.scrollContainer = '';
			this.scrollContent = '';
			this.usersListEl = this.simpleListEl.find('tbody');
			this.abonentsListBlock = this.panelEl.find('.j_abonents');
			this.abonentsListEl = this.abonentsListBlock.find('tbody');
			this.abonentsHeaderTextEl = this.abonentsListBlock.find('b_marks_label');
			this.talkTimeEl = this.abonentsListBlock.find('.b_marks_time');
			this.holdBlockEl = this.panelEl.find('.j_hold');
			this.holdListEl = this.holdBlockEl.find('tbody');
			this.queueBlockEl = this.panelEl.find('.j_queue');
			this.queueListEl = this.queueBlockEl.find('tbody');
			this.filterInput = this.panelEl.find('input');
			this.filterClearCross = this.panelEl.find('.jInputClear_close');
			debouncedSetFilter = false;
			this.buttonShowOffline = this.panelEl.find('.b_list_filter .i_online');
			this.buttonShowDeps = this.panelEl.find('.b_list_filter .i_group');
			this.buttonShowOffline.bind('click', function() {
				_this.config({
					showOffline: !_this.showOffline
				});
				return _this.setFilter(_this.filter, true);
			});
			this.buttonShowDeps.bind('click', function() {
				_this.config({
					showDeps: !_this.showDeps
				});
				return _this.setFilter(_this.filter, true);
			});
			this.dtmfEl.find('.o_close').bind('click', function() {
				return _this.hideDtmf();
			});
			this.dtmfEl.find('.btn-small').bind('click', function(e) {
				return _this.sendDtmf($(e.target).text());
			});
			this.usersWithBeforeConnectButtons = [];
			this.config();
			Department.prototype.config = function() {
				var args;

				args = 1 <= arguments.length ? __slice.call(arguments, 0) : [];
				return _this.config.apply(_this, args);
			};
			this.allUserDep = new Department('all_user_dep', 'allUsers');
			this.allUserDep.template = this.usersTableTemplate;
			this.exactMatchUserDep = new Department('exact_match_user_dep', 'exactUser');
			this.exactMatchUserDep.template = this.usersTableTemplate;
			this.initJScrollPane = function() {
				_this.usersListBlockEl.oktellPanelJScrollPane(_this.jScrollPaneParams);
				_this.jScrollPaneAPI = _this.usersListBlockEl.data('jsp');
				_this.scrollContainer = _this.usersListBlockEl.find('.jspContainer');
				_this.scrollContent = _this.usersListBlockEl.find('.jspPane');
				return _this.usersListBlockEl.bind('scroll', function() {
					return _this.processStickyHeaders();
				});
			};
			this.initJScrollPane();
			this.reinitScroll = function() {
				var _ref;

				return (_ref = _this.jScrollPaneAPI) != null ? _ref.reinitialise() : void 0;
			};
			this.userScrollerToTop = function() {
				return _this.jScrollPaneAPI.scrollToY(0);
			};
			this.filterClearCross.bind('click', function() {
				return _this.clearFilter();
			});
			this.filterInput.bind('keyup', function(e) {
				if (!_this.oktellConnected) {
					return true;
				}
				if (!debouncedSetFilter) {
					debouncedSetFilter = debounce(function() {
						return _this.setFilter(_this.filterInput.val().toString().toLowerCase());
					}, 100);
				}
				if (_this.filterInput.val()) {
					_this.filterClearCross.show();
				} else {
					_this.filterClearCross.hide();
				}
				if (e.keyCode === 13) {
					_this.filterInput.blur();
					setTimeout(function() {
						var _ref;

						if ((_ref = _this.scrollContent.find('tr:first').data('user')) != null) {
							_ref.doLastFirstAction();
						}
						return _this.clearFilter();
					}, 50);
				} else {
					debouncedSetFilter();
				}
				return true;
			});
			this.panelEl.bind('click', function(e) {
				var actionButton, buttonEl, target, user, _ref;

				target = $(e.target);
				if (target.is('.b_department_header') || target.parents('.b_department_header').size() > 0) {
					if ((_ref = target.parents('.b_department').data('department')) != null) {
						if (typeof _ref.showUsers === "function") {
							_ref.showUsers();
						}
					}
					_this.setUserListHeight();
					return false;
				}
				if (target.is('.o_dtmf')) {
					_this.showDtmf();
					return false;
				}
				if (target.is('.oktell_button_action .g_first')) {
					actionButton = target.parent();
				} else if (target.is('.oktell_button_action .g_first i')) {
					actionButton = target.parent().parent();
				} else if (target.is('.b_contact .drop_down')) {
					buttonEl = target.parent();
				} else if (target.is('.b_contact .drop_down i')) {
					buttonEl = target.parent().parent();
				}
				if (((actionButton == null) && (buttonEl == null)) || (actionButton && actionButton.size() === 0) || (buttonEl && buttonEl.size() === 0)) {
					return true;
				}
				if ((actionButton != null) && actionButton.size()) {
					return true;
				}
				if ((buttonEl != null) && buttonEl.size()) {
					user = buttonEl.data('user');
					if (user) {
						_this.showDropdown(user, buttonEl, user.loadOktellActions(), true);
					}
					return true;
				}
			});
			this.dropdownEl.bind('click', function(e) {
				var action, actionEl, target, user;

				target = $(e.target);
				if (target.is('[data-action]')) {
					actionEl = target;
				} else if (target.closest('[data-action]').size() !== 0) {
					actionEl = target.closest('[data-action]');
				} else {
					return true;
				}
				action = actionEl.data('action');
				if (!action) {
					return;
				}
				user = _this.dropdownEl.data('user');
				if (action && user) {
					user.doAction(action);
				}
				return _this.dropdownEl.hide();
			});
			dropdownHideTimer = '';
			this.dropdownEl.hover(function() {
				return clearTimeout(dropdownHideTimer);
			}, function() {
				return dropdownHideTimer = setTimeout(function() {
					return _this.hideActionListDropdown();
				}, 500);
			});
			this.panelEl.find('.j_keypad_expand').bind('click', function() {
				_this.toggleKeypadVisibility();
				return _this.filterInput.focus();
			});
			this.keypadEl.find('li').bind('click', function(e) {
				_this.filterInput.focus();
				_this.filterInput.val(_this.filterInput.val() + $(e.currentTarget).find('button').data('num'));
				return _this.filterInput.keyup();
			});
			this.setUserListHeight = function() {
				var h;

				h = $(window).height() - _this.usersListBlockEl[0].offsetTop + 'px';
				_this.usersListBlockEl.css({
					height: h
				});
				return _this.reinitScroll();
			};
			this.setUserListHeight();
			debouncedSetHeight = debounce(function() {
				_this.userScrollerToTop();
				return _this.setUserListHeight();
			}, 150);
			$(window).bind('resize', function() {
				return debouncedSetHeight();
			});
			this.hidePanel(true);
			oktell.on('webphoneConnect', function() {
				return _this.panelEl.addClass('webphone');
			});
			oktell.on('webphoneDisconnect', function() {
				return _this.panelEl.removeClass('webphone');
			});
			oktell.on('disconnect', function() {
				var phone, user, _ref, _results;

				if (_this.options.hideOnDisconnect) {
					_this.hidePanel();
				}
				_this.resetStickyHeaders();
				_this.oktellConnected = false;
				_this.usersByNumber = {};
				_this.panelUsers = [];
				_this.setPanelUsersHtml([]);
				_this.setAbonents([]);
				_this.setHold({
					hasHold: false
				});
				_this.filterInput.val('');
				_this.setFilter('', true);
				_this.setQueue([]);
				_ref = _this.userWithGeneratedButtons;
				_results = [];
				for (phone in _ref) {
					user = _ref[phone];
					_results.push(user.loadActions());
				}
				return _results;
			});
			oktell.on('connect', function() {
				var createdDeps, dep, id, numObj, number, oId, oInfo, oNumbers, oUser, oUsers, otherDep, strNumber, user, _i, _len, _ref, _ref1, _ref2;

				_this.oktellConnected = true;
				oInfo = oktell.getMyInfo();
				oInfo.userid = oInfo.userid.toString().toLowerCase();
				_this.myNumber = (_ref = oInfo.number) != null ? _ref.toString() : void 0;
				CUser.prototype.defaultAvatar = oInfo.defaultAvatar;
				CUser.prototype.defaultAvatar32 = oInfo.defaultAvatar32x32;
				CUser.prototype.defaultAvatar64 = oInfo.defaultAvatar64x64;
				_this.departments = [];
				_this.departmentsById = {};
				createdDeps = {};
				otherDep = new Department();
				oUsers = oktell.getUsers();
				oNumbers = oktell.getNumbers();
				for (id in oUsers) {
					if (!__hasProp.call(oUsers, id)) continue;
					user = oUsers[id];
					delete oNumbers[user.number];
				}
				for (number in oNumbers) {
					if (!__hasProp.call(oNumbers, number)) continue;
					numObj = oNumbers[number];
					id = newGuid();
					oUsers[id] = {
						id: id,
						number: number,
						name: numObj.caption,
						numberObj: numObj
					};
				}
				for (oId in oUsers) {
					if (!__hasProp.call(oUsers, oId)) continue;
					oUser = oUsers[oId];
					strNumber = ((_ref1 = oUser.number) != null ? _ref1.toString() : void 0) || '';
					if (!strNumber) {
						continue;
					}
					if (_this.usersByNumber[strNumber]) {
						user = _this.usersByNumber[strNumber];
						oUser.isFantom = false;
						user.init(oUser);
					} else {
						user = new CUser(oUser);
						if (user.number) {
							_this.usersByNumber[user.number] = user;
						}
					}
					if (user.id !== oInfo.userid) {
						_this.panelUsers.push(user);
						if (user.departmentId && user.departmentId !== '00000000-0000-0000-0000-000000000000') {
							if (createdDeps[user.departmentId]) {
								dep = createdDeps[user.departmentId];
							} else {
								dep = createdDeps[user.departmentId] = new Department(user.departmentId, user.department);
								_this.departments.push(dep);
								_this.departmentsById[user.departmentId] = dep;
							}
							dep.addUser(user);
						} else {
							otherDep.addUser(user);
						}
						_this.allUserDep.addUser(user);
					} else {
						_this.me = user;
					}
				}
				_this.departments.sort(function(a, b) {
					if (a.name > b.name) {
						return 1;
					} else if (b.name > a.name) {
						return -1;
					} else {
						return 0;
					}
				});
				_this.departments.push(otherDep);
				oktell.offNativeEvent('pbxnumberstatechanged', _this.onPbxNumberStateChange);
				oktell.onNativeEvent('pbxnumberstatechanged', _this.onPbxNumberStateChange);
				setTimeout(function() {
					_this.setAbonents(oktell.getAbonents());
					return _this.setHold(oktell.getHoldInfo());
				}, 1000);
				_this.setFilter('', true);
				oktell.getQueue(function(data) {
					if (data.result) {
						return _this.setQueue(data.queue);
					}
				});
				_ref2 = _this.usersWithBeforeConnectButtons;
				for (_i = 0, _len = _ref2.length; _i < _len; _i++) {
					user = _ref2[_i];
					user.loadActions();
				}
				_this.showPanel();
				_this.setTalking(oktell.getState() === 'talk');
				if (typeof afterOktellConnect === 'function') {
					return afterOktellConnect();
				}
			});
			oktell.on('abonentsChange', function(abonents) {
				if (_this.oktellConnected) {
					_this.setAbonents(abonents);
					return _this.reloadActions();
				}
			});
			oktell.on('holdStateChange', function(holdInfo) {
				if (_this.oktellConnected) {
					_this.setHold(holdInfo);
					return _this.reloadActions();
				}
			});
			oktell.on('talkTimer', function(seconds, formattedTime) {
				if (_this.oktellConnected) {
					if (seconds === false) {
						return _this.talkTimeEl.text('');
					} else {
						return _this.talkTimeEl.text(formattedTime);
					}
				}
			});
			oktell.on('stateChange', function(newState, oldState) {
				if (_this.oktellConnected) {
					_this.reloadActions();
					return _this.setTalking(newState === 'talk');
				}
			});
			oktell.on('queueChange', function(queue) {
				if (_this.oktellConnected) {
					return _this.setQueue(queue);
				}
			});
			oktell.on('connectError', function() {
				if (!_this.options.hideOnDisconnect) {
					return _this.showPanel();
				}
			});
			ringNotify = null;
			oktell.on('ringStart', function(abonents) {
				if (_this.options.useNotifies) {
					return ringNotify = new Notify(_this.langs.callPopup.title);
				}
			});
			oktell.on('ringStop', function() {
				if (ringNotify != null) {
					if (typeof ringNotify.close === "function") {
						ringNotify.close();
					}
				}
				return ringNotify = null;
			});
		}

		List.prototype.initStickyHeaders = function() {
			var conTop, h, i, _i, _j, _len, _len1, _ref, _ref1,
				_this = this;

			this.resetStickyHeaders();
			if (!this.oktellConnected) {
				return;
			}
			this.headerEls = this.usersListBlockEl.find('.b_department_header').toArray();
			if (this.headerEls.length === 0) {
				return;
			} else if ($(this.headerEls[0]).width() === 0) {
				setTimeout(function() {
					return _this.initStickyHeaders();
				}, 500);
				return;
			}
			this.headerFisrt = this.headerEls[0];
			this.headerLast = this.headerEls.length ? this.headerEls[this.headerEls.length - 1] : null;
			_ref = this.headerEls;
			for (i = _i = 0, _len = _ref.length; _i < _len; i = ++_i) {
				h = _ref[i];
				this.headerEls[i] = $(h);
			}
			conTop = this.scrollContainer.offset().top;
			_ref1 = this.headerEls;
			for (i = _j = 0, _len1 = _ref1.length; _j < _len1; i = ++_j) {
				h = _ref1[i];
				if (h.offset().top > conTop) {
					this.processStickyHeaders(i - 1);
					break;
				}
			}
			return this.processStickyHeaders();
		};

		List.prototype.headerHeight = 24;

		List.prototype.processStickyHeaders = function(elIndex) {
			var conTop, curTop, nexTop, _ref, _ref1, _ref2;

			if (((_ref = this.headerEls) != null ? _ref.length : void 0) > 0) {
				if (elIndex != null) {
					if (elIndex < 0) {
						elIndex = 0;
					}
					this.currentTopIndex = elIndex;
					if ((_ref1 = this.currentTopHeaderClone) != null) {
						_ref1.remove();
					}
					this.currentTopHeaderClone = this.headerEls[this.currentTopIndex].clone();
					this.headerEls[this.currentTopIndex].after(this.currentTopHeaderClone);
					this.currentTopHeaderClone.css({
						position: 'fixed',
						zIndex: 1,
						width: this.scrollContainer.width() + 'px'
					});
					this.currentTopHeaderClone.offset({
						top: this.scrollContainer.offset().top
					});
					return this.processStickyHeaders();
				} else if (this.currentTopIndex != null) {
					conTop = this.scrollContainer.offset().top;
					curTop = this.headerEls[this.currentTopIndex].offset().top;
					this.log('processStickyHeaders else', this.currentTopIndex, conTop, curTop, (_ref2 = this.headerEls[this.currentTopIndex]) != null ? typeof _ref2.offset === "function" ? _ref2.offset().top : void 0 : void 0);
					if (curTop > conTop) {
						if (this.currentTopIndex === 0) {
							if (!this.currentTopHeaderClone.data('hidden')) {
								this.currentTopHeaderClone.data('hidden', true);
								return this.currentTopHeaderClone.hide();
							}
						} else {
							return this.processStickyHeaders(this.currentTopIndex - 1);
						}
					} else {
						if (this.currentTopHeaderClone.data('hidden')) {
							this.currentTopHeaderClone.data('hidden', false);
							this.currentTopHeaderClone.show();
						}
						if (this.headerEls[this.currentTopIndex + 1]) {
							nexTop = this.headerEls[this.currentTopIndex + 1].offset().top;
							if (nexTop > conTop + this.headerHeight) {
								return this.currentTopHeaderClone.offset({
									top: conTop
								});
							} else if (nexTop > conTop) {
								return this.currentTopHeaderClone.offset({
									top: nexTop - this.headerHeight
								});
							} else if (nexTop < conTop) {
								return this.processStickyHeaders(this.currentTopIndex + 1);
							}
						}
					}
				}
			}
		};

		List.prototype.resetStickyHeaders = function() {
			var _ref;

			if ((_ref = this.currentTopHeaderClone) != null) {
				if (typeof _ref.remove === "function") {
					_ref.remove();
				}
			}
			this.currentTopHeaderClone = null;
			this.currentTopIndex = null;
			return this.headerEls = null;
		};

		List.prototype.beforeShow = function() {};

		List.prototype.afterShow = function() {
			return this.initStickyHeaders();
		};

		List.prototype.beforeHide = function() {};

		List.prototype.afterHide = function() {
			return this.resetStickyHeaders();
		};

		List.prototype.setTalking = function(isTalking) {
			if (isTalking) {
				return this.panelEl.addClass('talking');
			} else {
				this.hideDtmf();
				return this.panelEl.removeClass('talking');
			}
		};

		List.prototype.sendDtmf = function(code) {
			return this.oktell.dtmf(code.toString().replace('∗', '*'));
		};

		List.prototype.showDtmf = function(dontAnimate) {
			var _this = this;

			if (this.oktell.getState() === 'talk' && this.panelEl.hasClass('webphone') && !this.panelEl.hasClass('dtmf')) {
				this.panelEl.addClass('dtmf');
				this.dtmfEl.stop(true, true);
				if (dontAnimate) {
					return this.dtmfEl.show();
				} else {
					return this.dtmfEl.slideDown(200, function() {});
				}
			}
		};

		List.prototype.hideDtmf = function(dontAnimate) {
			var _this = this;

			if (this.panelEl.hasClass('dtmf')) {
				this.panelEl.removeClass('dtmf');
				this.dtmfEl.stop(true, true);
				if (dontAnimate) {
					return this.dtmfEl.hide();
				} else {
					return this.dtmfEl.slideUp(200, function() {});
				}
			}
		};

		List.prototype.onPbxNumberStateChange = function(data) {
			var dep, index, n, numStr, user, userNowIsFiltered, wasFiltered, _i, _len, _ref, _ref1, _ref2, _ref3, _ref4, _ref5, _results;

			_ref = data.numbers;
			_results = [];
			for (_i = 0, _len = _ref.length; _i < _len; _i++) {
				n = _ref[_i];
				numStr = n.num.toString();
				user = this.usersByNumber[numStr];
				if (user) {
					dep = null;
					if (this.showDeps) {
						dep = this.departmentsById[user.departmentId];
					} else {
						dep = this.allUserDep;
					}
					wasFiltered = user.isFiltered(this.filter, this.showOffline, this.filterLang);
					user.setState(n.numstateid);
					userNowIsFiltered = user.isFiltered(this.filter, this.showOffline, this.filterLang);
					if (!userNowIsFiltered) {
						if (dep.getContainer().children().length === 1) {
							_results.push(this.setFilter(this.filter, true));
						} else {
							_results.push((_ref1 = user.el) != null ? typeof _ref1.remove === "function" ? _ref1.remove() : void 0 : void 0);
						}
					} else if (!wasFiltered) {
						dep.getUsers(this.filter, this.showOffline, this.filterLang);
						index = dep.lastFilteredUsers.indexOf(user);
						if (index !== -1) {
							if (!dep.getContainer().is(':visible')) {
								_results.push(this.setFilter(this.filter, true));
							} else {
								if (index === 0) {
									dep.getContainer().prepend(user.getEl());
								} else {
									if ((_ref2 = dep.lastFilteredUsers[index - 1]) != null) {
										if ((_ref3 = _ref2.el) != null) {
											_ref3.after(user.getEl());
										}
									}
								}
								if (((_ref4 = dep.lastFilteredUsers[index - 1]) != null ? _ref4.letter : void 0) === user.letter) {
									_results.push(user.letterVisibility(false));
								} else if (((_ref5 = dep.lastFilteredUsers[index + 1]) != null ? _ref5.letter : void 0) === user.letter) {
									_results.push(dep.lastFilteredUsers[index + 1].letterVisibility(false));
								} else {
									_results.push(void 0);
								}
							}
						} else {
							_results.push(void 0);
						}
					} else {
						_results.push(void 0);
					}
				} else {
					_results.push(void 0);
				}
			}
			return _results;
		};

		List.prototype.hideActionListDropdown = function() {
			var _this = this;

			return this.dropdownEl.fadeOut(150, function() {
				return _this.dropdownOpenedOnPanel = false;
			});
		};

		List.prototype.showPanel = function(notAnimate) {
			var w,
				_this = this;

			w = this.panelEl.data('width');
			if (w > 0 && this.panelEl.data('hided')) {
				this.panelEl.data('width', w);
				this.panelEl.data('hided', false);
				this.panelEl.css({
					display: ''
				});
				if (notAnimate) {
					return this.panelEl.css({
						overflow: '',
						width: w + 'px'
					});
				} else {
					return this.panelEl.animate({
						width: w + 'px'
					}, 200, function() {
						return _this.panelEl.css({
							overflow: ''
						});
					});
				}
			}
		};

		List.prototype.hidePanel = function(notAnimate) {
			var w,
				_this = this;

			w = this.panelEl.data('width') != null ? this.panelEl.data('width') : this.panelEl.width();
			if (w > 0 && !this.panelEl.data('hided')) {
				this.panelEl.data('width', w);
				this.panelEl.data('hided', true);
				if (notAnimate) {
					return this.panelEl.css({
						display: '',
						overflow: 'hidden',
						width: '0px'
					});
				} else {
					return this.panelEl.animate({
						width: '0px'
					}, 200, function() {
						return _this.panelEl.css({
							display: '',
							overflow: 'hidden'
						});
					});
				}
			}
		};

		List.prototype.getUserButtonForPlugin = function(phone) {
			var button, user,
				_this = this;

			user = this.getUser(phone);
			if (!this.oktellConnected) {
				this.usersWithBeforeConnectButtons.push(user);
			}
			this.userWithGeneratedButtons[phone] = user;
			button = user.getButtonEl();
			button.find('.drop_down').bind('click', function() {
				var actions;

				actions = user.loadActions();
				return _this.showDropdown(user, button, actions);
			});
			return button;
		};

		List.prototype.clearFilter = function() {
			this.filterInput.val('');
			this.setFilter('');
			return this.filterInput.keyup();
		};

		List.prototype.toggleKeypadVisibility = function() {
			return this.setKeypadVisibility(!this.keypadIsVisible);
		};

		List.prototype.setKeypadVisibility = function(visible) {
			if ((visible != null) && Boolean(this.keypadIsVisible) !== Boolean(visible)) {
				this.keypadIsVisible = Boolean(visible);
				this.keypadEl.stop(true, true);
				if (this.keypadIsVisible) {
					return this.keypadEl.slideDown({
						duration: 200,
						easing: 'linear',
						done: this.setUserListHeight
					});
				} else {
					return this.keypadEl.slideUp({
						duration: 200,
						easing: 'linear',
						done: this.setUserListHeight
					});
				}
			}
		};

		List.prototype.addEventListenersForButton = function(user, button) {
			var _this = this;

			return button.bind('click', function() {
				user;        if (user) {
					return _this.showDropdown(user, $(_this));
				}
			});
		};

		List.prototype.showDropdown = function(user, buttonEl, actions, onPanel) {
			var a, aEls, t, _i, _len, _ref;

			t = this.dropdownElLiTemplate;
			this.dropdownEl.empty();
			if (actions != null ? actions.length : void 0) {
				aEls = [];
				for (_i = 0, _len = actions.length; _i < _len; _i++) {
					a = actions[_i];
					if (typeof a === 'string' && ((_ref = this.allActions[a]) != null ? _ref.text : void 0)) {
						aEls.push(t.replace(this.regexps.actionText, this.allActions[a].text).replace(this.regexps.action, a).replace(this.regexps.css, this.actionCssPrefix + a.toLowerCase()));
					}
				}
				if (aEls.length) {
					this.dropdownEl.append(aEls);
					this.dropdownEl.children('li:first').addClass('g_first');
					this.dropdownEl.children('li:last').addClass('g_last');
					this.dropdownEl.data('user', user);
					this.dropdownEl.css({
						'top': this.dropdownEl.height() + buttonEl.offset().top > $(window).height() ? $(window).height() - this.dropdownEl.height() - this.dropdownPaddingBottomLeft : buttonEl.offset().top,
						'left': Math.max(this.dropdownPaddingBottomLeft, buttonEl.offset().left - this.dropdownEl.width() + buttonEl.width()),
						'visibility': 'visible'
					});
					this.dropdownEl.fadeIn(100);
					if (onPanel) {
						return this.dropdownOpenedOnPanel = true;
					}
				} else {
					return this.dropdownEl.hide();
				}
			} else {
				return this.dropdownEl.hide();
			}
		};

		List.prototype.logUsers = function() {
			var k, u, _ref, _results;

			_ref = this.panelUsersFiltered;
			_results = [];
			for (k in _ref) {
				if (!__hasProp.call(_ref, k)) continue;
				u = _ref[k];
				_results.push(this.log(u.getInfo()));
			}
			return _results;
		};

		List.prototype.syncAbonentsAndUserlist = function(abonents, userlist) {
			var absByNumber, uNumber, user, _results,
				_this = this;

			absByNumber = {};
			$.each(abonents, function(i, ab) {
				var number, u;

				if (!ab) {
					return;
				}
				number = ab.phone.toString() || '';
				if (!number) {
					return;
				}
				absByNumber[number] = ab;
				if (!userlist[ab.phone.toString()]) {
					u = _this.getUser({
						name: ab.name,
						number: ab.phone,
						id: ab.userid,
						state: 1
					});
					return userlist[u.number] = u;
				}
			});
			_results = [];
			for (uNumber in userlist) {
				if (!__hasProp.call(userlist, uNumber)) continue;
				user = userlist[uNumber];
				if (!absByNumber[user.number]) {
					_results.push(delete userlist[user.number]);
				} else {
					_results.push(void 0);
				}
			}
			return _results;
		};

		List.prototype.setAbonents = function(abonents) {
			this.syncAbonentsAndUserlist(abonents, this.abonents);
			this.setAbonentsHtml();
			return this.setUserListHeight();
		};

		List.prototype.setQueue = function(queue) {
			var ab, key, user, _i, _len, _ref;

			if (this.oktell.getState() === 'ring') {
				for (key = _i = 0, _len = queue.length; _i < _len; key = ++_i) {
					ab = queue[key];
					if (this.abonents[ab.phone]) {
						delete queue[key];
					}
				}
			}
			this.syncAbonentsAndUserlist(queue, this.queue);
			_ref = this.queue;
			for (key in _ref) {
				if (!__hasProp.call(_ref, key)) continue;
				user = _ref[key];
				user.loadActions();
			}
			return this.setQueueHtml();
		};

		List.prototype.setHold = function(holdInfo) {
			var abs;

			abs = [];
			if (holdInfo.hasHold) {
				if (holdInfo.conferenceid) {
					abs = [
						{
							number: holdInfo.conferenceRoom,
							id: holdInfo.conferenceid,
							name: holdInfo.conferenceName
						}
					];
				} else {
					abs = [holdInfo.abonent];
				}
			}
			this.syncAbonentsAndUserlist(abs, this.hold);
			return this.setHoldHtml();
		};

		List.prototype.setPanelUsersHtml = function(usersArray) {
			this._setUsersHtml(usersArray, this.usersListEl);
			return this.userScrollerToTop();
		};

		List.prototype.setAbonentsHtml = function() {
			return this._setActivityPanelUserHtml(this.abonents, this.abonentsListEl, this.abonentsListBlock);
		};

		List.prototype.setHoldHtml = function() {
			return this._setActivityPanelUserHtml(this.hold, this.holdListEl, this.holdBlockEl);
		};

		List.prototype.setQueueHtml = function() {
			return this._setActivityPanelUserHtml(this.queue, this.queueListEl, this.queueBlockEl);
		};

		List.prototype._setActivityPanelUserHtml = function(users, listEl, blockEl) {
			var k, u, usersArray;

			usersArray = [];
			for (k in users) {
				if (!__hasProp.call(users, k)) continue;
				u = users[k];
				usersArray.push(u);
			}
			this._setUsersHtml(usersArray, listEl, true);
			if (usersArray.length && blockEl.is(':not(:visible)')) {
				blockEl.stop(true, true);
				return blockEl.slideDown(50, this.setUserListHeight);
			} else if (usersArray.length === 0 && blockEl.is(':visible')) {
				blockEl.stop(true, true);
				return blockEl.slideUp(50, this.setUserListHeight);
			}
		};

		List.prototype._setUsersHtml = function(usersArray, $el, useIndependentCopies) {
			var html, lastDepId, prevLetter, u, _i, _len;

			html = [];
			lastDepId = null;
			prevLetter = '';
			for (_i = 0, _len = usersArray.length; _i < _len; _i++) {
				u = usersArray[_i];
				html.push(u.getEl(useIndependentCopies));
				u.showLetter(prevLetter !== u.letter ? true : false);
				prevLetter = u.letter;
			}
			$el.children().detach();
			return $el.html(html);
		};

		List.prototype.setFilter = function(filter, reloadAnyway) {
			var allDeps, dep, el, exactMatch, oldFilter, renderDep, _i, _len, _ref,
				_this = this;

			if (this.filter === filter && !reloadAnyway) {
				return false;
			}
			oldFilter = this.filter;
			this.filter = filter;
			this.filterLang = filter.match(/^[^А-яёЁ]+$/) ? 'en' : filter.match(/^[^A-z]+$/) ? 'ru' : '';
			exactMatch = false;
			this.timer();
			this.panelUsersFiltered = [];
			allDeps = [];
			renderDep = function(dep) {
				var depExactMatch, el, users, _ref;

				el = dep.getEl(filter !== '');
				depExactMatch = false;
				_ref = dep.getUsers(filter, _this.showOffline, _this.filterLang), users = _ref[0], depExactMatch = _ref[1];
				_this.panelUsersFiltered = _this.panelUsersFiltered.concat(users);
				if (users.length !== 0) {
					if (!exactMatch) {
						exactMatch = depExactMatch;
					}
					_this._setUsersHtml(users, dep.getContainer());
					if (depExactMatch && exactMatch === depExactMatch) {
						return allDeps.unshift(el);
					} else {
						return allDeps.push(el);
					}
				}
			};
			if (this.showDeps) {
				_ref = this.departments;
				for (_i = 0, _len = _ref.length; _i < _len; _i++) {
					dep = _ref[_i];
					renderDep(dep);
				}
			} else {
				renderDep(this.allUserDep);
			}
			if (!exactMatch && filter.match(/[0-9\(\)\+\-]/)) {
				this.filterFantomUser = this.getUser({
					name: filter,
					number: filter
				}, true);
				this.exactMatchUserDep.clearUsers();
				this.exactMatchUserDep.addUser(this.filterFantomUser);
				el = this.exactMatchUserDep.getEl();
				this._setUsersHtml([this.filterFantomUser], this.exactMatchUserDep.getContainer());
				this.filterFantomUser.showLetter(false);
				allDeps.unshift(el);
			} else {
				this.filterFantomUser = false;
			}
			this.scrollContent.children().detach();
			this.scrollContent.html(allDeps);
			if (allDeps.length > 0) {
				allDeps[allDeps.length - 1].find('tr:last').addClass('g_last');
			}
			this.initStickyHeaders();
			this.userScrollerToTop();
			this.setUserListHeight();
			return this.timer(true);
		};

		List.prototype.afterSetFilter = function(filteredUsersArray) {
			return this.setPanelUsersHtml(filteredUsersArray);
		};

		List.prototype.getUser = function(data, dontRemember) {
			var fantom, numberFormatted, strNumber, _ref;

			if (typeof data === 'string' || typeof data === 'number') {
				strNumber = data.toString();
				data = {
					number: strNumber
				};
			} else {
				strNumber = data.number.toString();
			}
			numberFormatted = data.phoneFormatted || (typeof oktell.formatPhone === "function" ? oktell.formatPhone(strNumber) : void 0) || strNumber;
			if (!data.numberFormatted) {
				data.numberFormatted = numberFormatted;
			}
			if (!dontRemember && ((_ref = this.filterFantomUser) != null ? _ref.number : void 0) === strNumber) {
				this.usersByNumber[strNumber] = this.filterFantomUser;
				data.isFantom = true;
				this.filterFantomUser = false;
			}
			if (this.usersByNumber[strNumber]) {
				if (this.usersByNumber[strNumber].isFantom) {
					this.usersByNumber[strNumber].init(data);
				}
				return this.usersByNumber[strNumber];
			}
			fantom = new CUser({
				number: strNumber,
				numberFormatted: numberFormatted,
				name: data.name,
				isFantom: true,
				state: ((data != null ? data.state : void 0) != null ? data.state : 1)
			});
			if (!dontRemember) {
				this.usersByNumber[strNumber] = fantom;
			}
			return fantom;
		};

		List.prototype.reloadActions = function() {
			var _this = this;

			return setTimeout(function() {
				var actions, phone, user, _ref, _ref1, _ref2, _ref3, _results;

				_ref = _this.userWithGeneratedButtons;
				for (phone in _ref) {
					if (!__hasProp.call(_ref, phone)) continue;
					user = _ref[phone];
					actions = user.loadActions();
				}
				_ref1 = _this.abonents;
				for (phone in _ref1) {
					user = _ref1[phone];
					user.loadActions();
				}
				_ref2 = _this.queue;
				for (phone in _ref2) {
					user = _ref2[phone];
					user.loadActions();
				}
				_ref3 = _this.panelUsersFiltered;
				_results = [];
				for (phone in _ref3) {
					user = _ref3[phone];
					_results.push(user.loadActions());
				}
				return _results;
			}, 100);
		};

		List.prototype.timer = function(stop) {
			if (stop && this._time) {
				1;
			}
			if (!stop) {
				return this._time = Date.now();
			}
		};

		List.prototype.beforeUserAction = function(user, action) {
			if (this.filterFantomUser && user === this.filterFantomUser) {
				return this.clearFilter();
			}
		};

		List.prototype.config = function(data) {
			var e, k, v, _ref;

			if (!this._config) {
				if ((typeof localStorage !== "undefined" && localStorage !== null ? localStorage.oktellPanel : void 0) && (typeof JSON !== "undefined" && JSON !== null ? JSON.parse : void 0)) {
					try {
						this._config = JSON.parse(localStorage.oktellPanel);
					} catch (_error) {
						e = _error;
					}
					if ((this._config == null) || typeof this._config !== 'object') {
						this._config = {};
					}
				} else {
					this._config = {};
				}
				_ref = this.defaultConfig;
				for (k in _ref) {
					if (!__hasProp.call(_ref, k)) continue;
					v = _ref[k];
					if (this._config[k] == null) {
						this._config[k] = v;
					}
				}
			}
			if (data != null) {
				for (k in data) {
					if (!__hasProp.call(data, k)) continue;
					v = data[k];
					this._config[k] = v;
				}
				if (localStorage && (typeof JSON !== "undefined" && JSON !== null ? JSON.stringify : void 0)) {
					localStorage.setItem('oktellPanel', JSON.stringify(this._config));
				}
			}
			this.showDeps = this._config.showDeps;
			this.showOffline = this._config.showOffline;
			this.buttonShowOffline.toggleClass('g_active', !this.showOffline);
			this.buttonShowOffline.attr('title', this.showOffline ? this.langs.panel.showOnlineOnly : this.langs.panel.showOnlineOnlyCLicked);
			this.buttonShowDeps.toggleClass('g_active', this.showDeps);
			this.buttonShowDeps.attr('title', this.showDeps ? this.langs.panel.showDepartmentsClicked : this.langs.panel.showDepartments);
			return this._config;
		};

		return List;

	})();
	Popup = (function() {
		Popup.prototype.logGroup = 'Popup';

		function Popup(popupEl, oktell) {
			var _this = this;

			this.el = popupEl;
			this.absContainer = this.el.find('.b_content');
			this.abonentEl = this.absContainer.find('.b_abonent').remove();
			this.answerActive = false;
			this.answerButttonEl = this.el.find('.j_answer');
			this.puckupEl = this.el.find('.j_pickup');
			this.el.find('.j_abort_action').bind('click', function() {
				_this.hide();
				return oktell.endCall();
			});
			this.el.find('.j_answer').bind('click', function() {
				_this.hide();
				return oktell.answer();
			});
			this.el.find('.j_close_action').bind('click', function() {
				return _this.hide();
			});
			this.el.find('i.o_close').bind('click', function() {
				return _this.hide();
			});
			oktell.on('ringStart', function(abonents) {
				_this.setAbonents(abonents);
				_this.answerButtonVisible(oktell.webphoneIsActive());
				return _this.show();
			});
			oktell.on('ringStop', function() {
				return _this.hide();
			});
		}

		Popup.prototype.show = function(abonents) {
			this.log('Popup show! ', abonents);
			return this.el.fadeIn(200);
		};

		Popup.prototype.hide = function() {
			return this.el.fadeOut(200);
		};

		Popup.prototype.setAbonents = function(abonents) {
			var _this = this;

			this.absContainer.empty();
			return $.each(abonents, function(i, abonent) {
				var el, name, phone;

				phone = abonent.phone.toString();
				name = abonent.name.toString() || phone;
				if (name === phone) {
					phone = '';
				}
				el = _this.abonentEl.clone();
				el.find('span:first').text(name);
				el.find('span:last').text(phone);
				return _this.absContainer.append(el);
			});
		};

		Popup.prototype.answerButtonVisible = function(val) {
			if (val) {
				this.answerActive = true;
				this.answerButttonEl.show();
				this.puckupEl.hide();
			} else {
				this.answerActive = false;
				this.answerButttonEl.hide();
				this.puckupEl.show();
			}
			return this.answerActive;
		};

		Popup.prototype.setCallbacks = function(onAnswer, onTerminate) {
			this.onAnswer = onAnswer;
			return this.onTerminate = onTerminate;
		};

		return Popup;

	})();
	PermissionsPopup = (function() {
		function PermissionsPopup(popupEl, oktellVoice) {
			var _this = this;

			this.el = popupEl;
			if (oktellVoice) {
				oktellVoice.on('mediaPermissionsRequest', function() {
					return _this.show();
				});
				oktellVoice.on('mediaPermissionsAccept', function() {
					return _this.hide();
				});
				oktellVoice.on('mediaPermissionsRefuse', function() {
					if (typeof oktell !== "undefined" && oktell !== null) {
						oktell.endCall();
					}
					return _this.hide();
				});
			}
		}

		PermissionsPopup.prototype.show = function() {
			this.log('Permissions Popup show!');
			return this.el.show();
		};

		PermissionsPopup.prototype.hide = function() {
			return this.el.fadeOut(200);
		};

		return PermissionsPopup;

	})();
	Error = (function() {
		Error.prototype.logGroup = 'Error';

		Error.prototype.errorTypes = {
			1: 'usingOktellClient',
			2: 'loginPass',
			3: 'unavailable'
		};

		function Error(errorEl, oktell) {
			var _this = this;

			this.el = errorEl;
			oktell.on('connecting', function() {
				return _this.hide();
			});
			oktell.on('disconnect', function(reason) {
				_this.log('disconnect with reason ' + reason.code + ' ' + reason.message);
				if (reason.code === 12) {
					return _this.show(3, oktell.getMyInfo().login);
				}
			});
			oktell.on('connectError', function(error) {
				_this.log('connect error ' + error.errorCode + ' ' + error.errorMessage);
				switch (error.errorCode) {
					case 12:
						return _this.show(1, oktell.getMyInfo().login);
					case 13:
						return _this.show(2, oktell.getMyInfo().login);
					case 1204:
						return _this.show(1, oktell.getMyInfo().login);
					case 1202:
						return _this.show(2, oktell.getMyInfo().login);
					default:
						return _this.show(3, oktell.getMyInfo().login);
				}
			});
		}

		Error.prototype.onShow = function() {};

		Error.prototype.show = function(errorType, username) {
			var type, _ref, _ref1;

			if (!this.errorTypes[errorType]) {
				return false;
			}
			this.log('show ' + errorType);
			type = this.errorTypes[errorType];
			this.el.find('p:eq(0)').text(this.langs[type].header.replace('%username%', username));
			this.el.find('p:eq(1)').text(((_ref = this.langs[type].message) != null ? _ref.replace('%username%', username) : void 0) || '');
			this.el.find('p:eq(3)').text(((_ref1 = this.langs[type].message2) != null ? _ref1.replace('%username%', username) : void 0) || '');
			if (typeof this.onShow === "function") {
				this.onShow();
			}
			return this.el.fadeIn(200);
		};

		Error.prototype.hide = function() {
			return this.el.fadeOut(200);
		};

		return Error;

	})();
	defaultOptions = {
		position: 'right',
		dynamic: false,
		oktell: window.oktell,
		oktellVoice: window.oktellVoice,
		debug: false,
		lang: 'ru',
		noavatar: true,
		hideOnDisconnect: true,
		useNotifies: false,
		withoutPermissionsPopup: false,
		withoutCallPopup: false,
		withoutError: false
	};
	langs = {
		ru: {
			panel: {
				dtmf: 'донабор',
				inTalk: 'В разговоре',
				onHold: 'На удержании',
				queue: 'Очередь ожидания',
				inputPlaceholder: 'введите имя или номер',
				withoutDepartment: 'без отдела',
				showDepartments: 'Группировать по отделам',
				showDepartmentsClicked: 'Показать общим списком',
				showOnlineOnly: 'Показать только online',
				showOnlineOnlyCLicked: 'Показать всех'
			},
			actions: {
				answer: 'Ответить',
				call: 'Позвонить',
				conference: 'Конференция',
				transfer: 'Перевести',
				toggle: 'Переключиться',
				intercom: 'Интерком',
				endCall: 'Завершить',
				ghostListen: 'Прослушка',
				ghostHelp: 'Помощь',
				hold: 'Удержание',
				resume: 'Продолжить'
			},
			callPopup: {
				title: 'Входящий вызов',
				hide: 'Скрыть',
				answer: 'Ответить',
				reject: 'Отклонить',
				undefinedNumber: 'Номер не определен',
				goPickup: 'Поднимите трубку'
			},
			permissionsPopup: {
				header: 'Запрос на доступ к микрофону',
				text: 'Для использования веб-телефона необходимо разрешить браузеру доступ к микрофону.'
			},
			error: {
				usingOktellClient: {
					header: 'Пользователь «%username%» использует стандартный Oktell-клиент.',
					message: 'Одновременная работа двух типов клиентских приложений невозможна.',
					message2: 'Закройте стандартный Oktell-клиент и повторите попытку.'
				},
				loginPass: {
					header: 'Пароль для пользователя «%username%» не подходит.',
					message: 'Проверьте правильность имени пользователя и пароля.'
				},
				unavailable: {
					header: 'Сервер телефонии Oktell не доступен.',
					message: 'Убедитесь что сервер телефонии работает и проверьте настройки соединения.'
				}
			}
		},
		en: {
			panel: {
				dtfm: 'ext',
				inTalk: 'In conversation',
				onHold: 'On hold',
				queue: 'Wait queue',
				inputPlaceholder: 'Enter name or number',
				withoutDepartment: 'Without department',
				showDepartments: 'Show departments',
				showDepartmentsClicked: 'Hide departments',
				showOnlineOnly: 'Show online only',
				showOnlineOnlyCLicked: 'Show all'
			},
			actions: {
				answer: 'Answer',
				call: 'Dial',
				conference: 'Conference',
				transfer: 'Transfer',
				toggle: 'Switch',
				intercom: 'Intercom',
				endCall: 'End',
				ghostListen: 'Audition',
				ghostHelp: 'Help',
				hold: 'Hold',
				resume: 'Resume'
			},
			callPopup: {
				title: 'Incoming call',
				hide: 'Hide',
				answer: 'Answer',
				reject: 'Decline',
				undefinedNumber: 'Phone number is not defined',
				goPickup: 'Pick up the phone'
			},
			permissionsPopup: {
				header: 'Request for access to the microphone',
				text: 'To use the web-phone you need to allow browser access to the microphone.'
			},
			error: {
				usingOktellClient: {
					header: 'User «%username%» uses standard Oktell client application.',
					message: 'Simultaneous work of two types of client applications is not possible.',
					message2: 'Close standard Oktell client application and try again.'
				},
				loginPass: {
					header: 'Wrong password for user «%username%».',
					message: 'Make sure that the username and password are correct.'
				},
				unavailable: {
					header: 'Oktell server is not available.',
					message: 'Make sure that Oktell server is running and check your connection.'
				}
			}
		},
		cz: {
			panel: {
				dtmf: 'ext',
				inTalk: 'V rozhovoru',
				onHold: 'Na hold',
				queue: 'Fronta čekaní',
				inputPlaceholder: 'zadejte jméno nebo číslo',
				withoutDepartment: 'Bez oddělení',
				showDepartments: 'Zobrazit oddělení',
				showDepartmentsClicked: 'Skrýt oddělení',
				showOnlineOnly: 'Zobrazit pouze online',
				showOnlineOnlyCLicked: 'Zobrazit všechny'
			},
			actions: {
				answer: 'Odpověď',
				call: 'Zavolat',
				conference: 'Konference',
				transfer: 'Převést',
				toggle: 'Přepnout',
				intercom: 'Intercom',
				endCall: 'Ukončit',
				ghostListen: 'Odposlech',
				ghostHelp: 'Nápověda',
				hold: 'Udržet',
				resume: 'Pokračovat'
			},
			callPopup: {
				title: 'Příchozí hovor',
				hide: 'Schovat',
				answer: 'Odpovědět',
				reject: 'Odmítnout',
				undefinedNumber: '',
				goPickup: 'Zvedněte sluchátko'
			},
			permissionsPopup: {
				header: 'Žádost o přístup k mikrofonu',
				text: 'Abyste mohli používat telefon, musíte povolit prohlížeče přístup k mikrofonu.'
			},
			error: {
				usingOktellClient: {
					header: 'Uživatel «%username%» používá standardní Oktell klientské aplikace.',
					message: 'Současnou práci dvou typů klientských aplikací není možné.',
					message2: 'Zavřít Oktell standardní klientskou aplikaci a zkuste to znovu.'
				},
				loginPass: {
					header: 'Chybné heslo uživatele «%username%».',
					message: 'Ujistěte se, že uživatelské jméno a heslo jsou správné.'
				},
				unavailable: {
					header: 'Oktell server není k dispozici.',
					message: 'Ujistěte se, že Oktell server běží a zkontrolujte připojení.'
				}
			}
		}
	};
	options = null;
	actionListEl = null;
	oktell = null;
	oktellConnected = false;
	afterOktellConnect = null;
	list = null;
	popup = null;
	permissionsPopup = null;
	error = null;
	actionButtonContainerClass = 'oktellPanelActionButton';
	getOptions = function() {
		return options || defaultOptions;
	};
	logStr = '';
	checkCssAnimationSupport = function() {
		var div, divStyle, suffix, testProperties, v, _i, _len;

		div = document.createElement("div");
		divStyle = div.style;
		suffix = "Transform";
		testProperties = ["o" + suffix, "ms" + suffix, "webkit" + suffix, "Webkit" + suffix, "Moz" + suffix, 'transform'];
		for (_i = 0, _len = testProperties.length; _i < _len; _i++) {
			v = testProperties[_i];
			if (divStyle[v] != null) {
				return true;
			}
		}
		return divStyle;
		return false;
	};
	log = function() {
		var args, d, dd, e, fnName, i, t, val, _i, _len;

		args = 1 <= arguments.length ? __slice.call(arguments, 0) : [];
		if (!getOptions().debug) {
			return;
		}
		d = new Date();
		dd = d.getFullYear() + '-' + (d.getMonth() < 10 ? '0' : '') + d.getMonth() + '-' + (d.getDate() < 10 ? '0' : '') + d.getDate();
		t = (d.getHours() < 10 ? '0' : '') + d.getHours() + ':' + (d.getMinutes() < 10 ? '0' : '') + d.getMinutes() + ':' + (d.getSeconds() < 10 ? '0' : '') + d.getSeconds() + ':' + (d.getMilliseconds() + 1000).toString().substr(1);
		logStr += dd + ' ' + t + ' | ';
		fnName = 'log';
		if (args[0].toString().toLowerCase() === 'error') {
			fnName = 'error';
		}
		for (i = _i = 0, _len = args.length; _i < _len; i = ++_i) {
			val = args[i];
			if (typeof val === 'object') {
				try {
					logStr += JSON.stringify(val);
				} catch (_error) {
					e = _error;
					logStr += val.toString();
				}
			} else {
				logStr += val;
			}
			logStr += ' | ';
		}
		logStr += "\n\n";
		args.unshift('Oktell-Panel.js ' + t + ' |' + (typeof this.logGroup === 'string' ? ' ' + this.logGroup + ' |' : ''));
		try {
			return console[fnName].apply(console, args || []);
		} catch (_error) {
			e = _error;
		}
	};
	templates = {
		'templates/actionButton.html': '<ul class="oktell_button_action"><li class="g_first"><i></i></li><li class="g_last drop_down"><i></i></li></ul>',
		'templates/actionList.html': '<ul class="oktell_actions_group_list"><li class="{{css}}" data-action="{{action}}"><i></i><span>{{actionText}}</span></li></ul>',
		'templates/user.html': '<tr class="b_contact"><td class="b_contact_avatar {{css}}"><img src="{{avatarLink32x32}}"><i></i><div class="o_busy"></div></td><td class="b_capital_letter"><span></span></td><td class="b_contact_title"><div class="wrapword"><span class="b_contact_name"><b>{{name1}}</b><span>{{name2}}</span></span><span class="o_number">{{number}}</span><span class="o_dtmf">{{dtmf}}</span></div>{{button}}</td></tr>',
		'templates/department.html': '<tr class="b_contact"><td class="b_contact_department" colspan="3">{{department}}</td></tr>',
		'templates/dep.html': '<div class="b_department"><div class="b_department_header"><div class="h_shadow_top"><span>{{department}}</span></div></div><table class="b_main_list"><tbody></tbody></table></div>',
		'templates/usersTable.html': '<table class="b_main_list m_without_department"><tbody></tbody></table>',
		'templates/panel.html': '<div class="oktell_panel"><div class="i_panel_bookmark"><div class="i_panel_bookmark_bg"></div></div><div class="h_panel_bg"><div class="b_header"><ul class="b_list_filter"><li class="i_group"></li><li class="i_online"></li></ul></div><div class="h_padding"><div class="b_marks i_conference j_abonents"><div class="h_shadow_top"><div class="b_marks_noise"><p class="b_marks_header"><span class="b_marks_label">{{inTalk}}</span><span class="b_marks_time"></span></p><table><tbody></tbody></table></div></div></div><div class="b_marks i_extension" style="display: none"><div class="h_shadow_top"><div class="b_marks_noise"><p class="b_marks_header"><span class="b_marks_label">Донабор</span></p><div class="h_btn-group"><div class="btn-group"><button class="btn btn-small">1</button><button class="btn btn-small">2</button><button class="btn btn-small">3</button><button class="btn btn-small">4</button><button class="btn btn-small">5</button><button class="btn btn-small">6</button><button class="btn btn-small">7</button><button class="btn btn-small">8</button><button class="btn btn-small">9</button><button class="btn btn-small">0</button></div><div class="btn-group"><button class="btn btn-small">&lowast;</button><button class="btn btn-small">#</button></div></div></div></div><i class="o_close"></i></div><div class="b_marks i_flash j_hold"><div class="h_shadow_top"><div class="b_marks_noise"><p class="b_marks_header"><span class="b_marks_label">{{onHold}}</span></p><table class="j_table_favorite"><tbody></tbody></table></div></div></div><div class="b_marks i_flash j_queue"><div class="h_shadow_top"><div class="b_marks_noise"><p class="b_marks_header"><span class="b_marks_label">{{queue}}</span></p><table class="j_table_queue"><tbody></tbody></table></div></div></div><div class="b_inconversation j_phone_block"><table class="j_table_phone"><tbody></tbody></table></div><div class="b_marks i_phone"><div class="h_shadow_top"><div class="h_phone_number_input"><div class="i_phone_state_bg"></div><div class="h_input_padding"><div class="jInputClear_hover"><input class="b_phone_number_input" type="text" placeholder="{{inputPlaceholder}}"><span class="jInputClear_close">&times;</span></div></div></div></div></div><div class="h_main_list j_main_list"></div></div></div></div>',
		'templates/callPopup.html': '<div class="oktell_panel_popup" style="display: none"><div class="m_popup_staff"><div class="m_popup_data"><header><div class="h_header_bg"><i class="o_close"></i><h2>{{title}}</h2></div></header><div class="b_content"><div class="b_abonent"><span data-bind="text: name"></span>&nbsp;<span class="g_light" data-bind="textPhone: number"></span></div></div><div class="footer"><div class="b_take_phone j_pickup"><i></i>&nbsp;<span>{{goPickup}}</span></div><button class="oktell_panel_btn m_big m_button_green j_answer" style="margin-right: 20px; float: left"><i style="background: url(\'/img/icons/action/white/call.png\') no-repeat; vertical-align: -2px"></i>Ответить</button><button class="oktell_panel_btn m_big j_close_action">{{hide}}</button><button class="oktell_panel_btn m_big m_button_red j_abort_action"><i></i>{{reject}}</button></div></div></div></div>',
		'templates/permissionsPopup.html': '<div class="oktell_panel_popup" style="display: none"><div class="m_popup_staff"><div class="m_popup_data"><header><div class="h_header_bg"><h2>{{header}}</h2></div></header><div class="b_content"><p>{{text}}</p></div></div></div></div>',
		'templates/error.html': '<div class="b_error m_form" style="display: none"><div class="h_padding"><h4>Ошибка</h4><p class="b_error_alert"></p><p class="g_light"></p><p class="g_light"></p></div></div>'
	};
	loadTemplate = function(path) {
		var html;

		if (path[0] === '/') {
			path = path.substr(1);
		}
		if (templates[path] != null) {
			return templates[path];
		}
		html = '';
		$.ajax({
			url: path,
			async: false,
			success: function(data) {
				return html = data;
			}
		});
		return html;
	};
	actionButtonHtml = loadTemplate('/templates/actionButton.html');
	actionListHtml = loadTemplate('/templates/actionList.html');
	userTemplateHtml = loadTemplate('/templates/user.html');
	departmentTemplateHtml = loadTemplate('/templates/department.html');
	departmentTemplateHtml = loadTemplate('/templates/dep.html');
	usersTableHtml = loadTemplate('/templates/usersTable.html');
	panelHtml = loadTemplate('/templates/panel.html');
	popupHtml = loadTemplate('/templates/callPopup.html');
	permissionsPopupHtml = loadTemplate('/templates/permissionsPopup.html');
	errorHtml = loadTemplate('/templates/error.html');
	List.prototype.usersTableTemplate = usersTableHtml;
	CUser.prototype.buttonTemplate = actionButtonHtml;
	CUser.prototype.log = log;
	List.prototype.log = log;
	Popup.prototype.log = log;
	PermissionsPopup.prototype.log = log;
	Department.prototype.log = log;
	Error.prototype.log = log;
	Department.prototype.template = departmentTemplateHtml;
	panelWasInitialized = false;
	isAndroid = /android/gi.test(navigator.appVersion);
	isIDevice = /iphone|ipad/gi.test(navigator.appVersion);
	isTouchPad = /hp-tablet/gi.test(navigator.appVersion);
	hasTouch = __indexOf.call(window, 'ontouchstart') >= 0 && !isTouchPad;
	initPanel = function(opts) {
		var $user, $userActionButton, animOptHide, animOptShow, bookmarkAnimOptHide, bookmarkAnimOptShow, bookmarkPos, cssAnimNow, enableMoving, errorEl, hidePanel, hideTimer, killPanelHideTimer, maxPosClose, minPosOpen, mouseOnPanel, oldBinding, pageX, panelBookmarkEl, panelEl, panelHideTimer, panelMinPos, panelPos, panelStatus, permissionsPopupEl, popupEl, showPanel, showTimer, touchClickedContact, touchClickedContactClear, touchClickedCss, touchMoving, useCssAnim, _panelStatus,
			_this = this;

		panelWasInitialized = true;
		options = $.extend(defaultOptions, opts || {});
		if (getOptions().useNotifies && window.webkitNotifications && window.webkitNotifications.checkPermission() === 1) {
			webkitNotifications.requestPermission(function() {});
		}
		Department.prototype.withoutDepName = List.prototype.withoutDepName = 'zzzzz_without';
		langs = langs[options.lang] || langs.ru;
		CUser.prototype.template = userTemplateHtml.replace('{{button}}', actionButtonHtml);
		panelHtml = panelHtml.replace('{{inTalk}}', langs.panel.inTalk).replace('{{onHold}}', langs.panel.onHold).replace('{{queue}}', langs.panel.queue).replace('{{inputPlaceholder}}', langs.panel.inputPlaceholder);
		List.prototype.langs = langs;
		List.prototype.departmentTemplate = departmentTemplateHtml;
		Error.prototype.langs = langs.error;
		CUser.prototype.langs = langs;
		Department.prototype.langs = langs;
		panelEl = $(panelHtml);
		if (getOptions().noavatar) {
			panelEl.addClass('noavatar');
		}
		if (hasTouch) {
			panelEl.addClass('touch');
		}
		$user = $(userTemplateHtml);
		$userActionButton = $(actionButtonHtml);
		oldBinding = $userActionButton.attr('data-bind');
		$userActionButton.attr('data-bind', oldBinding + ', visible: $data.actionBarIsVisible');
		$user.find('td.b_contact_title').append($userActionButton);
		actionListEl = $(actionListHtml);
		$('body').append(actionListEl);
		oktell = getOptions().oktell;
		CUser.prototype.formatPhone = oktell.formatPhone;
		if (!getOptions().withoutCallPopup) {
			popupHtml = popupHtml.replace('{{title}}', langs.callPopup.title).replace('{{goPickup}}', langs.callPopup.goPickup).replace('{{hide}}', langs.callPopup.hide).replace('{{reject}}', langs.callPopup.reject);
			popupEl = $(popupHtml);
			$('body').append(popupEl);
			popup = new Popup(popupEl, oktell);
		}
		if (!getOptions().withoutPermissionsPopup) {
			permissionsPopupHtml = permissionsPopupHtml.replace('{{header}}', langs.permissionsPopup.header).replace('{{text}}', langs.permissionsPopup.text);
			permissionsPopupEl = $(permissionsPopupHtml);
			$('body').append(permissionsPopupEl);
			permissionsPopup = new PermissionsPopup(permissionsPopupEl, getOptions().oktellVoice);
		}
		if (!getOptions().withoutError) {
			errorEl = $(errorHtml);
			panelEl.find('.h_panel_bg:first').append(errorEl);
			error = new Error(errorEl, oktell);
		}
		panelPos = getOptions().position;
		animOptShow = {};
		animOptShow[panelPos] = '0px';
		animOptHide = {};
		animOptHide[panelPos] = '-281px';
		panelMinPos = -281;
		panelEl.hide();
		$("body").append(panelEl);
		list = new List(oktell, panelEl, actionListEl, afterOktellConnect, getOptions(), getOptions().debug);
		if (getOptions().debug) {
			window.wList = list;
			window.wPopup = popup;
			window.wError = error;
		}
		if (panelPos === "right") {
			panelEl.addClass("right");
		} else if (panelPos === "left") {
			panelEl.addClass("left");
		}
		if (getOptions().dynamic) {
			panelEl.addClass("dynamic");
		}
		panelBookmarkEl = panelEl.find('.i_panel_bookmark');
		bookmarkAnimOptShow = {};
		bookmarkPos = panelPos === 'left' ? 'right' : 'left';
		bookmarkAnimOptShow[bookmarkPos] = '0px';
		bookmarkAnimOptHide = {};
		bookmarkAnimOptHide[bookmarkPos] = '-40px';
		mouseOnPanel = false;
		panelHideTimer = false;
		_panelStatus = 'closed';
		panelStatus = function(st) {
			if (st && st !== _panelStatus) {
				_panelStatus = st;
			}
			return _panelStatus;
		};
		killPanelHideTimer = function() {
			clearTimeout(panelHideTimer);
			return panelHideTimer = false;
		};
		useCssAnim = checkCssAnimationSupport();
		showTimer = null;
		hideTimer = null;
		cssAnimNow = false;
		showPanel = function() {
			list.beforeShow();
			panelStatus('opening');
			panelBookmarkEl.css(bookmarkAnimOptShow);
			if (useCssAnim) {
				if (!cssAnimNow) {
					cssAnimNow = true;
					panelEl.css('right', '');
					clearTimeout(showTimer);
					panelEl.removeClass('hide_t_' + panelPos).addClass('show_t_' + panelPos);
					return showTimer = setTimeout(function() {
						panelEl.css('right', '0px');
						panelEl.removeClass('show_t_' + panelPos);
						list.afterShow();
						panelEl.addClass("g_hover");
						panelStatus('open');
						panelBookmarkEl.css(bookmarkAnimOptShow);
						return cssAnimNow = false;
					}, 200);
				}
			} else {
				panelEl.stop(true, true);
				return panelEl.animate(animOptShow, 100, "swing", function() {
					list.afterShow();
					panelEl.addClass("g_hover");
					panelStatus('open');
					return panelBookmarkEl.css(bookmarkAnimOptShow);
				});
			}
		};
		hidePanel = function() {
			var _this = this;

			if (useCssAnim) {
				if (!cssAnimNow) {
					panelStatus('closing');
					list.beforeHide();
					cssAnimNow = true;
					panelEl.css('right', '');
					clearTimeout(hideTimer);
					panelEl.removeClass('show_t_' + panelPos).addClass('hide_t_' + panelPos);
					return hideTimer = setTimeout(function() {
						panelEl.css('right', '-281px');
						panelEl.removeClass('hide_t_' + panelPos);
						list.afterHide();
						panelEl.removeClass("g_hover");
						panelBookmarkEl.css(bookmarkAnimOptHide);
						panelStatus('closed');
						return cssAnimNow = false;
					}, 400);
				}
			} else {
				panelStatus('closing');
				list.beforeHide();
				panelEl.stop(true, true);
				return panelEl.animate(animOptHide, 300, "swing", function() {
					panelEl.css({
						panelPos: 0
					});
					list.afterHide();
					panelEl.removeClass("g_hover");
					panelBookmarkEl.css(bookmarkAnimOptHide);
					return panelStatus('closed');
				});
			}
		};
		panelEl.bind("mouseenter", function() {
			mouseOnPanel = true;
			killPanelHideTimer();
			if (parseInt(panelEl.css(panelPos)) < 0 && (panelStatus() === 'closed' || panelStatus() === 'closing')) {
				showPanel();
			}
			return true;
		});
		pageX = false;
		minPosOpen = -250;
		maxPosClose = 30;
		touchMoving = false;
		enableMoving = false;
		panelBookmarkEl.bind('touchstart', function() {
			if (panelStatus() === 'closed') {
				panelStatus('touchopening');
			} else if (panelStatus() === 'open') {
				panelStatus('touchclosing');
			}
			return true;
		});
		panelBookmarkEl.bind('touchmove', function(e) {
			var pos, t, _ref, _ref1;

			if (panelStatus() === 'touchopening' || panelStatus() === 'touchclosing') {
				touchMoving = true;
			}
			if (enableMoving && touchMoving) {
				t = e != null ? (_ref = e.originalEvent) != null ? (_ref1 = _ref.touches) != null ? _ref1[0] : void 0 : void 0 : void 0;
				if (t) {
					if (pageX !== false) {
						pos = parseInt(panelEl.css(panelPos));
						panelEl.css(panelPos, Math.max(panelMinPos, Math.min(0, pos + pageX - t.pageX)) + 'px');
					}
					pageX = t.pageX;
				}
			}
			return true;
		});
		panelBookmarkEl.bind('touchend', function() {
			var pos;

			if (!touchMoving) {
				if (panelStatus() === 'touchopening') {
					showPanel();
				}
			} else {
				touchMoving = false;
				pos = parseInt(panelEl.css(panelPos));
				if (panelStatus() === 'touchopening') {
					if (pos > minPosOpen) {
						showPanel();
					} else {
						hidePanel();
					}
				} else if (panelStatus() === 'touchclosing') {
					if (pos < maxPosClose) {
						hidePanel();
					} else {
						openPanel();
					}
				}
			}
			return true;
		});
		panelBookmarkEl.bind('touchcancel', function() {
			return true;
		});
		touchClickedContact = null;
		touchClickedCss = 'm_touch_clicked';
		touchClickedContactClear = function() {
			if (touchClickedContact != null) {
				touchClickedContact.removeClass(touchClickedCss);
			}
			return touchClickedContact = null;
		};
		$(window).bind('touchcancel', function(e) {
			return true;
		});
		$(window).bind('touchend', function(e) {
			var parents, parentsArr, target;

			target = $(e.target);
			parents = target.parents();
			parentsArr = parents.toArray();
			if (parentsArr.indexOf(panelEl[0]) === -1) {
				hidePanel();
			}
			if (!target.is('.oktell_button_action .drop_down') && parents.filter('.oktell_button_action .drop_down').size() === 0) {
				if (list != null) {
					if (typeof list.hideActionListDropdown === "function") {
						list.hideActionListDropdown();
					}
				}
			}
			return true;
		});
		panelEl.bind('touchend', function(e) {
			var contact, parents, target;

			target = $(e.target);
			parents = target.parents();
			if (!target.is('.oktell_button_action .drop_down') && parents.filter('.oktell_button_action .drop_down').size() === 0) {
				if (list != null) {
					if (typeof list.hideActionListDropdown === "function") {
						list.hideActionListDropdown();
					}
				}
			}
			contact = target.is('.oktell_panel .b_contact') ? target : parents.filter('.oktell_panel .b_contact');
			if (contact.size() > 0) {
				if (!contact.hasClass(touchClickedCss)) {
					touchClickedContactClear();
					touchClickedContact = contact;
					contact.addClass(touchClickedCss);
					return false;
				}
			} else {
				touchClickedContactClear();
			}
			return true;
		});
		panelEl.bind("mouseleave", function() {
			mouseOnPanel = false;
			return true;
		});
		$('html').bind('mouseleave', function(e) {
			killPanelHideTimer();
			return true;
		});
		return $('html').bind('mousemove', function(e) {
			if (panelStatus() === 'open' && !mouseOnPanel && panelHideTimer === false && !list.dropdownOpenedOnPanel) {
				panelHideTimer = setTimeout(function() {
					return hidePanel();
				}, 100);
				1;
			}
			return true;
		});
	};
	afterOktellConnect = function() {
		return oktellConnected = true;
	};
	initButtonOnElement = function(el) {
		var button, phone;

		el.addClass(getOptions().buttonCss);
		phone = el.attr('data-phone');
		if (phone) {
			button = list.getUserButtonForPlugin(phone);
			return el.html(button);
		}
	};
	addActionButtonToEl = function(el) {
		return initButtonOnElement(el);
	};
	initActionButtons = function(selector) {
		return $(selector + ":not(." + actionButtonContainerClass + ")").each(function() {
			return addActionButtonToEl($(this));
		});
	};
	$.oktellPanel = function(arg) {
		if (typeof arg === 'string') {
			if (panelWasInitialized) {
				return initActionButtons(arg);
			}
		} else if (!panelWasInitialized) {
			return initPanel(arg);
		}
	};
	$.fn.oktellButton = function() {
		return $(this).each(function() {
			return addActionButtonToEl($(this));
		});
	};
	$.oktellPanel.show = function() {
		return list.showPanel();
	};
	return $.oktellPanel.hide = function() {
		return list.hidePanel();
	};
})($);


/*!
 * iScroll v4.1.9 ~ Copyright (c) 2011 Matteo Spinelli, http://cubiq.org
 * Released under MIT license, http://cubiq.org/license
 */
(function(){
var m = Math,
	mround = function (r) { return r >> 0; },
	vendor = (/webkit/i).test(navigator.appVersion) ? 'webkit' :
		(/firefox/i).test(navigator.userAgent) ? 'Moz' :
		'opera' in window ? 'O' : '',

    // Browser capabilities
    isAndroid = (/android/gi).test(navigator.appVersion),
    isIDevice = (/iphone|ipad/gi).test(navigator.appVersion),
    isPlaybook = (/playbook/gi).test(navigator.appVersion),
    isTouchPad = (/hp-tablet/gi).test(navigator.appVersion),

    has3d = 'WebKitCSSMatrix' in window && 'm11' in new WebKitCSSMatrix(),
    hasTouch = 'ontouchstart' in window && !isTouchPad,
    hasTransform = vendor + 'Transform' in document.documentElement.style,
    hasTransitionEnd = isIDevice || isPlaybook,

	nextFrame = (function() {
	    return window.requestAnimationFrame
			|| window.webkitRequestAnimationFrame
			|| window.mozRequestAnimationFrame
			|| window.oRequestAnimationFrame
			|| window.msRequestAnimationFrame
			|| function(callback) { return setTimeout(callback, 1); }
	})(),
	cancelFrame = (function () {
	    return window.cancelRequestAnimationFrame
			|| window.webkitCancelRequestAnimationFrame
			|| window.mozCancelRequestAnimationFrame
			|| window.oCancelRequestAnimationFrame
			|| window.msCancelRequestAnimationFrame
			|| clearTimeout
	})(),

	// Events
	RESIZE_EV = 'onorientationchange' in window ? 'orientationchange' : 'resize',
	START_EV = hasTouch ? 'touchstart' : 'mousedown',
	MOVE_EV = hasTouch ? 'touchmove' : 'mousemove',
	END_EV = hasTouch ? 'touchend' : 'mouseup',
	CANCEL_EV = hasTouch ? 'touchcancel' : 'mouseup',
	WHEEL_EV = vendor == 'Moz' ? 'DOMMouseScroll' : 'mousewheel',

	// Helpers
	trnOpen = 'translate' + (has3d ? '3d(' : '('),
	trnClose = has3d ? ',0)' : ')',

	// Constructor
	iScroll = function (el, options) {

		var that = this,
			doc = document,
			i;

		that.wrapper = typeof el == 'object' ? el : doc.getElementById(el);
		that.wrapper.style.overflow = 'hidden';
		that.scroller = that.wrapper.children[0];

		// Default options
		that.options = {
			hScroll: true,
			vScroll: true,
			x: 0,
			y: 0,
			bounce: true,
			bounceLock: false,
			momentum: true,
			lockDirection: true,
			useTransform: true,
			useTransition: false,
			topOffset: 0,
			checkDOMChanges: false,		// Experimental

			// Scrollbar
			hScrollbar: true,
			vScrollbar: true,
			fixedScrollbar: isAndroid,
			hideScrollbar: isIDevice,
			fadeScrollbar: isIDevice && has3d,
			scrollbarClass: '',

			// Zoom
			zoom: false,
			zoomMin: 1,
			zoomMax: 4,
			doubleTapZoom: 2,
			wheelAction: 'scroll',

			// Snap
			snap: false,
			snapThreshold: 1,

			// Events
			onRefresh: null,
			onBeforeScrollStart: function (e) { e.preventDefault(); },
			onScrollStart: null,
			onBeforeScrollMove: null,
			onScrollMove: null,
			onBeforeScrollEnd: null,
			onScrollEnd: null,
			onTouchEnd: null,
			onDestroy: null,
			onZoomStart: null,
			onZoom: null,
			onZoomEnd: null
		};
		// Helpers FIX ANDROID BUG!
		// translate3d and scale doesn't work together! 
		// Ignoring 3d ONLY WHEN YOU SET that.zoom
		if ( that.zoom && isAndroid ){
			trnOpen = 'translate(';
			trnClose = ')';
		}
		// User defined options
		for (i in options) that.options[i] = options[i];
		
		// Set starting position
		that.x = that.options.x;
		that.y = that.options.y;

		// Normalize options
		that.options.useTransform = hasTransform ? that.options.useTransform : false;
		that.options.hScrollbar = that.options.hScroll && that.options.hScrollbar;
		that.options.vScrollbar = that.options.vScroll && that.options.vScrollbar;
		that.options.zoom = that.options.useTransform && that.options.zoom;
		that.options.useTransition = hasTransitionEnd && that.options.useTransition;
		
		// Set some default styles
		that.scroller.style[vendor + 'TransitionProperty'] = that.options.useTransform ? '-' + vendor.toLowerCase() + '-transform' : 'top left';
		that.scroller.style[vendor + 'TransitionDuration'] = '0';
		that.scroller.style[vendor + 'TransformOrigin'] = '0 0';
		if (that.options.useTransition) that.scroller.style[vendor + 'TransitionTimingFunction'] = 'cubic-bezier(0.33,0.66,0.66,1)';
		
		if (that.options.useTransform) that.scroller.style[vendor + 'Transform'] = trnOpen + that.x + 'px,' + that.y + 'px' + trnClose;
		else that.scroller.style.cssText += ';position:absolute;top:' + that.y + 'px;left:' + that.x + 'px';

		if (that.options.useTransition) that.options.fixedScrollbar = true;

		that.refresh();

		that._bind(RESIZE_EV, window);
		that._bind(START_EV);
		if (!hasTouch) {
			that._bind('mouseout', that.wrapper);
			that._bind(WHEEL_EV);
		}

		if (that.options.checkDOMChanges) that.checkDOMTime = setInterval(function () {
			that._checkDOMChanges();
		}, 500);
	};

// Prototype
iScroll.prototype = {
	enabled: true,
	x: 0,
	y: 0,
	steps: [],
	scale: 1,
	currPageX: 0, currPageY: 0,
	pagesX: [], pagesY: [],
	aniTime: null,
	wheelZoomCount: 0,
	
	handleEvent: function (e) {
		var that = this;
		switch(e.type) {
			case START_EV:
				if (!hasTouch && e.button !== 0) { return; }
				if ( $(e.srcElement).is(":input") ) { return; }
				that._start(e);
				break;
			case MOVE_EV: that._move(e); break;
			case END_EV:
			case CANCEL_EV: that._end(e); break;
			case RESIZE_EV: that._resize(); break;
			case WHEEL_EV: that._wheel(e); break;
			case 'mouseout': that._mouseout(e); break;
			case 'webkitTransitionEnd': that._transitionEnd(e); break;
		}
	},
	
	_checkDOMChanges: function () {
		if (this.moved || this.zoomed || this.animating ||
			(this.scrollerW == this.scroller.offsetWidth * this.scale && this.scrollerH == this.scroller.offsetHeight * this.scale)) return;

		this.refresh();
	},
	
	_scrollbar: function (dir) {
		var that = this,
			doc = document,
			bar;

		if (!that[dir + 'Scrollbar']) {
			if (that[dir + 'ScrollbarWrapper']) {
				if (hasTransform) that[dir + 'ScrollbarIndicator'].style[vendor + 'Transform'] = '';
				that[dir + 'ScrollbarWrapper'].parentNode.removeChild(that[dir + 'ScrollbarWrapper']);
				that[dir + 'ScrollbarWrapper'] = null;
				that[dir + 'ScrollbarIndicator'] = null;
			}

			return;
		}

		if (!that[dir + 'ScrollbarWrapper']) {
			// Create the scrollbar wrapper
			bar = doc.createElement('div');

			if (that.options.scrollbarClass) bar.className = that.options.scrollbarClass + dir.toUpperCase();
			else bar.style.cssText = 'position:absolute;z-index:100;' + (dir == 'h' ? 'height:7px;bottom:1px;left:2px;right:' + (that.vScrollbar ? '7' : '2') + 'px' : 'width:5px;bottom:' + (that.hScrollbar ? '7' : '2') + 'px;top:2px;right:1px');

			bar.style.cssText += ';pointer-events:none;-' + vendor + '-transition-property:opacity;-' + vendor + '-transition-duration:' + (that.options.fadeScrollbar ? '350ms' : '0') + ';overflow:hidden;opacity:' + (that.options.hideScrollbar ? '0' : '1');

			that.wrapper.appendChild(bar);
			that[dir + 'ScrollbarWrapper'] = bar;

			// Create the scrollbar indicator
			bar = doc.createElement('div');
			if (!that.options.scrollbarClass) {
				bar.style.cssText = 'position:absolute;z-index:100;background:rgba(0,0,0,0.3);-' + vendor + '-background-clip:padding-box;-' + vendor + '-box-sizing:border-box;' + (dir == 'h' ? 'height:100%' : 'width:100%') + ';-' + vendor + '-border-radius:3px;border-radius:3px';
			}
			bar.style.cssText += ';pointer-events:none;-' + vendor + '-transition-property:-' + vendor + '-transform;-' + vendor + '-transition-timing-function:cubic-bezier(0.33,0.66,0.66,1);-' + vendor + '-transition-duration:0;-' + vendor + '-transform:' + trnOpen + '0,0' + trnClose;
			if (that.options.useTransition) bar.style.cssText += ';-' + vendor + '-transition-timing-function:cubic-bezier(0.33,0.66,0.66,1)';

			that[dir + 'ScrollbarWrapper'].appendChild(bar);
			that[dir + 'ScrollbarIndicator'] = bar;
		}

		if (dir == 'h') {
			that.hScrollbarSize = that.hScrollbarWrapper.clientWidth;
			that.hScrollbarIndicatorSize = m.max(mround(that.hScrollbarSize * that.hScrollbarSize / that.scrollerW), 8);
			that.hScrollbarIndicator.style.width = that.hScrollbarIndicatorSize + 'px';
			that.hScrollbarMaxScroll = that.hScrollbarSize - that.hScrollbarIndicatorSize;
			that.hScrollbarProp = that.hScrollbarMaxScroll / that.maxScrollX;
		} else {
			that.vScrollbarSize = that.vScrollbarWrapper.clientHeight;
			that.vScrollbarIndicatorSize = m.max(mround(that.vScrollbarSize * that.vScrollbarSize / that.scrollerH), 8);
			that.vScrollbarIndicator.style.height = that.vScrollbarIndicatorSize + 'px';
			that.vScrollbarMaxScroll = that.vScrollbarSize - that.vScrollbarIndicatorSize;
			that.vScrollbarProp = that.vScrollbarMaxScroll / that.maxScrollY;
		}

		// Reset position
		that._scrollbarPos(dir, true);
	},
	
	_resize: function () {
		var that = this;
		setTimeout(function () { that.refresh(); }, isAndroid ? 200 : 0);
	},
	
	_pos: function (x, y) {
		x = this.hScroll ? x : 0;
		y = this.vScroll ? y : 0;

		if (this.options.useTransform) {
			this.scroller.style[vendor + 'Transform'] = trnOpen + x + 'px,' + y + 'px' + trnClose + ' scale(' + this.scale + ')';
		} else {
			x = mround(x);
			y = mround(y);
			this.scroller.style.left = x + 'px';
			this.scroller.style.top = y + 'px';
		}

		this.x = x;
		this.y = y;

		this._scrollbarPos('h');
		this._scrollbarPos('v');
	},

	_scrollbarPos: function (dir, hidden) {
		var that = this,
			pos = dir == 'h' ? that.x : that.y,
			size;

		if (!that[dir + 'Scrollbar']) return;

		pos = that[dir + 'ScrollbarProp'] * pos;

		if (pos < 0) {
			if (!that.options.fixedScrollbar) {
				size = that[dir + 'ScrollbarIndicatorSize'] + mround(pos * 3);
				if (size < 8) size = 8;
				that[dir + 'ScrollbarIndicator'].style[dir == 'h' ? 'width' : 'height'] = size + 'px';
			}
			pos = 0;
		} else if (pos > that[dir + 'ScrollbarMaxScroll']) {
			if (!that.options.fixedScrollbar) {
				size = that[dir + 'ScrollbarIndicatorSize'] - mround((pos - that[dir + 'ScrollbarMaxScroll']) * 3);
				if (size < 8) size = 8;
				that[dir + 'ScrollbarIndicator'].style[dir == 'h' ? 'width' : 'height'] = size + 'px';
				pos = that[dir + 'ScrollbarMaxScroll'] + (that[dir + 'ScrollbarIndicatorSize'] - size);
			} else {
				pos = that[dir + 'ScrollbarMaxScroll'];
			}
		}

		that[dir + 'ScrollbarWrapper'].style[vendor + 'TransitionDelay'] = '0';
		that[dir + 'ScrollbarWrapper'].style.opacity = hidden && that.options.hideScrollbar ? '0' : '1';
		that[dir + 'ScrollbarIndicator'].style[vendor + 'Transform'] = trnOpen + (dir == 'h' ? pos + 'px,0' : '0,' + pos + 'px') + trnClose;
	},
	
	_start: function (e) {
		var that = this,
			point = hasTouch ? e.touches[0] : e,
			matrix, x, y,
			c1, c2;

		if (!that.enabled) return;

		if (that.options.onBeforeScrollStart) that.options.onBeforeScrollStart.call(that, e);

		if (that.options.useTransition || that.options.zoom) that._transitionTime(0);

		that.moved = false;
		that.animating = false;
		that.zoomed = false;
		that.distX = 0;
		that.distY = 0;
		that.absDistX = 0;
		that.absDistY = 0;
		that.dirX = 0;
		that.dirY = 0;

		// Gesture start
		if (that.options.zoom && hasTouch && e.touches.length > 1) {
			c1 = m.abs(e.touches[0].pageX-e.touches[1].pageX);
			c2 = m.abs(e.touches[0].pageY-e.touches[1].pageY);
			that.touchesDistStart = m.sqrt(c1 * c1 + c2 * c2);

			that.originX = m.abs(e.touches[0].pageX + e.touches[1].pageX - that.wrapperOffsetLeft * 2) / 2 - that.x;
			that.originY = m.abs(e.touches[0].pageY + e.touches[1].pageY - that.wrapperOffsetTop * 2) / 2 - that.y;

			if (that.options.onZoomStart) that.options.onZoomStart.call(that, e);
		}

		if (that.options.momentum) {
			if (that.options.useTransform) {
				// Very lame general purpose alternative to CSSMatrix
				matrix = getComputedStyle(that.scroller, null)[vendor + 'Transform'].replace(/[^0-9-.,]/g, '').split(',');
				x = matrix[4] * 1;
				y = matrix[5] * 1;
			} else {
				x = getComputedStyle(that.scroller, null).left.replace(/[^0-9-]/g, '') * 1;
				y = getComputedStyle(that.scroller, null).top.replace(/[^0-9-]/g, '') * 1;
			}
			
			if (x != that.x || y != that.y) {
				if (that.options.useTransition) that._unbind('webkitTransitionEnd');
				else cancelFrame(that.aniTime);
				that.steps = [];
				that._pos(x, y);
			}
		}

		that.absStartX = that.x;	// Needed by snap threshold
		that.absStartY = that.y;

		that.startX = that.x;
		that.startY = that.y;
		that.pointX = point.pageX;
		that.pointY = point.pageY;

		that.startTime = e.timeStamp || Date.now();

		if (that.options.onScrollStart) that.options.onScrollStart.call(that, e);

		that._bind(MOVE_EV);
		that._bind(END_EV);
		that._bind(CANCEL_EV);
	},
	
	_move: function (e) {
		var that = this,
			point = hasTouch ? e.touches[0] : e,
			deltaX = point.pageX - that.pointX,
			deltaY = point.pageY - that.pointY,
			newX = that.x + deltaX,
			newY = that.y + deltaY,
			c1, c2, scale,
			timestamp = e.timeStamp || Date.now();

		if (that.options.onBeforeScrollMove) that.options.onBeforeScrollMove.call(that, e);

		// Zoom
		if (that.options.zoom && hasTouch && e.touches.length > 1) {
			c1 = m.abs(e.touches[0].pageX - e.touches[1].pageX);
			c2 = m.abs(e.touches[0].pageY - e.touches[1].pageY);
			that.touchesDist = m.sqrt(c1*c1+c2*c2);

			that.zoomed = true;

			scale = 1 / that.touchesDistStart * that.touchesDist * this.scale;

			if (scale < that.options.zoomMin) scale = 0.5 * that.options.zoomMin * Math.pow(2.0, scale / that.options.zoomMin);
			else if (scale > that.options.zoomMax) scale = 2.0 * that.options.zoomMax * Math.pow(0.5, that.options.zoomMax / scale);

			that.lastScale = scale / this.scale;

			newX = this.originX - this.originX * that.lastScale + this.x,
			newY = this.originY - this.originY * that.lastScale + this.y;

			this.scroller.style[vendor + 'Transform'] = trnOpen + newX + 'px,' + newY + 'px' + trnClose + ' scale(' + scale + ')';

			if (that.options.onZoom) that.options.onZoom.call(that, e);
			return;
		}

		that.pointX = point.pageX;
		that.pointY = point.pageY;

		// Slow down if outside of the boundaries
		if (newX > 0 || newX < that.maxScrollX) {
			newX = that.options.bounce ? that.x + (deltaX / 2) : newX >= 0 || that.maxScrollX >= 0 ? 0 : that.maxScrollX;
		}
		if (newY > that.minScrollY || newY < that.maxScrollY) { 
			newY = that.options.bounce ? that.y + (deltaY / 2) : newY >= that.minScrollY || that.maxScrollY >= 0 ? that.minScrollY : that.maxScrollY;
		}

		if (that.absDistX < 6 && that.absDistY < 6) {
			that.distX += deltaX;
			that.distY += deltaY;
			that.absDistX = m.abs(that.distX);
			that.absDistY = m.abs(that.distY);

			return;
		}

		// Lock direction
		if (that.options.lockDirection) {
			if (that.absDistX > that.absDistY + 5) {
				newY = that.y;
				deltaY = 0;
			} else if (that.absDistY > that.absDistX + 5) {
				newX = that.x;
				deltaX = 0;
			}
		}

		that.moved = true;
		that._pos(newX, newY);
		that.dirX = deltaX > 0 ? -1 : deltaX < 0 ? 1 : 0;
		that.dirY = deltaY > 0 ? -1 : deltaY < 0 ? 1 : 0;

		if (timestamp - that.startTime > 300) {
			that.startTime = timestamp;
			that.startX = that.x;
			that.startY = that.y;
		}
		
		if (that.options.onScrollMove) that.options.onScrollMove.call(that, e);
	},
	
	_end: function (e) {
		if (hasTouch && e.touches.length != 0) return;

		var that = this,
			point = hasTouch ? e.changedTouches[0] : e,
			target, ev,
			momentumX = { dist:0, time:0 },
			momentumY = { dist:0, time:0 },
			duration = (e.timeStamp || Date.now()) - that.startTime,
			newPosX = that.x,
			newPosY = that.y,
			distX, distY,
			newDuration,
			snap,
			scale;

		that._unbind(MOVE_EV);
		that._unbind(END_EV);
		that._unbind(CANCEL_EV);

		if (that.options.onBeforeScrollEnd) that.options.onBeforeScrollEnd.call(that, e);

		if (that.zoomed) {
			scale = that.scale * that.lastScale;
			scale = Math.max(that.options.zoomMin, scale);
			scale = Math.min(that.options.zoomMax, scale);
			that.lastScale = scale / that.scale;
			that.scale = scale;

			that.x = that.originX - that.originX * that.lastScale + that.x;
			that.y = that.originY - that.originY * that.lastScale + that.y;
			
			that.scroller.style[vendor + 'TransitionDuration'] = '200ms';
			that.scroller.style[vendor + 'Transform'] = trnOpen + that.x + 'px,' + that.y + 'px' + trnClose + ' scale(' + that.scale + ')';
			
			that.zoomed = false;
			that.refresh();

			if (that.options.onZoomEnd) that.options.onZoomEnd.call(that, e);
			return;
		}

		if (!that.moved) {
			if (hasTouch) {
				if (that.doubleTapTimer && that.options.zoom) {
					// Double tapped
					clearTimeout(that.doubleTapTimer);
					that.doubleTapTimer = null;
					if (that.options.onZoomStart) that.options.onZoomStart.call(that, e);
					that.zoom(that.pointX, that.pointY, that.scale == 1 ? that.options.doubleTapZoom : 1);
					if (that.options.onZoomEnd) {
						setTimeout(function() {
							that.options.onZoomEnd.call(that, e);
						}, 200); // 200 is default zoom duration
					}
				} else {
					that.doubleTapTimer = setTimeout(function () {
						that.doubleTapTimer = null;

						// Find the last touched element
						target = point.target;
						while (target.nodeType != 1) target = target.parentNode;

						if (target.tagName != 'SELECT' && target.tagName != 'INPUT' && target.tagName != 'TEXTAREA') {
							ev = document.createEvent('MouseEvents');
							ev.initMouseEvent('click', true, true, e.view, 1,
								point.screenX, point.screenY, point.clientX, point.clientY,
								e.ctrlKey, e.altKey, e.shiftKey, e.metaKey,
								0, null);
							ev._fake = true;
							target.dispatchEvent(ev);
						}
					}, that.options.zoom ? 250 : 0);
				}
			}

			that._resetPos(200);

			if (that.options.onTouchEnd) that.options.onTouchEnd.call(that, e);
			return;
		}

		if (duration < 300 && that.options.momentum) {
			momentumX = newPosX ? that._momentum(newPosX - that.startX, duration, -that.x, that.scrollerW - that.wrapperW + that.x, that.options.bounce ? that.wrapperW : 0) : momentumX;
			momentumY = newPosY ? that._momentum(newPosY - that.startY, duration, -that.y, (that.maxScrollY < 0 ? that.scrollerH - that.wrapperH + that.y - that.minScrollY : 0), that.options.bounce ? that.wrapperH : 0) : momentumY;

			newPosX = that.x + momentumX.dist;
			newPosY = that.y + momentumY.dist;

 			if ((that.x > 0 && newPosX > 0) || (that.x < that.maxScrollX && newPosX < that.maxScrollX)) momentumX = { dist:0, time:0 };
 			if ((that.y > that.minScrollY && newPosY > that.minScrollY) || (that.y < that.maxScrollY && newPosY < that.maxScrollY)) momentumY = { dist:0, time:0 };
		}

		if (momentumX.dist || momentumY.dist) {
			newDuration = m.max(m.max(momentumX.time, momentumY.time), 10);

			// Do we need to snap?
			if (that.options.snap) {
				distX = newPosX - that.absStartX;
				distY = newPosY - that.absStartY;
				if (m.abs(distX) < that.options.snapThreshold && m.abs(distY) < that.options.snapThreshold) { that.scrollTo(that.absStartX, that.absStartY, 200); }
				else {
					snap = that._snap(newPosX, newPosY);
					newPosX = snap.x;
					newPosY = snap.y;
					newDuration = m.max(snap.time, newDuration);
				}
			}

			that.scrollTo(mround(newPosX), mround(newPosY), newDuration);

			if (that.options.onTouchEnd) that.options.onTouchEnd.call(that, e);
			return;
		}

		// Do we need to snap?
		if (that.options.snap) {
			distX = newPosX - that.absStartX;
			distY = newPosY - that.absStartY;
			if (m.abs(distX) < that.options.snapThreshold && m.abs(distY) < that.options.snapThreshold) that.scrollTo(that.absStartX, that.absStartY, 200);
			else {
				snap = that._snap(that.x, that.y);
				if (snap.x != that.x || snap.y != that.y) that.scrollTo(snap.x, snap.y, snap.time);
			}

			if (that.options.onTouchEnd) that.options.onTouchEnd.call(that, e);
			return;
		}

		that._resetPos(200);
		if (that.options.onTouchEnd) that.options.onTouchEnd.call(that, e);
	},
	
	_resetPos: function (time) {
		var that = this,
			resetX = that.x >= 0 ? 0 : that.x < that.maxScrollX ? that.maxScrollX : that.x,
			resetY = that.y >= that.minScrollY || that.maxScrollY > 0 ? that.minScrollY : that.y < that.maxScrollY ? that.maxScrollY : that.y;

		if (resetX == that.x && resetY == that.y) {
			if (that.moved) {
				that.moved = false;
				if (that.options.onScrollEnd) that.options.onScrollEnd.call(that);		// Execute custom code on scroll end
			}

			if (that.hScrollbar && that.options.hideScrollbar) {
				if (vendor == 'webkit') that.hScrollbarWrapper.style[vendor + 'TransitionDelay'] = '300ms';
				that.hScrollbarWrapper.style.opacity = '0';
			}
			if (that.vScrollbar && that.options.hideScrollbar) {
				if (vendor == 'webkit') that.vScrollbarWrapper.style[vendor + 'TransitionDelay'] = '300ms';
				that.vScrollbarWrapper.style.opacity = '0';
			}

			return;
		}

		that.scrollTo(resetX, resetY, time || 0);
	},

	_wheel: function (e) {
		var that = this,
			wheelDeltaX, wheelDeltaY,
			deltaX, deltaY,
			deltaScale;

		if ('wheelDeltaX' in e) {
			wheelDeltaX = e.wheelDeltaX / 12;
			wheelDeltaY = e.wheelDeltaY / 12;
		} else if ('detail' in e) {
			wheelDeltaX = wheelDeltaY = -e.detail * 3;
		} else {
			wheelDeltaX = wheelDeltaY = -e.wheelDelta;
		}
		
		if (that.options.wheelAction == 'zoom') {
			deltaScale = that.scale * Math.pow(2, 1/3 * (wheelDeltaY ? wheelDeltaY / Math.abs(wheelDeltaY) : 0));
			if (deltaScale < that.options.zoomMin) deltaScale = that.options.zoomMin;
			if (deltaScale > that.options.zoomMax) deltaScale = that.options.zoomMax;
			
			if (deltaScale != that.scale) {
				if (!that.wheelZoomCount && that.options.onZoomStart) that.options.onZoomStart.call(that, e);
				that.wheelZoomCount++;
				
				that.zoom(e.pageX, e.pageY, deltaScale, 400);
				
				setTimeout(function() {
					that.wheelZoomCount--;
					if (!that.wheelZoomCount && that.options.onZoomEnd) that.options.onZoomEnd.call(that, e);
				}, 400);
			}
			
			return;
		}
		
		deltaX = that.x + wheelDeltaX;
		deltaY = that.y + wheelDeltaY;

		if (deltaX > 0) deltaX = 0;
		else if (deltaX < that.maxScrollX) deltaX = that.maxScrollX;

		if (deltaY > that.minScrollY) deltaY = that.minScrollY;
		else if (deltaY < that.maxScrollY) deltaY = that.maxScrollY;

		that.scrollTo(deltaX, deltaY, 0);
	},
	
	_mouseout: function (e) {
		var t = e.relatedTarget;

		if (!t) {
			this._end(e);
			return;
		}

		while (t = t.parentNode) if (t == this.wrapper) return;
		
		this._end(e);
	},

	_transitionEnd: function (e) {
		var that = this;

		if (e.target != that.scroller) return;

		that._unbind('webkitTransitionEnd');
		
		that._startAni();
	},


	/**
	 *
	 * Utilities
	 *
	 */
	_startAni: function () {
		var that = this,
			startX = that.x, startY = that.y,
			startTime = Date.now(),
			step, easeOut,
			animate;

		if (that.animating) return;
		
		if (!that.steps.length) {
			that._resetPos(400);
			return;
		}
		
		step = that.steps.shift();
		
		if (step.x == startX && step.y == startY) step.time = 0;

		that.animating = true;
		that.moved = true;
		
		if (that.options.useTransition) {
			that._transitionTime(step.time);
			that._pos(step.x, step.y);
			that.animating = false;
			if (step.time) that._bind('webkitTransitionEnd');
			else that._resetPos(0);
			return;
		}

		animate = function () {
			var now = Date.now(),
				newX, newY;

			if (now >= startTime + step.time) {
				that._pos(step.x, step.y);
				that.animating = false;
				if (that.options.onAnimationEnd) that.options.onAnimationEnd.call(that);			// Execute custom code on animation end
				that._startAni();
				return;
			}

			now = (now - startTime) / step.time - 1;
			easeOut = m.sqrt(1 - now * now);
			newX = (step.x - startX) * easeOut + startX;
			newY = (step.y - startY) * easeOut + startY;
			that._pos(newX, newY);
			if (that.animating) that.aniTime = nextFrame(animate);
		};

		animate();
	},

	_transitionTime: function (time) {
		time += 'ms';
		this.scroller.style[vendor + 'TransitionDuration'] = time;
		if (this.hScrollbar) this.hScrollbarIndicator.style[vendor + 'TransitionDuration'] = time;
		if (this.vScrollbar) this.vScrollbarIndicator.style[vendor + 'TransitionDuration'] = time;
	},

	_momentum: function (dist, time, maxDistUpper, maxDistLower, size) {
		var deceleration = 0.0006,
			speed = m.abs(dist) / time,
			newDist = (speed * speed) / (2 * deceleration),
			newTime = 0, outsideDist = 0;

		// Proportinally reduce speed if we are outside of the boundaries 
		if (dist > 0 && newDist > maxDistUpper) {
			outsideDist = size / (6 / (newDist / speed * deceleration));
			maxDistUpper = maxDistUpper + outsideDist;
			speed = speed * maxDistUpper / newDist;
			newDist = maxDistUpper;
		} else if (dist < 0 && newDist > maxDistLower) {
			outsideDist = size / (6 / (newDist / speed * deceleration));
			maxDistLower = maxDistLower + outsideDist;
			speed = speed * maxDistLower / newDist;
			newDist = maxDistLower;
		}

		newDist = newDist * (dist < 0 ? -1 : 1);
		newTime = speed / deceleration;

		return { dist: newDist, time: mround(newTime) };
	},

	_offset: function (el) {
		var left = -el.offsetLeft,
			top = -el.offsetTop;
			
		while (el = el.offsetParent) {
			left -= el.offsetLeft;
			top -= el.offsetTop;
		}
		
		if (el != this.wrapper) {
			left *= this.scale;
			top *= this.scale;
		}

		return { left: left, top: top };
	},

	_snap: function (x, y) {
		var that = this,
			i, l,
			page, time,
			sizeX, sizeY;

		// Check page X
		page = that.pagesX.length - 1;
		for (i=0, l=that.pagesX.length; i<l; i++) {
			if (x >= that.pagesX[i]) {
				page = i;
				break;
			}
		}
		if (page == that.currPageX && page > 0 && that.dirX < 0) page--;
		x = that.pagesX[page];
		sizeX = m.abs(x - that.pagesX[that.currPageX]);
		sizeX = sizeX ? m.abs(that.x - x) / sizeX * 500 : 0;
		that.currPageX = page;

		// Check page Y
		page = that.pagesY.length-1;
		for (i=0; i<page; i++) {
			if (y >= that.pagesY[i]) {
				page = i;
				break;
			}
		}
		if (page == that.currPageY && page > 0 && that.dirY < 0) page--;
		y = that.pagesY[page];
		sizeY = m.abs(y - that.pagesY[that.currPageY]);
		sizeY = sizeY ? m.abs(that.y - y) / sizeY * 500 : 0;
		that.currPageY = page;

		// Snap with constant speed (proportional duration)
		time = mround(m.max(sizeX, sizeY)) || 200;

		return { x: x, y: y, time: time };
	},

	_bind: function (type, el, bubble) {
		(el || this.scroller).addEventListener(type, this, !!bubble);
	},

	_unbind: function (type, el, bubble) {
		(el || this.scroller).removeEventListener(type, this, !!bubble);
	},


	/**
	 *
	 * Public methods
	 *
	 */
	destroy: function () {
		var that = this;

		that.scroller.style[vendor + 'Transform'] = '';

		// Remove the scrollbars
		that.hScrollbar = false;
		that.vScrollbar = false;
		that._scrollbar('h');
		that._scrollbar('v');

		// Remove the event listeners
		that._unbind(RESIZE_EV, window);
		that._unbind(START_EV);
		that._unbind(MOVE_EV);
		that._unbind(END_EV);
		that._unbind(CANCEL_EV);
		
		if (that.options.hasTouch) {
			that._unbind('mouseout', that.wrapper);
			that._unbind(WHEEL_EV);
		}
		
		if (that.options.useTransition) that._unbind('webkitTransitionEnd');
		
		if (that.options.checkDOMChanges) clearInterval(that.checkDOMTime);
		
		if (that.options.onDestroy) that.options.onDestroy.call(that);
	},

	refresh: function () {
		var that = this,
			offset,
			i, l,
			els,
			pos = 0,
			page = 0;

		if (that.scale < that.options.zoomMin) that.scale = that.options.zoomMin;
		that.wrapperW = that.wrapper.clientWidth || 1;
		that.wrapperH = that.wrapper.clientHeight || 1;

		that.minScrollY = -that.options.topOffset || 0;
		that.scrollerW = mround(that.scroller.offsetWidth * that.scale);
		that.scrollerH = mround((that.scroller.offsetHeight + that.minScrollY) * that.scale);
		that.maxScrollX = that.wrapperW - that.scrollerW;
		that.maxScrollY = that.wrapperH - that.scrollerH + that.minScrollY;
		that.dirX = 0;
		that.dirY = 0;

		if (that.options.onRefresh) that.options.onRefresh.call(that);

		that.hScroll = that.options.hScroll && that.maxScrollX < 0;
		that.vScroll = that.options.vScroll && (!that.options.bounceLock && !that.hScroll || that.scrollerH > that.wrapperH);

		that.hScrollbar = that.hScroll && that.options.hScrollbar;
		that.vScrollbar = that.vScroll && that.options.vScrollbar && that.scrollerH > that.wrapperH;

		offset = that._offset(that.wrapper);
		that.wrapperOffsetLeft = -offset.left;
		that.wrapperOffsetTop = -offset.top;

		// Prepare snap
		if (typeof that.options.snap == 'string') {
			that.pagesX = [];
			that.pagesY = [];
			els = that.scroller.querySelectorAll(that.options.snap);
			for (i=0, l=els.length; i<l; i++) {
				pos = that._offset(els[i]);
				pos.left += that.wrapperOffsetLeft;
				pos.top += that.wrapperOffsetTop;
				that.pagesX[i] = pos.left < that.maxScrollX ? that.maxScrollX : pos.left * that.scale;
				that.pagesY[i] = pos.top < that.maxScrollY ? that.maxScrollY : pos.top * that.scale;
			}
		} else if (that.options.snap) {
			that.pagesX = [];
			while (pos >= that.maxScrollX) {
				that.pagesX[page] = pos;
				pos = pos - that.wrapperW;
				page++;
			}
			if (that.maxScrollX%that.wrapperW) that.pagesX[that.pagesX.length] = that.maxScrollX - that.pagesX[that.pagesX.length-1] + that.pagesX[that.pagesX.length-1];

			pos = 0;
			page = 0;
			that.pagesY = [];
			while (pos >= that.maxScrollY) {
				that.pagesY[page] = pos;
				pos = pos - that.wrapperH;
				page++;
			}
			if (that.maxScrollY%that.wrapperH) that.pagesY[that.pagesY.length] = that.maxScrollY - that.pagesY[that.pagesY.length-1] + that.pagesY[that.pagesY.length-1];
		}

		// Prepare the scrollbars
		that._scrollbar('h');
		that._scrollbar('v');

		if (!that.zoomed) {
			that.scroller.style[vendor + 'TransitionDuration'] = '0';
			that._resetPos(200);
		}
	},

	scrollTo: function (x, y, time, relative) {
		var that = this,
			step = x,
			i, l;

		that.stop();

		if (!step.length) step = [{ x: x, y: y, time: time, relative: relative }];
		
		for (i=0, l=step.length; i<l; i++) {
			if (step[i].relative) { step[i].x = that.x - step[i].x; step[i].y = that.y - step[i].y; }
			that.steps.push({ x: step[i].x, y: step[i].y, time: step[i].time || 0 });
		}

		that._startAni();
	},

	scrollToElement: function (el, time) {
		var that = this, pos;
		el = el.nodeType ? el : that.scroller.querySelector(el);
		if (!el) return;

		pos = that._offset(el);
		pos.left += that.wrapperOffsetLeft;
		pos.top += that.wrapperOffsetTop;

		pos.left = pos.left > 0 ? 0 : pos.left < that.maxScrollX ? that.maxScrollX : pos.left;
		pos.top = pos.top > that.minScrollY ? that.minScrollY : pos.top < that.maxScrollY ? that.maxScrollY : pos.top;
		time = time === undefined ? m.max(m.abs(pos.left)*2, m.abs(pos.top)*2) : time;

		that.scrollTo(pos.left, pos.top, time);
	},

	scrollToPage: function (pageX, pageY, time) {
		var that = this, x, y;

		if (that.options.onScrollStart) that.options.onScrollStart.call(that);

		if (that.options.snap) {
			pageX = pageX == 'next' ? that.currPageX+1 : pageX == 'prev' ? that.currPageX-1 : pageX;
			pageY = pageY == 'next' ? that.currPageY+1 : pageY == 'prev' ? that.currPageY-1 : pageY;

			pageX = pageX < 0 ? 0 : pageX > that.pagesX.length-1 ? that.pagesX.length-1 : pageX;
			pageY = pageY < 0 ? 0 : pageY > that.pagesY.length-1 ? that.pagesY.length-1 : pageY;

			that.currPageX = pageX;
			that.currPageY = pageY;
			x = that.pagesX[pageX];
			y = that.pagesY[pageY];
		} else {
			x = -that.wrapperW * pageX;
			y = -that.wrapperH * pageY;
			if (x < that.maxScrollX) x = that.maxScrollX;
			if (y < that.maxScrollY) y = that.maxScrollY;
		}

		that.scrollTo(x, y, time || 400);
	},

	disable: function () {
		this.stop();
		this._resetPos(0);
		this.enabled = false;

		// If disabled after touchstart we make sure that there are no left over events
		this._unbind(MOVE_EV);
		this._unbind(END_EV);
		this._unbind(CANCEL_EV);
	},
	
	enable: function () {
		this.enabled = true;
	},
	
	stop: function () {
		if (this.options.useTransition) this._unbind('webkitTransitionEnd');
		else cancelFrame(this.aniTime);
		this.steps = [];
		this.moved = false;
		this.animating = false;
	},
	
	zoom: function (x, y, scale, time) {
		var that = this,
			relScale = scale / that.scale;

		if (!that.options.useTransform) return;

		that.zoomed = true;
		time = time === undefined ? 200 : time;
		x = x - that.wrapperOffsetLeft - that.x;
		y = y - that.wrapperOffsetTop - that.y;
		that.x = x - x * relScale + that.x;
		that.y = y - y * relScale + that.y;

		that.scale = scale;
		that.refresh();

		that.x = that.x > 0 ? 0 : that.x < that.maxScrollX ? that.maxScrollX : that.x;
		that.y = that.y > that.minScrollY ? that.minScrollY : that.y < that.maxScrollY ? that.maxScrollY : that.y;

		that.scroller.style[vendor + 'TransitionDuration'] = time + 'ms';
		that.scroller.style[vendor + 'Transform'] = trnOpen + that.x + 'px,' + that.y + 'px' + trnClose + ' scale(' + scale + ')';
		that.zoomed = false;
	},
	
	isReady: function () {
		return !this.moved && !this.zoomed && !this.animating;
	}
};

if (typeof exports !== 'undefined') exports.iScroll = iScroll;
else window.iScroll = iScroll;

})();

(function($){
	
	$.fn.jScroll = function(params) {

		var pos,
            scroller_left_while_scrolling,
			scrolling = false,
			move_by_bar = false,
            debounce = function(func, wait, immediate) {
                var timeout;
                return function() {
                    var context = this, args = arguments;
                    var later = function() {
                        timeout = null;
                        if (!immediate) func.apply(context, args);
                    };
                    var callNow = immediate && !timeout;
                    clearTimeout(timeout);
                    timeout = setTimeout(later, wait);
                    if (callNow) func.apply(context, args);
                };
            };
		
		var params = $.extend( {
            onScroll:       function( opt ){},
            noMoveMouse:    true
		}, params );
		
		var scroll_array = new Array,
			// Device sniffing
			vendor = (/webkit/i).test(navigator.appVersion) ? 'webkit' :
				(/firefox/i).test(navigator.userAgent) ? 'Moz' :
				'opera' in window ? 'O' : '',
			isIthing = (/iphone|ipad/gi).test(navigator.appVersion),
			isTouch = ('ontouchstart' in window),
			has3d = 'WebKitCSSMatrix' in window && 'm11' in new WebKitCSSMatrix(),
			// Event sniffing
			START_EVENT = isTouch ? 'touchstart' : 'mousedown',
			MOVE_EVENT = isTouch ? 'touchmove' : 'mousemove',
			END_EVENT = isTouch ? 'touchend' : 'mouseup',
			WHEEL_EV = vendor == 'Moz' ? 'DOMMouseScroll' : 'mousewheel';
			
			
		$(this).each( function () {


			var that = $(this),
				wrapper,
				scroller,
				scrollbar_cont,
				scrollbar_inner,
				scroller_left_while_scrolling;

			if ( ! isTouch && $('.jscroll_wrapper', that).size() ) { return; }
			
			/* Init scroll DOM */
			init ();
			function init () {
				
				/* Create wrapper */
				that.wrapInner('<div class="jscroll_wrapper" />');
				wrapper = $(".jscroll_wrapper", that);
				wrapper.attr("id", "jscroll_id" + Math.round(Math.random()*10000000) );
				
				/* Create scroller */
				scroller = wrapper.wrapInner('<div class="jscroll_scroller" />');
				scroller = $(".jscroll_scroller", wrapper);
				
				/* Create scrollbar cont */
				scrollbar_cont = $('<div class="jscroll_scrollbar_cont"></div>').insertAfter(scroller);
				scrollbar_cont.css({
					'position': 'absolute',
					'right': '0px',
					'width': '13px',
					'top': '3px',
					'bottom': '6px'
				});
				
				/* Create scrollbar inner */
				scrollbar_inner = $('<div class="jscroll_scrollbar_inner"></div>').appendTo(scrollbar_cont);
				scrollbar_inner.css({
					'position': 'relative',
					'width': '100%',
					'display': 'none',
					'opacity': '0.4',
                    'cursor': 'pointer'
				});
				var scrollbar_bar = $('<div class="jscroll_scrollbar_bar"></div>').appendTo(scrollbar_inner);
				scrollbar_bar.css({
					'position': 'relative',
					'background': 'black',
					'width': '5px',
					'margin': '0 auto',
					'border-radius': '3px',
					'height': '100%',
					'-webkit-border-radius': '3px'
				});
				

				/* set wrapper style*/
				wrapper.css({
					"position": "relative",
					"height": "100%",
					"overflow": "hidden"
				});
				
				/* set scroller style*/
				scroller.css({
					"min-height": "100%",
					"overflow": "hidden"
				});
				
				if ( isTouch ) {
				
					/* Create scroller inner*/
					scroller.after('<div class="jscroll_scroller_inner" />');
					var scroller_inner = $(".jscroll_scroller_inner", wrapper);
					scroller_inner.appendTo('<div></div>');

					var myScroll = new iScroll( wrapper.attr("id") , {
						hScrollbar: false,
						scrollbarClass: 'jscroll_scroller_inner',
						checkDOMChanges: true,
						bounceLock: true,
						onScrollMove: function(){
							params.onScroll();
						},
						onScrollEnd: function(){
							params.onScroll();
						}
					});
					return true;
					
				} else {
					set_bar_bounds( wrapper, scroller, scrollbar_cont, scrollbar_inner );
					
				}
			}

			if ( isTouch ) { return; }
			
			/* EVENTS */
			
			// resize container or change data
			var jscroll_timer = new Array();
			wrapper.bind('resize', function (e) {
				var timer_id = wrapper.attr('id');
				if ( jscroll_timer[ timer_id ] != undefined ) {
					clearTimeout( jscroll_timer[ timer_id ] );
				}
				jscroll_timer[ timer_id ] = setTimeout( function(){ set_bar_bounds(wrapper, scroller, scrollbar_cont, scrollbar_inner ); jscroll_timer[ timer_id ] = undefined; }, 100 );
			});
			
			/* ??????? ? ??????????? ?????? ?? ???????? ? ??????? */
			if ( ! isTouch ) {
				wrapper.hover(function () {
					scroller_left_while_scrolling = false;
					set_bar_bounds( wrapper, scroller, scrollbar_cont, scrollbar_inner );
					scroll_show(scrollbar_inner);
				},
				function () {
					scroller_left_while_scrolling = true;
					if ( scrolling ) { return; }
					scroll_hide(scrollbar_inner);
				});

                var updateLayout = debounce(function(e) {
                    nativeScrollInit( wrapper, scroller, scrollbar_cont, scrollbar_inner );
                }, 500);

				wrapper.unbind('DOMNodeInserted', updateLayout);
				wrapper.unbind('DOMNodeRemoved', updateLayout); 
				wrapper.bind('DOMNodeInserted', updateLayout);
				wrapper.bind('DOMNodeRemoved', updateLayout);
			}
			
			/* ????????? ??????? START_EVENT, MOVE_EVENT, END_EVENT ??? ????? ?? wrapper  */
			
			scrollbar_inner.bind( START_EVENT, function(e){
				move_by_bar = true;
                params.noMoveMouse = false;
			});
		
			wrapper.bind( START_EVENT, function(e){
                scrollClick( e, wrapper, scroller, scrollbar_cont, scrollbar_inner );
			});
			$(document).bind( MOVE_EVENT, function(e){
                scrollClick(e, wrapper, scroller, scrollbar_cont, scrollbar_inner);

			});
			$(document).bind( END_EVENT, function(e){
				scrollClick(e, wrapper, scroller, scrollbar_cont, scrollbar_inner);
			});
			
			/* ????????? ?????? */
			wrapper.on( WHEEL_EV, function (e) {
                var wheelPos = scrollWheelPos(e, wrapper, scroller, scrollbar_cont, scrollbar_inner);
                scrollTo( wheelPos, wrapper, scroller, scrollbar_cont, scrollbar_inner );
                if ( !wrapper.parent().hasClass("j_native_scroll_block") ) {
                    return false;
                }
			});
		});
        function nativeScrollInit ( wrapper, scroller, scrollbar_cont, scrollbar_inner ) {
            if( ! wrapper.parent().is(".j_native_scroll_block:visible") ) {
				return;
			}
            if( !$(".j_native_scroll").size() ) {
                var body = $("body");
                /* Create scroll */
                body.append('<div class="j_native_scroll"></div>');
                var nativeWrapper = $(".j_native_scroll", body);

                /* Create scroll inner */
                nativeWrapper.append('<div class="j_native_scroll_inner">&nbsp;</div>');
                var nativeInner = $(".j_native_scroll", nativeWrapper);

                /* set scroll style*/
                nativeWrapper.css({
                    "width": '18px',
                    "height": "100%",
                    "position": "fixed",
                    "right": "0",
                    "overflow-y": "auto",
                    "overflow-x": "hidden",
                    "z-index": "10000"
                });

                /* set scroll inner style*/
                nativeInner.css({
                    "height": "auto"
                });
            }
			var ns =  $(".j_native_scroll")

			$("html").unbind(WHEEL_EV + '.jscroll');
			$("html").bind(WHEEL_EV + '.jscroll', function(e){
				//console.log("wheeel");
				var pos = scrollWheelPos(e, wrapper, scroller, scrollbar_cont, scrollbar_inner);
				ns.scrollTop(pos*-1);
			});

			SetHeightFromTo(scroller.height() + $(window).height() - wrapper.height(), $(".j_native_scroll_inner"));

			$(".j_native_scroll").unbind('scroll.jscroll');
			$(".j_native_scroll").bind('scroll.jscroll', function(){
				//debug('scrollll');
				scrollTo( -1 * ns.scrollTop(), wrapper, scroller, scrollbar_cont, scrollbar_inner );
			});
        }
        function scrollWheelPos (e, wrapper, scroller, scrollbar_cont, scrollbar_inner) {
            var koef = get_koef(wrapper, scroller),
                deltaY,
                deltaScale,
                e = e.originalEvent,
                wheelDeltaY = e.detail ? e.detail*(-14) : e.wheelDelta / 3,
                pos_start = get_position ( scroller),
                pageY_end = get_pageY (e);

            if( pos_start >=0 && wheelDeltaY > 0 || (pos_start+wheelDeltaY) > 0 ) {
                wheelDeltaY=0;
                pos_start = 0;
            }
            if( (pos_start <= ( wrapper.height() - scroller.height() ) ) && wheelDeltaY < 0 || (pos_start+wheelDeltaY) < wrapper.height() - scroller.height() ) {
                pos_start = wrapper.height() - scroller.height();
                wheelDeltaY=0;
            }
            pos = pos_start + wheelDeltaY;
            return pos;

        }
        function scrollClick (e, wrapper, scroller, scrollbar_cont, scrollbar_inner ) {
            if ( e.type == START_EVENT ) {
                if ( params.noMoveMouse ) { return; }
                pageY_start = get_pageY (e);
                pos_start = get_position ( scroller );
                scrolling = true;
                //document.title =  pos_start;

                // ????????? ????????? ??????
                $('body').css({
                    '-moz-user-select': 'none',
                    '-ms-user-select': 'none',
                    '-khtml-user-select': 'none',
                    '-webkit-user-select': 'none',
                    '-webkit-touch-callout': 'none',
                    'user-select': 'none'
                });
            }
            else if ( e.type == MOVE_EVENT ) {
                if ( ! scrolling ) { return; }

                /* ????? ?????? ?? ???????? ? ????? */
                if ( isTouch ) {
                    scroll_show(scrollbar_inner);
                }

                var koef_bar = get_koef( wrapper, scroller );
                var pageY_end = get_pageY (e);
                if ( move_by_bar ) {
                    pos = pos_start*koef_bar - (pageY_end - pageY_start);
                    pos = pos/koef_bar;
                } else {
                    pos = pos_start + (pageY_end - pageY_start);
                }

                // near borders
                if ( pos >= 0 ) {
                    pos_start = get_position ( scroller );
                    pageY_start = pageY_end;
                    pos = 0;
                }
                var max_pos = wrapper.height() - scroller.height();
                if ( pos <= max_pos ) {
                    pos_start = get_position (scroller);
                    pageY_start = pageY_end;
                    pos = max_pos;
                }

                scrollTo( pos, wrapper, scroller, scrollbar_cont, scrollbar_inner );
                params.noMoveMouse = true;

                /* Native Scroll */
                if(wrapper.parent().hasClass("j_native_scroll_block")) {
                    $(".j_native_scroll").scrollTop(pos*-1);
                }

            }
            else if ( e.type == END_EVENT ) {
                if ( ! scrolling ) { return; }
                scrolling = false;
                move_by_bar = false;

                /* ??????? ?????? ?? ???????? ? ????? */
                if ( isTouch ) {
                    scroll_hide(scrollbar_inner);
                }

                /* ???????? ?????? ?? ????????? ?????? */
                $('body').css({
                    '-moz-user-select': '',
                    '-ms-user-select': '',
                    '-khtml-user-select': '',
                    '-webkit-user-select': '',
                    '-webkit-touch-callout': '',
                    'user-select': ''
                });

                if ( scroller_left_while_scrolling ) {
                    scroll_hide(scrollbar_inner);
                }
            }

        }
		function SetHeightFromTo (objFrom, objTo) {
            if (typeof(objFrom) == "object" ){
                var height = objFrom.height();
            }
            else if (typeof(objFrom) == "number") {
                var height = objFrom;
            }
            objTo.css('height', height + 'px');
        }
		function scrollTo (posTop, wrapper, scroller, scrollbar_cont, scrollbar_inner) {
            scroll_show (scrollbar_inner);
            set_position( scroller, posTop );
            set_bar_bounds( wrapper, scroller, scrollbar_cont, scrollbar_inner );
		}
		/* ???? ?????????? ????????? ?????????? ???? ???????????? ?????????. */
		function get_pageY (e) {
			return isTouch ? e.originalEvent.targetTouches[0].clientY : e.clientY
		}
		function set_position ( object, pos ) {
			object.css({
				'position': 'relative',
				'top': pos
			});
		}
		function get_position ( object ) {
			var position = object.css('top') ;
			if (position == 'auto') {
				position = 0;
			}
			return parseInt(position);
		}
		function get_koef ( wrapper, scroller ) {
			var w_height = wrapper.height();
			var s_height = scroller.height();
			var koef = w_height/s_height;
			return koef;
		}
		function scroll_show (scrollbar_inner) {
			scrollbar_inner.stop(true,true);
			scrollbar_inner.fadeIn(100);

		}
		function scroll_hide (scrollbar_inner) {
			scrollbar_inner.stop(true,true);
			scrollbar_inner.fadeOut("slow");
		}
		function set_bar_bounds ( wrapper, scroller, scrollbar_cont, scrollbar_inner ) {
			var c_height = scrollbar_cont.height();
			var koef = get_koef (wrapper, scroller);
			var inner_height = c_height*koef;
			/* hidden scroll if box size is bigger than content size */
			if (koef >= 1) {
				var visibility = 'hidden'
			}
			else {
				var visibility = 'visible'
			}
			scrollbar_inner.css({
				'height': inner_height,
				'visibility': visibility
			});

			/* ????????????? ????????? ??????? ??? ??????? */
			var scroller_position = 	get_position( scroller );
			var wrapper_height = 		wrapper.height();
			var scroller_height = 		scroller.height();

			if ( scroller_position <= 0 && scroller_position <= ( wrapper_height - scroller_height ) ) {
				var pos = wrapper_height - scroller_height;
				pos = Math.min ( pos, 0 );
				set_position( scroller, pos );
			}
			pos_koef = scroller_position / wrapper_height;
			pos = wrapper_height*pos_koef;
			set_position( scrollbar_inner, pos*koef*-1 );
            params.onScroll({ wrapper: wrapper, scroller: scroller, position: scroller_position, length: scroller_height });
		}
		
	}
})(jQuery);
(function($){

	$.fn.hoverselect = function(options) {


        var options;
        options = $.extend({
            link:false,
            hover:true,
            class_name_mousedown:'g_mousedown',
            class_name_click:'g_active',
            callback_mouseover:null,
            callback_mouseout:null,
            callback_mousedown:null,
            callback_mouseup:null,
			container_selector:null
        }, options);

        /* ������ ��������, ���� ������� �������� ���� ����� */
        $(options.link).live("click", function (event) {
            //event.stopPropagation();
        });

        if (!is_mobile()) {
            var mousedown = false;
            /* add class hover  */
            if (options.hover) {
                $(this).live('mouseenter', function (event) {

                    $(this).mousedown(function () {
                        mousedown = true;
                    });
                    $(this).mouseup(function () {
                        mousedown = false;
                    });
                    if ($(this).hasClass('disable')) {
                        // Default cursor tag <a> in elements with class �disable�
                        $('.disable a').css('cursor', 'default !important');
                        return true;
                    }

                    if (!mousedown) {
                        $(this).addClass("g_hover");

                    }
                    if (options.callback_mouseover) {
                        options.callback_mouseover($(this));
                    }
                });
                /* remove class hover  */
                $(this).live('mouseleave', function () {
                    $(this).removeClass("g_hover");
                    $(this).removeClass(options.class_name_mousedown);
                    if (options.callback_mouseout) {
                        options.callback_mouseout($(this));
                    }
                });
            }
        }

        /* SELECT */
        $(this).live('mousedown', function (e) {
            e.stopPropagation();
            if ($(this).hasClass('disable')) {
                return true;
            }
            var self = $(this);
            self.addClass(options.class_name_mousedown);
            if (options.callback_mousedown) {
                options.callback_mousedown($(this));
            }
        });
        $(this).live('click', function (e) {
            e.stopPropagation();
            if ($(this).hasClass('disable')) {
                return true;
            }
            var self = $(this);
			if ( !self.hasClass("g_clicked") ) {
				self.addClass("g_clicked");
			} else {
				self.removeClass("g_clicked");
			}
            self.removeClass(options.class_name_mousedown);
            if ( options.container_selector ) {
				$("." + options.class_name_click, $(options.container_selector) ).removeClass(options.class_name_click);
			} else {
				self.parent().find("." + options.class_name_click).removeClass(options.class_name_click);
			}
            self.addClass(options.class_name_click);
            /* �������� ����� �� ������ ������ �������� ��� ����� �� ���� �������� */
            if (options.link) {
                $(options.link, self).click();
            }
            if (options.callback_mouseup) {
                options.callback_mouseup($(this));
            }
        });
    }
	
	function is_mobile () {
		if ( 
			navigator.userAgent.indexOf('iPad') != -1 ||
			navigator.userAgent.indexOf('iPhone') != -1 ||
			navigator.userAgent.indexOf('iPod') != -1 )
		{
			return true;
		}
		else {
			return false;
		}
	}

})(jQuery);
/*
 * Gritter for jQuery
 * http://www.boedesign.com/
 *
 * Copyright (c) 2011 Jordan Boesch
 * Dual licensed under the MIT and GPL licenses.
 *
 * Date: December 8, 2011
 * Version: 1.7.3
 */

(function($){

	/**
	 * Set it up as an object under the jQuery namespace
	 */
	$.gritter = {};

	/**
	 * Set up global options that the user can over-ride
	 */
	$.gritter.options = {
		position: 'bottom-right',
		class_name: '', // could be set to 'gritter-light' to use white notifications
		fade_in_speed: 'medium', // how fast notifications fade in
		fade_out_speed: 100, // how fast the notices fade out
		time: 6000, // hang on the screen for...
		color: '#000'
	}

	/**
	 * Add a gritter notification to the screen
	 * @see Gritter#add();
	 */
	$.gritter.add = function(params){

		try {
			return Gritter.add(params || {});
		} catch(e) {

			var err = 'Gritter Error: ' + e;
			(typeof(console) != 'undefined' && console.error) ?
				console.error(err, params) :
				alert(err);

		}

	}

	/**
	 * Remove a gritter notification from the screen
	 * @see Gritter#removeSpecific();
	 */
	$.gritter.remove = function(id, params){
		Gritter.removeSpecific(id, params || {});
	}

	/**
	 * Remove all notifications
	 * @see Gritter#stop();
	 */
	$.gritter.removeAll = function(params){
		Gritter.stop(params || {});
	}

	/**
	 * Big fat Gritter object
	 * @constructor (not really since its object literal)
	 */
	var Gritter = {

		// Public - options to over-ride with $.gritter.options in "add"
		position: '',
		fade_in_speed: '',
		fade_out_speed: '',
		time: '',

		// Private - no touchy the private parts
		_custom_timer: 0,
		_item_count: 0,
		_is_setup: 0,
		_tpl_close: '<div class="gritter-close">X</div>',
//		_tpl_item: '<div id="gritter-item-[[number]]" class="gritter-item-wrapper [[item_class]]" style="display:none;">'+
//						'<div class="gritter-top">' +
//						'</div>'+
//						'<div class="gritter-item">'+
//							'[[close]][[image]]'+
//							'<div class="[[class_name]]">'+
//								'<span class="gritter-title">'+
//									'[[username]]'+
//								'</span>'+
//								'<p>[[text]]</p>'+
//							'</div>'+
//							'<div style="clear:both"></div>'+
//						'</div>'+
//					'<div class="gritter-bottom"></div>'+
//				'</div>',
		_tpl_item: '<div class="gritter-item-wrapper b_popup_messager [[textColor]]" style="border-color: [[borderColor]]" id="gritter-item-[[number]]">' +
			'<div class="b_popup_messager_text [[closeClass]]">' +
			'<b>[[title]]</b><br>' +
			'[[text]]'+
			'</div>' +
			'<div class="b_popup_messager_bg  [[closeClass]]" style="background-color: [[color]]"></div>' +
			'</div>',
		_tpl_wrap: '<div id="gritter-notice-wrapper"></div>',

		/**
		 * Add a gritter notification to the screen
		 * @param {Object} params The object that contains all the options for drawing the notification
		 * @return {Integer} The specific numeric id to that gritter notification
		 */
		add: function(params){

			// We might have some issues if we don't have a title or text!
			if(!params.title || !params.text){
				throw 'You need to fill out the first 2 params: "title" and "text"';
			}

			// Check the options and set them once
			if(!this._is_setup){
				this._runSetup();
			}

			// Basics
			var user = params.title,
				text = params.text,
				image = params.image || '',
				sticky = params.sticky || false,
				item_class = params.class_name || $.gritter.options.class_name,
				position = $.gritter.options.position,
				color = params.color || '#FFF',
				time_alive = params.time || '';

			this._verifyWrapper();

			this._item_count++;
			var number = this._item_count,
				tmp = this._tpl_item;

			// Assign callbacks
			$(['before_open', 'after_open', 'before_close', 'after_close']).each(function(i, val){
				Gritter['_' + val + '_' + number] = ($.isFunction(params[val])) ? params[val] : function(){}
			});

			// Reset
			this._custom_timer = 0;

			// A custom fade time set
			if(time_alive){
				this._custom_timer = time_alive;
			}

			var image_str = (image != '') ? '<img src="' + image + '" class="gritter-image" />' : '',
				class_name = (image != '') ? 'gritter-with-image' : 'gritter-without-image';

//			if ( ! this.messageTemplateDot ) {
//				this.messageTemplateDot = doT.template( $('#t_notify_message').html() );
//			}

			// String replacements on the template
			tmp = this._str_replace(
				['[[textColor]]', '[[borderColor]]', '[[number]]', '[[title]]', '[[text]]', '[[closeClass]]', '[[color]]'],
				[ params.textColor == 'black' ? 'm_dark' : 'm_light', params.borderColor, this._item_count, params.title, params.text, "gritter-close", color], tmp
			);

//			tmp = this.messageTemplateDot({
//				title: params.title,
//				text: params.text,
//				number: this._item_count,
//				closeClass: "gritter-close",
//				color: color,
//				borderColor: params.borderColor,
//				textColor: params.textColor == 'black' ? 'm_dark' : 'm_light'
//			});

			tmp = $(tmp);


			// If it's false, don't show another gritter message
			if(this['_before_open_' + number]() === false){
				return false;
			}

			$('#gritter-notice-wrapper').addClass(position).append(tmp);

			if ( typeof  params.onclick == 'function' ) {
				tmp.click(function(){
					params.onclick();
				});
			}

			var item = $('#gritter-item-' + this._item_count);

			//item.css('background-color', color);

			item.fadeIn(this.fade_in_speed, function(){
				Gritter['_after_open_' + number]($(this));
			});

			if(!sticky){
				this._setFadeTimer(item, number);
			}

			// Bind the hover/unhover states
			$(item).bind('mouseenter mouseleave', function(event){
				if(event.type == 'mouseenter'){
					if(!sticky){
						Gritter._restoreItemIfFading($(this), number);
					}
				}
				else {
					if(!sticky){
						Gritter._setFadeTimer($(this), number);
					}
				}
				Gritter._hoverState($(this), event.type);
			});

			return number;

		},

		/**
		 * If we don't have any more gritter notifications, get rid of the wrapper using this check
		 * @private
		 * @param {Integer} unique_id The ID of the element that was just deleted, use it for a callback
		 * @param {Object} e The jQuery element that we're going to perform the remove() action on
		 * @param {Boolean} manual_close Did we close the gritter dialog with the (X) button
		 */
		_countRemoveWrapper: function(unique_id, e, manual_close){

			// Remove it then run the callback function
			e.remove();
			this['_after_close_' + unique_id](e, manual_close);

			// Check if the wrapper is empty, if it is.. remove the wrapper
			if($('.gritter-item-wrapper').length == 0){
				$('#gritter-notice-wrapper').remove();
			}

		},

		/**
		 * Fade out an element after it's been on the screen for x amount of time
		 * @private
		 * @param {Object} e The jQuery element to get rid of
		 * @param {Integer} unique_id The id of the element to remove
		 * @param {Object} params An optional list of params to set fade speeds etc.
		 * @param {Boolean} unbind_events Unbind the mouseenter/mouseleave events if they click (X)
		 */
		_fade: function(e, unique_id, params, unbind_events){

			var params = params || {},
				fade = (typeof(params.fade) != 'undefined') ? params.fade : true;
			var fade_out_speed = params.speed || this.fade_out_speed,
				manual_close = unbind_events;

			if ( this['_before_close_' + unique_id] ) {
				this['_before_close_' + unique_id](e, manual_close);
			}

			// If this is true, then we are coming from clicking the (X)
			if(unbind_events){
				e.unbind('mouseenter mouseleave');
			}

			// Fade it out or remove it
			if(fade){

				e.animate({
					opacity: 0
				}, fade_out_speed, function(){
					e.animate({ height: 0 }, 300, function(){
						Gritter._countRemoveWrapper(unique_id, e, manual_close);
					})
				})

			}
			else {

				this._countRemoveWrapper(unique_id, e);

			}

		},

		/**
		 * Perform actions based on the type of bind (mouseenter, mouseleave)
		 * @private
		 * @param {Object} e The jQuery element
		 * @param {String} type The type of action we're performing: mouseenter or mouseleave
		 */
		_hoverState: function(e, type){

			// Change the border styles and add the (X) close button when you hover
			if(type == 'mouseenter'){

				e.addClass('hover');

				// Show close button
				e.find('.gritter-close').show();

				// Clicking (X) makes the perdy thing close
				e.find('.gritter-close').click(function(){
					var unique_id = e.attr('id').split('-')[2];
					Gritter.removeSpecific(unique_id, {}, e, true);
				});

			}
			// Remove the border styles and hide (X) close button when you mouse out
			else {

				e.removeClass('hover');

				// Hide close button
				//e.find('.gritter-close').hide();

			}

		},

		/**
		 * Remove a specific notification based on an ID
		 * @param {Integer} unique_id The ID used to delete a specific notification
		 * @param {Object} params A set of options passed in to determine how to get rid of it
		 * @param {Object} e The jQuery element that we're "fading" then removing
		 * @param {Boolean} unbind_events If we clicked on the (X) we set this to true to unbind mouseenter/mouseleave
		 */
		removeSpecific: function(unique_id, params, e, unbind_events){

			if(!e){
				var e = $('#gritter-item-' + unique_id);
			}

			// We set the fourth param to let the _fade function know to 
			// unbind the "mouseleave" event.  Once you click (X) there's no going back!
			this._fade(e, unique_id, params || {}, unbind_events);

		},

		/**
		 * If the item is fading out and we hover over it, restore it!
		 * @private
		 * @param {Object} e The HTML element to remove
		 * @param {Integer} unique_id The ID of the element
		 */
		_restoreItemIfFading: function(e, unique_id){

			clearTimeout(this['_int_id_' + unique_id]);
			e.stop().css({ opacity: '', height: '' });

		},

		/**
		 * Setup the global options - only once
		 * @private
		 */
		_runSetup: function(){

			for(opt in $.gritter.options){
				this[opt] = $.gritter.options[opt];
			}
			this._is_setup = 1;

		},

		/**
		 * Set the notification to fade out after a certain amount of time
		 * @private
		 * @param {Object} item The HTML element we're dealing with
		 * @param {Integer} unique_id The ID of the element
		 */
		_setFadeTimer: function(e, unique_id){

			var timer_str = (this._custom_timer) ? this._custom_timer : this.time;
			this['_int_id_' + unique_id] = setTimeout(function(){
				Gritter._fade(e, unique_id);
			}, timer_str);

		},

		/**
		 * Bring everything to a halt
		 * @param {Object} params A list of callback functions to pass when all notifications are removed
		 */
		stop: function(params){

			// callbacks (if passed)
			var before_close = ($.isFunction(params.before_close)) ? params.before_close : function(){};
			var after_close = ($.isFunction(params.after_close)) ? params.after_close : function(){};

			var wrap = $('#gritter-notice-wrapper');
			before_close(wrap);
			wrap.fadeOut(function(){
				$(this).remove();
				after_close();
			});

		},

		/**
		 * An extremely handy PHP function ported to JS, works well for templating
		 * @private
		 * @param {String/Array} search A list of things to search for
		 * @param {String/Array} replace A list of things to replace the searches with
		 * @return {String} sa The output
		 */
		_str_replace: function(search, replace, subject, count){

			var i = 0, j = 0, temp = '', repl = '', sl = 0, fl = 0,
				f = [].concat(search),
				r = [].concat(replace),
				s = subject,
				ra = r instanceof Array, sa = s instanceof Array;
			s = [].concat(s);

			if(count){
				this.window[count] = 0;
			}

			for(i = 0, sl = s.length; i < sl; i++){

				if(s[i] === ''){
					continue;
				}

				for (j = 0, fl = f.length; j < fl; j++){

					temp = s[i] + '';
					repl = ra ? (r[j] !== undefined ? r[j] : '') : r[0];
					s[i] = (temp).split(f[j]).join(repl);

					if(count && s[i] !== temp){
						this.window[count] += (temp.length-s[i].length) / f[j].length;
					}

				}
			}

			return sa ? s : s[0];

		},

		/**
		 * A check to make sure we have something to wrap our notices with
		 * @private
		 */
		_verifyWrapper: function(){

			if($('#gritter-notice-wrapper').length == 0){
				$('body').append(this._tpl_wrap);
			}

		}

	}

})(jQuery);

// Avoid `console` errors in browsers that lack a console.
(function() {
    var method;
    var noop = function noop() {};
    var methods = [
        'assert', 'clear', 'count', 'debug', 'dir', 'dirxml', 'error',
        'exception', 'group', 'groupCollapsed', 'groupEnd', 'info', 'log',
        'markTimeline', 'profile', 'profileEnd', 'table', 'time', 'timeEnd',
        'timeStamp', 'trace', 'warn'
    ];
    var length = methods.length;
    var console = (window.console = window.console || {});

    while (length--) {
        method = methods[length];

        // Only stub undefined methods.
        if (!console[method]) {
            console[method] = noop;
        }
    }
}());

// Place any jQuery/helper plugins in here.

/*
 Copyright 2012 Igor Vaynberg

 Version: 3.2 Timestamp: Mon Sep 10 10:38:04 PDT 2012

 Licensed under the Apache License, Version 2.0 (the "License"); you may not use this work except in
 compliance with the License. You may obtain a copy of the License in the LICENSE file, or at:

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software distributed under the License is
 distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and limitations under the License.
 */

 (function ($) {
 	if(typeof $.fn.each2 == "undefined"){
 		$.fn.extend({
 			/*
			* 4-10 times faster .each replacement
			* use it carefully, as it overrides jQuery context of element on each iteration
			*/
			each2 : function (c) {
				var j = $([0]), i = -1, l = this.length;
				while (
					++i < l
					&& (j.context = j[0] = this[i])
					&& c.call(j[0], i, j) !== false //"this"=DOM, i=index, j=jQuery object
				);
				return this;
			}
 		});
 	}
})(jQuery);

(function ($, undefined) {
    "use strict";
    /*global document, window, jQuery, console */

    if (window.Select2 !== undefined) {
        return;
    }

    var KEY, AbstractSelect2, SingleSelect2, MultiSelect2, nextUid, sizer;

    KEY = {
        TAB: 9,
        ENTER: 13,
        ESC: 27,
        SPACE: 32,
        LEFT: 37,
        UP: 38,
        RIGHT: 39,
        DOWN: 40,
        SHIFT: 16,
        CTRL: 17,
        ALT: 18,
        PAGE_UP: 33,
        PAGE_DOWN: 34,
        HOME: 36,
        END: 35,
        BACKSPACE: 8,
        DELETE: 46,
        isArrow: function (k) {
            k = k.which ? k.which : k;
            switch (k) {
            case KEY.LEFT:
            case KEY.RIGHT:
            case KEY.UP:
            case KEY.DOWN:
                return true;
            }
            return false;
        },
        isControl: function (e) {
            var k = e.which;
            switch (k) {
            case KEY.SHIFT:
            case KEY.CTRL:
            case KEY.ALT:
                return true;
            }

            if (e.metaKey) return true;

            return false;
        },
        isFunctionKey: function (k) {
            k = k.which ? k.which : k;
            return k >= 112 && k <= 123;
        }
    };

    nextUid=(function() { var counter=1; return function() { return counter++; }; }());

    function indexOf(value, array) {
        var i = 0, l = array.length, v;

        if (typeof value === "undefined") {
          return -1;
        }

        if (value.constructor === String) {
            for (; i < l; i = i + 1) if (value.localeCompare(array[i]) === 0) return i;
        } else {
            for (; i < l; i = i + 1) {
                v = array[i];
                if (v.constructor === String) {
                    if (v.localeCompare(value) === 0) return i;
                } else {
                    if (v === value) return i;
                }
            }
        }
        return -1;
    }

    /**
     * Compares equality of a and b taking into account that a and b may be strings, in which case localeCompare is used
     * @param a
     * @param b
     */
    function equal(a, b) {
        if (a === b) return true;
        if (a === undefined || b === undefined) return false;
        if (a === null || b === null) return false;
        if (a.constructor === String) return a.localeCompare(b) === 0;
        if (b.constructor === String) return b.localeCompare(a) === 0;
        return false;
    }

    /**
     * Splits the string into an array of values, trimming each value. An empty array is returned for nulls or empty
     * strings
     * @param string
     * @param separator
     */
    function splitVal(string, separator) {
        var val, i, l;
        if (string === null || string.length < 1) return [];
        val = string.split(separator);
        for (i = 0, l = val.length; i < l; i = i + 1) val[i] = $.trim(val[i]);
        return val;
    }

    function getSideBorderPadding(element) {
        return element.outerWidth() - element.width();
    }

    function installKeyUpChangeEvent(element) {
        var key="keyup-change-value";
        element.bind("keydown", function () {
            if ($.data(element, key) === undefined) {
                $.data(element, key, element.val());
            }
        });
        element.bind("keyup", function () {
            var val= $.data(element, key);
            if (val !== undefined && element.val() !== val) {
                $.removeData(element, key);
                element.trigger("keyup-change");
            }
        });
    }

    $(document).delegate("body", "mousemove", function (e) {
        $.data(document, "select2-lastpos", {x: e.pageX, y: e.pageY});
    });

    /**
     * filters mouse events so an event is fired only if the mouse moved.
     *
     * filters out mouse events that occur when mouse is stationary but
     * the elements under the pointer are scrolled.
     */
    function installFilteredMouseMove(element) {
	    element.bind("mousemove", function (e) {
            var lastpos = $.data(document, "select2-lastpos");
            if (lastpos === undefined || lastpos.x !== e.pageX || lastpos.y !== e.pageY) {
                $(e.target).trigger("mousemove-filtered", e);
            }
        });
    }

    /**
     * Debounces a function. Returns a function that calls the original fn function only if no invocations have been made
     * within the last quietMillis milliseconds.
     *
     * @param quietMillis number of milliseconds to wait before invoking fn
     * @param fn function to be debounced
     * @param ctx object to be used as this reference within fn
     * @return debounced version of fn
     */
    function debounce(quietMillis, fn, ctx) {
        ctx = ctx || undefined;
        var timeout;
        return function () {
            var args = arguments;
            window.clearTimeout(timeout);
            timeout = window.setTimeout(function() {
                fn.apply(ctx, args);
            }, quietMillis);
        };
    }

    /**
     * A simple implementation of a thunk
     * @param formula function used to lazily initialize the thunk
     * @return {Function}
     */
    function thunk(formula) {
        var evaluated = false,
            value;
        return function() {
            if (evaluated === false) { value = formula(); evaluated = true; }
            return value;
        };
    };

    function installDebouncedScroll(threshold, element) {
        var notify = debounce(threshold, function (e) { element.trigger("scroll-debounced", e);});
        element.bind("scroll", function (e) {
            if (indexOf(e.target, element.get()) >= 0) notify(e);
        });
    }

    function killEvent(event) {
        event.preventDefault();
        event.stopPropagation();
    }

    function measureTextWidth(e) {
        if (!sizer){
        	var style = e[0].currentStyle || window.getComputedStyle(e[0], null);
        	sizer = $("<div></div>").css({
	            position: "absolute",
	            left: "-10000px",
	            top: "-10000px",
	            display: "none",
	            fontSize: style.fontSize,
	            fontFamily: style.fontFamily,
	            fontStyle: style.fontStyle,
	            fontWeight: style.fontWeight,
	            letterSpacing: style.letterSpacing,
	            textTransform: style.textTransform,
	            whiteSpace: "nowrap"
	        });
        	$("body").append(sizer);
        }
        sizer.text(e.val());
        return sizer.width();
    }

    function markMatch(text, term, markup) {
        var match=text.toUpperCase().indexOf(term.toUpperCase()),
            tl=term.length;

        if (match<0) {
            markup.push(text);
            return;
        }

        markup.push(text.substring(0, match));
        markup.push("<span class='select2-match'>");
        markup.push(text.substring(match, match + tl));
        markup.push("</span>");
        markup.push(text.substring(match + tl, text.length));
    }

    /**
     * Produces an ajax-based query function
     *
     * @param options object containing configuration paramters
     * @param options.transport function that will be used to execute the ajax request. must be compatible with parameters supported by $.ajax
     * @param options.url url for the data
     * @param options.data a function(searchTerm, pageNumber, context) that should return an object containing query string parameters for the above url.
     * @param options.dataType request data type: ajax, jsonp, other datatatypes supported by jQuery's $.ajax function or the transport function if specified
     * @param options.traditional a boolean flag that should be true if you wish to use the traditional style of param serialization for the ajax request
     * @param options.quietMillis (optional) milliseconds to wait before making the ajaxRequest, helps debounce the ajax function if invoked too often
     * @param options.results a function(remoteData, pageNumber) that converts data returned form the remote request to the format expected by Select2.
     *      The expected format is an object containing the following keys:
     *      results array of objects that will be used as choices
     *      more (optional) boolean indicating whether there are more results available
     *      Example: {results:[{id:1, text:'Red'},{id:2, text:'Blue'}], more:true}
     */
    function ajax(options) {
        var timeout, // current scheduled but not yet executed request
            requestSequence = 0, // sequence used to drop out-of-order responses
            handler = null,
            quietMillis = options.quietMillis || 100;

        return function (query) {
            window.clearTimeout(timeout);
            timeout = window.setTimeout(function () {
                requestSequence += 1; // increment the sequence
                var requestNumber = requestSequence, // this request's sequence number
                    data = options.data, // ajax data function
                    transport = options.transport || $.ajax,
                    traditional = options.traditional || false,
                    type = options.type || 'GET'; // set type of request (GET or POST)

                data = data.call(this, query.term, query.page, query.context);

                if( null !== handler) { handler.abort(); }

                handler = transport.call(null, {
                    url: options.url,
                    dataType: options.dataType,
                    data: data,
                    type: type,
                    traditional: traditional,
                    success: function (data) {
                        if (requestNumber < requestSequence) {
                            return;
                        }
                        // TODO 3.0 - replace query.page with query so users have access to term, page, etc.
                        var results = options.results(data, query.page);
                        query.callback(results);
                    }
                });
            }, quietMillis);
        };
    }

    /**
     * Produces a query function that works with a local array
     *
     * @param options object containing configuration parameters. The options parameter can either be an array or an
     * object.
     *
     * If the array form is used it is assumed that it contains objects with 'id' and 'text' keys.
     *
     * If the object form is used ti is assumed that it contains 'data' and 'text' keys. The 'data' key should contain
     * an array of objects that will be used as choices. These objects must contain at least an 'id' key. The 'text'
     * key can either be a String in which case it is expected that each element in the 'data' array has a key with the
     * value of 'text' which will be used to match choices. Alternatively, text can be a function(item) that can extract
     * the text.
     */
    function local(options) {
        var data = options, // data elements
            dataText,
            text = function (item) { return ""+item.text; }; // function used to retrieve the text portion of a data item that is matched against the search

        if (!$.isArray(data)) {
            text = data.text;
            // if text is not a function we assume it to be a key name
            if (!$.isFunction(text)) {
              dataText = data.text; // we need to store this in a separate variable because in the next step data gets reset and data.text is no longer available
              text = function (item) { return item[dataText]; };
            }
            data = data.results;
        }

        return function (query) {
            var t = query.term, filtered = { results: [] }, process;
            if (t === "") {
                query.callback({results: data});
                return;
            }

            process = function(datum, collection) {
                var group, attr;
                datum = datum[0];
                if (datum.children) {
                    group = {};
                    for (attr in datum) {
                        if (datum.hasOwnProperty(attr)) group[attr]=datum[attr];
                    }
                    group.children=[];
                    $(datum.children).each2(function(i, childDatum) { process(childDatum, group.children); });
                    if (group.children.length) {
                        collection.push(group);
                    }
                } else {
                    if (query.matcher(t, text(datum))) {
                        collection.push(datum);
                    }
                }
            };

            $(data).each2(function(i, datum) { process(datum, filtered.results); });
            query.callback(filtered);
        };
    }

    // TODO javadoc
    function tags(data) {
        // TODO even for a function we should probably return a wrapper that does the same object/string check as
        // the function for arrays. otherwise only functions that return objects are supported.
        if ($.isFunction(data)) {
            return data;
        }

        // if not a function we assume it to be an array

        return function (query) {
            var t = query.term, filtered = {results: []};
            $(data).each(function () {
                var isObject = this.text !== undefined,
                    text = isObject ? this.text : this;
                if (t === "" || query.matcher(t, text)) {
                    filtered.results.push(isObject ? this : {id: this, text: this});
                }
            });
            query.callback(filtered);
        };
    }

    /**
     * Checks if the formatter function should be used.
     *
     * Throws an error if it is not a function. Returns true if it should be used,
     * false if no formatting should be performed.
     *
     * @param formatter
     */
    function checkFormatter(formatter, formatterName) {
        if ($.isFunction(formatter)) return true;
        if (!formatter) return false;
        throw new Error("formatterName must be a function or a falsy value");
    }

    function evaluate(val) {
        return $.isFunction(val) ? val() : val;
    }

    function countResults(results) {
        var count = 0;
        $.each(results, function(i, item) {
            if (item.children) {
                count += countResults(item.children);
            } else {
                count++;
            }
        });
        return count;
    }

    /**
     * Default tokenizer. This function uses breaks the input on substring match of any string from the
     * opts.tokenSeparators array and uses opts.createSearchChoice to create the choice object. Both of those
     * two options have to be defined in order for the tokenizer to work.
     *
     * @param input text user has typed so far or pasted into the search field
     * @param selection currently selected choices
     * @param selectCallback function(choice) callback tho add the choice to selection
     * @param opts select2's opts
     * @return undefined/null to leave the current input unchanged, or a string to change the input to the returned value
     */
    function defaultTokenizer(input, selection, selectCallback, opts) {
        var original = input, // store the original so we can compare and know if we need to tell the search to update its text
            dupe = false, // check for whether a token we extracted represents a duplicate selected choice
            token, // token
            index, // position at which the separator was found
            i, l, // looping variables
            separator; // the matched separator

        if (!opts.createSearchChoice || !opts.tokenSeparators || opts.tokenSeparators.length < 1) return undefined;

        while (true) {
            index = -1;

            for (i = 0, l = opts.tokenSeparators.length; i < l; i++) {
                separator = opts.tokenSeparators[i];
                index = input.indexOf(separator);
                if (index >= 0) break;
            }

            if (index < 0) break; // did not find any token separator in the input string, bail

            token = input.substring(0, index);
            input = input.substring(index + separator.length);

            if (token.length > 0) {
                token = opts.createSearchChoice(token, selection);
                if (token !== undefined && token !== null && opts.id(token) !== undefined && opts.id(token) !== null) {
                    dupe = false;
                    for (i = 0, l = selection.length; i < l; i++) {
                        if (equal(opts.id(token), opts.id(selection[i]))) {
                            dupe = true; break;
                        }
                    }

                    if (!dupe) selectCallback(token);
                }
            }
        }

        if (original.localeCompare(input) != 0) return input;
    }

    /**
     * blurs any Select2 container that has focus when an element outside them was clicked or received focus
     *
     * also takes care of clicks on label tags that point to the source element
     */
    $(document).ready(function () {
        $(document).delegate("body", "mousedown touchend", function (e) {
            var target = $(e.target).closest("div.select2-container").get(0), attr;
            if (target) {
                $(document).find("div.select2-container-active").each(function () {
                    if (this !== target) $(this).data("select2").blur();
                });
            } else {
                target = $(e.target).closest("div.select2-drop").get(0);
                $(document).find("div.select2-drop-active").each(function () {
                    if (this !== target) $(this).data("select2").blur();
                });
            }

            target=$(e.target);
            attr = target.attr("for");
            if ("LABEL" === e.target.tagName && attr && attr.length > 0) {
                target = $("#"+attr);
                target = target.data("select2");
                if (target !== undefined) { target.focus(); e.preventDefault();}
            }
        });
    });

    /**
     * Creates a new class
     *
     * @param superClass
     * @param methods
     */
    function clazz(SuperClass, methods) {
        var constructor = function () {};
        constructor.prototype = new SuperClass;
        constructor.prototype.constructor = constructor;
        constructor.prototype.parent = SuperClass.prototype;
        constructor.prototype = $.extend(constructor.prototype, methods);
        return constructor;
    }

    AbstractSelect2 = clazz(Object, {

        // abstract
        bind: function (func) {
            var self = this;
            return function () {
                func.apply(self, arguments);
            };
        },

        // abstract
        init: function (opts) {
            var results, search, resultsSelector = ".select2-results";

            // prepare options
            this.opts = opts = this.prepareOpts(opts);

            this.id=opts.id;

            // destroy if called on an existing component
            if (opts.element.data("select2") !== undefined &&
                opts.element.data("select2") !== null) {
                this.destroy();
            }

            this.enabled=true;
            this.container = this.createContainer();

            this.containerId="s2id_"+(opts.element.attr("id") || "autogen"+nextUid());
            this.containerSelector="#"+this.containerId.replace(/([;&,\.\+\*\~':"\!\^#$%@\[\]\(\)=>\|])/g, '\\$1');
            this.container.attr("id", this.containerId);

            // cache the body so future lookups are cheap
            this.body = thunk(function() { return opts.element.closest("body"); });

            if (opts.element.attr("class") !== undefined) {
                this.container.addClass(opts.element.attr("class").replace(/validate\[[\S ]+] ?/, ''));
            }

            this.container.css(evaluate(opts.containerCss));
            this.container.addClass(evaluate(opts.containerCssClass));

            // swap container for the element
            this.opts.element
                .data("select2", this)
                .hide()
                .before(this.container);
            this.container.data("select2", this);

            this.dropdown = this.container.find(".select2-drop");
            this.dropdown.addClass(evaluate(opts.dropdownCssClass));
            this.dropdown.data("select2", this);

            this.results = results = this.container.find(resultsSelector);
            this.search = search = this.container.find("input.select2-input");

            search.attr("tabIndex", this.opts.element.attr("tabIndex"));

            this.resultsPage = 0;
            this.context = null;

            // initialize the container
            this.initContainer();
            this.initContainerWidth();

            installFilteredMouseMove(this.results);
            this.dropdown.delegate(resultsSelector, "mousemove-filtered", this.bind(this.highlightUnderEvent));

            installDebouncedScroll(80, this.results);
            this.dropdown.delegate(resultsSelector, "scroll-debounced", this.bind(this.loadMoreIfNeeded));

            // if jquery.mousewheel plugin is installed we can prevent out-of-bounds scrolling of results via mousewheel
            if ($.fn.mousewheel) {
                results.mousewheel(function (e, delta, deltaX, deltaY) {
                    var top = results.scrollTop(), height;
                    if (deltaY > 0 && top - deltaY <= 0) {
                        results.scrollTop(0);
                        killEvent(e);
                    } else if (deltaY < 0 && results.get(0).scrollHeight - results.scrollTop() + deltaY <= results.height()) {
                        results.scrollTop(results.get(0).scrollHeight - results.height());
                        killEvent(e);
                    }
                });
            }

            installKeyUpChangeEvent(search);
            search.bind("keyup-change", this.bind(this.updateResults));
            search.bind("focus", function () { search.addClass("select2-focused"); if (search.val() === " ") search.val(""); });
            search.bind("blur", function () { search.removeClass("select2-focused");});

            this.dropdown.delegate(resultsSelector, "mouseup", this.bind(function (e) {
                if ($(e.target).closest(".select2-result-selectable:not(.select2-disabled)").length > 0) {
                    this.highlightUnderEvent(e);
                    this.selectHighlighted(e);
                } else {
                    this.focusSearch();
                }
                killEvent(e);
            }));

            // trap all mouse events from leaving the dropdown. sometimes there may be a modal that is listening
            // for mouse events outside of itself so it can close itself. since the dropdown is now outside the select2's
            // dom it will trigger the popup close, which is not what we want
            this.dropdown.bind("click mouseup mousedown", function (e) { e.stopPropagation(); });

            if ($.isFunction(this.opts.initSelection)) {
                // initialize selection based on the current value of the source element
                this.initSelection();

                // if the user has provided a function that can set selection based on the value of the source element
                // we monitor the change event on the element and trigger it, allowing for two way synchronization
                this.monitorSource();
            }

            if (opts.element.is(":disabled") || opts.element.is("[readonly='readonly']")) this.disable();
        },

        // abstract
        destroy: function () {
            var select2 = this.opts.element.data("select2");
            if (select2 !== undefined) {
                select2.container.remove();
                select2.dropdown.remove();
                select2.opts.element
                    .removeData("select2")
                    .unbind(".select2")
                    .show();
            }
        },

        // abstract
        prepareOpts: function (opts) {
            var element, select, idKey, ajaxUrl;

            element = opts.element;

            if (element.get(0).tagName.toLowerCase() === "select") {
                this.select = select = opts.element;
            }

            if (select) {
                // these options are not allowed when attached to a select because they are picked up off the element itself
                $.each(["id", "multiple", "ajax", "query", "createSearchChoice", "initSelection", "data", "tags"], function () {
                    if (this in opts) {
                        throw new Error("Option '" + this + "' is not allowed for Select2 when attached to a <select> element.");
                    }
                });
            }

            opts = $.extend({}, {
                populateResults: function(container, results, query) {
                    var populate,  data, result, children, id=this.opts.id, self=this;

                    populate=function(results, container, depth) {

                        var i, l, result, selectable, compound, node, label, innerContainer, formatted;
                        for (i = 0, l = results.length; i < l; i = i + 1) {

                            result=results[i];
                            selectable=id(result) !== undefined;
                            compound=result.children && result.children.length > 0;

                            node=$("<li></li>");
                            node.addClass("select2-results-dept-"+depth);
                            node.addClass("select2-result");
                            node.addClass(selectable ? "select2-result-selectable" : "select2-result-unselectable");
                            if (compound) { node.addClass("select2-result-with-children"); }
                            node.addClass(self.opts.formatResultCssClass(result));

                            label=$("<div></div>");
                            label.addClass("select2-result-label");

                            formatted=opts.formatResult(result, label, query);
                            if (formatted!==undefined) {
                                label.html(self.opts.escapeMarkup(formatted));
                            }

                            node.append(label);

                            if (compound) {

                                innerContainer=$("<ul></ul>");
                                innerContainer.addClass("select2-result-sub");
                                populate(result.children, innerContainer, depth+1);
                                node.append(innerContainer);
                            }

                            node.data("select2-data", result);
                            container.append(node);
                        }
                    };

                    populate(results, container, 0);
                }
            }, $.fn.select2.defaults, opts);

            if (typeof(opts.id) !== "function") {
                idKey = opts.id;
                opts.id = function (e) { return e[idKey]; };
            }

            if (select) {
                opts.query = this.bind(function (query) {
                    var data = { results: [], more: false },
                        term = query.term,
                        children, firstChild, process;

                    process=function(element, collection) {
                        var group;
                        if (element.is("option")) {
                            if (query.matcher(term, element.text(), element)) {
                                collection.push({id:element.attr("value"), text:element.text(), element: element.get(), css: element.attr("class")});
                            }
                        } else if (element.is("optgroup")) {
                            group={text:element.attr("label"), children:[], element: element.get(), css: element.attr("class")};
                            element.children().each2(function(i, elm) { process(elm, group.children); });
                            if (group.children.length>0) {
                                collection.push(group);
                            }
                        }
                    };

                    children=element.children();

                    // ignore the placeholder option if there is one
                    if (this.getPlaceholder() !== undefined && children.length > 0) {
                        firstChild = children[0];
                        if ($(firstChild).text() === "") {
                            children=children.not(firstChild);
                        }
                    }

                    children.each2(function(i, elm) { process(elm, data.results); });

                    query.callback(data);
                });
                // this is needed because inside val() we construct choices from options and there id is hardcoded
                opts.id=function(e) { return e.id; };
                opts.formatResultCssClass = function(data) { return data.css; }
            } else {
                if (!("query" in opts)) {
                    if ("ajax" in opts) {
                        ajaxUrl = opts.element.data("ajax-url");
                        if (ajaxUrl && ajaxUrl.length > 0) {
                            opts.ajax.url = ajaxUrl;
                        }
                        opts.query = ajax(opts.ajax);
                    } else if ("data" in opts) {
                        opts.query = local(opts.data);
                    } else if ("tags" in opts) {
                        opts.query = tags(opts.tags);
                        opts.createSearchChoice = function (term) { return {id: term, text: term}; };
                        opts.initSelection = function (element, callback) {
                            var data = [];
                            $(splitVal(element.val(), opts.separator)).each(function () {
                                var id = this, text = this, tags=opts.tags;
                                if ($.isFunction(tags)) tags=tags();
                                $(tags).each(function() { if (equal(this.id, id)) { text = this.text; return false; } });
                                data.push({id: id, text: text});
                            });

                            callback(data);
                        };
                    }
                }
            }
            if (typeof(opts.query) !== "function") {
                throw "query function not defined for Select2 " + opts.element.attr("id");
            }

            return opts;
        },

        /**
         * Monitor the original element for changes and update select2 accordingly
         */
        // abstract
        monitorSource: function () {
            this.opts.element.bind("change.select2", this.bind(function (e) {
                if (this.opts.element.data("select2-change-triggered") !== true) {
                    this.initSelection();
                }
            }));
        },

        /**
         * Triggers the change event on the source element
         */
        // abstract
        triggerChange: function (details) {

            details = details || {};
            details= $.extend({}, details, { type: "change", val: this.val() });
            // prevents recursive triggering
            this.opts.element.data("select2-change-triggered", true);
            this.opts.element.trigger(details);
            this.opts.element.data("select2-change-triggered", false);

            // some validation frameworks ignore the change event and listen instead to keyup, click for selects
            // so here we trigger the click event manually
            this.opts.element.click();

            // ValidationEngine ignorea the change event and listens instead to blur
            // so here we trigger the blur event manually if so desired
            if (this.opts.blurOnChange)
                this.opts.element.blur();
        },


        // abstract
        enable: function() {
            if (this.enabled) return;

            this.enabled=true;
            this.container.removeClass("select2-container-disabled");
        },

        // abstract
        disable: function() {
            if (!this.enabled) return;

            this.close();

            this.enabled=false;
            this.container.addClass("select2-container-disabled");
        },

        // abstract
        opened: function () {
            return this.container.hasClass("select2-dropdown-open");
        },

        // abstract
        positionDropdown: function() {
            var offset = this.container.offset(),
                height = this.container.outerHeight(),
                width = this.container.outerWidth(),
                dropHeight = this.dropdown.outerHeight(),
                viewportBottom = $(window).scrollTop() + document.documentElement.clientHeight,
                dropTop = offset.top + height,
                dropLeft = offset.left,
                enoughRoomBelow = dropTop + dropHeight <= viewportBottom,
                enoughRoomAbove = (offset.top - dropHeight) >= this.body().scrollTop(),
                aboveNow = this.dropdown.hasClass("select2-drop-above"),
                bodyOffset,
                above,
                css;

            // console.log("below/ droptop:", dropTop, "dropHeight", dropHeight, "sum", (dropTop+dropHeight)+" viewport bottom", viewportBottom, "enough?", enoughRoomBelow);
            // console.log("above/ offset.top", offset.top, "dropHeight", dropHeight, "top", (offset.top-dropHeight), "scrollTop", this.body().scrollTop(), "enough?", enoughRoomAbove);

            // fix positioning when body has an offset and is not position: static

            if (this.body().css('position') !== 'static') {
                bodyOffset = this.body().offset();
                dropTop -= bodyOffset.top;
                dropLeft -= bodyOffset.left;
            }

            // always prefer the current above/below alignment, unless there is not enough room

            if (aboveNow) {
                above = true;
                if (!enoughRoomAbove && enoughRoomBelow) above = false;
            } else {
                above = false;
                if (!enoughRoomBelow && enoughRoomAbove) above = true;
            }

            if (above) {
                dropTop = offset.top - dropHeight;
                this.container.addClass("select2-drop-above");
                this.dropdown.addClass("select2-drop-above");
            }
            else {
                this.container.removeClass("select2-drop-above");
                this.dropdown.removeClass("select2-drop-above");
            }

            css = $.extend({
                top: dropTop,
                left: dropLeft,
                width: width
            }, evaluate(this.opts.dropdownCss));

            this.dropdown.css(css);
        },

        // abstract
        shouldOpen: function() {
            var event;

            if (this.opened()) return false;

            event = $.Event("open");
            this.opts.element.trigger(event);
            return !event.isDefaultPrevented();
        },

        // abstract
        clearDropdownAlignmentPreference: function() {
            // clear the classes used to figure out the preference of where the dropdown should be opened
            this.container.removeClass("select2-drop-above");
            this.dropdown.removeClass("select2-drop-above");
        },

        /**
         * Opens the dropdown
         *
         * @return {Boolean} whether or not dropdown was opened. This method will return false if, for example,
         * the dropdown is already open, or if the 'open' event listener on the element called preventDefault().
         */
        // abstract
        open: function () {

            if (!this.shouldOpen()) return false;

            window.setTimeout(this.bind(this.opening), 1);

            return true;
        },

        /**
         * Performs the opening of the dropdown
         */
        // abstract
        opening: function() {
            var cid = this.containerId, selector = this.containerSelector,
                scroll = "scroll." + cid, resize = "resize." + cid;

            this.container.parents().each(function() {
                $(this).bind(scroll, function() {
                    var s2 = $(selector);
                    if (s2.length == 0) {
                        $(this).unbind(scroll);
                    }
                    s2.select2("close");
                });
            });

            $(window).bind(resize, function() {
                var s2 = $(selector);
                if (s2.length == 0) {
                    $(window).unbind(resize);
                }
                s2.select2("close");
            });

            this.clearDropdownAlignmentPreference();

            if (this.search.val() === " ") { this.search.val(""); }

            this.container.addClass("select2-dropdown-open").addClass("select2-container-active");

            this.updateResults(true);

            if(this.dropdown[0] !== this.body().children().last()[0]) {
                this.dropdown.detach().appendTo(this.body());
            }

            this.dropdown.show();

            this.positionDropdown();
            this.dropdown.addClass("select2-drop-active");

            this.ensureHighlightVisible();

            this.focusSearch();
        },

        // abstract
        close: function () {
            if (!this.opened()) return;

            var self = this;

            this.container.parents().each(function() {
                $(this).unbind("scroll." + self.containerId);
            });
            $(window).unbind("resize." + this.containerId);

            this.clearDropdownAlignmentPreference();

            this.dropdown.hide();
            this.container.removeClass("select2-dropdown-open").removeClass("select2-container-active");
            this.results.empty();
            this.clearSearch();

            this.opts.element.trigger($.Event("close"));
        },

        // abstract
        clearSearch: function () {

        },

        // abstract
        ensureHighlightVisible: function () {
            var results = this.results, children, index, child, hb, rb, y, more;

            index = this.highlight();

            if (index < 0) return;

            if (index == 0) {

                // if the first element is highlighted scroll all the way to the top,
                // that way any unselectable headers above it will also be scrolled
                // into view

                results.scrollTop(0);
                return;
            }

            children = results.find(".select2-result-selectable");

            child = $(children[index]);

            hb = child.offset().top + child.outerHeight();

            // if this is the last child lets also make sure select2-more-results is visible
            if (index === children.length - 1) {
                more = results.find("li.select2-more-results");
                if (more.length > 0) {
                    hb = more.offset().top + more.outerHeight();
                }
            }

            rb = results.offset().top + results.outerHeight();
            if (hb > rb) {
                results.scrollTop(results.scrollTop() + (hb - rb));
            }
            y = child.offset().top - results.offset().top;

            // make sure the top of the element is visible
            if (y < 0) {
                results.scrollTop(results.scrollTop() + y); // y is negative
            }
        },

        // abstract
        moveHighlight: function (delta) {
            var choices = this.results.find(".select2-result-selectable"),
                index = this.highlight();

            while (index > -1 && index < choices.length) {
                index += delta;
                var choice = $(choices[index]);
                if (choice.hasClass("select2-result-selectable") && !choice.hasClass("select2-disabled")) {
                    this.highlight(index);
                    break;
                }
            }
        },

        // abstract
        highlight: function (index) {
            var choices = this.results.find(".select2-result-selectable").not(".select2-disabled");

            if (arguments.length === 0) {
                return indexOf(choices.filter(".select2-highlighted")[0], choices.get());
            }

            if (index >= choices.length) index = choices.length - 1;
            if (index < 0) index = 0;

            choices.removeClass("select2-highlighted");

            $(choices[index]).addClass("select2-highlighted");
            this.ensureHighlightVisible();

        },

        // abstract
        countSelectableResults: function() {
            return this.results.find(".select2-result-selectable").not(".select2-disabled").length;
        },

        // abstract
        highlightUnderEvent: function (event) {
            var el = $(event.target).closest(".select2-result-selectable");
            if (el.length > 0 && !el.is(".select2-highlighted")) {
        		var choices = this.results.find('.select2-result-selectable');
                this.highlight(choices.index(el));
            } else if (el.length == 0) {
                // if we are over an unselectable item remove al highlights
                this.results.find(".select2-highlighted").removeClass("select2-highlighted");
            }
        },

        // abstract
        loadMoreIfNeeded: function () {
            var results = this.results,
                more = results.find("li.select2-more-results"),
                below, // pixels the element is below the scroll fold, below==0 is when the element is starting to be visible
                offset = -1, // index of first element without data
                page = this.resultsPage + 1,
                self=this,
                term=this.search.val(),
                context=this.context;

            if (more.length === 0) return;
            below = more.offset().top - results.offset().top - results.height();

            if (below <= 0) {
                more.addClass("select2-active");
                this.opts.query({
                        term: term,
                        page: page,
                        context: context,
                        matcher: this.opts.matcher,
                        callback: this.bind(function (data) {

                    // ignore a response if the select2 has been closed before it was received
                    if (!self.opened()) return;


                    self.opts.populateResults.call(this, results, data.results, {term: term, page: page, context:context});

                    if (data.more===true) {
                        more.detach().appendTo(results).text(self.opts.formatLoadMore(page+1));
                        window.setTimeout(function() { self.loadMoreIfNeeded(); }, 10);
                    } else {
                        more.remove();
                    }
                    self.positionDropdown();
                    self.resultsPage = page;
                })});
            }
        },

        /**
         * Default tokenizer function which does nothing
         */
        tokenize: function() {

        },

        /**
         * @param initial whether or not this is the call to this method right after the dropdown has been opened
         */
        // abstract
        updateResults: function (initial) {
            var search = this.search, results = this.results, opts = this.opts, data, self=this, input;

            // if the search is currently hidden we do not alter the results
            if (initial !== true && (this.showSearchInput === false || !this.opened())) {
                return;
            }

            search.addClass("select2-active");

            function postRender() {
                results.scrollTop(0);
                search.removeClass("select2-active");
                self.positionDropdown();
            }

            function render(html) {
                results.html(self.opts.escapeMarkup(html));
                postRender();
            }

            if (opts.maximumSelectionSize >=1) {
                data = this.data();
                if ($.isArray(data) && data.length >= opts.maximumSelectionSize && checkFormatter(opts.formatSelectionTooBig, "formatSelectionTooBig")) {
            	    render("<li class='select2-selection-limit'>" + opts.formatSelectionTooBig(opts.maximumSelectionSize) + "</li>");
            	    return;
                }
            }

            if (search.val().length < opts.minimumInputLength && checkFormatter(opts.formatInputTooShort, "formatInputTooShort")) {
                render("<li class='select2-no-results'>" + opts.formatInputTooShort(search.val(), opts.minimumInputLength) + "</li>");
                return;
            }
            else {
                render("<li class='select2-searching'>" + opts.formatSearching() + "</li>");
            }

            // give the tokenizer a chance to pre-process the input
            input = this.tokenize();
            if (input != undefined && input != null) {
                search.val(input);
            }

            this.resultsPage = 1;
            opts.query({
                    term: search.val(),
                    page: this.resultsPage,
                    context: null,
                    matcher: opts.matcher,
                    callback: this.bind(function (data) {
                var def; // default choice

                // ignore a response if the select2 has been closed before it was received
                if (!this.opened()) return;

                // save context, if any
                this.context = (data.context===undefined) ? null : data.context;

                // create a default choice and prepend it to the list
                if (this.opts.createSearchChoice && search.val() !== "") {
                    def = this.opts.createSearchChoice.call(null, search.val(), data.results);
                    if (def !== undefined && def !== null && self.id(def) !== undefined && self.id(def) !== null) {
                        if ($(data.results).filter(
                            function () {
                                return equal(self.id(this), self.id(def));
                            }).length === 0) {
                            data.results.unshift(def);
                        }
                    }
                }

                if (data.results.length === 0 && checkFormatter(opts.formatNoMatches, "formatNoMatches")) {
                    render("<li class='select2-no-results'>" + opts.formatNoMatches(search.val()) + "</li>");
                    return;
                }

                results.empty();
                self.opts.populateResults.call(this, results, data.results, {term: search.val(), page: this.resultsPage, context:null});

                if (data.more === true && checkFormatter(opts.formatLoadMore, "formatLoadMore")) {
                    results.append("<li class='select2-more-results'>" + self.opts.escapeMarkup(opts.formatLoadMore(this.resultsPage)) + "</li>");
                    window.setTimeout(function() { self.loadMoreIfNeeded(); }, 10);
                }

                this.postprocessResults(data, initial);

                postRender();
            })});
        },

        // abstract
        cancel: function () {
            this.close();
        },

        // abstract
        blur: function () {
            this.close();
            this.container.removeClass("select2-container-active");
            this.dropdown.removeClass("select2-drop-active");
            // synonymous to .is(':focus'), which is available in jquery >= 1.6
            if (this.search[0] === document.activeElement) { this.search.blur(); }
            this.clearSearch();
            this.selection.find(".select2-search-choice-focus").removeClass("select2-search-choice-focus");
        },

        // abstract
        focusSearch: function () {
            // need to do it here as well as in timeout so it works in IE
            this.search.show();
            this.search.focus();

            /* we do this in a timeout so that current event processing can complete before this code is executed.
             this makes sure the search field is focussed even if the current event would blur it */
            window.setTimeout(this.bind(function () {
                // reset the value so IE places the cursor at the end of the input box
                this.search.show();
                this.search.focus();
                this.search.val(this.search.val());
            }), 10);
        },

        // abstract
        selectHighlighted: function () {
            var index=this.highlight(),
                highlighted=this.results.find(".select2-highlighted").not(".select2-disabled"),
                data = highlighted.closest('.select2-result-selectable').data("select2-data");
            if (data) {
                highlighted.addClass("select2-disabled");
                this.highlight(index);
                this.onSelect(data);
            }
        },

        // abstract
        getPlaceholder: function () {
            return this.opts.element.attr("placeholder") ||
                this.opts.element.attr("data-placeholder") || // jquery 1.4 compat
                this.opts.element.data("placeholder") ||
                this.opts.placeholder;
        },

        /**
         * Get the desired width for the container element.  This is
         * derived first from option `width` passed to select2, then
         * the inline 'style' on the original element, and finally
         * falls back to the jQuery calculated element width.
         */
        // abstract
        initContainerWidth: function () {
            function resolveContainerWidth() {
                var style, attrs, matches, i, l;

                if (this.opts.width === "off") {
                    return null;
                } else if (this.opts.width === "element"){
                    return this.opts.element.outerWidth() === 0 ? 'auto' : this.opts.element.outerWidth() + 'px';
                } else if (this.opts.width === "copy" || this.opts.width === "resolve") {
                    // check if there is inline style on the element that contains width
                    style = this.opts.element.attr('style');
                    if (style !== undefined) {
                        attrs = style.split(';');
                        for (i = 0, l = attrs.length; i < l; i = i + 1) {
                            matches = attrs[i].replace(/\s/g, '')
                                .match(/width:(([-+]?([0-9]*\.)?[0-9]+)(px|em|ex|%|in|cm|mm|pt|pc))/);
                            if (matches !== null && matches.length >= 1)
                                return matches[1];
                        }
                    }

                    if (this.opts.width === "resolve") {
                        // next check if css('width') can resolve a width that is percent based, this is sometimes possible
                        // when attached to input type=hidden or elements hidden via css
                        style = this.opts.element.css('width');
                        if (style.indexOf("%") > 0) return style;

                        // finally, fallback on the calculated width of the element
                        return (this.opts.element.outerWidth() === 0 ? 'auto' : this.opts.element.outerWidth() + 'px');
                    }

                    return null;
                } else if ($.isFunction(this.opts.width)) {
                    return this.opts.width();
                } else {
                    return this.opts.width;
               }
            };

            var width = resolveContainerWidth.call(this);
            if (width !== null) {
                this.container.attr("style", "width: "+width);
            }
        }
    });

    SingleSelect2 = clazz(AbstractSelect2, {

        // single

		createContainer: function () {
            var container = $("<div></div>", {
                "class": "select2-container"
            }).html([
                "    <a href='#' onclick='return false;' class='select2-choice'>",
                "   <span></span><abbr class='select2-search-choice-close' style='display:none;'></abbr>",
                "   <div><b></b></div>" ,
                "</a>",
                "    <div class='select2-drop select2-offscreen'>" ,
                "   <div class='select2-search'>" ,
                "       <input type='text' autocomplete='off' class='select2-input'/>" ,
                "   </div>" ,
                "   <ul class='select2-results'>" ,
                "   </ul>" ,
                "</div>"].join(""));
            return container;
        },

        // single
        opening: function () {
            this.search.show();
            this.parent.opening.apply(this, arguments);
            this.dropdown.removeClass("select2-offscreen");
        },

        // single
        close: function () {
            if (!this.opened()) return;
            this.parent.close.apply(this, arguments);
            this.dropdown.removeAttr("style").addClass("select2-offscreen").insertAfter(this.selection).show();
        },

        // single
        focus: function () {
            this.close();
            this.selection.focus();
        },

        // single
        isFocused: function () {
            return this.selection[0] === document.activeElement;
        },

        // single
        cancel: function () {
            this.parent.cancel.apply(this, arguments);
            this.selection.focus();
        },

        // single
        initContainer: function () {

            var selection,
                container = this.container,
                dropdown = this.dropdown,
                clickingInside = false;

            this.selection = selection = container.find(".select2-choice");

            this.search.bind("keydown", this.bind(function (e) {
                if (!this.enabled) return;

                if (e.which === KEY.PAGE_UP || e.which === KEY.PAGE_DOWN) {
                    // prevent the page from scrolling
                    killEvent(e);
                    return;
                }

                if (this.opened()) {
                    switch (e.which) {
                        case KEY.UP:
                        case KEY.DOWN:
                            this.moveHighlight((e.which === KEY.UP) ? -1 : 1);
                            killEvent(e);
                            return;
                        case KEY.TAB:
                        case KEY.ENTER:
                            this.selectHighlighted();
                            killEvent(e);
                            return;
                        case KEY.ESC:
                            this.cancel(e);
                            killEvent(e);
                            return;
                    }
                } else {

                    if (e.which === KEY.TAB || KEY.isControl(e) || KEY.isFunctionKey(e) || e.which === KEY.ESC) {
                        return;
                    }

                    if (this.opts.openOnEnter === false && e.which === KEY.ENTER) {
                        return;
                    }

                    this.open();

                    if (e.which === KEY.ENTER) {
                        // do not propagate the event otherwise we open, and propagate enter which closes
                        return;
                    }
                }
            }));

            this.search.bind("focus", this.bind(function() {
                this.selection.attr("tabIndex", "-1");
            }));
            this.search.bind("blur", this.bind(function() {
                if (!this.opened()) this.container.removeClass("select2-container-active");
                window.setTimeout(this.bind(function() { this.selection.attr("tabIndex", this.opts.element.attr("tabIndex")); }), 10);
            }));

            selection.bind("mousedown", this.bind(function (e) {
                clickingInside = true;

                if (this.opened()) {
                    this.close();
                    this.selection.focus();
                } else if (this.enabled) {
                    this.open();
                }

                clickingInside = false;
            }));

            dropdown.bind("mousedown", this.bind(function() { this.search.focus(); }));

            selection.bind("focus", this.bind(function() {
                this.container.addClass("select2-container-active");
                // hide the search so the tab key does not focus on it
                this.search.attr("tabIndex", "-1");
            }));

            selection.bind("blur", this.bind(function() {
                if (!this.opened()) {
                    this.container.removeClass("select2-container-active");
                }
                window.setTimeout(this.bind(function() { this.search.attr("tabIndex", this.opts.element.attr("tabIndex")); }), 10);
            }));

            selection.bind("keydown", this.bind(function(e) {
                if (!this.enabled) return;

                if (e.which === KEY.PAGE_UP || e.which === KEY.PAGE_DOWN) {
                    // prevent the page from scrolling
                    killEvent(e);
                    return;
                }

                if (e.which === KEY.TAB || KEY.isControl(e) || KEY.isFunctionKey(e)
                 || e.which === KEY.ESC) {
                    return;
                }

                if (this.opts.openOnEnter === false && e.which === KEY.ENTER) {
                    return;
                }

                if (e.which == KEY.DELETE) {
                    if (this.opts.allowClear) {
                        this.clear();
                    }
                    return;
                }

                this.open();

                if (e.which === KEY.ENTER) {
                    // do not propagate the event otherwise we open, and propagate enter which closes
                    killEvent(e);
                    return;
                }

                // do not set the search input value for non-alpha-numeric keys
                // otherwise pressing down results in a '(' being set in the search field
                if (e.which < 48 ) { // '0' == 48
                    killEvent(e);
                    return;
                }

                var keyWritten = String.fromCharCode(e.which).toLowerCase();

                if (e.shiftKey) {
                    keyWritten = keyWritten.toUpperCase();
                }

                // focus the field before calling val so the cursor ends up after the value instead of before
                this.search.focus();
                this.search.val(keyWritten);

                // prevent event propagation so it doesnt replay on the now focussed search field and result in double key entry
                killEvent(e);
            }));

            selection.delegate("abbr", "mousedown", this.bind(function (e) {
                if (!this.enabled) return;
                this.clear();
                killEvent(e);
                this.close();
                this.triggerChange();
                this.selection.focus();
            }));

            this.setPlaceholder();

            this.search.bind("focus", this.bind(function() {
                this.container.addClass("select2-container-active");
            }));
        },

        // single
        clear: function() {
            this.opts.element.val("");
            this.selection.find("span").empty();
            this.selection.removeData("select2-data");
            this.setPlaceholder();
        },

        /**
         * Sets selection based on source element's value
         */
        // single
        initSelection: function () {
            var selected;
            if (this.opts.element.val() === "") {
                this.close();
                this.setPlaceholder();
            } else {
                var self = this;
                this.opts.initSelection.call(null, this.opts.element, function(selected){
                    if (selected !== undefined && selected !== null) {
                        self.updateSelection(selected);
                        self.close();
                        self.setPlaceholder();
                    }
                });
            }
        },

        // single
        prepareOpts: function () {
            var opts = this.parent.prepareOpts.apply(this, arguments);

            if (opts.element.get(0).tagName.toLowerCase() === "select") {
                // install the selection initializer
                opts.initSelection = function (element, callback) {
                    var selected = element.find(":selected");
                    // a single select box always has a value, no need to null check 'selected'
                    if ($.isFunction(callback))
                        callback({id: selected.attr("value"), text: selected.text()});
                };
            }

            return opts;
        },

        // single
        setPlaceholder: function () {
            var placeholder = this.getPlaceholder();

            if (this.opts.element.val() === "" && placeholder !== undefined) {

                // check for a first blank option if attached to a select
                if (this.select && this.select.find("option:first").text() !== "") return;

                this.selection.find("span").html(this.opts.escapeMarkup(placeholder));

                this.selection.addClass("select2-default");

                this.selection.find("abbr").hide();
            }
        },

        // single
        postprocessResults: function (data, initial) {
            var selected = 0, self = this, showSearchInput = true;

            // find the selected element in the result list

            this.results.find(".select2-result-selectable").each2(function (i, elm) {
                if (equal(self.id(elm.data("select2-data")), self.opts.element.val())) {
                    selected = i;
                    return false;
                }
            });

            // and highlight it

            this.highlight(selected);

            // hide the search box if this is the first we got the results and there are a few of them

            if (initial === true) {
                showSearchInput = this.showSearchInput = countResults(data.results) >= this.opts.minimumResultsForSearch;
                this.dropdown.find(".select2-search")[showSearchInput ? "removeClass" : "addClass"]("select2-search-hidden");

                //add "select2-with-searchbox" to the container if search box is shown
                $(this.dropdown, this.container)[showSearchInput ? "addClass" : "removeClass"]("select2-with-searchbox");
            }

        },

        // single
        onSelect: function (data) {
            var old = this.opts.element.val();

            this.opts.element.val(this.id(data));
            this.updateSelection(data);
            this.close();
            this.selection.focus();

            if (!equal(old, this.id(data))) { this.triggerChange(); }
        },

        // single
        updateSelection: function (data) {

            var container=this.selection.find("span"), formatted;

            this.selection.data("select2-data", data);

            container.empty();
            formatted=this.opts.formatSelection(data, container);
            if (formatted !== undefined) {
                container.append(this.opts.escapeMarkup(formatted));
            }

            this.selection.removeClass("select2-default");

            if (this.opts.allowClear && this.getPlaceholder() !== undefined) {
                this.selection.find("abbr").show();
            }
        },

        // single
        val: function () {
            var val, data = null, self = this;

            if (arguments.length === 0) {
                return this.opts.element.val();
            }

            val = arguments[0];

            if (this.select) {
                this.select
                    .val(val)
                    .find(":selected").each2(function (i, elm) {
                        data = {id: elm.attr("value"), text: elm.text()};
                        return false;
                    });
                this.updateSelection(data);
                this.setPlaceholder();
            } else {
                if (this.opts.initSelection === undefined) {
                    throw new Error("cannot call val() if initSelection() is not defined");
                }
                // val is an id. !val is true for [undefined,null,'']
                if (!val) {
                    this.clear();
                    return;
                }
                this.opts.element.val(val);
                this.opts.initSelection(this.opts.element, function(data){
                    self.opts.element.val(!data ? "" : self.id(data));
                    self.updateSelection(data);
                    self.setPlaceholder();
                });
            }
        },

        // single
        clearSearch: function () {
            this.search.val("");
        },

        // single
        data: function(value) {
            var data;

            if (arguments.length === 0) {
                data = this.selection.data("select2-data");
                if (data == undefined) data = null;
                return data;
            } else {
                if (!value || value === "") {
                    this.clear();
                } else {
                    this.opts.element.val(!value ? "" : this.id(value));
                    this.updateSelection(value);
                }
            }
        }
    });

    MultiSelect2 = clazz(AbstractSelect2, {

        // multi
        createContainer: function () {
            var container = $("<div></div>", {
                "class": "select2-container select2-container-multi"
            }).html([
                "    <ul class='select2-choices'>",
                //"<li class='select2-search-choice'><span>California</span><a href="javascript:void(0)" class="select2-search-choice-close"></a></li>" ,
                "  <li class='select2-search-field'>" ,
                "    <input type='text' autocomplete='off' class='select2-input'>" ,
                "  </li>" ,
                "</ul>" ,
                "<div class='select2-drop select2-drop-multi' style='display:none;'>" ,
                "   <ul class='select2-results'>" ,
                "   </ul>" ,
                "</div>"].join(""));
			return container;
        },

        // multi
        prepareOpts: function () {
            var opts = this.parent.prepareOpts.apply(this, arguments);

            // TODO validate placeholder is a string if specified

            if (opts.element.get(0).tagName.toLowerCase() === "select") {
                // install sthe selection initializer
                opts.initSelection = function (element,callback) {

                    var data = [];
                    element.find(":selected").each2(function (i, elm) {
                        data.push({id: elm.attr("value"), text: elm.text()});
                    });

                    if ($.isFunction(callback))
                        callback(data);
                };
            }

            return opts;
        },

        // multi
        initContainer: function () {

            var selector = ".select2-choices", selection;

            this.searchContainer = this.container.find(".select2-search-field");
            this.selection = selection = this.container.find(selector);

            this.search.bind("keydown", this.bind(function (e) {
                if (!this.enabled) return;

                if (e.which === KEY.BACKSPACE && this.search.val() === "") {
                    this.close();

                    var choices,
                        selected = selection.find(".select2-search-choice-focus");
                    if (selected.length > 0) {
                        this.unselect(selected.first());
                        this.search.width(10);
                        killEvent(e);
                        return;
                    }

                    choices = selection.find(".select2-search-choice");
                    if (choices.length > 0) {
                        choices.last().addClass("select2-search-choice-focus");
                    }
                } else {
                    selection.find(".select2-search-choice-focus").removeClass("select2-search-choice-focus");
                }

                if (this.opened()) {
                    switch (e.which) {
                    case KEY.UP:
                    case KEY.DOWN:
                        this.moveHighlight((e.which === KEY.UP) ? -1 : 1);
                        killEvent(e);
                        return;
                    case KEY.ENTER:
                    case KEY.TAB:
                        this.selectHighlighted();
                        killEvent(e);
                        return;
                    case KEY.ESC:
                        this.cancel(e);
                        killEvent(e);
                        return;
                    }
                }

                if (e.which === KEY.TAB || KEY.isControl(e) || KEY.isFunctionKey(e)
                 || e.which === KEY.BACKSPACE || e.which === KEY.ESC) {
                    return;
                }

                if (this.opts.openOnEnter === false && e.which === KEY.ENTER) {
                    return;
                }

                this.open();

                if (e.which === KEY.PAGE_UP || e.which === KEY.PAGE_DOWN) {
                    // prevent the page from scrolling
                    killEvent(e);
                }
            }));

            this.search.bind("keyup", this.bind(this.resizeSearch));

            this.search.bind("blur", this.bind(function(e) {
                this.container.removeClass("select2-container-active");
                this.search.removeClass("select2-focused");
                this.clearSearch();
                e.stopImmediatePropagation();
            }));

            this.container.delegate(selector, "mousedown", this.bind(function (e) {
                if (!this.enabled) return;
                if ($(e.target).closest(".select2-search-choice").length > 0) {
                    // clicked inside a select2 search choice, do not open
                    return;
                }
                this.clearPlaceholder();
                this.open();
                this.focusSearch();
                e.preventDefault();
            }));

            this.container.delegate(selector, "focus", this.bind(function () {
                if (!this.enabled) return;
                this.container.addClass("select2-container-active");
                this.dropdown.addClass("select2-drop-active");
                this.clearPlaceholder();
            }));

            // set the placeholder if necessary
            this.clearSearch();
        },

        // multi
        enable: function() {
            if (this.enabled) return;

            this.parent.enable.apply(this, arguments);

            this.search.removeAttr("disabled");
        },

        // multi
        disable: function() {
            if (!this.enabled) return;

            this.parent.disable.apply(this, arguments);

            this.search.attr("disabled", true);
        },

        // multi
        initSelection: function () {
            var data;
            if (this.opts.element.val() === "") {
                this.updateSelection([]);
                this.close();
                // set the placeholder if necessary
                this.clearSearch();
            }
            if (this.select || this.opts.element.val() !== "") {
                var self = this;
                this.opts.initSelection.call(null, this.opts.element, function(data){
                    if (data !== undefined && data !== null) {
                        self.updateSelection(data);
                        self.close();
                        // set the placeholder if necessary
                        self.clearSearch();
                    }
                });
            }
        },

        // multi
        clearSearch: function () {
            var placeholder = this.getPlaceholder();

            if (placeholder !== undefined  && this.getVal().length === 0 && this.search.hasClass("select2-focused") === false) {
                this.search.val(placeholder).addClass("select2-default");
                // stretch the search box to full width of the container so as much of the placeholder is visible as possible
                this.resizeSearch();
            } else {
                // we set this to " " instead of "" and later clear it on focus() because there is a firefox bug
                // that does not properly render the caret when the field starts out blank
                this.search.val(" ").width(10);
            }
        },

        // multi
        clearPlaceholder: function () {
            if (this.search.hasClass("select2-default")) {
                this.search.val("").removeClass("select2-default");
            } else {
                // work around for the space character we set to avoid firefox caret bug
                if (this.search.val() === " ") this.search.val("");
            }
        },

        // multi
        opening: function () {
            this.parent.opening.apply(this, arguments);

            this.clearPlaceholder();
			this.resizeSearch();
            this.focusSearch();
        },

        // multi
        close: function () {
            if (!this.opened()) return;
            this.parent.close.apply(this, arguments);
        },

        // multi
        focus: function () {
            this.close();
            this.search.focus();
        },

        // multi
        isFocused: function () {
            return this.search.hasClass("select2-focused");
        },

        // multi
        updateSelection: function (data) {
            var ids = [], filtered = [], self = this;

            // filter out duplicates
            $(data).each(function () {
                if (indexOf(self.id(this), ids) < 0) {
                    ids.push(self.id(this));
                    filtered.push(this);
                }
            });
            data = filtered;

            this.selection.find(".select2-search-choice").remove();
            $(data).each(function () {
                self.addSelectedChoice(this);
            });
            self.postprocessResults();
        },

        tokenize: function() {
            var input = this.search.val();
            input = this.opts.tokenizer(input, this.data(), this.bind(this.onSelect), this.opts);
            if (input != null && input != undefined) {
                this.search.val(input);
                if (input.length > 0) {
                    this.open();
                }
            }

        },

        // multi
        onSelect: function (data) {
            this.addSelectedChoice(data);
            if (this.select) { this.postprocessResults(); }

            if (this.opts.closeOnSelect) {
                this.close();
                this.search.width(10);
            } else {
                if (this.countSelectableResults()>0) {
                    this.search.width(10);
                    this.resizeSearch();
                    this.positionDropdown();
                } else {
                    // if nothing left to select close
                    this.close();
                }
            }

            // since its not possible to select an element that has already been
            // added we do not need to check if this is a new element before firing change
            this.triggerChange({ added: data });

            this.focusSearch();
        },

        // multi
        cancel: function () {
            this.close();
            this.focusSearch();
        },

        // multi
        addSelectedChoice: function (data) {
            var choice=$(
                    "<li class='select2-search-choice'>" +
                    "    <div></div>" +
                    "    <a href='#' onclick='return false;' class='select2-search-choice-close' tabindex='-1'></a>" +
                    "</li>"),
                id = this.id(data),
                val = this.getVal(),
                formatted;

            formatted=this.opts.formatSelection(data, choice);
            choice.find("div").replaceWith("<div>"+this.opts.escapeMarkup(formatted)+"</div>");
            choice.find(".select2-search-choice-close")
                .bind("mousedown", killEvent)
                .bind("click dblclick", this.bind(function (e) {
                if (!this.enabled) return;

                $(e.target).closest(".select2-search-choice").fadeOut('fast', this.bind(function(){
                    this.unselect($(e.target));
                    this.selection.find(".select2-search-choice-focus").removeClass("select2-search-choice-focus");
                    this.close();
                    this.focusSearch();
                })).dequeue();
                killEvent(e);
            })).bind("focus", this.bind(function () {
                if (!this.enabled) return;
                this.container.addClass("select2-container-active");
                this.dropdown.addClass("select2-drop-active");
            }));

            choice.data("select2-data", data);
            choice.insertBefore(this.searchContainer);

            val.push(id);
            this.setVal(val);
        },

        // multi
        unselect: function (selected) {
            var val = this.getVal(),
                data,
                index;

            selected = selected.closest(".select2-search-choice");

            if (selected.length === 0) {
                throw "Invalid argument: " + selected + ". Must be .select2-search-choice";
            }

            data = selected.data("select2-data");

            index = indexOf(this.id(data), val);

            if (index >= 0) {
                val.splice(index, 1);
                this.setVal(val);
                if (this.select) this.postprocessResults();
            }
            selected.remove();
            this.triggerChange({ removed: data });
        },

        // multi
        postprocessResults: function () {
            var val = this.getVal(),
                choices = this.results.find(".select2-result-selectable"),
                compound = this.results.find(".select2-result-with-children"),
                self = this;

            choices.each2(function (i, choice) {
                var id = self.id(choice.data("select2-data"));
                if (indexOf(id, val) >= 0) {
                    choice.addClass("select2-disabled").removeClass("select2-result-selectable");
                } else {
                    choice.removeClass("select2-disabled").addClass("select2-result-selectable");
                }
            });

            compound.each2(function(i, e) {
                if (e.find(".select2-result-selectable").length==0) {
                    e.addClass("select2-disabled");
                } else {
                    e.removeClass("select2-disabled");
                }
            });

            choices.each2(function (i, choice) {
                if (!choice.hasClass("select2-disabled") && choice.hasClass("select2-result-selectable")) {
                    self.highlight(0);
                    return false;
                }
            });

        },

        // multi
        resizeSearch: function () {

            var minimumWidth, left, maxWidth, containerLeft, searchWidth,
            	sideBorderPadding = getSideBorderPadding(this.search);

            minimumWidth = measureTextWidth(this.search) + 10;

            left = this.search.offset().left;

            maxWidth = this.selection.width();
            containerLeft = this.selection.offset().left;

            searchWidth = maxWidth - (left - containerLeft) - sideBorderPadding;
            if (searchWidth < minimumWidth) {
                searchWidth = maxWidth - sideBorderPadding;
            }

            if (searchWidth < 40) {
                searchWidth = maxWidth - sideBorderPadding;
            }
            this.search.width(searchWidth);
        },

        // multi
        getVal: function () {
            var val;
            if (this.select) {
                val = this.select.val();
                return val === null ? [] : val;
            } else {
                val = this.opts.element.val();
                return splitVal(val, this.opts.separator);
            }
        },

        // multi
        setVal: function (val) {
            var unique;
            if (this.select) {
                this.select.val(val);
            } else {
                unique = [];
                // filter out duplicates
                $(val).each(function () {
                    if (indexOf(this, unique) < 0) unique.push(this);
                });
                this.opts.element.val(unique.length === 0 ? "" : unique.join(this.opts.separator));
            }
        },

        // multi
        val: function () {
            var val, data = [], self=this;

            if (arguments.length === 0) {
                return this.getVal();
            }

            val = arguments[0];

            if (!val) {
                this.opts.element.val("");
                this.updateSelection([]);
                this.clearSearch();
                return;
            }

            // val is a list of ids
            this.setVal(val);

            if (this.select) {
                this.select.find(":selected").each(function () {
                    data.push({id: $(this).attr("value"), text: $(this).text()});
                });
                this.updateSelection(data);
            } else {
                if (this.opts.initSelection === undefined) {
                    throw new Error("val() cannot be called if initSelection() is not defined")
                }

                this.opts.initSelection(this.opts.element, function(data){
                    var ids=$(data).map(self.id);
                    self.setVal(ids);
                    self.updateSelection(data);
                    self.clearSearch();
                });
            }
            this.clearSearch();
        },

        // multi
        onSortStart: function() {
            if (this.select) {
                throw new Error("Sorting of elements is not supported when attached to <select>. Attach to <input type='hidden'/> instead.");
            }

            // collapse search field into 0 width so its container can be collapsed as well
            this.search.width(0);
            // hide the container
            this.searchContainer.hide();
        },

        // multi
        onSortEnd:function() {

            var val=[], self=this;

            // show search and move it to the end of the list
            this.searchContainer.show();
            // make sure the search container is the last item in the list
            this.searchContainer.appendTo(this.searchContainer.parent());
            // since we collapsed the width in dragStarted, we resize it here
            this.resizeSearch();

            // update selection

            this.selection.find(".select2-search-choice").each(function() {
                val.push(self.opts.id($(this).data("select2-data")));
            });
            this.setVal(val);
            this.triggerChange();
        },

        // multi
        data: function(values) {
            var self=this, ids;
            if (arguments.length === 0) {
                 return this.selection
                     .find(".select2-search-choice")
                     .map(function() { return $(this).data("select2-data"); })
                     .get();
            } else {
                if (!values) { values = []; }
                ids = $.map(values, function(e) { return self.opts.id(e)});
                this.setVal(ids);
                this.updateSelection(values);
                this.clearSearch();
            }
        }
    });

    $.fn.select2 = function () {

        var args = Array.prototype.slice.call(arguments, 0),
            opts,
            select2,
            value, multiple, allowedMethods = ["val", "destroy", "opened", "open", "close", "focus", "isFocused", "container", "onSortStart", "onSortEnd", "enable", "disable", "positionDropdown", "data"];

        this.each(function () {
            if (args.length === 0 || typeof(args[0]) === "object") {
                opts = args.length === 0 ? {} : $.extend({}, args[0]);
                opts.element = $(this);

                if (opts.element.get(0).tagName.toLowerCase() === "select") {
                    multiple = opts.element.attr("multiple");
                } else {
                    multiple = opts.multiple || false;
                    if ("tags" in opts) {opts.multiple = multiple = true;}
                }

                select2 = multiple ? new MultiSelect2() : new SingleSelect2();
                select2.init(opts);
            } else if (typeof(args[0]) === "string") {

                if (indexOf(args[0], allowedMethods) < 0) {
                    throw "Unknown method: " + args[0];
                }

                value = undefined;
                select2 = $(this).data("select2");
                if (select2 === undefined) return;
                if (args[0] === "container") {
                    value=select2.container;
                } else {
                    value = select2[args[0]].apply(select2, args.slice(1));
                }
                if (value !== undefined) {return false;}
            } else {
                throw "Invalid arguments to select2 plugin: " + args;
            }
        });
        return (value === undefined) ? this : value;
    };

    // plugin defaults, accessible to users
    $.fn.select2.defaults = {
        width: "copy",
        closeOnSelect: true,
        openOnEnter: true,
        containerCss: {},
        dropdownCss: {},
        containerCssClass: "",
        dropdownCssClass: "",
        formatResult: function(result, container, query) {
            var markup=[];
            markMatch(result.text, query.term, markup);
            return markup.join("");
        },
        formatSelection: function (data, container) {
            return data ? data.text : undefined;
        },
        formatResultCssClass: function(data) {return undefined;},
        formatNoMatches: function () { return "No matches found"; },
        formatInputTooShort: function (input, min) { return "Please enter " + (min - input.length) + " more characters"; },
        formatSelectionTooBig: function (limit) { return "You can only select " + limit + " item" + (limit == 1 ? "" : "s"); },
        formatLoadMore: function (pageNumber) { return "Loading more results..."; },
        formatSearching: function () { return "Searching..."; },
        minimumResultsForSearch: 0,
        minimumInputLength: 0,
        maximumSelectionSize: 0,
        id: function (e) { return e.id; },
        matcher: function(term, text) {
            return text.toUpperCase().indexOf(term.toUpperCase()) >= 0;
        },
        separator: ",",
        tokenSeparators: [],
        tokenizer: defaultTokenizer,
        escapeMarkup: function (markup) {
            if (markup && typeof(markup) === "string") {
                return markup.replace(/&/g, "&amp;");
            }
            return markup;
        },
        blurOnChange: false
    };

    // exports
    window.Select2 = {
        query: {
            ajax: ajax,
            local: local,
            tags: tags
        }, util: {
            debounce: debounce,
            markMatch: markMatch
        }, "class": {
            "abstract": AbstractSelect2,
            "single": SingleSelect2,
            "multi": MultiSelect2
        }
    };

}(jQuery));

/* =========================================================
 * bootstrap-datepicker.js 
 * http://www.eyecon.ro/bootstrap-datepicker
 * =========================================================
 * Copyright 2012 Stefan Petre
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * ========================================================= */

!function( $ ) {
	
	// Picker object
	
	var Datepicker = function(element, options){
		this.element = $(element);
		this.format = DPGlobal.parseFormat(options.format||this.element.data('date-format')||'mm/dd/yyyy');
		this.picker = $(DPGlobal.template)
							.appendTo('body')
							.on({
								click: $.proxy(this.click, this),
								mousedown: $.proxy(this.mousedown, this)
							});
		this.isInput = this.element.is('input');
		this.component = this.element.is('.date') ? this.element.find('.add-on') : false;
		
		if (this.isInput) {
			this.element.on({
				focus: $.proxy(this.show, this),
				blur: $.proxy(this.hide, this),
				keyup: $.proxy(this.update, this)
			});
		} else {
			if (this.component){
				this.component.on('click', $.proxy(this.show, this));
			} else {
				this.element.on('click', $.proxy(this.show, this));
			}
		}
		this.minViewMode = options.minViewMode||this.element.data('date-minviewmode')||0;
		if (typeof this.minViewMode === 'string') {
			switch (this.minViewMode) {
				case 'months':
					this.minViewMode = 1;
					break;
				case 'years':
					this.minViewMode = 2;
					break;
				default:
					this.minViewMode = 0;
					break;
			}
		}
		this.viewMode = options.viewMode||this.element.data('date-viewmode')||0;
		if (typeof this.viewMode === 'string') {
			switch (this.viewMode) {
				case 'months':
					this.viewMode = 1;
					break;
				case 'years':
					this.viewMode = 2;
					break;
				default:
					this.viewMode = 0;
					break;
			}
		}
		this.startViewMode = this.viewMode;
		this.weekStart = options.weekStart||this.element.data('date-weekstart')||1;
		this.weekEnd = this.weekStart === 1 ? 7 : this.weekStart - 2;
		this.fillDow();
		this.fillMonths();
		this.update();
		this.showMode();
	};
	
	Datepicker.prototype = {
		constructor: Datepicker,
		
		show: function(e) {
			this.picker.show();
			this.height = this.component ? this.component.outerHeight() : this.element.outerHeight();
			this.place();
			$(window).on('resize', $.proxy(this.place, this));
			if (e ) {
				e.stopPropagation();
				e.preventDefault();
			}
			if (!this.isInput) {
				$(document).on('mousedown', $.proxy(this.hide, this));
			}
			this.element.trigger({
				type: 'show',
				date: this.date
			});
		},
		
		hide: function(){
			this.picker.hide();
			$(window).off('resize', this.place);
			this.viewMode = this.startViewMode;
			this.showMode();
			if (!this.isInput) {
				$(document).off('mousedown', this.hide);
			}
			this.set();
			this.element.trigger({
				type: 'hide',
				date: this.date
			});
		},
		
		set: function() {
			var formated = DPGlobal.formatDate(this.date, this.format);
			if (!this.isInput) {
				if (this.component){
					this.element.find('input').prop('value', formated);
				}
				this.element.data('date', formated);
			} else {
				this.element.prop('value', formated);
			}
		},
		
		setValue: function(newDate) {
			if (typeof newDate === 'string') {
				this.date = DPGlobal.parseDate(newDate, this.format);
			} else {
				this.date = new Date(newDate);
			}
			this.set();
			this.viewDate = new Date(this.date.getFullYear(), this.date.getMonth(), 1, 0, 0, 0, 0);
			this.fill();
		},
		
		place: function(){
			var offset = this.component ? this.component.offset() : this.element.offset();
			this.picker.css({
				top: offset.top + this.height,
				left: offset.left
			});
		},
		
		update: function(newDate){
			this.date = DPGlobal.parseDate(
				typeof newDate === 'string' ? newDate : (this.isInput ? this.element.prop('value') : this.element.data('date')),
				this.format
			);
			this.viewDate = new Date(this.date.getFullYear(), this.date.getMonth(), 1, 0, 0, 0, 0);
			this.fill();
		},
		
		fillDow: function(){
			var dowCnt = this.weekStart;
			var html = '<tr>';
			while (dowCnt < this.weekStart + 7) {
				html += '<th class="dow">'+DPGlobal.dates.daysMin[(dowCnt++)%7]+'</th>';
			}
			html += '</tr>';
			this.picker.find('.datepicker-days thead').append(html);
		},
		
		fillMonths: function(){
			var html = '';
			var i = 0
			while (i < 12) {
				html += '<span class="month">'+DPGlobal.dates.monthsShort[i++]+'</span>';
			}
			this.picker.find('.datepicker-months td').append(html);
		},
		
		fill: function() {
			var d = new Date(this.viewDate),
				year = d.getFullYear(),
				month = d.getMonth(),
				currentDate = this.date.valueOf();
			this.picker.find('.datepicker-days th:eq(1)')
						.text(DPGlobal.dates.months[month]+' '+year);
			var prevMonth = new Date(year, month-1, 28,0,0,0,0),
				day = DPGlobal.getDaysInMonth(prevMonth.getFullYear(), prevMonth.getMonth());
			prevMonth.setDate(day);
			prevMonth.setDate(day - (prevMonth.getDay() - this.weekStart + 7)%7);
			var nextMonth = new Date(prevMonth);
			nextMonth.setDate(nextMonth.getDate() + 42);
			nextMonth = nextMonth.valueOf();
			html = [];
			var clsName;
			while(prevMonth.valueOf() < nextMonth) {
				if (prevMonth.getDay() === this.weekStart) {
					html.push('<tr>');
				}
				clsName = '';
				if (prevMonth.getMonth() < month) {
					clsName += ' old';
				} else if (prevMonth.getMonth() > month) {
					clsName += ' new';
				}
				if (prevMonth.valueOf() === currentDate) {
					clsName += ' active';
				}
				html.push('<td class="day'+clsName+'">'+prevMonth.getDate() + '</td>');
				if (prevMonth.getDay() === this.weekEnd) {
					html.push('</tr>');
				}
				prevMonth.setDate(prevMonth.getDate()+1);
			}
			this.picker.find('.datepicker-days tbody').empty().append(html.join(''));
			var currentYear = this.date.getFullYear();
			
			var months = this.picker.find('.datepicker-months')
						.find('th:eq(1)')
							.text(year)
							.end()
						.find('span').removeClass('active');
			if (currentYear === year) {
				months.eq(this.date.getMonth()).addClass('active');
			}
			
			html = '';
			year = parseInt(year/10, 10) * 10;
			var yearCont = this.picker.find('.datepicker-years')
								.find('th:eq(1)')
									.text(year + '-' + (year + 9))
									.end()
								.find('td');
			year -= 1;
			for (var i = -1; i < 11; i++) {
				html += '<span class="year'+(i === -1 || i === 10 ? ' old' : '')+(currentYear === year ? ' active' : '')+'">'+year+'</span>';
				year += 1;
			}
			yearCont.html(html);
		},
		
		click: function(e) {
			e.stopPropagation();
			e.preventDefault();
			var target = $(e.target).closest('span, td, th');
			if (target.length === 1) {
				switch(target[0].nodeName.toLowerCase()) {
					case 'th':
						switch(target[0].className) {
							case 'switch':
								this.showMode(1);
								break;
							case 'prev':
							case 'next':
								this.viewDate['set'+DPGlobal.modes[this.viewMode].navFnc].call(
									this.viewDate,
									this.viewDate['get'+DPGlobal.modes[this.viewMode].navFnc].call(this.viewDate) + 
									DPGlobal.modes[this.viewMode].navStep * (target[0].className === 'prev' ? -1 : 1)
								);
								this.fill();
								this.set();
								break;
						}
						break;
					case 'span':
						if (target.is('.month')) {
							var month = target.parent().find('span').index(target);
							this.viewDate.setMonth(month);
						} else {
							var year = parseInt(target.text(), 10)||0;
							this.viewDate.setFullYear(year);
						}
						if (this.viewMode !== 0) {
							this.date = new Date(this.viewDate);
							this.element.trigger({
								type: 'changeDate',
								date: this.date,
								viewMode: DPGlobal.modes[this.viewMode].clsName
							});
						}
						this.showMode(-1);
						this.fill();
						this.set();
						break;
					case 'td':
						if (target.is('.day')){
							var day = parseInt(target.text(), 10)||1;
							var month = this.viewDate.getMonth();
							if (target.is('.old')) {
								month -= 1;
							} else if (target.is('.new')) {
								month += 1;
							}
							var year = this.viewDate.getFullYear();
							this.date = new Date(year, month, day,0,0,0,0);
							this.viewDate = new Date(year, month, Math.min(28, day),0,0,0,0);
							this.fill();
							this.set();
							this.element.trigger({
								type: 'changeDate',
								date: this.date,
								viewMode: DPGlobal.modes[this.viewMode].clsName
							});
						}
						break;
				}
			}
		},
		
		mousedown: function(e){
			e.stopPropagation();
			e.preventDefault();
		},
		
		showMode: function(dir) {
			if (dir) {
				this.viewMode = Math.max(this.minViewMode, Math.min(2, this.viewMode + dir));
			}
			this.picker.find('>div').hide().filter('.datepicker-'+DPGlobal.modes[this.viewMode].clsName).show();
		}
	};
	
	$.fn.datepicker = function ( option, val ) {
		return this.each(function () {
			var $this = $(this),
				data = $this.data('datepicker'),
				options = typeof option === 'object' && option;
			if (!data) {
				$this.data('datepicker', (data = new Datepicker(this, $.extend({}, $.fn.datepicker.defaults,options))));
			}
			if (typeof option === 'string') data[option](val);
		});
	};

	$.fn.datepicker.defaults = {
	};
	$.fn.datepicker.Constructor = Datepicker;
	
	var DPGlobal = {
		modes: [
			{
				clsName: 'days',
				navFnc: 'Month',
				navStep: 1
			},
			{
				clsName: 'months',
				navFnc: 'FullYear',
				navStep: 1
			},
			{
				clsName: 'years',
				navFnc: 'FullYear',
				navStep: 10
		}],
		dates:{
			days: ["Воскресенье", "Понедельник", "Вторник", "Среда", "Четверг", "Пятница", "Суббота", "Воскресенье"],
			daysShort: ["Вс", "Пн", "Вт", "Ср", "Чт", "Пт", "Сб", "Вс"],
			daysMin: ["Вс", "Пн", "Вт", "Ср", "Чт", "Пт", "Сб", "Вс"],
			months: ["Январь", "Февраль", "Март", "Апрель", "Май", "Июнь", "Июль", "Август", "Сентябрь", "Октябрь", "Ноябрь", "Декабрь"],
			monthsShort: ["Янв", "Фев", "Мар", "Апр", "Май", "Июн", "Июл", "Авг", "Сен", "Окт", "Ноя", "Дек"]
		},
		isLeapYear: function (year) {
			return (((year % 4 === 0) && (year % 100 !== 0)) || (year % 400 === 0))
		},
		getDaysInMonth: function (year, month) {
			return [31, (DPGlobal.isLeapYear(year) ? 29 : 28), 31, 30, 31, 30, 31, 31, 30, 31, 30, 31][month]
		},
		parseFormat: function(format){
			var separator = format.match(/[.\/\-\s].*?/),
				parts = format.split(/\W+/);
			if (!separator || !parts || parts.length === 0){
				throw new Error("Invalid date format.");
			}
			return {separator: separator, parts: parts};
		},
		parseDate: function(date, format) {
			var parts = date.split(format.separator),
				date = new Date(),
				val;
			date.setHours(0);
			date.setMinutes(0);
			date.setSeconds(0);
			date.setMilliseconds(0);
			if (parts.length === format.parts.length) {
				for (var i=0, cnt = format.parts.length; i < cnt; i++) {
					val = parseInt(parts[i], 10)||1;
					switch(format.parts[i]) {
						case 'dd':
						case 'd':
							date.setDate(val);
							break;
						case 'mm':
						case 'm':
							date.setMonth(val - 1);
							break;
						case 'yy':
							date.setFullYear(2000 + val);
							break;
						case 'yyyy':
							date.setFullYear(val);
							break;
					}
				}
			}
			return date;
		},
		formatDate: function(date, format){
			var val = {
				d: date.getDate(),
				m: date.getMonth() + 1,
				yy: date.getFullYear().toString().substring(2),
				yyyy: date.getFullYear()
			};
			val.dd = (val.d < 10 ? '0' : '') + val.d;
			val.mm = (val.m < 10 ? '0' : '') + val.m;
			var date = [];
			for (var i=0, cnt = format.parts.length; i < cnt; i++) {
				date.push(val[format.parts[i]]);
			}
			return date.join(format.separator);
		},
		headTemplate: '<thead>'+
							'<tr>'+
								'<th class="prev">&lsaquo;</th>'+
								'<th colspan="5" class="switch"></th>'+
								'<th class="next">&rsaquo;</th>'+
							'</tr>'+
						'</thead>',
		contTemplate: '<tbody><tr><td colspan="7"></td></tr></tbody>'
	};
	DPGlobal.template = '<div class="datepicker dropdown-menu">'+
							'<div class="datepicker-days">'+
								'<table class=" table-condensed">'+
									DPGlobal.headTemplate+
									'<tbody></tbody>'+
								'</table>'+
							'</div>'+
							'<div class="datepicker-months">'+
								'<table class="table-condensed">'+
									DPGlobal.headTemplate+
									DPGlobal.contTemplate+
								'</table>'+
							'</div>'+
							'<div class="datepicker-years">'+
								'<table class="table-condensed">'+
									DPGlobal.headTemplate+
									DPGlobal.contTemplate+
								'</table>'+
							'</div>'+
						'</div>';

}( window.jQuery )
/* =========================================================
 * bootstrap-timepicker.js
 * http://www.github.com/jdewit/bootstrap-timepicker
 * =========================================================
 * Copyright 2012
 *
 * Created By:
 * Joris de Wit @joris_dewit
 *
 * Contributions By:
 * Gilbert @mindeavor
 * Koen Punt info@koenpunt.nl
 * Nek
 * Chris Martin
 * Dominic Barnes contact@dominicbarnes.us
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * ========================================================= */

!function($) {

    "use strict"; // jshint ;_;

    /* TIMEPICKER PUBLIC CLASS DEFINITION
     * ================================== */
    var Timepicker = function(element, options) {
        this.$element = $(element);
        this.options = $.extend({}, $.fn.timepicker.defaults, options, this.$element.data());
        this.minuteStep = this.options.minuteStep || this.minuteStep;
        this.secondStep = this.options.secondStep || this.secondStep;
        this.showMeridian = this.options.showMeridian || this.showMeridian;
        this.showSeconds = this.options.showSeconds || this.showSeconds;
        this.showInputs = this.options.showInputs || this.showInputs;
        this.disableFocus = this.options.disableFocus || this.disableFocus;
        this.template = this.options.template || this.template;
        this.modalBackdrop = this.options.modalBackdrop || this.modalBackdrop;
        this.defaultTime = this.options.defaultTime || this.defaultTime;
        this.open = false;
        this.init();
    };

    Timepicker.prototype = {

        constructor: Timepicker

        , init: function () {
            if (this.$element.parent().hasClass('input-append')) {
                this.$element.parent('.input-append').find('.add-on').on('click', $.proxy(this.showWidget, this));
                this.$element.on({
                    focus: $.proxy(this.highlightUnit, this),
                    click: $.proxy(this.highlightUnit, this),
                    keypress: $.proxy(this.elementKeypress, this),
                    blur: $.proxy(this.blurElement, this)
                });

            } else {
                if (this.template) {
                    this.$element.on({
                        focus: $.proxy(this.showWidget, this),
                        click: $.proxy(this.showWidget, this),
                        blur: $.proxy(this.blurElement, this)
                    });
                } else {
                    this.$element.on({
                        focus: $.proxy(this.highlightUnit, this),
                        click: $.proxy(this.highlightUnit, this),
                        keypress: $.proxy(this.elementKeypress, this),
                        blur: $.proxy(this.blurElement, this)
                    });
                }
            }


            this.$widget = $(this.getTemplate()).appendTo('body');

            this.$widget.on('click', $.proxy(this.widgetClick, this));

            if (this.showInputs) {
                this.$widget.find('input').on({
                    click: function() { this.select(); },
                    keypress: $.proxy(this.widgetKeypress, this),
                    change: $.proxy(this.updateFromWidgetInputs, this)
                });
            }

            this.setDefaultTime(this.defaultTime);
        }

        , showWidget: function(e) {
            e.stopPropagation();
            e.preventDefault();

            if (this.open) {
                return;
            }

            this.$element.trigger('show');

            if (this.disableFocus) {
                this.$element.blur();
            }

            var pos = $.extend({}, this.$element.offset(), {
                height: this.$element[0].offsetHeight
            });

            this.updateFromElementVal();

            $('html')
                .trigger('click.timepicker.data-api')
                .one('click.timepicker.data-api', $.proxy(this.hideWidget, this));

            if (this.template === 'modal') {
                this.$widget.modal('show').on('hidden', $.proxy(this.hideWidget, this));
            } else {
                this.$widget.css({
                    top: pos.top + pos.height
                    , left: pos.left
                })

                if (!this.open) {
                    this.$widget.addClass('open');
                }
            }

            this.open = true;
            this.$element.trigger('shown');
        }

        , hideWidget: function(){
            this.$element.trigger('hide');

            if (this.template === 'modal') {
                this.$widget.modal('hide');
            } else {
                this.$widget.removeClass('open');
            }
            this.open = false;
            this.$element.trigger('hidden');
        }

        , widgetClick: function(e) {
            e.stopPropagation();
            e.preventDefault();

            var action = $(e.target).closest('a').data('action');
            if (action) {
                this[action]();
                this.update();
            }
        }

        , widgetKeypress: function(e) {
            var input = $(e.target).closest('input').attr('name');

            switch (e.keyCode) {
                case 9: //tab
                    if (this.showMeridian) {
                        if (input == 'meridian') {
                            this.hideWidget();
                        }
                    } else {
                        if (this.showSeconds) {
                            if (input == 'second') {
                                this.hideWidget();
                            }
                        } else {
                            if (input == 'minute') {
                                this.hideWidget();
                            }
                        }
                    }
                break;
                case 27: // escape
                    this.hideWidget();
                break;
                case 38: // up arrow
                    switch (input) {
                        case 'hour':
                            this.incrementHour();
                        break;
                        case 'minute':
                            this.incrementMinute();
                        break;
                        case 'second':
                            this.incrementSecond();
                        break;
                        case 'meridian':
                            this.toggleMeridian();
                        break;
                    }
                    this.update();
                break;
                case 40: // down arrow
                    switch (input) {
                        case 'hour':
                            this.decrementHour();
                        break;
                        case 'minute':
                            this.decrementMinute();
                        break;
                        case 'second':
                            this.decrementSecond();
                        break;
                        case 'meridian':
                            this.toggleMeridian();
                        break;
                    }
                    this.update();
                break;
            }
        }

        , elementKeypress: function(e) {
            var input = this.$element.get(0);
            switch (e.keyCode) {
                case 0: //input
                break;
                case 9: //tab
                    this.updateFromElementVal();
                    if (this.showMeridian) {
                        if (this.highlightedUnit != 'meridian') {
                            e.preventDefault();
                            this.highlightNextUnit();
                        }
                    } else {
                        if (this.showSeconds) {
                            if (this.highlightedUnit != 'second') {
                                e.preventDefault();
                                this.highlightNextUnit();
                            }
                        } else {
                            if (this.highlightedUnit != 'minute') {
                                e.preventDefault();
                                this.highlightNextUnit();
                            }
                        }
                    }
                break;
                case 27: // escape
                    this.updateFromElementVal();
                break;
                case 37: // left arrow
                    this.updateFromElementVal();
                    this.highlightPrevUnit();
                break;
                case 38: // up arrow
                    switch (this.highlightedUnit) {
                        case 'hour':
                            this.incrementHour();
                        break;
                        case 'minute':
                            this.incrementMinute();
                        break;
                        case 'second':
                            this.incrementSecond();
                        break;
                        case 'meridian':
                            this.toggleMeridian();
                        break;
                    }
                    this.updateElement();
                break;
                case 39: // right arrow
                    this.updateFromElementVal();
                    this.highlightNextUnit();
                break;
                case 40: // down arrow
                    switch (this.highlightedUnit) {
                        case 'hour':
                            this.decrementHour();
                        break;
                        case 'minute':
                            this.decrementMinute();
                        break;
                        case 'second':
                            this.decrementSecond();
                        break;
                        case 'meridian':
                            this.toggleMeridian();
                        break;
                    }
                    this.updateElement();
                break;
            }

            if (e.keyCode !== 0 && e.keyCode !== 8 && e.keyCode !== 9 && e.keyCode !== 46) {
                e.preventDefault();
            }
        }

        , setValues: function(time) {
            if (this.showMeridian) {
                var arr = time.split(' ');
                var timeArray = arr[0].split(':');
                this.meridian = arr[1];
            } else {
                var timeArray = time.split(':');
            }

            this.hour = parseInt(timeArray[0], 10);
            this.minute = parseInt(timeArray[1], 10);
            this.second = parseInt(timeArray[2], 10);

            if (isNaN(this.hour)) {
                this.hour = 0;
            }
            if (isNaN(this.minute)) {
                this.minute = 0;
            }

            if (this.showMeridian) {
                if (this.hour > 12) {
                    this.hour = 12;
                } else if (this.hour < 1) {
                    this.hour = 1;
                }

                if (this.meridian == 'am' || this.meridian == 'a') {
                    this.meridian = 'AM';
                } else if (this.meridian == 'pm' || this.meridian == 'p') {
                    this.meridian = 'PM';
                }

                if (this.meridian != 'AM' && this.meridian != 'PM') {
                    this.meridian = 'AM';
                }
            } else {
                 if (this.hour >= 24) {
                    this.hour = 23;
                } else if (this.hour < 0) {
                    this.hour = 0;
                }
            }

            if (this.minute < 0) {
                this.minute = 0;
            } else if (this.minute >= 60) {
                this.minute = 59;
            }

            if (this.showSeconds) {
                if (isNaN(this.second)) {
                    this.second = 0;
                } else if (this.second < 0) {
                    this.second = 0;
                } else if (this.second >= 60) {
                    this.second = 59;
                }
            }

            if ( this.$element.val() != '' )
                this.updateElement();
            this.updateWidget();
        }

        , setMeridian: function(meridian) {
            if (meridian == 'a' || meridian == 'am' || meridian == 'AM' ) {
                this.meridian = 'AM';
            } else if (meridian == 'p' || meridian == 'pm' || meridian == 'PM' ) {
                this.meridian = 'PM';
            } else {
                this.updateWidget();
            }

            this.updateElement();
        }

        , setDefaultTime: function(defaultTime){
            if (defaultTime) {
                if (defaultTime === 'current') {
                    var dTime = new Date();
                    var hours = dTime.getHours();
                    var minutes = Math.floor(dTime.getMinutes() / this.minuteStep) * this.minuteStep;
                    var seconds = Math.floor(dTime.getSeconds() / this.secondStep) * this.secondStep;
                    var meridian = "AM";
                    if (this.showMeridian) {
                        if (hours === 0) {
                            hours = 12;
                        } else if (hours >= 12) {
                            if (hours > 12) {
                                hours = hours - 12;
                            }
                            meridian = "PM";
                        } else {
                           meridian = "AM";
                        }
                    }
                    this.hour = hours;
                    this.minute = minutes;
                    this.second = seconds;
                    this.meridian = meridian;
                } else if (defaultTime === 'value') {
                    this.setValues(this.$element.val());
                } else {
                    this.setValues(defaultTime);
                }
                if ( this.$element.val() != '' )
                    this.updateElement();
                this.updateWidget();
            } else {
                this.hour = 0;
                this.minute = 0;
                this.second = 0;
            }
        }

        , formatTime: function(hour, minute, second, meridian) {
            hour = hour < 10 ? '0' + hour : hour;
            minute = minute < 10 ? '0' + minute : minute;
            second = second < 10 ? '0' + second : second;

            return hour + ':' + minute + (this.showSeconds ? ':' + second : '') + (this.showMeridian ? ' ' + meridian : '');
        }

        , getTime: function() {
            return this.formatTime(this.hour, this.minute, this.second, this.meridian);
        }

        , setTime: function(time) {
            this.setValues(time);
            this.update();
        }

        , update: function() {
            this.updateElement();
            this.updateWidget();
        }

        , blurElement: function() {
          this.highlightedUnit = undefined;
          this.updateFromElementVal();
        }

        , updateElement: function() {
            var time = this.getTime();

            this.$element.val(time).change();

            switch (this.highlightedUnit) {
                case 'hour':
                    this.highlightHour();
                break;
                case 'minute':
                    this.highlightMinute();
                break;
                case 'second':
                    this.highlightSecond();
                break;
                case 'meridian':
                    this.highlightMeridian();
                break;
            }
        }

        , updateWidget: function() {
            if (this.showInputs) {
                this.$widget.find('input.bootstrap-timepicker-hour').val(this.hour < 10 ? '0' + this.hour : this.hour);
                this.$widget.find('input.bootstrap-timepicker-minute').val(this.minute < 10 ? '0' + this.minute : this.minute);
                if (this.showSeconds) {
                    this.$widget.find('input.bootstrap-timepicker-second').val(this.second < 10 ? '0' + this.second : this.second);
                }
                if (this.showMeridian) {
                    this.$widget.find('input.bootstrap-timepicker-meridian').val(this.meridian);
                }
            } else {
                this.$widget.find('span.bootstrap-timepicker-hour').text(this.hour);
                this.$widget.find('span.bootstrap-timepicker-minute').text(this.minute < 10 ? '0' + this.minute : this.minute);
                if (this.showSeconds) {
                    this.$widget.find('span.bootstrap-timepicker-second').text(this.second < 10 ? '0' + this.second : this.second);
                }
                if (this.showMeridian) {
                    this.$widget.find('span.bootstrap-timepicker-meridian').text(this.meridian);
                }
            }
        }

        , updateFromElementVal: function (e) {
            var time = this.$element.val();
            if (time) {
                this.setValues(time);
                this.updateWidget();
            }
        }

        , updateFromWidgetInputs: function () {
            var time = $('input.bootstrap-timepicker-hour', this.$widget).val() + ':' +
                       $('input.bootstrap-timepicker-minute', this.$widget).val() +
                       (this.showSeconds ?
                           ':' + $('input.bootstrap-timepicker-second', this.$widget).val()
                        : '') +
                       (this.showMeridian ?
                           ' ' + $('input.bootstrap-timepicker-meridian', this.$widget).val()
                        : '');

            this.setValues(time);
        }

        , getCursorPosition: function() {
            var input = this.$element.get(0);

            if ('selectionStart' in input) {
                // Standard-compliant browsers
                return input.selectionStart;
            } else if (document.selection) {
                // IE fix
                input.focus();
                var sel = document.selection.createRange();
                var selLen = document.selection.createRange().text.length;
                sel.moveStart('character', - input.value.length);

                return sel.text.length - selLen;
            }
        }

        , highlightUnit: function () {
            var input = this.$element.get(0);

            this.position = this.getCursorPosition();
            if (this.position >= 0 && this.position <= 2) {
                this.highlightHour();
            } else if (this.position >= 3 && this.position <= 5) {
                this.highlightMinute();
            } else if (this.position >= 6 && this.position <= 8) {
                if (this.showSeconds) {
                    this.highlightSecond();
                } else {
                    this.highlightMeridian();
                }
            } else if (this.position >= 9 && this.position <= 11) {
                this.highlightMeridian();
            }
        }

        , highlightNextUnit: function() {
            switch (this.highlightedUnit) {
                case 'hour':
                    this.highlightMinute();
                break;
                case 'minute':
                    if (this.showSeconds) {
                        this.highlightSecond();
                    } else {
                        this.highlightMeridian();
                    }
                break;
                case 'second':
                    this.highlightMeridian();
                break;
                case 'meridian':
                    this.highlightHour();
                break;
            }
        }

        , highlightPrevUnit: function() {
            switch (this.highlightedUnit) {
                case 'hour':
                    this.highlightMeridian();
                break;
                case 'minute':
                    this.highlightHour();
                break;
                case 'second':
                    this.highlightMinute();
                break;
                case 'meridian':
                    if (this.showSeconds) {
                        this.highlightSecond();
                    } else {
                        this.highlightMinute();
                    }
                break;
            }
        }

        , highlightHour: function() {
            this.highlightedUnit = 'hour';
            this.$element.get(0).setSelectionRange(0,2);
        }

        , highlightMinute: function() {
            this.highlightedUnit = 'minute';
            this.$element.get(0).setSelectionRange(3,5);
        }

        , highlightSecond: function() {
            this.highlightedUnit = 'second';
            this.$element.get(0).setSelectionRange(6,8);
        }

        , highlightMeridian: function() {
            this.highlightedUnit = 'meridian';
            if (this.showSeconds) {
                this.$element.get(0).setSelectionRange(9,11);
            } else {
                this.$element.get(0).setSelectionRange(6,8);
            }
        }

        , incrementHour: function() {
            if (this.showMeridian) {
                if (this.hour === 11) {
                    this.toggleMeridian();
                } else if (this.hour === 12) {
                    return this.hour = 1;
                }
            }
            if (this.hour === 23) {
                return this.hour = 0;
            }
            this.hour = this.hour + 1;
        }

        , decrementHour: function() {
            if (this.showMeridian) {
                if (this.hour === 1) {
                    return this.hour = 12;
                }
                else if (this.hour === 12) {
                    this.toggleMeridian();
                }
            }
            if (this.hour === 0) {
                return this.hour = 23;
            }
            this.hour = this.hour - 1;
        }

        , incrementMinute: function() {
            var newVal = this.minute + this.minuteStep - (this.minute % this.minuteStep);
            if (newVal > 59) {
                this.incrementHour();
                this.minute = newVal - 60;
            } else {
                this.minute = newVal;
            }
        }

        , decrementMinute: function() {
            var newVal = this.minute - this.minuteStep;
            if (newVal < 0) {
                this.decrementHour();
                this.minute = newVal + 60;
            } else {
                this.minute = newVal;
            }
        }

        , incrementSecond: function() {
            var newVal = this.second + this.secondStep - (this.second % this.secondStep);
            if (newVal > 59) {
                this.incrementMinute();
                this.second = newVal - 60;
            } else {
                this.second = newVal;
            }
        }

        , decrementSecond: function() {
            var newVal = this.second - this.secondStep;
            if (newVal < 0) {
                this.decrementMinute();
                this.second = newVal + 60;
            } else {
                this.second = newVal;
            }
        }

        , toggleMeridian: function() {
            this.meridian = this.meridian === 'AM' ? 'PM' : 'AM';

            this.update();
        }

        , getTemplate: function() {
            if (this.options.templates[this.options.template]) {
                return this.options.templates[this.options.template];
            }
            if (this.showInputs) {
                var hourTemplate = '<input type="text" name="hour" class="bootstrap-timepicker-hour" maxlength="2"/>';
                var minuteTemplate = '<input type="text" name="minute" class="bootstrap-timepicker-minute" maxlength="2"/>';
                var secondTemplate = '<input type="text" name="second" class="bootstrap-timepicker-second" maxlength="2"/>';
                var meridianTemplate = '<input type="text" name="meridian" class="bootstrap-timepicker-meridian" maxlength="2"/>';
            } else {
                var hourTemplate = '<span class="bootstrap-timepicker-hour"></span>';
                var minuteTemplate = '<span class="bootstrap-timepicker-minute"></span>';
                var secondTemplate = '<span class="bootstrap-timepicker-second"></span>';
                var meridianTemplate = '<span class="bootstrap-timepicker-meridian"></span>';
            }
            var templateContent = '<table class="'+ (this.showSeconds ? 'show-seconds' : '') +' '+ (this.showMeridian ? 'show-meridian' : '') +'">'+
                                       '<tr>'+
                                           '<td><a href="#" data-action="incrementHour"><i class="icon-chevron-up"></i></a></td>'+
                                           '<td class="separator">&nbsp;</td>'+
                                           '<td><a href="#" data-action="incrementMinute"><i class="icon-chevron-up"></i></a></td>'+
                                           (this.showSeconds ?
                                               '<td class="separator">&nbsp;</td>'+
                                               '<td><a href="#" data-action="incrementSecond"><i class="icon-chevron-up"></i></a></td>'
                                           : '') +
                                           (this.showMeridian ?
                                               '<td class="separator">&nbsp;</td>'+
                                               '<td class="meridian-column"><a href="#" data-action="toggleMeridian"><i class="icon-chevron-up"></i></a></td>'
                                           : '') +
                                       '</tr>'+
                                       '<tr>'+
                                           '<td>'+ hourTemplate +'</td> '+
                                           '<td class="separator">:</td>'+
                                           '<td>'+ minuteTemplate +'</td> '+
                                           (this.showSeconds ?
                                                '<td class="separator">:</td>'+
                                                '<td>'+ secondTemplate +'</td>'
                                           : '') +
                                           (this.showMeridian ?
                                                '<td class="separator">&nbsp;</td>'+
                                                '<td>'+ meridianTemplate +'</td>'
                                           : '') +
                                       '</tr>'+
                                       '<tr>'+
                                           '<td><a href="#" data-action="decrementHour"><i class="icon-chevron-down"></i></a></td>'+
                                           '<td class="separator"></td>'+
                                           '<td><a href="#" data-action="decrementMinute"><i class="icon-chevron-down"></i></a></td>'+
                                           (this.showSeconds ?
                                                '<td class="separator">&nbsp;</td>'+
                                                '<td><a href="#" data-action="decrementSecond"><i class="icon-chevron-down"></i></a></td>'
                                           : '') +
                                           (this.showMeridian ?
                                                '<td class="separator">&nbsp;</td>'+
                                                '<td><a href="#" data-action="toggleMeridian"><i class="icon-chevron-down"></i></a></td>'
                                           : '') +
                                       '</tr>'+
                                   '</table>';

            var template;
            switch(this.options.template) {
                case 'modal':
                    template = '<div class="bootstrap-timepicker modal hide fade in" style="top: 30%; margin-top: 0; width: 200px; margin-left: -100px;" data-backdrop="'+ (this.modalBackdrop ? 'true' : 'false') +'">'+
                                   '<div class="modal-header">'+
                                       '<a href="#" class="close" data-dismiss="modal">×</a>'+
                                       '<h3>Pick a Time</h3>'+
                                   '</div>'+
                                   '<div class="modal-content">'+
                                        templateContent +
                                   '</div>'+
                                   '<div class="modal-footer">'+
                                       '<a href="#" class="btn btn-primary" data-dismiss="modal">Ok</a>'+
                                   '</div>'+
                               '</div>';

                break;
                case 'dropdown':
                    template = '<div class="bootstrap-timepicker dropdown-menu">'+
                                    templateContent +
                               '</div>';
                break;

            }
            return template;
        }
    };


    /* TIMEPICKER PLUGIN DEFINITION
     * =========================== */

    $.fn.timepicker = function (option) {
		var args = Array.apply(null, arguments);
		args.shift();
		return this.each(function() {
			var $this = $(this),
				data = $this.data('timepicker'),
				options = typeof option === 'object' && option;

			if (!data) {
				$this.data('timepicker', (data = new Timepicker(this, options)));
			}

			if (typeof option === 'string') {
				data[option].apply(data, args);
			}
		});
//		return this.each(function () {
//            var $this = $(this)
//            , data = $this.data('timepicker')
//            , options = typeof option == 'object' && option;
//            if (!data) {
//                $this.data('timepicker', (data = new Timepicker(this, options)));
//            }
//            if (typeof option == 'string') {
//                data[option]();
//            }
//        })


    }

    $.fn.timepicker.defaults = {
      minuteStep: 15
    , secondStep: 15
    , disableFocus: false
    , defaultTime: 'current'
    , showSeconds: false
    , showInputs: true
    , showMeridian: true
    , template: 'dropdown'
    , modalBackdrop: false
    , templates: {} // set custom templates
    }

    $.fn.timepicker.Constructor = Timepicker
}(window.jQuery);

/* =============================================================
 * bootstrap-collapse.js v2.0.4
 * http://twitter.github.com/bootstrap/javascript.html#collapse
 * =============================================================
 * Copyright 2012 Twitter, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * ============================================================ */


!function ($) {

    "use strict"; // jshint ;_;


    /* COLLAPSE PUBLIC CLASS DEFINITION
     * ================================ */

    var Collapse = function (element, options) {
        this.$element = $(element)
        this.options = $.extend({}, $.fn.collapse.defaults, options)

        if (this.options.parent) {
            this.$parent = $(this.options.parent)
        }

        this.options.toggle && this.toggle()
    }

    Collapse.prototype = {

        constructor: Collapse

        , dimension: function () {
            var hasWidth = this.$element.hasClass('width')
            return hasWidth ? 'width' : 'height'
        }

        , show: function () {
            var dimension
                , scroll
                , actives
                , hasData

            if (this.transitioning) return

            dimension = this.dimension()
            scroll = $.camelCase(['scroll', dimension].join('-'))
            actives = this.$parent && this.$parent.find('> .accordion-group > .in')

            if (actives && actives.length) {
                hasData = actives.data('collapse')
                if (hasData && hasData.transitioning) return
                actives.collapse('hide')
                hasData || actives.data('collapse', null)
            }

            this.$element[dimension](0)
            this.transition('addClass', $.Event('show'), 'shown')
            this.$element[dimension](this.$element[0][scroll])
        }

        , hide: function () {
            var dimension
            if (this.transitioning) return
            dimension = this.dimension()
            this.reset(this.$element[dimension]())
            this.transition('removeClass', $.Event('hide'), 'hidden')
            this.$element[dimension](0)
        }

        , reset: function (size) {
            var dimension = this.dimension()

            this.$element
                .removeClass('collapse')
                [dimension](size || 'auto')
                [0].offsetWidth

            this.$element[size !== null ? 'addClass' : 'removeClass']('collapse')

            return this
        }

        , transition: function (method, startEvent, completeEvent) {
            var that = this
                , complete = function () {
                    if (startEvent.type == 'show') that.reset()
                    that.transitioning = 0
                    that.$element.trigger(completeEvent)
                }

            this.$element.trigger(startEvent)

            if (startEvent.isDefaultPrevented()) return

            this.transitioning = 1

            this.$element[method]('in')

            $.support.transition && this.$element.hasClass('collapse') ?
                this.$element.one($.support.transition.end, complete) :
                complete()
        }

        , toggle: function () {
            this[this.$element.hasClass('in') ? 'hide' : 'show']()
        }

    }


    /* COLLAPSIBLE PLUGIN DEFINITION
     * ============================== */

    $.fn.collapse = function (option) {
        return this.each(function () {
            var $this = $(this)
                , data = $this.data('collapse')
                , options = typeof option == 'object' && option
            if (!data) $this.data('collapse', (data = new Collapse(this, options)))
            if (typeof option == 'string') data[option]()
        })
    }

    $.fn.collapse.defaults = {
        toggle: true
    }

    $.fn.collapse.Constructor = Collapse


    /* COLLAPSIBLE DATA-API
     * ==================== */

    $(function () {
        $('body').on('click.collapse.data-api', '[data-toggle=collapse]', function ( e ) {
            var $this = $(this), href
                , target = $this.attr('data-target')
                    || e.preventDefault()
                    || (href = $this.attr('href')) && href.replace(/.*(?=#[^\s]+$)/, '') //strip for ie7
                , option = $(target).data('collapse') ? 'toggle' : $this.data()
            $(target).collapse(option)
        })
    })

}(window.jQuery);
//console.log("garbaje");
/* Функция проверки устройства на iPad ) */
function is_ipad () {
    if ( navigator.userAgent.indexOf('iPad') != -1 )
    {
        return true;
    }
}

$(document).ready(function() {

//    $('.j_recall_callendar').datepicker({
//        format: "mm-dd-yyyy"
//    });
//    $('.j_recall_time').timepicker({
//        showMeridian: false
//    });

    /* iШняги */

    /* Отключение баблинга в iШнягах */
    if (is_ipad()) {

        /* Скроллинг при скрытии клавиатуры на айпаде ( есть глюки с несколькими тестовыми полями. При перескоке с одного на другое)*/
        $("textarea").live('blur', function() {
            $('body').scrollTop(0);
            $('body').scroll();
        });

        $("body").bind("touchmove", function(){
            return false;
        });

    }


});

/*
 * JsSIP version 0.3.7
 * Copyright (c) 2012-2013 José Luis Millán - Versatica <http://www.versatica.com>
 * Homepage: http://jssip.net
 * License: http://jssip.net/license
 */


/*global console: false*/

/**
 * @name JsSIP
 * @namespace
 */
(function (window) {

	var JsSIP = (function () {
		"use strict";

		var JsSIP = {};

		Object.defineProperties(JsSIP, {
			version: {
				get: function () {
					return '0.3.7';
				}
			},
			name: {
				get: function () {
					return 'JsSIP';
				}
			}
		});

		return JsSIP;
	}());


	/**
	 * @fileoverview EventEmitter
	 */

	/**
	 * @augments JsSIP
	 * @class Class creating an event emitter.
	 */
	(function (JsSIP) {
		var
			EventEmitter,
			Event,
			LOG_PREFIX = JsSIP.name + ' | ' + 'EVENT EMITTER' + ' | ';

		EventEmitter = function () {
		};
		EventEmitter.prototype = {
			/**
			 * Initialize events dictionary.
			 * @param {Array} events
			 */
			initEvents: function (events) {
				var i = events.length;

				this.events = {};
				this.onceNotFired = []; // Array containing events with _once_ defined tat didn't fire yet.
				this.maxListeners = 10;
				this.events.newListener = function (event) { // Default newListener callback
					console.log(LOG_PREFIX + 'new listener added to event ' + event);
				};

				while (i--) {
					console.log(LOG_PREFIX + 'adding event ' + events[i]);
					this.events[events[i]] = [];
				}
			},

			/**
			 * Check whether an event exists or not.
			 * @param {String} event
			 * @returns {Boolean}
			 */
			checkEvent: function (event) {
				if (!this.events[event]) {
					console.error(LOG_PREFIX + 'no event named ' + event);
					return false;
				} else {
					return true;
				}
			},

			/**
			 * Add a listener to the end of the listeners array for the specified event.
			 * @param {String} event
			 * @param {Function} listener
			 */
			addListener: function (event, listener) {
				if (!this.checkEvent(event)) {
					return;
				}

				if (this.events[event].length >= this.maxListeners) {
					console.warn(LOG_PREFIX + 'max listeners exceeded for event ' + event);
				}

				this.events[event].push(listener);
				this.events.newListener.call(null, event);
			},

			on: function (event, listener) {
				this.addListener(event, listener);
			},

			/**
			 * Add a one time listener for the event.
			 * The listener is invoked only the first time the event is fired, after which it is removed.
			 * @param {String} event
			 * @param {Function} listener
			 */
			once: function (event, listener) {
				this.events[event].unshift(listener);
				this.onceNotFired.push(event);
			},

			/**
			 * Remove a listener from the listener array for the specified event.
			 * Caution: changes array indices in the listener array behind the listener.
			 * @param {String} event
			 * @param {Function} listener
			 */
			removeListener: function (event, listener) {
				if (!this.checkEvent(event)) {
					return;
				}

				var array = this.events[event], i = 0, length = array.length;

				while (i < length) {
					if (array[i] && array[i].toString() === listener.toString()) {
						array.splice(i, 1);
					} else {
						i++;
					}
				}
			},

			/**
			 * Remove all listeners from the listener array for the specified event.
			 * @param {String} event
			 */
			removeAllListener: function (event) {
				if (!this.checkEvent(event)) {
					return;
				}

				this.events[event] = [];
			},

			/**
			 * By default EventEmitter will print a warning
			 * if more than 10 listeners are added for a particular event.
			 * This function allows that limit to be modified.
			 * @param {Number} listeners
			 */
			setMaxListeners: function (listeners) {
				if (Number(listeners)) {
					this.maxListeners = listeners;
				}
			},

			/**
			 * Get the listeners for a specific event.
			 * @param {String} event
			 * @returns {Array}  Array of listeners for the specified event.
			 */
			listeners: function (event) {
				return this.events[event];
			},

			/**
			 * Execute each of the listeners in order with the supplied arguments.
			 * @param {String} events
			 * @param {Array} args
			 */
			emit: function (event, sender, data) {
				var listeners, length,
					idx = 0;

				if (!this.checkEvent(event)) {
					return;
				}

				console.log(LOG_PREFIX + 'emitting event ' + event);

				listeners = this.events[event];
				length = listeners.length;

				var e = new JsSIP.Event(event, sender, data);

				if (e) {
					for (idx; idx < length; idx++) {
						listeners[idx].apply(null, [e]);
					}
				} else {
					for (idx; idx < length; idx++) {
						listeners[idx].call();
					}
				}

				// Check whether _once_ was defined for the event
				idx = this.onceNotFired.indexOf(event);

				if (idx !== -1) {
					this.onceNotFired.splice(idx, 1);
					this.events[event].shift();
				}
			},

			/**
			 * This function is executed anytime a new listener is added to EventEmitter instance.
			 * @param {Function} listener
			 */
			newListener: function (listener) {
				this.events.newListener = listener;
			}
		};

		Event = function (type, sender, data) {
			this.type = type;
			this.sender = sender;
			this.data = data;
		};

		JsSIP.EventEmitter = EventEmitter;
		JsSIP.Event = Event;
	}(JsSIP));


	/**
	 * @fileoverview JsSIP Constants
	 */

	/**
	 * JsSIP Constants.
	 * @augments JsSIP
	 */

	JsSIP.C = {
		USER_AGENT: JsSIP.name + ' ' + JsSIP.version,

		// SIP scheme
		SIP: 'sip',

		// Invalid target
		INVALID_TARGET_URI: 'sip:invalid@invalid',

		// End and Failure causes
		causes: {
			// Generic error causes
			CONNECTION_ERROR: 'Connection Error',
			REQUEST_TIMEOUT: 'Request Timeout',
			SIP_FAILURE_CODE: 'SIP Failure Code',
			INVALID_TARGET: 'Invalid Target',
			INTERNAL_ERROR: 'Internal Error',

			// SIP error causes
			BUSY: 'Busy',
			REJECTED: 'Rejected',
			REDIRECTED: 'Redirected',
			UNAVAILABLE: 'Unavailable',
			NOT_FOUND: 'Not Found',
			ADDRESS_INCOMPLETE: 'Address Incomplete',
			INCOMPATIBLE_SDP: 'Incompatible SDP',
			AUTHENTICATION_ERROR: 'Authentication Error',
			DIALOG_ERROR: 'Dialog Error',

			// Session error causes
			WEBRTC_NOT_SUPPORTED: 'WebRTC Not Supported',
			WEBRTC_ERROR: 'WebRTC Error',
			CANCELED: 'Canceled',
			NO_ANSWER: 'No Answer',
			EXPIRES: 'Expires',
			NO_ACK: 'No ACK',
			USER_DENIED_MEDIA_ACCESS: 'User Denied Media Access',
			BAD_MEDIA_DESCRIPTION: 'Bad Media Description',
			RTP_TIMEOUT: 'RTP Timeout'
		},

		SIP_ERROR_CAUSES: {
			REDIRECTED: [300, 301, 302, 305, 380],
			BUSY: [486, 600],
			REJECTED: [403, 603],
			NOT_FOUND: [404, 604],
			UNAVAILABLE: [480, 410, 408, 430],
			ADDRESS_INCOMPLETE: [484],
			INCOMPATIBLE_SDP: [488, 606],
			AUTHENTICATION_ERROR: [401, 407]
		},

		// SIP Methods
		ACK: 'ACK',
		BYE: 'BYE',
		CANCEL: 'CANCEL',
		INFO: 'INFO',
		INVITE: 'INVITE',
		MESSAGE: 'MESSAGE',
		NOTIFY: 'NOTIFY',
		OPTIONS: 'OPTIONS',
		REGISTER: 'REGISTER',
		UPDATE: 'UPDATE',
		SUBSCRIBE: 'SUBSCRIBE',

		/* SIP Response Reasons
		 * DOC: http://www.iana.org/assignments/sip-parameters
		 * Copied from https://github.com/versatica/OverSIP/blob/master/lib/oversip/sip/constants.rb#L7
		 */
		REASON_PHRASE: {
			100: 'Trying',
			180: 'Ringing',
			181: 'Call Is Being Forwarded',
			182: 'Queued',
			183: 'Session Progress',
			199: 'Early Dialog Terminated',  // draft-ietf-sipcore-199
			200: 'OK',
			202: 'Accepted',  // RFC 3265
			204: 'No Notification',  //RFC 5839
			300: 'Multiple Choices',
			301: 'Moved Permanently',
			302: 'Moved Temporarily',
			305: 'Use Proxy',
			380: 'Alternative Service',
			400: 'Bad Request',
			401: 'Unauthorized',
			402: 'Payment Required',
			403: 'Forbidden',
			404: 'Not Found',
			405: 'Method Not Allowed',
			406: 'Not Acceptable',
			407: 'Proxy Authentication Required',
			408: 'Request Timeout',
			410: 'Gone',
			412: 'Conditional Request Failed',  // RFC 3903
			413: 'Request Entity Too Large',
			414: 'Request-URI Too Long',
			415: 'Unsupported Media Type',
			416: 'Unsupported URI Scheme',
			417: 'Unknown Resource-Priority',  // RFC 4412
			420: 'Bad Extension',
			421: 'Extension Required',
			422: 'Session Interval Too Small',  // RFC 4028
			423: 'Interval Too Brief',
			428: 'Use Identity Header',  // RFC 4474
			429: 'Provide Referrer Identity',  // RFC 3892
			430: 'Flow Failed',  // RFC 5626
			433: 'Anonymity Disallowed',  // RFC 5079
			436: 'Bad Identity-Info',  // RFC 4474
			437: 'Unsupported Certificate',  // RFC 4744
			438: 'Invalid Identity Header',  // RFC 4744
			439: 'First Hop Lacks Outbound Support',  // RFC 5626
			440: 'Max-Breadth Exceeded',  // RFC 5393
			469: 'Bad Info Package',  // draft-ietf-sipcore-info-events
			470: 'Consent Needed',  // RFC 5360
			478: 'Unresolvable Destination',  // Custom code copied from Kamailio.
			480: 'Temporarily Unavailable',
			481: 'Call/Transaction Does Not Exist',
			482: 'Loop Detected',
			483: 'Too Many Hops',
			484: 'Address Incomplete',
			485: 'Ambiguous',
			486: 'Busy Here',
			487: 'Request Terminated',
			488: 'Not Acceptable Here',
			489: 'Bad Event',  // RFC 3265
			491: 'Request Pending',
			493: 'Undecipherable',
			494: 'Security Agreement Required',  // RFC 3329
			500: 'Server Internal Error',
			501: 'Not Implemented',
			502: 'Bad Gateway',
			503: 'Service Unavailable',
			504: 'Server Time-out',
			505: 'Version Not Supported',
			513: 'Message Too Large',
			580: 'Precondition Failure',  // RFC 3312
			600: 'Busy Everywhere',
			603: 'Decline',
			604: 'Does Not Exist Anywhere',
			606: 'Not Acceptable'
		}
	};


	/**
	 * @fileoverview Exceptions
	 */

	/**
	 * JsSIP Exceptions.
	 * @augments JsSIP
	 */
	(function (JsSIP) {
		var Exceptions;

		Exceptions = {
			ConfigurationError: (function () {
				var exception = function (parameter, value) {
					this.code = 1;
					this.name = 'CONFIGURATION_ERROR';
					this.parameter = parameter;
					this.value = value;
					this.message = (!this.value) ? 'Missing parameter: ' + this.parameter : 'Invalid value ' + window.JSON.stringify(this.value) + ' for parameter "' + this.parameter + '"';
				};
				exception.prototype = new Error();
				return exception;
			}()),

			InvalidTargetError: (function () {
				var exception = function (target) {
					this.code = 2;
					this.name = 'INVALID_TARGET_ERROR';
					this.target = target;
					this.message = 'Invalid target: ' + this.target;
				};
				exception.prototype = new Error();
				return exception;
			}()),

			InvalidStateError: (function () {
				var exception = function (status) {
					this.code = 3;
					this.name = 'INVALID_STATE_ERROR';
					this.status = status;
				};
				exception.prototype = new Error();
				return exception;
			}())
		};

		JsSIP.Exceptions = Exceptions;
	}(JsSIP));


	/**
	 * @fileoverview SIP TIMERS
	 */

	/**
	 * @augments JsSIP
	 */
	(function (JsSIP) {
		var Timers,
			T1 = 500,
			T2 = 4000,
			T4 = 5000;

		Timers = {
			T1: T1,
			T2: T2,
			T4: T4,
			TIMER_B: 64 * T1,
			TIMER_D: 0 * T1,
			TIMER_F: 64 * T1,
			TIMER_H: 64 * T1,
			TIMER_I: 0 * T1,
			TIMER_J: 0 * T1,
			TIMER_K: 0 * T4,
			TIMER_L: 64 * T1,
			TIMER_M: 64 * T1,
			PROVISIONAL_RESPONSE_INTERVAL: 60000  // See RFC 3261 Section 13.3.1.1
		};

		JsSIP.Timers = Timers;
	}(JsSIP));


	/**
	 * @fileoverview Transport
	 */

	/**
	 * @augments JsSIP
	 * @class Transport
	 * @param {JsSIP.UA} ua
	 * @param {Object} server ws_server Object
	 */
	(function (JsSIP) {
		var Transport,
			LOG_PREFIX = JsSIP.name + ' | ' + 'TRANSPORT' + ' | ',
			C = {
				// Transport status codes
				STATUS_READY: 0,
				STATUS_DISCONNECTED: 1,
				STATUS_ERROR: 2
			};

		Transport = function (ua, server) {
			this.ua = ua;
			this.ws = null;
			this.server = server;
			this.reconnection_attempts = 0;
			this.closed = false;
			this.connected = false;
			this.reconnectTimer = null;
			this.lastTransportError = {};

			this.ua.transport = this;

			// Connect
			this.connect();
		};

		Transport.prototype = {
			/**
			 * Send a message.
			 * @param {JsSIP.OutgoingRequest|String} msg
			 * @returns {Boolean}
			 */
			send: function (msg) {
				var message = msg.toString();

				if (this.ws && this.ws.readyState === WebSocket.OPEN) {
					if (this.ua.configuration.trace_sip === true) {
						console.log(LOG_PREFIX + 'sending WebSocket message:\n\n' + message + '\n');
					}
					this.ws.send(message);
					return true;
				} else {
					console.warn(LOG_PREFIX + 'unable to send message, WebSocket is not open');
					return false;
				}
			},

			/**
			 * Disconnect socket.
			 */
			disconnect: function () {
				if (this.ws) {
					this.closed = true;
					console.log(LOG_PREFIX + 'closing WebSocket ' + this.server.ws_uri);
					this.ws.close();
				}
			},

			/**
			 * Connect socket.
			 */
			connect: function () {
				var transport = this;

				if (this.ws && (this.ws.readyState === WebSocket.OPEN || this.ws.readyState === WebSocket.CONNECTING)) {
					console.log(LOG_PREFIX + 'WebSocket ' + this.server.ws_uri + ' is already connected');
					return false;
				}

				if (this.ws) {
					this.ws.close();
				}

				console.log(LOG_PREFIX + 'connecting to WebSocket ' + this.server.ws_uri);

				try {
					this.ws = new WebSocket(this.server.ws_uri, 'sip');
				} catch (e) {
					console.warn(LOG_PREFIX + 'error connecting to WebSocket ' + this.server.ws_uri + ': ' + e);
				}

				this.ws.binaryType = 'arraybuffer';

				this.ws.onopen = function () {
					transport.onOpen();
				};

				this.ws.onclose = function (e) {
					transport.onClose(e);
				};

				this.ws.onmessage = function (e) {
					transport.onMessage(e);
				};

				this.ws.onerror = function (e) {
					transport.onError(e);
				};
			},

			// Transport Event Handlers

			/**
			 * @event
			 * @param {event} e
			 */
			onOpen: function () {
				this.connected = true;

				console.log(LOG_PREFIX + 'WebSocket ' + this.server.ws_uri + ' connected');
				// Clear reconnectTimer since we are not disconnected
				window.clearTimeout(this.reconnectTimer);
				// Disable closed
				this.closed = false;
				// Trigger onTransportConnected callback
				this.ua.onTransportConnected(this);
			},

			/**
			 * @event
			 * @param {event} e
			 */
			onClose: function (e) {
				var connected_before = this.connected;

				this.connected = false;
				this.lastTransportError.code = e.code;
				this.lastTransportError.reason = e.reason;
				console.log(LOG_PREFIX + 'WebSocket disconnected (code: ' + e.code + (e.reason ? '| reason: ' + e.reason : '') + ')');

				if (e.wasClean === false) {
					console.warn(LOG_PREFIX + 'WebSocket abrupt disconnection');
				}
				// Transport was connected
				if (connected_before === true) {
					this.ua.onTransportClosed(this);
					// Check whether the user requested to close.
					if (!this.closed) {
						// Reset reconnection_attempts
						this.reconnection_attempts = 0;
						this.reConnect();
					} else {
						this.ua.emit('disconnected', this.ua, {
							transport: this,
							code: this.lastTransportError.code,
							reason: this.lastTransportError.reason
						});
					}
				} else {
					// This is the first connection attempt
					//Network error
					this.ua.onTransportError(this);
				}
			},

			/**
			 * @event
			 * @param {event} e
			 */
			onMessage: function (e) {
				var message, transaction,
					data = e.data;

				// CRLF Keep Alive response from server. Ignore it.
				if (data === '\r\n') {
					if (this.ua.configuration.trace_sip === true) {
						console.log(LOG_PREFIX + 'received WebSocket message with CRLF Keep Alive response');
					}
					return;
				}

				// WebSocket binary message.
				else if (typeof data !== 'string') {
					try {
						data = String.fromCharCode.apply(null, new Uint8Array(data));
					} catch (evt) {
						console.warn(LOG_PREFIX + 'received WebSocket binary message failed to be converted into string, message discarded');
						return;
					}

					if (this.ua.configuration.trace_sip === true) {
						console.log(LOG_PREFIX + 'received WebSocket binary message:\n\n' + data + '\n');
					}
				}

				// WebSocket text message.
				else {
					if (this.ua.configuration.trace_sip === true) {
						console.log(LOG_PREFIX + 'received WebSocket text message:\n\n' + data + '\n');
					}
				}

				message = JsSIP.Parser.parseMessage(data);

				if (this.ua.status === JsSIP.UA.C.STATUS_USER_CLOSED && message instanceof JsSIP.IncomingRequest) {
					return;
				}

				// Do some sanity check
				if (message && JsSIP.sanityCheck(message, this.ua, this)) {
					if (message instanceof JsSIP.IncomingRequest) {
						message.transport = this;
						this.ua.receiveRequest(message);
					} else if (message instanceof JsSIP.IncomingResponse) {
						/* Unike stated in 18.1.2, if a response does not match
						 * any transaction, it is discarded here and no passed to the core
						 * in order to be discarded there.
						 */
						switch (message.method) {
							case JsSIP.C.INVITE:
								transaction = this.ua.transactions.ict[message.via_branch];
								if (transaction) {
									transaction.receiveResponse(message);
								}
								break;
							case JsSIP.C.ACK:
								// Just in case ;-)
								break;
							default:
								transaction = this.ua.transactions.nict[message.via_branch];
								if (transaction) {
									transaction.receiveResponse(message);
								}
								break;
						}
					}
				}
			},

			/**
			 * @event
			 * @param {event} e
			 */
			onError: function (e) {
				console.warn(LOG_PREFIX + 'WebSocket connection error: ' + e);
			},

			/**
			 * Reconnection attempt logic.
			 * @private
			 */
			reConnect: function () {
				var transport = this;

				this.reconnection_attempts += 1;

				if (this.reconnection_attempts > this.ua.configuration.ws_server_max_reconnection) {
					console.warn(LOG_PREFIX + 'maximum reconnection attempts for WebSocket ' + this.server.ws_uri);
					this.ua.onTransportError(this);
				} else {
					console.log(LOG_PREFIX + 'trying to reconnect to WebSocket ' + this.server.ws_uri + ' (reconnection attempt ' + this.reconnection_attempts + ')');

					this.reconnectTimer = window.setTimeout(function () {
						transport.connect();
					}, this.ua.configuration.ws_server_reconnection_timeout * 1000);
				}
			}
		};

		Transport.C = C;
		JsSIP.Transport = Transport;
	}(JsSIP));


	/**
	 * @fileoverview SIP Message Parser
	 */

	/**
	 * Extract and parse every header of a SIP message.
	 * @augments JsSIP
	 * @namespace
	 */
	(function (JsSIP) {
		var Parser,
			LOG_PREFIX = JsSIP.name + ' | ' + 'PARSER' + ' | ';

		function getHeader(data, headerStart) {
			var
			// 'start' position of the header.
				start = headerStart,
			// 'end' position of the header.
				end = 0,
			// 'partial end' position of the header.
				partialEnd = 0;

			//End of message.
			if (data.substring(start, start + 2).match(/(^\r\n)/)) {
				return -2;
			}

			while (end === 0) {
				// Partial End of Header.
				partialEnd = data.indexOf('\r\n', start);

				// 'indexOf' returns -1 if the value to be found never occurs.
				if (partialEnd === -1) {
					return partialEnd;
				}

				if (!data.substring(partialEnd + 2, partialEnd + 4).match(/(^\r\n)/) && data.charAt(partialEnd + 2).match(/(^\s+)/)) {
					// Not the end of the message. Continue from the next position.
					start = partialEnd + 2;
				} else {
					end = partialEnd;
				}
			}

			return end;
		}

		function parseHeader(message, data, headerStart, headerEnd) {
			var header, idx, parsed,
				hcolonIndex = data.indexOf(':', headerStart),
				headerName = data.substring(headerStart, hcolonIndex).trim(),
				headerValue = data.substring(hcolonIndex + 1, headerEnd).trim();

			// If header-field is well-known, parse it.
			switch (headerName.toLowerCase()) {
				case 'via':
				case 'v':
					message.addHeader('via', headerValue);
					if (message.countHeader('via') === 1) {
						parsed = message.parseHeader('Via');
						if (parsed) {
							message.via = parsed;
							message.via_branch = parsed.branch;
						}
					} else {
						parsed = 0;
					}
					break;
				case 'from':
				case 'f':
					message.setHeader('from', headerValue);
					parsed = message.parseHeader('from');
					if (parsed) {
						message.from = parsed;
						message.from_tag = parsed.getParam('tag');
					}
					break;
				case 'to':
				case 't':
					message.setHeader('to', headerValue);
					parsed = message.parseHeader('to');
					if (parsed) {
						message.to = parsed;
						message.to_tag = parsed.getParam('tag');
					}
					break;
				case 'record-route':
					parsed = JsSIP.Grammar.parse(headerValue, 'Record_Route');

					if (parsed === -1) {
						parsed = undefined;
					}

					for (idx in parsed) {
						header = parsed[idx];
						message.addHeader('record-route', headerValue.substring(header.possition, header.offset));
						message.headers['Record-Route'][message.countHeader('record-route') - 1].parsed = header.parsed;
					}
					break;
				case 'call-id':
				case 'i':
					message.setHeader('call-id', headerValue);
					parsed = message.parseHeader('call-id');
					if (parsed) {
						message.call_id = headerValue;
					}
					break;
				case 'contact':
				case 'm':
					parsed = JsSIP.Grammar.parse(headerValue, 'Contact');

					if (parsed === -1) {
						parsed = undefined;
					}

					for (idx in parsed) {
						header = parsed[idx];
						message.addHeader('contact', headerValue.substring(header.possition, header.offset));
						message.headers['Contact'][message.countHeader('contact') - 1].parsed = header.parsed;
					}
					break;
				case 'content-length':
				case 'l':
					message.setHeader('content-length', headerValue);
					parsed = message.parseHeader('content-length');
					break;
				case 'content-type':
				case 'c':
					message.setHeader('content-type', headerValue);
					parsed = message.parseHeader('content-type');
					break;
				case 'cseq':
					message.setHeader('cseq', headerValue);
					parsed = message.parseHeader('cseq');
					if (parsed) {
						message.cseq = parsed.value;
					}
					if (message instanceof JsSIP.IncomingResponse) {
						message.method = parsed.method;
					}
					break;
				case 'max-forwards':
					message.setHeader('max-forwards', headerValue);
					parsed = message.parseHeader('max-forwards');
					break;
				case 'www-authenticate':
					message.setHeader('www-authenticate', headerValue);
					parsed = message.parseHeader('www-authenticate');
					break;
				case 'proxy-authenticate':
					message.setHeader('proxy-authenticate', headerValue);
					parsed = message.parseHeader('proxy-authenticate');
					break;
				default:
					// Do not parse this header.
					message.setHeader(headerName, headerValue);
					parsed = 0;
			}

			if (parsed === undefined) {
				return false;
			} else {
				return true;
			}
		}

		/** Parse SIP Message
		 * @function
		 * @param {String} message SIP message.
		 * @returns {JsSIP.IncomingRequest|JsSIP.IncomingResponse|undefined}
		 */
		Parser = {};
		Parser.parseMessage = function (data) {
			var message, firstLine, contentLength, bodyStart, parsed,
				headerStart = 0,
				headerEnd = data.indexOf('\r\n');

			if (headerEnd === -1) {
				console.warn(LOG_PREFIX + 'no CRLF found, not a SIP message, discarded');
				return;
			}

			// Parse first line. Check if it is a Request or a Reply.
			firstLine = data.substring(0, headerEnd);
			parsed = JsSIP.Grammar.parse(firstLine, 'Request_Response');

			if (parsed === -1) {
				console.warn(LOG_PREFIX + 'error parsing first line of SIP message: "' + firstLine + '"');
				return;
			} else if (!parsed.status_code) {
				message = new JsSIP.IncomingRequest();
				message.method = parsed.method;
				message.ruri = parsed.uri;
			} else {
				message = new JsSIP.IncomingResponse();
				message.status_code = parsed.status_code;
				message.reason_phrase = parsed.reason_phrase;
			}

			message.data = data;
			headerStart = headerEnd + 2;

			/* Loop over every line in data. Detect the end of each header and parse
			 * it or simply add to the headers collection.
			 */
			while (true) {
				headerEnd = getHeader(data, headerStart);

				// The SIP message has normally finished.
				if (headerEnd === -2) {
					bodyStart = headerStart + 2;
					break;
				}
				// data.indexOf returned -1 due to a malformed message.
				else if (headerEnd === -1) {
					return;
				}

				parsed = parseHeader(message, data, headerStart, headerEnd);

				if (!parsed) {
					return;
				}

				headerStart = headerEnd + 2;
			}

			/* RFC3261 18.3.
			 * If there are additional bytes in the transport packet
			 * beyond the end of the body, they MUST be discarded.
			 */
			if (message.hasHeader('content-length')) {
				contentLength = message.getHeader('content-length');
				message.body = data.substr(bodyStart, contentLength);
			} else {
				message.body = data.substring(bodyStart);
			}

			return message;
		};

		JsSIP.Parser = Parser;
	}(JsSIP));


	/**
	 * @fileoverview SIP Message
	 */

	(function (JsSIP) {
		var
			OutgoingRequest,
			IncomingMessage,
			IncomingRequest,
			IncomingResponse,
			LOG_PREFIX = JsSIP.name + ' | ' + 'SIP MESSAGE' + ' | ';

		/**
		 * @augments JsSIP
		 * @class Class for outgoing SIP request.
		 * @param {String} method request method
		 * @param {String} ruri request uri
		 * @param {JsSIP.UA} ua
		 * @param {Object} params parameters that will have priority over ua.configuration parameters:
		 * <br>
		 *  - cseq, call_id, from_tag, from_uri, from_display_name, to_uri, to_tag, route_set
		 * @param {Object} [headers] extra headers
		 * @param {String} [body]
		 */
		OutgoingRequest = function (method, ruri, ua, params, extraHeaders, body) {
			var
				to,
				from,
				call_id,
				cseq;

			params = params || {};

			// Mandatory parameters check
			if (!method || !ruri || !ua) {
				return null;
			}

			this.headers = {};
			this.method = method;
			this.ruri = ruri;
			this.body = body;
			this.extraHeaders = extraHeaders || [];

			// Fill the Common SIP Request Headers

			// Route
			if (params.route_set) {
				this.setHeader('route', params.route_set);
			} else if (ua.configuration.use_preloaded_route) {
				this.setHeader('route', ua.transport.server.sip_uri);
			}

			// Via
			// Empty Via header. Will be filled by the client transaction.
			this.setHeader('via', '');

			// Max-Forwards
			this.setHeader('max-forwards', JsSIP.UA.C.MAX_FORWARDS);

			// To
			to = (params.to_display_name || params.to_display_name === 0) ? '"' + params.to_display_name + '" ' : '';
			to += '<' + (params.to_uri || ruri) + '>';
			to += params.to_tag ? ';tag=' + params.to_tag : '';
			this.to = new JsSIP.NameAddrHeader.parse(to);
			this.setHeader('to', to);

			// From
			if (params.from_display_name || params.from_display_name === 0) {
				from = '"' + params.from_display_name + '" ';
			} else if (ua.configuration.display_name) {
				from = '"' + ua.configuration.display_name + '" ';
			} else {
				from = '';
			}
			from += '<' + (params.from_uri || ua.configuration.uri) + '>;tag=';
			from += params.from_tag || JsSIP.Utils.newTag();
			this.from = new JsSIP.NameAddrHeader.parse(from);
			this.setHeader('from', from);

			// Call-ID
			call_id = params.call_id || (ua.configuration.jssip_id + JsSIP.Utils.createRandomToken(15));
			this.call_id = call_id;
			this.setHeader('call-id', call_id);

			// CSeq
			cseq = params.cseq || Math.floor(Math.random() * 10000);
			this.cseq = cseq;
			this.setHeader('cseq', cseq + ' ' + method);
		};

		OutgoingRequest.prototype = {
			/**
			 * Replace the the given header by the given value.
			 * @param {String} name header name
			 * @param {String | Array} value header value
			 */
			setHeader: function (name, value) {
				this.headers[JsSIP.Utils.headerize(name)] = (value instanceof Array) ? value : [value];
			},
			toString: function () {
				var msg = '', header, length, idx;

				msg += this.method + ' ' + this.ruri + ' SIP/2.0\r\n';

				for (header in this.headers) {
					for (idx in this.headers[header]) {
						msg += header + ': ' + this.headers[header][idx] + '\r\n';
					}
				}

				length = this.extraHeaders.length;
				for (idx = 0; idx < length; idx++) {
					msg += this.extraHeaders[idx] + '\r\n';
				}

				msg += 'Supported: ' + JsSIP.UA.C.SUPPORTED + '\r\n';
				msg += 'User-Agent: ' + JsSIP.C.USER_AGENT + '\r\n';

				if (this.body) {
					length = JsSIP.Utils.str_utf8_length(this.body);
					msg += 'Content-Length: ' + length + '\r\n\r\n';
					msg += this.body;
				} else {
					msg += 'Content-Length: 0\r\n\r\n';
				}

				return msg;
			}
		};

		/**
		 * @augments JsSIP
		 * @class Class for incoming SIP message.
		 */
		IncomingMessage = function () {
			this.data = null;
			this.headers = null;
			this.method = null;
			this.via = null;
			this.via_branch = null;
			this.call_id = null;
			this.cseq = null;
			this.from = null;
			this.from_tag = null;
			this.to = null;
			this.to_tag = null;
			this.body = null;
		};

		IncomingMessage.prototype = {
			/**
			 * Insert a header of the given name and value into the last position of the
			 * header array.
			 * @param {String} name header name
			 * @param {String} value header value
			 */
			addHeader: function (name, value) {
				var header = { raw: value };

				name = JsSIP.Utils.headerize(name);

				if (this.headers[name]) {
					this.headers[name].push(header);
				} else {
					this.headers[name] = [header];
				}
			},

			/**
			 * Count the number of headers of the given header name.
			 * @param {String} name header name
			 * @returns {Number} Number of headers with the given name
			 */
			countHeader: function (name) {
				var header = this.headers[JsSIP.Utils.headerize(name)];

				if (header) {
					return header.length;
				} else {
					return 0;
				}
			},

			/**
			 * Get the value of the given header name at the given position.
			 * @param {String} name header name
			 * @param {Number} [idx=0] header index
			 * @returns {String|undefined} Returns the specified header, null if header doesn't exist.
			 */
			getHeader: function (name, idx) {
				var header = this.headers[JsSIP.Utils.headerize(name)];

				idx = idx || 0;

				if (header) {
					if (header[idx]) {
						return header[idx].raw;
					}
				} else {
					return;
				}
			},

			/**
			 * Get the header/s of the given name.
			 * @param {String} name header name
			 * @returns {Array} Array with all the headers of the specified name.
			 */
			getHeaderAll: function (name) {
				var idx,
					header = this.headers[JsSIP.Utils.headerize(name)],
					result = [];

				if (!header) {
					return [];
				}

				for (idx in header) {
					result.push(header[idx].raw);
				}

				return result;
			},

			/**
			 * Verify the existence of the given header.
			 * @param {String} name header name
			 * @returns {boolean} true if header with given name exists, false otherwise
			 */
			hasHeader: function (name) {
				return(this.headers[JsSIP.Utils.headerize(name)]) ? true : false;
			},

			/**
			 * Parse the given header on the given index.
			 * @param {String} name header name
			 * @param {Number} [idx=0] header index
			 * @returns {Object|undefined} Parsed header object, undefined if the header is not present or in case of a parsing error.
			 */
			parseHeader: function (name, idx) {
				var header, value, parsed;

				name = JsSIP.Utils.headerize(name);

				idx = idx || 0;

				if (!this.headers[name]) {
					console.log(LOG_PREFIX + 'header "' + name + '" not present');
					return;
				} else if (idx >= this.headers[name].length) {
					console.log(LOG_PREFIX + 'not so many "' + name + '" headers present');
					return;
				}

				header = this.headers[name][idx];
				value = header.raw;

				if (header.parsed) {
					return header.parsed;
				}

				//substitute '-' by '_' for grammar rule matching.
				parsed = JsSIP.Grammar.parse(value, name.replace(/-/g, '_'));

				if (parsed === -1) {
					this.headers[name].splice(idx, 1); //delete from headers
					console.warn(LOG_PREFIX + 'error parsing "' + name + '" header field with value "' + value + '"');
					return;
				} else {
					header.parsed = parsed;
					return parsed;
				}
			},

			/**
			 * Message Header attribute selector. Alias of parseHeader.
			 * @param {String} name header name
			 * @param {Number} [idx=0] header index
			 * @returns {Object|undefined} Parsed header object, undefined if the header is not present or in case of a parsing error.
			 *
			 * @example
			 * message.s('via',3).port
			 */
			s: function (name, idx) {
				return this.parseHeader(name, idx);
			},

			/**
			 * Replace the value of the given header by the value.
			 * @param {String} name header name
			 * @param {String} value header value
			 */
			setHeader: function (name, value) {
				var header = { raw: value };
				this.headers[JsSIP.Utils.headerize(name)] = [header];
			},

			toString: function () {
				return this.data;
			}
		};

		/**
		 * @augments IncomingMessage
		 * @class Class for incoming SIP request.
		 */
		IncomingRequest = function () {
			this.headers = {};
			this.ruri = null;
			this.transport = null;
			this.server_transaction = null;
		};
		IncomingRequest.prototype = new IncomingMessage();

		/**
		 * Stateful reply.
		 * @param {Number} code status code
		 * @param {String} reason reason phrase
		 * @param {Object} headers extra headers
		 * @param {String} body body
		 * @param {Function} [onSuccess] onSuccess callback
		 * @param {Function} [onFailure] onFailure callback
		 */
		IncomingRequest.prototype.reply = function (code, reason, extraHeaders, body, onSuccess, onFailure) {
			var rr, vias, length, idx, response,
				to = this.getHeader('To'),
				r = 0,
				v = 0;

			code = code || null;
			reason = reason || null;

			// Validate code and reason values
			if (!code || (code < 100 || code > 699)) {
				throw new TypeError('Invalid status_code: ' + code);
			} else if (reason && typeof reason !== 'string' && !(reason instanceof String)) {
				throw new TypeError('Invalid reason_phrase: ' + reason);
			}

			reason = reason || JsSIP.C.REASON_PHRASE[code] || '';
			extraHeaders = extraHeaders || [];

			response = 'SIP/2.0 ' + code + ' ' + reason + '\r\n';

			if (this.method === JsSIP.C.INVITE && code > 100 && code <= 200) {
				rr = this.countHeader('record-route');

				for (r; r < rr; r++) {
					response += 'Record-Route: ' + this.getHeader('record-route', r) + '\r\n';
				}
			}

			vias = this.countHeader('via');

			for (v; v < vias; v++) {
				response += 'Via: ' + this.getHeader('via', v) + '\r\n';
			}

			if (!this.to_tag && code > 100) {
				to += ';tag=' + JsSIP.Utils.newTag();
			} else if (this.to_tag && !this.s('to').hasParam('tag')) {
				to += ';tag=' + this.to_tag;
			}

			response += 'To: ' + to + '\r\n';
			response += 'From: ' + this.getHeader('From') + '\r\n';
			response += 'Call-ID: ' + this.call_id + '\r\n';
			response += 'CSeq: ' + this.cseq + ' ' + this.method + '\r\n';

			length = extraHeaders.length;
			for (idx = 0; idx < length; idx++) {
				response += extraHeaders[idx] + '\r\n';
			}

			if (body) {
				length = JsSIP.Utils.str_utf8_length(body);
				response += 'Content-Type: application/sdp\r\n';
				response += 'Content-Length: ' + length + '\r\n\r\n';
				response += body;
			} else {
				response += 'Content-Length: ' + 0 + '\r\n\r\n';
			}

			this.server_transaction.receiveResponse(code, response, onSuccess, onFailure);
		};

		/**
		 * Stateless reply.
		 * @param {Number} code status code
		 * @param {String} reason reason phrase
		 */
		IncomingRequest.prototype.reply_sl = function (code, reason) {
			var to, response,
				vias = this.countHeader('via');

			code = code || null;
			reason = reason || null;

			// Validate code and reason values
			if (!code || (code < 100 || code > 699)) {
				throw new TypeError('Invalid status_code: ' + code);
			} else if (reason && typeof reason !== 'string' && !(reason instanceof String)) {
				throw new TypeError('Invalid reason_phrase: ' + reason);
			}

			reason = reason || JsSIP.C.REASON_PHRASE[code] || '';

			response = 'SIP/2.0 ' + code + ' ' + reason + '\r\n';

			for (var v = 0; v < vias; v++) {
				response += 'Via: ' + this.getHeader('via', v) + '\r\n';
			}

			to = this.getHeader('To');

			if (!this.to_tag && code > 100) {
				to += ';tag=' + JsSIP.Utils.newTag();
			} else if (this.to_tag && !this.s('to').hasParam('tag')) {
				to += ';tag=' + this.to_tag;
			}

			response += 'To: ' + to + '\r\n';
			response += 'From: ' + this.getHeader('From') + '\r\n';
			response += 'Call-ID: ' + this.call_id + '\r\n';
			response += 'CSeq: ' + this.cseq + ' ' + this.method + '\r\n';
			response += 'Content-Length: ' + 0 + '\r\n\r\n';

			this.transport.send(response);
		};


		/**
		 * @augments IncomingMessage
		 * @class Class for incoming SIP response.
		 */
		IncomingResponse = function () {
			this.headers = {};
			this.status_code = null;
			this.reason_phrase = null;
		};
		IncomingResponse.prototype = new IncomingMessage();

		JsSIP.OutgoingRequest = OutgoingRequest;
		JsSIP.IncomingRequest = IncomingRequest;
		JsSIP.IncomingResponse = IncomingResponse;
	}(JsSIP));


	/**
	 * @fileoverview SIP URI
	 */

	/**
	 * @augments JsSIP
	 * @class Class creating a SIP URI.
	 *
	 * @param {String} [scheme]
	 * @param {String} [user]
	 * @param {String} host
	 * @param {String} [port]
	 * @param {Object} [parameters]
	 * @param {Object} [headers]
	 *
	 */
	(function (JsSIP) {
		var URI;

		URI = function (scheme, user, host, port, parameters, headers) {
			var param, header;

			// Checks
			if (!host) {
				throw new TypeError('missing or invalid "host" parameter');
			}

			// Initialize parameters
			scheme = scheme || JsSIP.C.SIP;
			this.parameters = {};
			this.headers = {};

			for (param in parameters) {
				this.setParam(param, parameters[param]);
			}

			for (header in headers) {
				this.setHeader(header, headers[header]);
			}

			Object.defineProperties(this, {
				scheme: {
					get: function () {
						return scheme;
					},
					set: function (value) {
						scheme = value.toLowerCase();
					}
				},

				user: {
					get: function () {
						return user;
					},
					set: function (value) {
						user = value;
					}
				},

				host: {
					get: function () {
						return host;
					},
					set: function (value) {
						host = value.toLowerCase();
					}
				},

				port: {
					get: function () {
						return port;
					},
					set: function (value) {
						port = value === 0 ? value : (parseInt(value, 10) || null);
					}
				}
			});
		};
		URI.prototype = {
			setParam: function (key, value) {
				if (key) {
					this.parameters[key.toLowerCase()] = (typeof value === 'undefined' || value === null) ? null : value.toString().toLowerCase();
				}
			},

			getParam: function (key) {
				if (key) {
					return this.parameters[key.toLowerCase()];
				}
			},

			hasParam: function (key) {
				if (key) {
					return (this.parameters.hasOwnProperty(key.toLowerCase()) && true) || false;
				}
			},

			deleteParam: function (parameter) {
				var value;
				parameter = parameter.toLowerCase();
				if (this.parameters.hasOwnProperty(parameter)) {
					value = this.parameters[parameter];
					delete this.parameters[parameter];
					return value;
				}
			},

			clearParams: function () {
				this.parameters = {};
			},

			setHeader: function (name, value) {
				this.headers[JsSIP.Utils.headerize(name)] = (value instanceof Array) ? value : [value];
			},

			getHeader: function (name) {
				if (name) {
					return this.headers[JsSIP.Utils.headerize(name)];
				}
			},

			hasHeader: function (name) {
				if (name) {
					return (this.headers.hasOwnProperty(JsSIP.Utils.headerize(name)) && true) || false;
				}
			},

			deleteHeader: function (header) {
				var value;
				header = JsSIP.Utils.headerize(header);
				if (this.headers.hasOwnProperty(header)) {
					value = this.headers[header];
					delete this.headers[header];
					return value;
				}
			},

			clearHeaders: function () {
				this.headers = {};
			},

			clone: function () {
				return new URI(
					this.scheme,
					this.user,
					this.host,
					this.port,
					window.JSON.parse(window.JSON.stringify(this.parameters)),
					window.JSON.parse(window.JSON.stringify(this.headers)));
			},

			toString: function () {
				var header, parameter, idx, uri,
					headers = [];

				uri = this.scheme + ':';
				if (this.user) {
					uri += JsSIP.Utils.escapeUser(this.user) + '@';
				}
				uri += this.host;
				if (this.port || this.port === 0) {
					uri += ':' + this.port;
				}

				for (parameter in this.parameters) {
					uri += ';' + parameter;

					if (this.parameters[parameter] !== null) {
						uri += '=' + this.parameters[parameter];
					}
				}

				for (header in this.headers) {
					for (idx in this.headers[header]) {
						headers.push(header + '=' + this.headers[header][idx]);
					}
				}

				if (headers.length > 0) {
					uri += '?' + headers.join('&');
				}

				return uri;
			},

			toAor: function (show_port) {
				var aor;

				aor = this.scheme + ':';
				if (this.user) {
					aor += JsSIP.Utils.escapeUser(this.user) + '@';
				}
				aor += this.host;
				if (show_port && (this.port || this.port === 0)) {
					aor += ':' + this.port;
				}

				return aor;
			}
		};


		/**
		 * Parse the given string and returns a JsSIP.URI instance or undefined if
		 * it is an invalid URI.
		 * @public
		 * @param {String} uri
		 */
		URI.parse = function (uri) {
			uri = JsSIP.Grammar.parse(uri, 'SIP_URI');

			if (uri !== -1) {
				return uri;
			} else {
				return undefined;
			}
		};

		JsSIP.URI = URI;
	}(JsSIP));


	/**
	 * @fileoverview JsSIP NameAddrHeader
	 */

	/**
	 * @augments JsSIP
	 * @class Class creating a Name Address SIP header.
	 *
	 * @param {JsSIP.URI} uri
	 * @param {String} [display_name]
	 * @param {Object} [parameters]
	 *
	 */
	(function (JsSIP) {
		var NameAddrHeader;

		NameAddrHeader = function (uri, display_name, parameters) {
			var param;

			// Checks
			if (!uri || !(uri instanceof JsSIP.URI)) {
				throw new TypeError('missing or invalid "uri" parameter');
			}

			// Initialize parameters
			this.uri = uri;
			this.parameters = {};

			for (param in parameters) {
				this.setParam(param, parameters[param]);
			}

			Object.defineProperties(this, {
				display_name: {
					get: function () {
						return display_name;
					},
					set: function (value) {
						display_name = (value === 0) ? '0' : value;
					}
				}
			});
		};
		NameAddrHeader.prototype = {
			setParam: function (key, value) {
				if (key) {
					this.parameters[key.toLowerCase()] = (typeof value === 'undefined' || value === null) ? null : value.toString();
				}
			},

			getParam: function (key) {
				if (key) {
					return this.parameters[key.toLowerCase()];
				}
			},

			hasParam: function (key) {
				if (key) {
					return (this.parameters.hasOwnProperty(key.toLowerCase()) && true) || false;
				}
			},

			deleteParam: function (parameter) {
				var value;
				parameter = parameter.toLowerCase();
				if (this.parameters.hasOwnProperty(parameter)) {
					value = this.parameters[parameter];
					delete this.parameters[parameter];
					return value;
				}
			},

			clearParams: function () {
				this.parameters = {};
			},

			clone: function () {
				return new NameAddrHeader(
					this.uri.clone(),
					this.display_name,
					window.JSON.parse(window.JSON.stringify(this.parameters)));
			},

			toString: function () {
				var body, parameter;

				body = (this.display_name || this.display_name === 0) ? '"' + this.display_name + '" ' : '';
				body += '<' + this.uri.toString() + '>';

				for (parameter in this.parameters) {
					body += ';' + parameter;

					if (this.parameters[parameter] !== null) {
						body += '=' + this.parameters[parameter];
					}
				}

				return body;
			}
		};


		/**
		 * Parse the given string and returns a JsSIP.NameAddrHeader instance or undefined if
		 * it is an invalid NameAddrHeader.
		 * @public
		 * @param {String} name_addr_header
		 */
		NameAddrHeader.parse = function (name_addr_header) {
			name_addr_header = JsSIP.Grammar.parse(name_addr_header, 'Name_Addr_Header');

			if (name_addr_header !== -1) {
				return name_addr_header;
			} else {
				return undefined;
			}
		};

		JsSIP.NameAddrHeader = NameAddrHeader;
	}(JsSIP));


	/**
	 * @fileoverview SIP Transactions
	 */

	/**
	 * SIP Transactions module.
	 * @augments JsSIP
	 */
	(function (JsSIP) {
		var Transactions,
			LOG_PREFIX = JsSIP.name + ' | ' + 'TRANSACTION' + ' | ',
			C = {
				// Transaction states
				STATUS_TRYING: 1,
				STATUS_PROCEEDING: 2,
				STATUS_CALLING: 3,
				STATUS_ACCEPTED: 4,
				STATUS_COMPLETED: 5,
				STATUS_TERMINATED: 6,
				STATUS_CONFIRMED: 7
			};

		Transactions = {};

		/**
		 * @class Client Transaction
		 * @private
		 */
		var ClientTransaction = function () {
			this.init = function (request_sender, request, transport) {
				var via;

				this.transport = transport;
				this.id = 'z9hG4bK' + Math.floor(Math.random() * 10000000);
				this.request_sender = request_sender;
				this.request = request;

				via = 'SIP/2.0/' + (request_sender.ua.configuration.hack_via_tcp ? 'TCP' : transport.server.scheme);
				via += ' ' + request_sender.ua.configuration.via_host + ';branch=' + this.id;

				this.request.setHeader('via', via);
			};
		};

		/**
		 * @class Non Invite Client Transaction Prototype
		 * @private
		 */
		var NonInviteClientTransactionPrototype = function () {
			this.send = function () {
				var tr = this;

				this.state = C.STATUS_TRYING;
				this.F = window.setTimeout(function () {
					tr.timer_F();
				}, JsSIP.Timers.TIMER_F);

				if (!this.transport.send(this.request)) {
					this.onTransportError();
				}
			};

			this.onTransportError = function () {
				console.log(LOG_PREFIX + 'transport error occurred, deleting non-INVITE client transaction ' + this.id);
				window.clearTimeout(this.F);
				window.clearTimeout(this.K);
				delete this.request_sender.ua.transactions.nict[this.id];
				this.request_sender.onTransportError();
			};

			this.timer_F = function () {
				console.log(LOG_PREFIX + 'Timer F expired for non-INVITE client transaction ' + this.id);
				this.state = C.STATUS_TERMINATED;
				this.request_sender.onRequestTimeout();
				delete this.request_sender.ua.transactions.nict[this.id];
			};

			this.timer_K = function () {
				this.state = C.STATUS_TERMINATED;
				delete this.request_sender.ua.transactions.nict[this.id];
			};

			this.receiveResponse = function (response) {
				var
					tr = this,
					status_code = response.status_code;

				if (status_code < 200) {
					switch (this.state) {
						case C.STATUS_TRYING:
						case C.STATUS_PROCEEDING:
							this.state = C.STATUS_PROCEEDING;
							this.request_sender.receiveResponse(response);
							break;
					}
				} else {
					switch (this.state) {
						case C.STATUS_TRYING:
						case C.STATUS_PROCEEDING:
							this.state = C.STATUS_COMPLETED;
							window.clearTimeout(this.F);

							if (status_code === 408) {
								this.request_sender.onRequestTimeout();
							} else {
								this.request_sender.receiveResponse(response);
							}

							this.K = window.setTimeout(function () {
								tr.timer_K();
							}, JsSIP.Timers.TIMER_K);
							break;
						case C.STATUS_COMPLETED:
							break;
					}
				}
			};
		};
		NonInviteClientTransactionPrototype.prototype = new ClientTransaction();


		/**
		 * @class Invite Client Transaction Prototype
		 * @private
		 */
		var InviteClientTransactionPrototype = function () {

			this.send = function () {
				var tr = this;
				this.state = C.STATUS_CALLING;
				this.B = window.setTimeout(function () {
					tr.timer_B();
				}, JsSIP.Timers.TIMER_B);

				if (!this.transport.send(this.request)) {
					this.onTransportError();
				}
			};

			this.onTransportError = function () {
				console.log(LOG_PREFIX + 'transport error occurred, deleting INVITE client transaction ' + this.id);
				window.clearTimeout(this.B);
				window.clearTimeout(this.D);
				window.clearTimeout(this.M);
				delete this.request_sender.ua.transactions.ict[this.id];

				if (this.state !== C.STATUS_ACCEPTED) {
					this.request_sender.onTransportError();
				}
			};

			// RFC 6026 7.2
			this.timer_M = function () {
				console.log(LOG_PREFIX + 'Timer M expired for INVITE client transaction ' + this.id);

				if (this.state === C.STATUS_ACCEPTED) {
					this.state = C.STATUS_TERMINATED;
					window.clearTimeout(this.B);
					delete this.request_sender.ua.transactions.ict[this.id];
				}
			};

			// RFC 3261 17.1.1
			this.timer_B = function () {
				console.log(LOG_PREFIX + 'Timer B expired for INVITE client transaction ' + this.id);
				if (this.state === C.STATUS_CALLING) {
					this.state = C.STATUS_TERMINATED;
					this.request_sender.onRequestTimeout();
					delete this.request_sender.ua.transactions.ict[this.id];
				}
			};

			this.timer_D = function () {
				console.log(LOG_PREFIX + 'Timer D expired for INVITE client transaction ' + this.id);
				this.state = C.STATUS_TERMINATED;
				window.clearTimeout(this.B);
				delete this.request_sender.ua.transactions.ict[this.id];
			};

			this.sendACK = function (response) {
				var tr = this;

				this.ack = 'ACK ' + this.request.ruri + ' SIP/2.0\r\n';
				this.ack += 'Via: ' + this.request.headers['Via'].toString() + '\r\n';

				if (this.request.headers['Route']) {
					this.ack += 'Route: ' + this.request.headers['Route'].toString() + '\r\n';
				}

				this.ack += 'To: ' + response.getHeader('to') + '\r\n';
				this.ack += 'From: ' + this.request.headers['From'].toString() + '\r\n';
				this.ack += 'Call-ID: ' + this.request.headers['Call-ID'].toString() + '\r\n';
				this.ack += 'CSeq: ' + this.request.headers['CSeq'].toString().split(' ')[0];
				this.ack += ' ACK\r\n\r\n';

				this.D = window.setTimeout(function () {
					tr.timer_D();
				}, JsSIP.Timers.TIMER_D);

				this.transport.send(this.ack);
			};

			this.cancel_request = function (tr, reason) {
				var request = tr.request;

				this.cancel = JsSIP.C.CANCEL + ' ' + request.ruri + ' SIP/2.0\r\n';
				this.cancel += 'Via: ' + request.headers['Via'].toString() + '\r\n';

				if (this.request.headers['Route']) {
					this.cancel += 'Route: ' + request.headers['Route'].toString() + '\r\n';
				}

				this.cancel += 'To: ' + request.headers['To'].toString() + '\r\n';
				this.cancel += 'From: ' + request.headers['From'].toString() + '\r\n';
				this.cancel += 'Call-ID: ' + request.headers['Call-ID'].toString() + '\r\n';
				this.cancel += 'CSeq: ' + request.headers['CSeq'].toString().split(' ')[0] +
					' CANCEL\r\n';

				if (reason) {
					this.cancel += 'Reason: ' + reason + '\r\n';
				}

				this.cancel += 'Content-Length: 0\r\n\r\n';

				// Send only if a provisional response (>100) has been received.
				if (this.state === C.STATUS_PROCEEDING) {
					this.transport.send(this.cancel);
				}
			};

			this.receiveResponse = function (response) {
				var
					tr = this,
					status_code = response.status_code;

				if (status_code >= 100 && status_code <= 199) {
					switch (this.state) {
						case C.STATUS_CALLING:
							this.state = C.STATUS_PROCEEDING;
							this.request_sender.receiveResponse(response);
							if (this.cancel) {
								this.transport.send(this.cancel);
							}
							break;
						case C.STATUS_PROCEEDING:
							this.request_sender.receiveResponse(response);
							break;
					}
				} else if (status_code >= 200 && status_code <= 299) {
					switch (this.state) {
						case C.STATUS_CALLING:
						case C.STATUS_PROCEEDING:
							this.state = C.STATUS_ACCEPTED;
							this.M = window.setTimeout(function () {
								tr.timer_M();
							}, JsSIP.Timers.TIMER_M);
							this.request_sender.receiveResponse(response);
							break;
						case C.STATUS_ACCEPTED:
							this.request_sender.receiveResponse(response);
							break;
					}
				} else if (status_code >= 300 && status_code <= 699) {
					switch (this.state) {
						case C.STATUS_CALLING:
						case C.STATUS_PROCEEDING:
							this.state = C.STATUS_COMPLETED;
							this.sendACK(response);
							this.request_sender.receiveResponse(response);
							break;
						case C.STATUS_COMPLETED:
							this.sendACK(response);
							break;
					}
				}
			};
		};
		InviteClientTransactionPrototype.prototype = new ClientTransaction();

		/**
		 * @class Server Transaction
		 * @private
		 */
		var ServerTransaction = function () {
			this.init = function (request, ua) {
				this.id = request.via_branch;
				this.request = request;
				this.transport = request.transport;
				this.ua = ua;
				this.last_response = '';
				request.server_transaction = this;
			};
		};

		/**
		 * @class Non Invite Server Transaction Prototype
		 * @private
		 */
		var NonInviteServerTransactionPrototype = function () {
			this.timer_J = function () {
				console.log(LOG_PREFIX + 'Timer J expired for non-INVITE server transaction ' + this.id);
				this.state = C.STATUS_TERMINATED;
				delete this.ua.transactions.nist[this.id];
			};

			this.onTransportError = function () {
				if (!this.transportError) {
					this.transportError = true;

					console.log(LOG_PREFIX + 'transport error occurred, deleting non-INVITE server transaction ' + this.id);

					window.clearTimeout(this.J);
					delete this.ua.transactions.nist[this.id];
				}
			};

			this.receiveResponse = function (status_code, response, onSuccess, onFailure) {
				var tr = this;

				if (status_code === 100) {
					/* RFC 4320 4.1
					 * 'A SIP element MUST NOT
					 * send any provisional response with a
					 * Status-Code other than 100 to a non-INVITE request.'
					 */
					switch (this.state) {
						case C.STATUS_TRYING:
							this.state = C.STATUS_PROCEEDING;
							if (!this.transport.send(response)) {
								this.onTransportError();
							}
							break;
						case C.STATUS_PROCEEDING:
							this.last_response = response;
							if (!this.transport.send(response)) {
								this.onTransportError();
								if (onFailure) {
									onFailure();
								}
							} else if (onSuccess) {
								onSuccess();
							}
							break;
					}
				} else if (status_code >= 200 && status_code <= 699) {
					switch (this.state) {
						case C.STATUS_TRYING:
						case C.STATUS_PROCEEDING:
							this.state = C.STATUS_COMPLETED;
							this.last_response = response;
							this.J = window.setTimeout(function () {
								tr.timer_J();
							}, JsSIP.Timers.TIMER_J);
							if (!this.transport.send(response)) {
								this.onTransportError();
								if (onFailure) {
									onFailure();
								}
							} else if (onSuccess) {
								onSuccess();
							}
							break;
						case C.STATUS_COMPLETED:
							break;
					}
				}
			};
		};
		NonInviteServerTransactionPrototype.prototype = new ServerTransaction();

		/**
		 * @class Invite Server Transaction Prototype
		 * @private
		 */
		var InviteServerTransactionPrototype = function () {
			this.timer_H = function () {
				console.log(LOG_PREFIX + 'Timer H expired for INVITE server transaction ' + this.id);

				if (this.state === C.STATUS_COMPLETED) {
					console.warn(LOG_PREFIX + 'transactions', 'ACK for INVITE server transaction was never received, call will be terminated');
					this.state = C.STATUS_TERMINATED;
				}

				delete this.ua.transactions.ist[this.id];
			};

			this.timer_I = function () {
				this.state = C.STATUS_TERMINATED;
				delete this.ua.transactions.ist[this.id];
			};

			// RFC 6026 7.1
			this.timer_L = function () {
				console.log(LOG_PREFIX + 'Timer L expired for INVITE server transaction ' + this.id);

				if (this.state === C.STATUS_ACCEPTED) {
					this.state = C.STATUS_TERMINATED;
					delete this.ua.transactions.ist[this.id];
				}
			};

			this.onTransportError = function () {
				if (!this.transportError) {
					this.transportError = true;

					console.log(LOG_PREFIX + 'transport error occurred, deleting INVITE server transaction ' + this.id);

					if (this.resendProvisionalTimer !== null) {
						window.clearInterval(this.resendProvisionalTimer);
						this.resendProvisionalTimer = null;
					}
					window.clearTimeout(this.L);
					window.clearTimeout(this.H);
					window.clearTimeout(this.I);
					delete this.ua.transactions.ist[this.id];
				}
			};

			this.resend_provisional = function () {
				if (!this.transport.send(this.last_response)) {
					this.onTransportError();
				}
			};

			// INVITE Server Transaction RFC 3261 17.2.1
			this.receiveResponse = function (status_code, response, onSuccess, onFailure) {
				var tr = this;

				if (status_code >= 100 && status_code <= 199) {
					switch (this.state) {
						case C.STATUS_PROCEEDING:
							if (!this.transport.send(response)) {
								this.onTransportError();
							}
							this.last_response = response;
							break;
					}
				}

				if (status_code > 100 && status_code <= 199 && this.state === C.STATUS_PROCEEDING) {
					// Trigger the resendProvisionalTimer only for the first non 100 provisional response.
					if (this.resendProvisionalTimer === null) {
						this.resendProvisionalTimer = window.setInterval(function () {
							tr.resend_provisional();
						}, JsSIP.Timers.PROVISIONAL_RESPONSE_INTERVAL);
					}
				} else if (status_code >= 200 && status_code <= 299) {
					switch (this.state) {
						case C.STATUS_PROCEEDING:
							this.state = C.STATUS_ACCEPTED;
							this.last_response = response;
							this.L = window.setTimeout(function () {
								tr.timer_L();
							}, JsSIP.Timers.TIMER_L);
							if (this.resendProvisionalTimer !== null) {
								window.clearInterval(this.resendProvisionalTimer);
								this.resendProvisionalTimer = null;
							}
						/* falls through */
						case C.STATUS_ACCEPTED:
							// Note that this point will be reached for proceeding tr.state also.
							if (!this.transport.send(response)) {
								this.onTransportError();
								if (onFailure) {
									onFailure();
								}
							} else if (onSuccess) {
								onSuccess();
							}
							break;
					}
				} else if (status_code >= 300 && status_code <= 699) {
					switch (this.state) {
						case C.STATUS_PROCEEDING:
							if (this.resendProvisionalTimer !== null) {
								window.clearInterval(this.resendProvisionalTimer);
								this.resendProvisionalTimer = null;
							}
							if (!this.transport.send(response)) {
								this.onTransportError();
								if (onFailure) {
									onFailure();
								}
							} else {
								this.state = C.STATUS_COMPLETED;
								this.H = window.setTimeout(function () {
									tr.timer_H();
								}, JsSIP.Timers.TIMER_H);
								if (onSuccess) {
									onSuccess();
								}
							}
							break;
					}
				}
			};
		};
		InviteServerTransactionPrototype.prototype = new ServerTransaction();

		/**
		 * @augments JsSIP.Transactions
		 * @class Non Invite Client Transaction
		 * @param {JsSIP.RequestSender} request_sender
		 * @param {JsSIP.OutgoingRequest} request
		 * @param {JsSIP.Transport} transport
		 */
		Transactions.NonInviteClientTransaction = function (request_sender, request, transport) {
			this.init(request_sender, request, transport);
			this.request_sender.ua.transactions.nict[this.id] = this;
		};
		Transactions.NonInviteClientTransaction.prototype = new NonInviteClientTransactionPrototype();

		/**
		 * @augments JsSIP.Transactions
		 * @class Invite Client Transaction
		 * @param {JsSIP.RequestSender} request_sender
		 * @param {JsSIP.OutgoingRequest} request
		 * @param {JsSIP.Transport} transport
		 */
		Transactions.InviteClientTransaction = function (request_sender, request, transport) {
			var tr = this;

			this.init(request_sender, request, transport);
			this.request_sender.ua.transactions.ict[this.id] = this;

			// Add the cancel property to the request.
			//Will be called from the request instance, not the transaction itself.
			this.request.cancel = function (reason) {
				tr.cancel_request(tr, reason);
			};
		};
		Transactions.InviteClientTransaction.prototype = new InviteClientTransactionPrototype();

		Transactions.AckClientTransaction = function (request_sender, request, transport) {
			this.init(request_sender, request, transport);
			this.send = function () {
				this.transport.send(request);
			};
		};
		Transactions.AckClientTransaction.prototype = new NonInviteClientTransactionPrototype();


		/**
		 * @augments JsSIP.Transactions
		 * @class Non Invite Server Transaction
		 * @param {JsSIP.IncomingRequest} request
		 * @param {JsSIP.UA} ua
		 */
		Transactions.NonInviteServerTransaction = function (request, ua) {
			this.init(request, ua);
			this.state = C.STATUS_TRYING;

			ua.transactions.nist[this.id] = this;
		};
		Transactions.NonInviteServerTransaction.prototype = new NonInviteServerTransactionPrototype();


		/**
		 * @augments JsSIP.Transactions
		 * @class Invite Server Transaction
		 * @param {JsSIP.IncomingRequest} request
		 * @param {JsSIP.UA} ua
		 */
		Transactions.InviteServerTransaction = function (request, ua) {
			this.init(request, ua);
			this.state = C.STATUS_PROCEEDING;

			ua.transactions.ist[this.id] = this;

			this.resendProvisionalTimer = null;

			request.reply(100);
		};
		Transactions.InviteServerTransaction.prototype = new InviteServerTransactionPrototype();

		/**
		 * @function
		 * @param {JsSIP.UA} ua
		 * @param {JsSIP.IncomingRequest} request
		 *
		 * @return {boolean}
		 * INVITE:
		 *  _true_ if retransmission
		 *  _false_ new request
		 *
		 * ACK:
		 *  _true_  ACK to non2xx response
		 *  _false_ ACK must be passed to TU (accepted state)
		 *          ACK to 2xx response
		 *
		 * CANCEL:
		 *  _true_  no matching invite transaction
		 *  _false_ matching invite transaction and no final response sent
		 *
		 * OTHER:
		 *  _true_  retransmission
		 *  _false_ new request
		 */
		Transactions.checkTransaction = function (ua, request) {
			var tr;

			switch (request.method) {
				case JsSIP.C.INVITE:
					tr = ua.transactions.ist[request.via_branch];
					if (tr) {
						switch (tr.state) {
							case C.STATUS_PROCEEDING:
								tr.transport.send(tr.last_response);
								break;

							// RFC 6026 7.1 Invite retransmission
							//received while in C.STATUS_ACCEPTED state. Absorb it.
							case C.STATUS_ACCEPTED:
								break;
						}
						return true;
					}
					break;
				case JsSIP.C.ACK:
					tr = ua.transactions.ist[request.via_branch];

					// RFC 6026 7.1
					if (tr) {
						if (tr.state === C.STATUS_ACCEPTED) {
							return false;
						} else if (tr.state === C.STATUS_COMPLETED) {
							tr.state = C.STATUS_CONFIRMED;
							tr.I = window.setTimeout(function () {
								tr.timer_I();
							}, JsSIP.Timers.TIMER_I);
							return true;
						}
					}

					// ACK to 2XX Response.
					else {
						return false;
					}
					break;
				case JsSIP.C.CANCEL:
					tr = ua.transactions.ist[request.via_branch];
					if (tr) {
						request.reply_sl(200);
						if (tr.state === C.STATUS_PROCEEDING) {
							return false;
						} else {
							return true;
						}
					} else {
						request.reply_sl(481);
						return true;
					}
					break;
				default:

					// Non-INVITE Server Transaction RFC 3261 17.2.2
					tr = ua.transactions.nist[request.via_branch];
					if (tr) {
						switch (tr.state) {
							case C.STATUS_TRYING:
								break;
							case C.STATUS_PROCEEDING:
							case C.STATUS_COMPLETED:
								tr.transport.send(tr.last_response);
								break;
						}
						return true;
					}
					break;
			}
		};

		Transactions.C = C;
		JsSIP.Transactions = Transactions;
	}(JsSIP));


	/**
	 * @fileoverview SIP Dialog
	 */

	/**
	 * @augments JsSIP
	 * @class Class creating a SIP dialog.
	 * @param {JsSIP.Session} session
	 * @param {JsSIP.IncomingRequest|JsSIP.IncomingResponse} message
	 * @param {Enum} type UAC / UAS
	 * @param {Enum} state JsSIP.Dialog.C.STATUS_EARLY / JsSIP.Dialog.C.STATUS_CONFIRMED
	 */
	(function (JsSIP) {
		var Dialog,
			LOG_PREFIX = JsSIP.name + ' | ' + 'DIALOG' + ' | ',
			C = {
				// Dialog states
				STATUS_EARLY: 1,
				STATUS_CONFIRMED: 2
			};

// RFC 3261 12.1
		Dialog = function (session, message, type, state) {
			var contact;

			if (!message.hasHeader('contact')) {
				console.error(LOG_PREFIX + 'unable to create a Dialog without Contact header field');
				return false;
			}

			if (message instanceof JsSIP.IncomingResponse) {
				state = (message.status_code < 200) ? C.STATUS_EARLY : C.STATUS_CONFIRMED;
			} else {
				// Create confirmed dialog if state is not defined
				state = state || C.STATUS_CONFIRMED;
			}

			contact = message.parseHeader('contact');

			// RFC 3261 12.1.1
			if (type === 'UAS') {
				this.id = {
					call_id: message.call_id,
					local_tag: message.to_tag,
					remote_tag: message.from_tag,
					toString: function () {
						return this.call_id + this.local_tag + this.remote_tag;
					}
				};
				this.state = state;
				this.remote_seqnum = message.cseq;
				this.local_uri = message.parseHeader('to').uri;
				this.remote_uri = message.parseHeader('from').uri;
				this.remote_target = contact.uri;
				this.route_set = message.getHeaderAll('record-route');
			}
			// RFC 3261 12.1.2
			else if (type === 'UAC') {
				this.id = {
					call_id: message.call_id,
					local_tag: message.from_tag,
					remote_tag: message.to_tag,
					toString: function () {
						return this.call_id + this.local_tag + this.remote_tag;
					}
				};
				this.state = state;
				this.local_seqnum = message.cseq;
				this.local_uri = message.parseHeader('from').uri;
				this.remote_uri = message.parseHeader('to').uri;
				this.remote_target = contact.uri;
				this.route_set = message.getHeaderAll('record-route').reverse();
			}

			this.session = session;
			session.ua.dialogs[this.id.toString()] = this;
			console.log(LOG_PREFIX + 'new ' + type + ' dialog created with status ' + (this.state === C.STATUS_EARLY ? 'EARLY' : 'CONFIRMED'));
		};

		Dialog.prototype = {
			/**
			 * @param {JsSIP.IncomingMessage} message
			 * @param {Enum} UAC/UAS
			 */
			update: function (message, type) {
				this.state = C.STATUS_CONFIRMED;

				console.log(LOG_PREFIX + 'dialog ' + this.id.toString() + '  changed to CONFIRMED state');

				if (type === 'UAC') {
					// RFC 3261 13.2.2.4
					this.route_set = message.getHeaderAll('record-route').reverse();
				}
			},

			terminate: function () {
				console.log(LOG_PREFIX + 'dialog ' + this.id.toString() + ' deleted');
				delete this.session.ua.dialogs[this.id.toString()];
			},

			/**
			 * @param {String} method request method
			 * @param {Object} extraHeaders extra headers
			 * @returns {JsSIP.OutgoingRequest}
			 */

			// RFC 3261 12.2.1.1
			createRequest: function (method, extraHeaders) {
				var cseq, request;
				extraHeaders = extraHeaders || [];

				if (!this.local_seqnum) {
					this.local_seqnum = Math.floor(Math.random() * 10000);
				}

				cseq = (method === JsSIP.C.CANCEL || method === JsSIP.C.ACK) ? this.local_seqnum : this.local_seqnum += 1;

				request = new JsSIP.OutgoingRequest(
					method,
					this.remote_target,
					this.session.ua, {
						'cseq': cseq,
						'call_id': this.id.call_id,
						'from_uri': this.local_uri,
						'from_tag': this.id.local_tag,
						'to_uri': this.remote_uri,
						'to_tag': this.id.remote_tag,
						'route_set': this.route_set
					}, extraHeaders);

				request.dialog = this;

				return request;
			},

			/**
			 * @param {JsSIP.IncomingRequest} request
			 * @returns {Boolean}
			 */

			// RFC 3261 12.2.2
			checkInDialogRequest: function (request) {
				if (!this.remote_seqnum) {
					this.remote_seqnum = request.cseq;
				} else if (request.method !== JsSIP.C.INVITE && request.cseq < this.remote_seqnum) {
					//Do not try to reply to an ACK request.
					if (request.method !== JsSIP.C.ACK) {
						request.reply(500);
					}
					return false;
				} else if (request.cseq > this.remote_seqnum) {
					this.remote_seqnum = request.cseq;
				}

				switch (request.method) {
					// RFC3261 14.2 Modifying an Existing Session -UAS BEHAVIOR-
					case JsSIP.C.INVITE:
						if (request.cseq < this.remote_seqnum) {
							if (this.state === C.STATUS_EARLY) {
								var retryAfter = (Math.random() * 10 | 0) + 1;
								request.reply(500, null, ['Retry-After:' + retryAfter]);
							} else {
								request.reply(500);
							}
							return false;
						}
						// RFC3261 14.2
						if (this.state === C.STATUS_EARLY) {
							request.reply(491);
							return false;
						}
						// RFC3261 12.2.2 Replace the dialog`s remote target URI
						if (request.hasHeader('contact')) {
							this.remote_target = request.parseHeader('contact').uri;
						}
						break;
					case JsSIP.C.NOTIFY:
						// RFC6655 3.2 Replace the dialog`s remote target URI
						if (request.hasHeader('contact')) {
							this.remote_target = request.parseHeader('contact').uri;
						}
						break;
				}

				return true;
			},

			/**
			 * @param {JsSIP.IncomingRequest} request
			 */
			receiveRequest: function (request) {
				//Check in-dialog request
				if (!this.checkInDialogRequest(request)) {
					return;
				}

				this.session.receiveRequest(request);
			}
		};

		Dialog.C = C;
		JsSIP.Dialog = Dialog;
	}(JsSIP));


	/**
	 * @fileoverview Request Sender
	 */

	/**
	 * @augments JsSIP
	 * @class Class creating a request sender.
	 * @param {Object} applicant
	 * @param {JsSIP.UA} ua
	 */
	(function (JsSIP) {
		var RequestSender,
			LOG_PREFIX = JsSIP.name + ' | ' + 'REQUEST SENDER' + ' | ';

		RequestSender = function (applicant, ua) {
			this.ua = ua;
			this.applicant = applicant;
			this.method = applicant.request.method;
			this.request = applicant.request;
			this.credentials = null;
			this.challenged = false;
			this.staled = false;

			// If ua is in closing process or even closed just allow sending Bye and ACK
			if (ua.status === JsSIP.UA.C.STATUS_USER_CLOSED && (this.method !== JsSIP.C.BYE || this.method !== JsSIP.C.ACK)) {
				this.onTransportError();
			}
		};

		/**
		 * Create the client transaction and send the message.
		 */
		RequestSender.prototype = {
			send: function () {
				switch (this.method) {
					case "INVITE":
						this.clientTransaction = new JsSIP.Transactions.InviteClientTransaction(this, this.request, this.ua.transport);
						break;
					case "ACK":
						this.clientTransaction = new JsSIP.Transactions.AckClientTransaction(this, this.request, this.ua.transport);
						break;
					default:
						this.clientTransaction = new JsSIP.Transactions.NonInviteClientTransaction(this, this.request, this.ua.transport);
				}
				this.clientTransaction.send();
			},

			/**
			 * Callback fired when receiving a request timeout error from the client transaction.
			 * To be re-defined by the applicant.
			 * @event
			 */
			onRequestTimeout: function () {
				this.applicant.onRequestTimeout();
			},

			/**
			 * Callback fired when receiving a transport error from the client transaction.
			 * To be re-defined by the applicant.
			 * @event
			 */
			onTransportError: function () {
				this.applicant.onTransportError();
			},

			/**
			 * Called from client transaction when receiving a correct response to the request.
			 * Authenticate request if needed or pass the response back to the applicant.
			 * @param {JsSIP.IncomingResponse} response
			 */
			receiveResponse: function (response) {
				var cseq, challenge, authorization_header_name,
					status_code = response.status_code;

				/*
				 * Authentication
				 * Authenticate once. _challenged_ flag used to avoid infinite authentications.
				 */
				if ((status_code === 401 || status_code === 407) && this.ua.configuration.password !== null) {

					// Get and parse the appropriate WWW-Authenticate or Proxy-Authenticate header.
					if (response.status_code === 401) {
						challenge = response.parseHeader('www-authenticate');
						authorization_header_name = 'authorization';
					} else {
						challenge = response.parseHeader('proxy-authenticate');
						authorization_header_name = 'proxy-authorization';
					}

					// Verify it seems a valid challenge.
					if (!challenge) {
						console.warn(LOG_PREFIX + response.status_code + ' with wrong or missing challenge, cannot authenticate');
						this.applicant.receiveResponse(response);
						return;
					}

					if (!this.challenged || (!this.staled && challenge.stale === true)) {
						if (!this.credentials) {
							this.credentials = new JsSIP.DigestAuthentication(this.ua);
						}

						// Verify that the challenge is really valid.
						if (!this.credentials.authenticate(this.request, challenge)) {
							this.applicant.receiveResponse(response);
							return;
						}
						this.challenged = true;

						if (challenge.stale) {
							this.staled = true;
						}

						if (response.method === JsSIP.C.REGISTER) {
							cseq = this.applicant.cseq += 1;
						} else if (this.request.dialog) {
							cseq = this.request.dialog.local_seqnum += 1;
						} else {
							cseq = this.request.cseq + 1;
							this.request.cseq = cseq;
						}
						this.request.setHeader('cseq', cseq + ' ' + this.method);

						this.request.setHeader(authorization_header_name, this.credentials.toString());
						this.send();
					} else {
						this.applicant.receiveResponse(response);
					}
				} else {
					this.applicant.receiveResponse(response);
				}
			}
		};

		JsSIP.RequestSender = RequestSender;
	}(JsSIP));


	/**
	 * @fileoverview In-Dialog Request Sender
	 */

	/**
	 * @augments JsSIP
	 * @class Class creating an In-dialog request sender.
	 * @param {Object} applicant
	 */
	/**
	 * @fileoverview in-Dialog Request Sender
	 */

	(function (JsSIP) {
		var InDialogRequestSender;

		InDialogRequestSender = function (applicant) {
			this.applicant = applicant;
			this.request = applicant.request;
		};

		InDialogRequestSender.prototype = {
			send: function () {
				var request_sender = new JsSIP.RequestSender(this, this.applicant.session.ua);
				request_sender.send();
			},

			onRequestTimeout: function () {
				this.applicant.session.onRequestTimeout();
				this.applicant.onRequestTimeout();
			},

			onTransportError: function () {
				this.applicant.session.onTransportError();
				this.applicant.onTransportError();
			},

			receiveResponse: function (response) {
				// RFC3261 14.1. Terminate the dialog if a 408 or 481 is received from a re-Invite.
				if (response.status_code === 408 || response.status_code === 481) {
					this.applicant.session.ended('remote', response, JsSIP.C.causes.DIALOG_ERROR);
				}
				this.applicant.receiveResponse(response);
			}
		};

		JsSIP.InDialogRequestSender = InDialogRequestSender;
	}(JsSIP));


	/**
	 * @fileoverview Registrator Agent
	 */

	/**
	 * @augments JsSIP
	 * @class Class creating a registrator agent.
	 * @param {JsSIP.UA} ua
	 * @param {JsSIP.Transport} transport
	 */
	(function (JsSIP) {
		var Registrator,
			LOG_PREFIX = JsSIP.name + ' | ' + 'REGISTRATOR' + ' | ';

		Registrator = function (ua, transport) {
			var reg_id = 1; //Force reg_id to 1.

			this.ua = ua;
			this.transport = transport;

			this.registrar = ua.configuration.registrar_server;
			this.expires = ua.configuration.register_expires;

			// Call-ID and CSeq values RFC3261 10.2
			this.call_id = JsSIP.Utils.createRandomToken(22);
			this.cseq = 80;

			// this.to_uri
			this.to_uri = ua.configuration.uri;

			this.registrationTimer = null;

			// Set status
			this.registered = this.registered_before = false;

			// Save into ua instance
			this.ua.registrator = this;

			// Contact header
			this.contact = this.ua.contact.toString();

			if (reg_id) {
				this.contact += ';reg-id=' + reg_id;
				this.contact += ';+sip.instance="<urn:uuid:' + this.ua.configuration.instance_id + '>"';
			}
		};

		Registrator.prototype = {
			/**
			 * @param {Object} [options]
			 */
			register: function (options) {
				var request_sender, cause, extraHeaders,
					self = this;

				options = options || {};
				extraHeaders = options.extraHeaders || [];
				extraHeaders.push('Contact: ' + this.contact + ';expires=' + this.expires);
				extraHeaders.push('Allow: ' + JsSIP.Utils.getAllowedMethods(this.ua));

				this.request = new JsSIP.OutgoingRequest(JsSIP.C.REGISTER, this.registrar, this.ua, {
					'to_uri': this.to_uri,
					'call_id': this.call_id,
					'cseq': (this.cseq += 1)
				}, extraHeaders);

				request_sender = new JsSIP.RequestSender(this, this.ua);

				/**
				 * @private
				 */
				this.receiveResponse = function (response) {
					var contact, expires,
						contacts = response.countHeader('contact');

					// Discard responses to older REGISTER/un-REGISTER requests.
					if (response.cseq !== this.cseq) {
						return;
					}

					// Clear registration timer
					if (this.registrationTimer !== null) {
						window.clearTimeout(this.registrationTimer);
						this.registrationTimer = null;
					}

					switch (true) {
						case /^1[0-9]{2}$/.test(response.status_code):
							// Ignore provisional responses.
							break;
						case /^2[0-9]{2}$/.test(response.status_code):
							if (response.hasHeader('expires')) {
								expires = response.getHeader('expires');
							}

							// Search the Contact pointing to us and update the expires value accordingly.
							if (!contacts) {
								console.warn(LOG_PREFIX + 'no Contact header in response to REGISTER, response ignored');
								break;
							}

							while (contacts--) {
								contact = response.parseHeader('contact', contacts);
								if (contact.uri.user === this.ua.contact.uri.user) {
									expires = contact.getParam('expires');
									break;
								} else {
									contact = null;
								}
							}

							if (!contact) {
								console.warn(LOG_PREFIX + 'no Contact header pointing to us, response ignored');
								//break;
							}

							if (!expires) {
								expires = this.expires;
							}

							// Re-Register before the expiration interval has elapsed.
							// For that, decrease the expires value. ie: 3 seconds
							this.registrationTimer = window.setTimeout(function () {
								self.registrationTimer = null;
								self.register();
							}, (expires * 1000) - 3000);

							//Save gruu values
//							if (contact.hasParam('temp-gruu')) {
//								this.ua.contact.temp_gruu = contact.getParam('temp-gruu').replace(/"/g, '');
//							}
//							if (contact.hasParam('pub-gruu')) {
//								this.ua.contact.pub_gruu = contact.getParam('pub-gruu').replace(/"/g, '');
//							}

							this.registered = true;
							this.ua.emit('registered', this.ua, {
								response: response
							});
							break;
						// Interval too brief RFC3261 10.2.8
						case /^423$/.test(response.status_code):
							if (response.hasHeader('min-expires')) {
								// Increase our registration interval to the suggested minimum
								this.expires = response.getHeader('min-expires');
								// Attempt the registration again immediately 
								this.register();
							} else { //This response MUST contain a Min-Expires header field
								console.warn(LOG_PREFIX + '423 response received for REGISTER without Min-Expires');
								this.registrationFailure(response, JsSIP.C.causes.SIP_FAILURE_CODE);
							}
							break;
						default:
							cause = JsSIP.Utils.sipErrorCause(response.status_code);
							this.registrationFailure(response, cause);
					}
				};

				/**
				 * @private
				 */
				this.onRequestTimeout = function () {
					this.registrationFailure(null, JsSIP.C.causes.REQUEST_TIMEOUT);
				};

				/**
				 * @private
				 */
				this.onTransportError = function () {
					this.registrationFailure(null, JsSIP.C.causes.CONNECTION_ERROR);
				};

				request_sender.send();
			},

			/**
			 * @param {Object} [options]
			 */
			unregister: function (options) {
				var extraHeaders;

				if (!this.registered) {
					console.warn(LOG_PREFIX + 'already unregistered');
					return;
				}

				options = options || {};
				extraHeaders = options.extraHeaders || [];

				this.registered = false;

				// Clear the registration timer.
				if (this.registrationTimer !== null) {
					window.clearTimeout(this.registrationTimer);
					this.registrationTimer = null;
				}

				if (options.all) {
					extraHeaders.push('Contact: *');
					extraHeaders.push('Expires: 0');

					this.request = new JsSIP.OutgoingRequest(JsSIP.C.REGISTER, this.registrar, this.ua, {
						'to_uri': this.to_uri,
						'call_id': this.call_id,
						'cseq': (this.cseq += 1)
					}, extraHeaders);
				} else {
					extraHeaders.push('Contact: ' + this.contact + ';expires=0');

					this.request = new JsSIP.OutgoingRequest(JsSIP.C.REGISTER, this.registrar, this.ua, {
						'to_uri': this.to_uri,
						'call_id': this.call_id,
						'cseq': (this.cseq += 1)
					}, extraHeaders);
				}

				var request_sender = new JsSIP.RequestSender(this, this.ua);

				/**
				 * @private
				 */
				this.receiveResponse = function (response) {
					var cause;

					switch (true) {
						case /^1[0-9]{2}$/.test(response.status_code):
							// Ignore provisional responses.
							break;
						case /^2[0-9]{2}$/.test(response.status_code):
							this.unregistered(response);
							break;
						default:
							cause = JsSIP.Utils.sipErrorCause(response.status_code);
							this.unregistered(response, cause);
					}
				};

				/**
				 * @private
				 */
				this.onRequestTimeout = function () {
					this.unregistered(null, JsSIP.C.causes.REQUEST_TIMEOUT);
				};

				/**
				 * @private
				 */
				this.onTransportError = function () {
					this.unregistered(null, JsSIP.C.causes.CONNECTION_ERROR);
				};

				request_sender.send();
			},

			/**
			 * @private
			 */
			registrationFailure: function (response, cause) {
				this.ua.emit('registrationFailed', this.ua, {
					response: response || null,
					cause: cause
				});

				if (this.registered) {
					this.registered = false;
					this.ua.emit('unregistered', this.ua, {
						response: response || null,
						cause: cause
					});
				}
			},

			/**
			 * @private
			 */
			unregistered: function (response, cause) {
				this.registered = false;
				this.ua.emit('unregistered', this.ua, {
					response: response || null,
					cause: cause || null
				});
			},

			/**
			 * @private
			 */
			onTransportClosed: function () {
				this.registered_before = this.registered;
				if (this.registrationTimer !== null) {
					window.clearTimeout(this.registrationTimer);
					this.registrationTimer = null;
				}

				if (this.registered) {
					this.registered = false;
					this.ua.emit('unregistered', this.ua);
				}
			},

			/**
			 * @private
			 */
			onTransportConnected: function () {
				this.register();
			},

			/**
			 * @private
			 */
			close: function () {
				this.registered_before = this.registered;
				this.unregister();
			}
		};

		JsSIP.Registrator = Registrator;
	}(JsSIP));


	/**
	 * @fileoverview Session
	 */

	/**
	 * @augments JsSIP
	 * @class Invite Session
	 */
	(function (JsSIP) {

// Load dependencies
		var RequestSender = (function (JsSIP) {

			var RequestSender = function (applicant, request) {
				this.applicant = applicant;
				this.request = request || applicant.request;
				this.session = (applicant instanceof JsSIP.RTCSession) ? applicant : applicant.session;
				this.reattempt = false;
				this.reatemptTimer = null;
				this.request_sender = new JsSIP.InDialogRequestSender(this);
			};

			RequestSender.prototype = {
				receiveResponse: function (response) {
					var
						self = this,
						status_code = response.status_code;

					if (response.method === JsSIP.C.INVITE && status_code === 491) {
						if (!this.reattempt) {
							this.request.cseq.value = this.request.dialog.local_seqnum += 1;
							this.reatemptTimer = window.setTimeout(
								function () {
									if (self.session.status !== JsSIP.RTCSession.C.STATUS_TERMINATED) {
										self.reattempt = true;
										self.request_sender.send();
									}
								},
								this.getReattemptTimeout()
							);
						} else {
							this.applicant.receiveResponse(response);
						}
					} else {
						this.applicant.receiveResponse(response);
					}
				},

				send: function () {
					this.request_sender.send();
				},

				onRequestTimeout: function () {
					this.applicant.onRequestTimeout();
				},

				onTransportError: function () {
					this.applicant.onTransportError();
				},

				// RFC3261 14.1
				getReattemptTimeout: function () {
					if (this.session.direction === 'outgoing') {
						return (Math.random() * (4 - 2.1) + 2.1).toFixed(2);
					} else {
						return (Math.random() * 2).toFixed(2);
					}
				}
			};

			return RequestSender;
		}(JsSIP));
		var RTCMediaHandler = (function (JsSIP) {

			var RTCMediaHandler = function (session, constraints) {
				constraints = constraints || {};

				this.session = session;
				this.localMedia = null;
				this.peerConnection = null;

				this.init(constraints);
			};

			RTCMediaHandler.prototype = {

				createOffer: function (onSuccess, onFailure) {
					var
						self = this,
						sent = false;

					this.onIceCompleted = function () {
						if (!sent) {
							sent = true;
							onSuccess(self.peerConnection.localDescription.sdp);
						}
					};

					this.peerConnection.createOffer(
						function (sessionDescription) {
							self.setLocalDescription(
								sessionDescription,
								onFailure
							);
						},
						function (e) {
							console.error(LOG_PREFIX + 'unable to create offer');
							console.error(e);
							onFailure();
						}
					);
				},

				createAnswer: function (onSuccess, onFailure) {
					var
						self = this,
						sent = false;

					this.onIceCompleted = function () {
						if (!sent) {
							sent = true;
							onSuccess(self.peerConnection.localDescription.sdp);
						}
					};

					this.peerConnection.createAnswer(
						function (sessionDescription) {
							self.setLocalDescription(
								sessionDescription,
								onFailure
							);
						},
						function (e) {
							console.error(LOG_PREFIX + 'unable to create answer');
							console.error(e);
							onFailure();
						}
					);
				},

				setLocalDescription: function (sessionDescription, onFailure) {
					this.peerConnection.setLocalDescription(
						sessionDescription,
						function () {
						},
						function (e) {
							console.error(LOG_PREFIX + 'unable to set local description');
							console.error(e);
							onFailure();
						}
					);
				},

				addStream: function (stream, onSuccess, onFailure, constraints) {
					try {
						this.peerConnection.addStream(stream, constraints);
					} catch (e) {
						console.error(LOG_PREFIX + 'error adding stream');
						console.error(e);
						onFailure();
						return;
					}

					onSuccess();
				},

				/**
				 * peerConnection creation.
				 * @param {Function} onSuccess Fired when there are no more ICE candidates
				 */
				init: function (constraints) {
					var idx, server, scheme, url,
						self = this,
						servers = [];

					for (idx in this.session.ua.configuration.stun_servers) {
						server = this.session.ua.configuration.stun_servers[idx];
						servers.push({'url': server});
					}

					for (idx in this.session.ua.configuration.turn_servers) {
						server = this.session.ua.configuration.turn_servers[idx];
						url = server.server;
						scheme = url.substr(0, url.indexOf(':'));
						servers.push({
							'url': scheme + ':' + server.username + '@' + url.substr(scheme.length + 1),
							'credential': server.password
						});
					}

					this.peerConnection = new JsSIP.WebRTC.RTCPeerConnection({'iceServers': servers}, constraints);

					this.peerConnection.onaddstream = function (e) {
						console.log(LOG_PREFIX + 'stream added: ' + e.stream.id);
					};

					this.peerConnection.onremovestream = function (e) {
						console.log(LOG_PREFIX + 'stream removed: ' + e.stream.id);
					};

					this.peerConnection.onicecandidate = function (e) {
//						if (e.candidate) {
//							console.log(LOG_PREFIX + 'ICE candidate received: ' + e.candidate.candidate);
//						} else {
//							console.log(LOG_PREFIX + 'ICE complete');
							self.onIceCompleted();
//						}
					};

					// To be deprecated as per https://code.google.com/p/webrtc/issues/detail?id=1393
					this.peerConnection.ongatheringchange = function (e) {
//						if ( e.currentTarget.iceGatheringState === 'complete' && this.iceConnectionState !== 'closed') {
							self.onIceCompleted();
//						}
					};

					this.peerConnection.onicechange = function () {
						console.log(LOG_PREFIX + 'ICE connection state changed to "' + this.iceConnectionState + '"');
					};

					this.peerConnection.onstatechange = function () {
						console.log(LOG_PREFIX + 'PeerConnection state changed to "' + this.readyState + '"');
					};
				},

				close: function () {
					console.log(LOG_PREFIX + 'closing PeerConnection');
					if (this.peerConnection) {
						this.peerConnection.close();

						if (this.localMedia) {
//							this.localMedia.stop();
						}
					}
				},

				/**
				 * @param {Object} mediaConstraints
				 * @param {Function} onSuccess
				 * @param {Function} onFailure
				 */
				getUserMedia: function (ua,onSuccess, onFailure, constraints) {
					var self = this;

					console.log(LOG_PREFIX + 'requesting access to local media');
					var onSuccessGetUserMedia = function (stream) {
						console.log(LOG_PREFIX + 'got local media stream');
						self.localMedia = stream;
						ua.emit('mediaPermissionsAccept', ua);
						onSuccess(stream);
					}
					var onError = function (e) {
						console.error(LOG_PREFIX + 'unable to get user media');
						console.error(e);
						ua.emit('mediaPermissionsRefuse', ua);
						onFailure();
					}
					var okMediaStream = oktellVoice && typeof oktellVoice.getUserMediaStream == 'function' ? oktellVoice.getUserMediaStream() : undefined;
					if ( okMediaStream ){
						onSuccessGetUserMedia(okMediaStream);
					} else {
						if ( oktellVoice && typeof oktellVoice.getUserMediaStream == 'function' ) {
							ua.emit('mediaPermissionsRequest', ua);
							oktellVoice.getUserMediaStream(onSuccessGetUserMedia, onError, false);
						} else {
							JsSIP.WebRTC.getUserMedia(constraints,onSuccessGetUserMedia,onError);
						}
					}
//					JsSIP.WebRTC.getUserMedia(constraints,
//						function (stream) {
//							console.log(LOG_PREFIX + 'got local media stream');
//							self.localMedia = stream;
//							onSuccess(stream);
//						},
//						function (e) {
//							console.error(LOG_PREFIX + 'unable to get user media');
//							console.error(e);
//							onFailure();
//						}
//					);
				},

				/**
				 * Message reception.
				 * @param {String} type
				 * @param {String} sdp
				 * @param {Function} onSuccess
				 * @param {Function} onFailure
				 */
				onMessage: function (type, body, onSuccess, onFailure) {
					this.peerConnection.setRemoteDescription(
						new JsSIP.WebRTC.RTCSessionDescription({type: type, sdp: body}),
						onSuccess,
						onFailure
					);
				}
			};

// Return since it will be assigned to a variable.
			return RTCMediaHandler;
		}(JsSIP));

		var DTMF = (function (JsSIP) {

			var DTMF,
				C = {
					MIN_DURATION: 70,
					MAX_DURATION: 6000,
					DEFAULT_DURATION: 100,
					MIN_INTER_TONE_GAP: 50,
					DEFAULT_INTER_TONE_GAP: 500
				};

			DTMF = function (session) {
				var events = [
					'succeeded',
					'failed'
				];

				this.session = session;
				this.direction = null;
				this.tone = null;
				this.duration = null;

				this.initEvents(events);
			};
			DTMF.prototype = new JsSIP.EventEmitter();


			DTMF.prototype.send = function (tone, options) {
				var request_sender, event, eventHandlers, extraHeaders;

				if (tone === undefined) {
					throw new TypeError('Not enough arguments');
				}

				this.direction = 'outgoing';

				// Check RTCSession Status
				if (this.session.status !== JsSIP.RTCSession.C.STATUS_CONFIRMED && this.session.status !== JsSIP.RTCSession.C.STATUS_WAITING_FOR_ACK) {
					throw new JsSIP.Exceptions.InvalidStateError(this.session.status);
				}

				// Get DTMF options
				options = options || {};
				extraHeaders = options.extraHeaders ? options.extraHeaders.slice() : [];
				eventHandlers = options.eventHandlers || {};

				// Check tone type
				if (typeof tone === 'string') {
					tone = tone.toUpperCase();
				} else if (typeof tone === 'number') {
					tone = tone.toString();
				} else {
					throw new TypeError('Invalid tone: ' + tone);
				}

				// Check tone value
				if (!tone.match(/^[0-9A-D#*]$/)) {
					throw new TypeError('Invalid tone: ' + tone);
				} else {
					this.tone = tone;
				}

				// Check duration
				if (options.duration && !JsSIP.Utils.isDecimal(options.duration)) {
					throw new TypeError('Invalid tone duration: ' + options.duration);
				} else if (!options.duration) {
					options.duration = C.DEFAULT_DURATION;
				} else if (options.duration < C.MIN_DURATION) {
					console.warn(LOG_PREFIX + '"duration" value is lower than the minimum allowed, setting it to ' + C.MIN_DURATION + ' milliseconds');
					options.duration = C.MIN_DURATION;
				} else if (options.duration > C.MAX_DURATION) {
					console.warn(LOG_PREFIX + '"duration" value is greater than the maximum allowed, setting it to ' + C.MAX_DURATION + ' milliseconds');
					options.duration = C.MAX_DURATION;
				} else {
					options.duration = Math.abs(options.duration);
				}
				this.duration = options.duration;

				// Set event handlers
				for (event in eventHandlers) {
					this.on(event, eventHandlers[event]);
				}

				extraHeaders.push('Content-Type: application/dtmf-relay');

				this.request = this.session.dialog.createRequest(JsSIP.C.INFO, extraHeaders);

				this.request.body = "Signal= " + this.tone + "\r\n";
				this.request.body += "Duration= " + this.duration;

				request_sender = new RequestSender(this);

				this.session.emit('newDTMF', this.session, {
					originator: 'local',
					dtmf: this,
					request: this.request
				});

				request_sender.send();
			};

			/**
			 * @private
			 */
			DTMF.prototype.receiveResponse = function (response) {
				var cause;

				switch (true) {
					case /^1[0-9]{2}$/.test(response.status_code):
						// Ignore provisional responses.
						break;

					case /^2[0-9]{2}$/.test(response.status_code):
						this.emit('succeeded', this, {
							originator: 'remote',
							response: response
						});
						break;

					default:
						cause = JsSIP.Utils.sipErrorCause(response.status_code);
						this.emit('failed', this, {
							originator: 'remote',
							response: response,
							cause: cause
						});
						break;
				}
			};

			/**
			 * @private
			 */
			DTMF.prototype.onRequestTimeout = function () {
				this.emit('failed', this, {
					originator: 'system',
					cause: JsSIP.C.causes.REQUEST_TIMEOUT
				});
			};

			/**
			 * @private
			 */
			DTMF.prototype.onTransportError = function () {
				this.emit('failed', this, {
					originator: 'system',
					cause: JsSIP.C.causes.CONNECTION_ERROR
				});
			};

			/**
			 * @private
			 */
			DTMF.prototype.init_incoming = function (request) {
				var body,
					reg_tone = /^(Signal\s*?=\s*?)([0-9A-D#*]{1})(\s)?.*/,
					reg_duration = /^(Duration\s?=\s?)([0-9]{1,4})(\s)?.*/;

				this.direction = 'incoming';
				this.request = request;

				request.reply(200);

				if (request.body) {
					body = request.body.split('\r\n');
					if (body.length === 2) {
						if (reg_tone.test(body[0])) {
							this.tone = body[0].replace(reg_tone, "$2");
						}
						if (reg_duration.test(body[1])) {
							this.duration = parseInt(body[1].replace(reg_duration, "$2"), 10);
						}
					}
				}

				if (!this.tone || !this.duration) {
					console.warn(LOG_PREFIX + 'invalid INFO DTMF received, discarded');
				} else {
					this.session.emit('newDTMF', this.session, {
						originator: 'remote',
						dtmf: this,
						request: request
					});
				}
			};

			DTMF.C = C;
			return DTMF;
		}(JsSIP));


		var RTCSession,
			LOG_PREFIX = JsSIP.name + ' | ' + 'RTC SESSION' + ' | ',
			C = {
				// RTCSession states
				STATUS_NULL: 0,
				STATUS_INVITE_SENT: 1,
				STATUS_1XX_RECEIVED: 2,
				STATUS_INVITE_RECEIVED: 3,
				STATUS_WAITING_FOR_ANSWER: 4,
				STATUS_WAITING_FOR_ACK: 5,
				STATUS_CANCELED: 6,
				STATUS_TERMINATED: 7,
				STATUS_CONFIRMED: 8
			};


		RTCSession = function (ua) {
			var events = [
				'progress',
				'failed',
				'started',
				'ended',
				'newDTMF'
			];

			this.ua = ua;
			this.status = C.STATUS_NULL;
			this.dialog = null;
			this.earlyDialogs = [];
			this.rtcMediaHandler = null;

			// Session Timers
			this.timers = {
				ackTimer: null,
				expiresTimer: null,
				invite2xxTimer: null,
				userNoAnswerTimer: null
			};

			// Session info
			this.direction = null;
			this.local_identity = null;
			this.remote_identity = null;
			this.start_time = null;
			this.end_time = null;

			// Custom session empty object for high level use
			this.data = {};

			this.initEvents(events);
		};
		RTCSession.prototype = new JsSIP.EventEmitter();


		/**
		 * User API
		 */

		/**
		 * Terminate the call.
		 * @param {Object} [options]
		 */
		RTCSession.prototype.terminate = function (options) {
			options = options || {};

			var cancel_reason,
				status_code = options.status_code,
				reason_phrase = options.reason_phrase,
				extraHeaders = options.extraHeaders || [],
				body = options.body;

			// Check Session Status
			if (this.status === C.STATUS_TERMINATED) {
				throw new JsSIP.Exceptions.InvalidStateError(this.status);
			}

			switch (this.status) {
				// - UAC -
				case C.STATUS_NULL:
				case C.STATUS_INVITE_SENT:
				case C.STATUS_1XX_RECEIVED:
					console.log(LOG_PREFIX + 'canceling RTCSession');

					if (status_code && (status_code < 200 || status_code >= 700)) {
						throw new TypeError('Invalid status_code: ' + status_code);
					} else if (status_code) {
						reason_phrase = reason_phrase || JsSIP.C.REASON_PHRASE[status_code] || '';
						cancel_reason = 'SIP ;cause=' + status_code + ' ;text="' + reason_phrase + '"';
					}

					// Check Session Status
					if (this.status === C.STATUS_NULL) {
						this.isCanceled = true;
						this.cancelReason = cancel_reason;
					} else if (this.status === C.STATUS_INVITE_SENT) {
						if (this.received_100) {
							this.request.cancel(cancel_reason);
						} else {
							this.isCanceled = true;
							this.cancelReason = cancel_reason;
						}
					} else if (this.status === C.STATUS_1XX_RECEIVED) {
						this.request.cancel(cancel_reason);
					}

					this.failed('local', null, JsSIP.C.causes.CANCELED);
					break;

				// - UAS -
				case C.STATUS_WAITING_FOR_ANSWER:
					console.log(LOG_PREFIX + 'rejecting RTCSession');

					status_code = status_code || 480;

					if (status_code < 300 || status_code >= 700) {
						throw new TypeError('Invalid status_code: ' + status_code);
					}

					this.request.reply(status_code, reason_phrase, extraHeaders, body);
					this.failed('local', null, JsSIP.C.causes.REJECTED);
					break;
				case C.STATUS_WAITING_FOR_ACK:
				case C.STATUS_CONFIRMED:
					console.log(LOG_PREFIX + 'terminating RTCSession');

					// Send Bye
					this.sendBye(options);
					this.ended('local', null, JsSIP.C.causes.BYE);
					break;
			}

			this.close();
		};

		/**
		 * Answer the call.
		 * @param {Object} [options]
		 */
		RTCSession.prototype.answer = function (options) {
			options = options || {};

			var
				self = this,
				request = this.request,
				extraHeaders = options.extraHeaders || [],
				mediaConstraints = options.mediaConstraints || {'audio': true, 'video': true},

			// User media succeeded
				userMediaSucceeded = function (stream) {
					self.rtcMediaHandler.addStream(
						stream,
						streamAdditionSucceeded,
						streamAdditionFailed
					);
				},

			// User media failed
				userMediaFailed = function () {
					request.reply(480);
					self.failed('local', null, JsSIP.C.causes.USER_DENIED_MEDIA_ACCESS);
				},

			// rtcMediaHandler.addStream successfully added
				streamAdditionSucceeded = function () {
					self.rtcMediaHandler.createAnswer(
						answerCreationSucceeded,
						answerCreationFailed
					);
				},

			// rtcMediaHandler.addStream failed
				streamAdditionFailed = function () {
					if (self.status === C.STATUS_TERMINATED) {
						return;
					}

					self.failed('local', null, JsSIP.C.causes.WEBRTC_ERROR);
				},

			// rtcMediaHandler.createAnswer succeeded
				answerCreationSucceeded = function (body) {
					var
					// run for reply success callback
						replySucceeded = function () {
							var timeout = JsSIP.Timers.T1;

							self.status = C.STATUS_WAITING_FOR_ACK;

							/**
							 * RFC3261 13.3.1.4
							 * Response retransmissions cannot be accomplished by transaction layer
							 *  since it is destroyed when receiving the first 2xx answer
							 */
							self.timers.invite2xxTimer = window.setTimeout(function invite2xxRetransmission() {
									if (self.status !== C.STATUS_WAITING_FOR_ACK) {
										return;
									}

									request.reply(200, null, ['Contact: ' + self.contact], body);

									if (timeout < JsSIP.Timers.T2) {
										timeout = timeout * 2;
										if (timeout > JsSIP.Timers.T2) {
											timeout = JsSIP.Timers.T2;
										}
									}
									self.timers.invite2xxTimer = window.setTimeout(
										invite2xxRetransmission, timeout
									);
								},
								timeout
							);

							/**
							 * RFC3261 14.2
							 * If a UAS generates a 2xx response and never receives an ACK,
							 *  it SHOULD generate a BYE to terminate the dialog.
							 */
							self.timers.ackTimer = window.setTimeout(function () {
									if (self.status === C.STATUS_WAITING_FOR_ACK) {
										console.log(LOG_PREFIX + 'no ACK received, terminating the call');
										window.clearTimeout(self.timers.invite2xxTimer);
										self.sendBye();
										self.ended('remote', null, JsSIP.C.causes.NO_ACK);
									}
								},
								JsSIP.Timers.TIMER_H
							);

							self.started('local');
						},

					// run for reply failure callback
						replyFailed = function () {
							self.failed('system', null, JsSIP.C.causes.CONNECTION_ERROR);
						};

					extraHeaders.push('Contact: ' + self.contact);

					request.reply(200, null, extraHeaders,
						body,
						replySucceeded,
						replyFailed
					);
				},

			// rtcMediaHandler.createAnsewr failed
				answerCreationFailed = function () {
					if (self.status === C.STATUS_TERMINATED) {
						return;
					}

					self.failed('local', null, JsSIP.C.causes.WEBRTC_ERROR);
				};


			// Check Session Direction and Status
			if (this.direction !== 'incoming') {
				throw new TypeError('Invalid method "answer" for an outgoing call');
			} else if (this.status !== C.STATUS_WAITING_FOR_ANSWER) {
				throw new JsSIP.Exceptions.InvalidStateError(this.status);
			}

			// An error on dialog creation will fire 'failed' event
			if (!this.createDialog(request, 'UAS')) {
				request.reply(500, 'Missing Contact header field');
				return;
			}

			window.clearTimeout(this.timers.userNoAnswerTimer);

			this.rtcMediaHandler.getUserMedia(
				this.ua,
				userMediaSucceeded,
				userMediaFailed,
				mediaConstraints
			);
		};

		/**
		 * Send a DTMF
		 *
		 * @param {String|Number} tones
		 * @param {Object} [options]
		 */
		RTCSession.prototype.sendDTMF = function (tones, options) {
			var timer, interToneGap,
				possition = 0,
				self = this,
				ready = true;

			options = options || {};
			interToneGap = options.interToneGap || null;

			if (tones === undefined) {
				throw new TypeError('Not enough arguments');
			}

			// Check Session Status
			if (this.status !== C.STATUS_CONFIRMED && this.status !== C.STATUS_WAITING_FOR_ACK) {
				throw new JsSIP.Exceptions.InvalidStateError(this.status);
			}

			// Check tones
			if (!tones || (typeof tones !== 'string' && typeof tones !== 'number') || !tones.toString().match(/^[0-9A-D#*]+$/i)) {
				throw new TypeError('Invalid tones: ' + tones);
			}

			tones = tones.toString();

			// Check interToneGap
			if (interToneGap && !JsSIP.Utils.isDecimal(interToneGap)) {
				throw new TypeError('Invalid interToneGap: ' + interToneGap);
			} else if (!interToneGap) {
				interToneGap = DTMF.C.DEFAULT_INTER_TONE_GAP;
			} else if (interToneGap < DTMF.C.MIN_INTER_TONE_GAP) {
				console.warn(LOG_PREFIX + '"interToneGap" value is lower than the minimum allowed, setting it to ' + DTMF.C.MIN_INTER_TONE_GAP + ' milliseconds');
				interToneGap = DTMF.C.MIN_INTER_TONE_GAP;
			} else {
				interToneGap = Math.abs(interToneGap);
			}

			function sendDTMF() {
				var tone,
					dtmf = new DTMF(self);

				dtmf.on('failed', function () {
					ready = false;
				});

				tone = tones[possition];
				possition += 1;

				dtmf.send(tone, options);
			}

			// Send the first tone
			sendDTMF();

			// Send the following tones
			timer = window.setInterval(
				function () {
					if (self.status !== C.STATUS_TERMINATED && ready && tones.length > possition) {
						sendDTMF();
					} else {
						window.clearInterval(timer);
					}
				},
				interToneGap
			);
		};


		/**
		 * RTCPeerconnection handlers
		 */
		RTCSession.prototype.getLocalStreams = function () {
			return this.rtcMediaHandler &&
				this.rtcMediaHandler.peerConnection &&
				this.rtcMediaHandler.peerConnection.getLocalStreams() || [];
		};

		RTCSession.prototype.getRemoteStreams = function () {
			return this.rtcMediaHandler &&
				this.rtcMediaHandler.peerConnection &&
				this.rtcMediaHandler.peerConnection.getRemoteStreams() || [];
		};


		/**
		 * Session Management
		 */

		/**
		 * @private
		 */
		RTCSession.prototype.init_incoming = function (request) {
			var expires,
				self = this,
				contentType = request.getHeader('Content-Type');

			// Check body and content type
			if (!request.body || (contentType !== 'application/sdp')) {
				request.reply(415);
				return;
			}

			// Session parameter initialization
			this.status = C.STATUS_INVITE_RECEIVED;
			this.from_tag = request.from_tag;
			this.id = request.call_id + this.from_tag;
			this.request = request;
			this.contact = this.ua.contact.toString();

			//Save the session into the ua sessions collection.
			this.ua.sessions[this.id] = this;

			//Get the Expires header value if exists
			if (request.hasHeader('expires')) {
				expires = request.getHeader('expires') * 1000;
			}

			/* Set the to_tag before
			 * replying a response code that will create a dialog.
			 */
			request.to_tag = JsSIP.Utils.newTag();

			// An error on dialog creation will fire 'failed' event
			if (!this.createDialog(request, 'UAS', true)) {
				request.reply(500, 'Missing Contact header field');
				return;
			}

			//Initialize Media Session
			this.rtcMediaHandler = new RTCMediaHandler(this,
				{"optional": [
					{'DtlsSrtpKeyAgreement': 'true'}
				]}
			);
			this.rtcMediaHandler.onMessage(
				'offer',
				request.body,
				/*
				 * onSuccess
				 * SDP Offer is valid. Fire UA newRTCSession
				 */
				function () {
					request.reply(180, null, ['Contact: ' + self.contact]);
					self.status = C.STATUS_WAITING_FOR_ANSWER;

					// Set userNoAnswerTimer
					self.timers.userNoAnswerTimer = window.setTimeout(function () {
							request.reply(408);
							self.failed('local', null, JsSIP.C.causes.NO_ANSWER);
						}, self.ua.configuration.no_answer_timeout
					);

					/* Set expiresTimer
					 * RFC3261 13.3.1
					 */
					if (expires) {
						self.timers.expiresTimer = window.setTimeout(function () {
								if (self.status === C.STATUS_WAITING_FOR_ANSWER) {
									request.reply(487);
									self.failed('system', null, JsSIP.C.causes.EXPIRES);
								}
							}, expires
						);
					}

					self.newRTCSession('remote', request);
				},
				/*
				 * onFailure
				 * Bad media description
				 */
				function (e) {
					console.warn(LOG_PREFIX + 'invalid SDP');
					console.warn(e);
					request.reply(488);
				}
			);
		};

		/**
		 * @private
		 */
		RTCSession.prototype.connect = function (target, options) {
			options = options || {};

			var event, requestParams,
				invalidTarget = false,
				eventHandlers = options.eventHandlers || {},
				extraHeaders = options.extraHeaders || [],
				mediaConstraints = options.mediaConstraints || {audio: true, video: true},
				RTCConstraints = options.RTCConstraints || {};

			if (target === undefined) {
				throw new TypeError('Not enough arguments');
			}

			// Check Session Status
			if (this.status !== C.STATUS_NULL) {
				throw new JsSIP.Exceptions.InvalidStateError(this.status);
			}

			// Set event handlers
			for (event in eventHandlers) {
				this.on(event, eventHandlers[event]);
			}

			// Check target validity
			try {
				target = JsSIP.Utils.normalizeURI(target, this.ua.configuration.hostport_params);
			} catch (e) {
				target = JsSIP.URI.parse(JsSIP.C.INVALID_TARGET_URI);
				invalidTarget = true;
			}

			// Session parameter initialization
			this.from_tag = JsSIP.Utils.newTag();
			this.rtcMediaHandler = new RTCMediaHandler(this, RTCConstraints);

			// Set anonymous property
			this.anonymous = options.anonymous;

			// OutgoingSession specific parameters
			this.isCanceled = false;
			this.received_100 = false;

			requestParams = {from_tag: this.from_tag};

			this.contact = this.ua.contact.toString({
				anonymous: this.anonymous,
				outbound: true
			});

			if (this.anonymous) {
				requestParams.from_display_name = 'Anonymous';
				requestParams.from_uri = 'sip:anonymous@anonymous.invalid';

				extraHeaders.push('P-Preferred-Identity: ' + this.ua.configuration.uri.toString());
				extraHeaders.push('Privacy: id');
			}

			extraHeaders.push('Contact: ' + this.contact);
			extraHeaders.push('Allow: ' + JsSIP.Utils.getAllowedMethods(this.ua));
			extraHeaders.push('Content-Type: application/sdp');

			this.request = new JsSIP.OutgoingRequest(JsSIP.C.INVITE, target, this.ua, requestParams, extraHeaders);

			this.id = this.request.call_id + this.from_tag;

			//Save the session into the ua sessions collection.
			this.ua.sessions[this.id] = this;

			this.newRTCSession('local', this.request);

			if (invalidTarget) {
				this.failed('local', null, JsSIP.C.causes.INVALID_TARGET);
			} else if (!JsSIP.WebRTC.isSupported) {
				this.failed('local', null, JsSIP.C.causes.WEBRTC_NOT_SUPPORTED);
			} else {
				this.sendInitialRequest(mediaConstraints);
			}
		};

		/**
		 * @private
		 */
		RTCSession.prototype.close = function () {
			var idx;

			if (this.status === C.STATUS_TERMINATED) {
				return;
			}

			console.log(LOG_PREFIX + 'closing INVITE session ' + this.id);

			// 1st Step. Terminate media.
			if (this.rtcMediaHandler) {
				this.rtcMediaHandler.close();
			}

			// 2nd Step. Terminate signaling.

			// Clear session timers
			for (idx in this.timers) {
				window.clearTimeout(this.timers[idx]);
			}

			// Terminate dialogs

			// Terminate confirmed dialog
			if (this.dialog) {
				this.dialog.terminate();
				delete this.dialog;
			}

			// Terminate early dialogs
			for (idx in this.earlyDialogs) {
				this.earlyDialogs[idx].terminate();
				delete this.earlyDialogs[idx];
			}

			this.status = C.STATUS_TERMINATED;

			delete this.ua.sessions[this.id];
		};

		/**
		 * Dialog Management
		 * @private
		 */
		RTCSession.prototype.createDialog = function (message, type, early) {
			var dialog, early_dialog,
				local_tag = (type === 'UAS') ? message.to_tag : message.from_tag,
				remote_tag = (type === 'UAS') ? message.from_tag : message.to_tag,
				id = message.call_id + local_tag + remote_tag;

			early_dialog = this.earlyDialogs[id];

			// Early Dialog
			if (early) {
				if (early_dialog) {
					return true;
				} else {
					early_dialog = new JsSIP.Dialog(this, message, type, JsSIP.Dialog.C.STATUS_EARLY);

					// Dialog has been successfully created.
					if (early_dialog.id) {
						this.earlyDialogs[id] = early_dialog;
						return true;
					}
					// Dialog not created due to an error.
					else {
						this.failed('remote', message, JsSIP.C.causes.INTERNAL_ERROR);
						return false;
					}
				}
			}

			// Confirmed Dialog
			else {
				// In case the dialog is in _early_ state, update it
				if (early_dialog) {
					early_dialog.update(message, type);
					this.dialog = early_dialog;
					delete this.earlyDialogs[id];
					return true;
				}

				// Otherwise, create a _confirmed_ dialog
				dialog = new JsSIP.Dialog(this, message, type);

				if (dialog.id) {
					this.to_tag = message.to_tag;
					this.dialog = dialog;
					return true;
				}
				// Dialog not created due to an error
				else {
					this.failed('remote', message, JsSIP.C.causes.INTERNAL_ERROR);
					return false;
				}
			}
		};


		/**
		 * In dialog Request Reception
		 * @private
		 */
		RTCSession.prototype.receiveRequest = function (request) {
			var contentType;

			if (request.method === JsSIP.C.CANCEL) {
				/* RFC3261 15 States that a UAS may have accepted an invitation while a CANCEL
				 * was in progress and that the UAC MAY continue with the session established by
				 * any 2xx response, or MAY terminate with BYE. JsSIP does continue with the
				 * established session. So the CANCEL is processed only if the session is not yet
				 * established.
				 */

				/*
				 * Terminate the whole session in case the user didn't accept nor reject the
				 *request opening the session.
				 */
				if (this.status === C.STATUS_WAITING_FOR_ANSWER) {
					this.status = C.STATUS_CANCELED;
					this.request.reply(487);
					this.failed('remote', request, JsSIP.C.causes.CANCELED);
				}
			} else {
				// Requests arriving here are in-dialog requests.
				switch (request.method) {
					case JsSIP.C.ACK:
						if (this.status === C.STATUS_WAITING_FOR_ACK) {
							window.clearTimeout(this.timers.ackTimer);
							window.clearTimeout(this.timers.invite2xxTimer);
							this.status = C.STATUS_CONFIRMED;
						}
						break;
					case JsSIP.C.BYE:
						if (this.status === C.STATUS_CONFIRMED) {
							request.reply(200);
							this.ended('remote', request, JsSIP.C.causes.BYE);
						}
						break;
					case JsSIP.C.INVITE:
						if (this.status === C.STATUS_CONFIRMED) {
							console.log(LOG_PREFIX + 're-INVITE received');
						}
						break;
					case JsSIP.C.INFO:
						if (this.status === C.STATUS_CONFIRMED || this.status === C.STATUS_WAITING_FOR_ACK) {
							contentType = request.getHeader('content-type');
							if (contentType && (contentType.match(/^application\/dtmf-relay/i))) {
								new DTMF(this).init_incoming(request);
							}
						}
				}
			}
		};


		/**
		 * Initial Request Sender
		 * @private
		 */
		RTCSession.prototype.sendInitialRequest = function (constraints) {
			var
				self = this,
				request_sender = new JsSIP.RequestSender(self, this.ua),

			// User media succeeded
				userMediaSucceeded = function (stream) {
					self.rtcMediaHandler.addStream(
						stream,
						streamAdditionSucceeded,
						streamAdditionFailed
					);
				},

			// User media failed
				userMediaFailed = function () {
					if (self.status === C.STATUS_TERMINATED) {
						return;
					}

					self.failed('local', null, JsSIP.C.causes.USER_DENIED_MEDIA_ACCESS);
				},

			// rtcMediaHandler.addStream successfully added
				streamAdditionSucceeded = function () {
					self.rtcMediaHandler.createOffer(
						offerCreationSucceeded,
						offerCreationFailed
					);
				},

			// rtcMediaHandler.addStream failed
				streamAdditionFailed = function () {
					if (self.status === C.STATUS_TERMINATED) {
						return;
					}

					self.failed('local', null, JsSIP.C.causes.WEBRTC_ERROR);
				},

			// rtcMediaHandler.createOffer succeeded
				offerCreationSucceeded = function (offer) {
					if (self.isCanceled || self.status === C.STATUS_TERMINATED) {
						return;
					}

					self.request.body = offer;
					self.status = C.STATUS_INVITE_SENT;
					request_sender.send();
				},

			// rtcMediaHandler.createOffer failed
				offerCreationFailed = function () {
					if (self.status === C.STATUS_TERMINATED) {
						return;
					}

					self.failed('local', null, JsSIP.C.causes.WEBRTC_ERROR);
				};
			this.rtcMediaHandler.getUserMedia(
				this.ua,
				userMediaSucceeded,
				userMediaFailed,
				constraints
			);
		};

		/**
		 * Reception of Response for Initial Request
		 * @private
		 */
		RTCSession.prototype.receiveResponse = function (response) {
			var cause,
				session = this;

			if (this.status !== C.STATUS_INVITE_SENT && this.status !== C.STATUS_1XX_RECEIVED) {
				return;
			}

			// Proceed to cancellation if the user requested.
			if (this.isCanceled) {
				if (response.status_code >= 100 && response.status_code < 200) {
					this.request.cancel(this.cancelReason);
				} else if (response.status_code >= 200 && response.status_code < 299) {
					this.acceptAndTerminate(response);
				}
				return;
			}

			switch (true) {
				case /^100$/.test(response.status_code):
					this.received_100 = true;
					break;
				case /^1[0-9]{2}$/.test(response.status_code):
					// Do nothing with 1xx responses without To tag.
					if (!response.to_tag) {
						console.warn(LOG_PREFIX + '1xx response received without to tag');
						break;
					}

					// Create Early Dialog if 1XX comes with contact
					if (response.hasHeader('contact')) {
						// An error on dialog creation will fire 'failed' event
						this.createDialog(response, 'UAC', true);
					}

					this.status = C.STATUS_1XX_RECEIVED;
					this.progress('remote', response);
					break;
				case /^2[0-9]{2}$/.test(response.status_code):
					// Do nothing if this.dialog is already confirmed
					if (this.dialog) {
						break;
					}

					if (!response.body) {
						this.acceptAndTerminate(response, 400, 'Missing session description');
						this.failed('remote', response, JsSIP.C.causes.BAD_MEDIA_DESCRIPTION);
						break;
					}

					// An error on dialog creation will fire 'failed' event
					if (!this.createDialog(response, 'UAC')) {
						break;
					}

					this.rtcMediaHandler.onMessage(
						'answer',
						response.body,
						/*
						 * onSuccess
						 * SDP Answer fits with Offer. Media will start
						 */
						function () {
							session.status = C.STATUS_CONFIRMED;
							session.sendACK();
							session.started('remote', response);
						},
						/*
						 * onFailure
						 * SDP Answer does not fit the Offer. Accept the call and Terminate.
						 */
						function (e) {
							console.warn(e);
							session.acceptAndTerminate(response, 488, 'Not Acceptable Here');
							session.failed('remote', response, JsSIP.C.causes.BAD_MEDIA_DESCRIPTION);
						}
					);
					break;
				default:
					cause = JsSIP.Utils.sipErrorCause(response.status_code);
					this.failed('remote', response, cause);
			}
		};


		/**
		 * @private
		 */
		RTCSession.prototype.acceptAndTerminate = function (response, status_code, reason_phrase) {
			// Send ACK and BYE
			// An error on dialog creation will fire 'failed' event
			if (this.dialog || this.createDialog(response, 'UAC')) {
				this.sendACK();
				this.sendBye({
					status_code: status_code,
					reason_phrase: reason_phrase
				});
			}
		};

		/**
		 * @private
		 */
		RTCSession.prototype.sendACK = function () {
			var request = this.dialog.createRequest(JsSIP.C.ACK);

			this.sendRequest(request);
		};

		/**
		 * @private
		 */
		RTCSession.prototype.sendBye = function (options) {
			options = options || {};

			var request, reason,
				status_code = options.status_code,
				reason_phrase = options.reason_phrase || JsSIP.C.REASON_PHRASE[status_code] || '',
				extraHeaders = options.extraHeaders || [],
				body = options.body;

			if (status_code && (status_code < 200 || status_code >= 700)) {
				throw new TypeError('Invalid status_code: ' + status_code);
			} else if (status_code) {
				reason = 'SIP ;cause=' + status_code + '; text="' + reason_phrase + '"';
				extraHeaders.push('Reason: ' + reason);
			}

			request = this.dialog.createRequest(JsSIP.C.BYE, extraHeaders);
			request.body = body;

			this.sendRequest(request);
		};

		/**
		 * @private
		 */
		RTCSession.prototype.sendRequest = function (request) {
			var request_sender = new RequestSender(this, request);
			request_sender.send();
		};

		/**
		 * Session Callbacks
		 */

		/**
		 * Callback to be called from UA instance when TransportError occurs
		 * @private
		 */
		RTCSession.prototype.onTransportError = function () {
			if (this.status !== C.STATUS_TERMINATED) {
				if (this.status === C.STATUS_CONFIRMED) {
					this.ended('system', null, JsSIP.C.causes.CONNECTION_ERROR);
				} else {
					this.failed('system', null, JsSIP.C.causes.CONNECTION_ERROR);
				}
			}
		};

		/**
		 * Callback to be called from UA instance when RequestTimeout occurs
		 * @private
		 */
		RTCSession.prototype.onRequestTimeout = function () {
			if (this.status !== C.STATUS_TERMINATED) {
				if (this.status === C.STATUS_CONFIRMED) {
					this.ended('system', null, JsSIP.C.causes.REQUEST_TIMEOUT);
				} else {
					this.failed('system', null, JsSIP.C.causes.CONNECTION_ERROR);
				}
			}
		};

		/**
		 * Internal Callbacks
		 */

		/**
		 * @private
		 */
		RTCSession.prototype.newRTCSession = function (originator, request) {
			var session = this,
				event_name = 'newRTCSession';

			if (originator === 'remote') {
				session.direction = 'incoming';
				session.local_identity = request.to;
				session.remote_identity = request.from;
			} else if (originator === 'local') {
				session.direction = 'outgoing';
				session.local_identity = request.from;
				session.remote_identity = request.to;
			}

			session.ua.emit(event_name, session.ua, {
				originator: originator,
				session: session,
				request: request
			});
		};

		/**
		 * @private
		 */
		RTCSession.prototype.connecting = function (originator, request) {
			var session = this,
				event_name = 'connecting';

			session.emit(event_name, session, {
				originator: 'local',
				request: request
			});
		};

		/**
		 * @private
		 */
		RTCSession.prototype.progress = function (originator, response) {
			var session = this,
				event_name = 'progress';

			session.emit(event_name, session, {
				originator: originator,
				response: response || null
			});
		};

		/**
		 * @private
		 */
		RTCSession.prototype.started = function (originator, message) {
			var session = this,
				event_name = 'started';

			session.start_time = new Date();

			session.emit(event_name, session, {
				originator: originator,
				response: message || null
			});
		};

		/**
		 * @private
		 */
		RTCSession.prototype.ended = function (originator, message, cause) {
			var session = this,
				event_name = 'ended';

			session.end_time = new Date();

			session.close();
			session.emit(event_name, session, {
				originator: originator,
				message: message || null,
				cause: cause
			});
		};

		/**
		 * @private
		 */
		RTCSession.prototype.failed = function (originator, message, cause) {
			var session = this,
				event_name = 'failed';

			session.close();
			session.emit(event_name, session, {
				originator: originator,
				message: message || null,
				cause: cause
			});
		};


		RTCSession.C = C;
		JsSIP.RTCSession = RTCSession;
	}(JsSIP));


	/**
	 * @fileoverview Message
	 */

	/**
	 * @augments JsSIP
	 * @class Class creating SIP MESSAGE request.
	 * @param {JsSIP.UA} ua
	 */
	(function (JsSIP) {
		var Message;

		Message = function (ua) {
			this.ua = ua;
			this.direction = null;
			this.local_identity = null;
			this.remote_identity = null;

			// Custom message empty object for high level use
			this.data = {};
		};
		Message.prototype = new JsSIP.EventEmitter();


		Message.prototype.send = function (target, body, options) {
			var request_sender, event, contentType, eventHandlers, extraHeaders,
				events = [
					'succeeded',
					'failed'
				],
				invalidTarget = false;

			if (target === undefined || body === undefined) {
				throw new TypeError('Not enough arguments');
			}

			this.initEvents(events);

			// Get call options
			options = options || {};
			extraHeaders = options.extraHeaders || [];
			eventHandlers = options.eventHandlers || {};
			contentType = options.contentType || 'text/plain';

			// Set event handlers
			for (event in eventHandlers) {
				this.on(event, eventHandlers[event]);
			}

			// Check target validity
			try {
				target = JsSIP.Utils.normalizeURI(target, this.ua.configuration.hostport_params);
			} catch (e) {
				target = JsSIP.URI.parse(JsSIP.C.INVALID_TARGET_URI);
				invalidTarget = true;
			}

			// Message parameter initialization
			this.direction = 'outgoing';
			this.local_identity = this.ua.configuration.uri;
			this.remote_identity = target;

			this.closed = false;
			this.ua.applicants[this] = this;

			extraHeaders.push('Content-Type: ' + contentType);

			this.request = new JsSIP.OutgoingRequest(JsSIP.C.MESSAGE, target, this.ua, null, extraHeaders);

			if (body) {
				this.request.body = body;
			}

			request_sender = new JsSIP.RequestSender(this, this.ua);

			this.ua.emit('newMessage', this.ua, {
				originator: 'local',
				message: this,
				request: this.request
			});

			if (invalidTarget) {
				this.emit('failed', this, {
					originator: 'local',
					cause: JsSIP.C.causes.INVALID_TARGET
				});
			} else {
				request_sender.send();
			}
		};

		/**
		 * @private
		 */
		Message.prototype.receiveResponse = function (response) {
			var cause;

			if (this.closed) {
				return;
			}
			switch (true) {
				case /^1[0-9]{2}$/.test(response.status_code):
					// Ignore provisional responses.
					break;

				case /^2[0-9]{2}$/.test(response.status_code):
					delete this.ua.applicants[this];
					this.emit('succeeded', this, {
						originator: 'remote',
						response: response
					});
					break;

				default:
					delete this.ua.applicants[this];
					cause = JsSIP.Utils.sipErrorCause(response.status_code);
					this.emit('failed', this, {
						originator: 'remote',
						response: response,
						cause: cause
					});
					break;
			}
		};


		/**
		 * @private
		 */
		Message.prototype.onRequestTimeout = function () {
			if (this.closed) {
				return;
			}
			this.emit('failed', this, {
				originator: 'system',
				cause: JsSIP.C.causes.REQUEST_TIMEOUT
			});
		};

		/**
		 * @private
		 */
		Message.prototype.onTransportError = function () {
			if (this.closed) {
				return;
			}
			this.emit('failed', this, {
				originator: 'system',
				cause: JsSIP.C.causes.CONNECTION_ERROR
			});
		};

		/**
		 * @private
		 */
		Message.prototype.close = function () {
			this.closed = true;
			delete this.ua.applicants[this];
		};

		/**
		 * @private
		 */
		Message.prototype.init_incoming = function (request) {
			var transaction,
				contentType = request.getHeader('content-type');

			this.direction = 'incoming';
			this.request = request;
			this.local_identity = request.to.uri;
			this.remote_identity = request.from.uri;

			if (contentType && (contentType.match(/^text\/plain(\s*;\s*.+)*$/i) || contentType.match(/^text\/html(\s*;\s*.+)*$/i))) {
				this.ua.emit('newMessage', this.ua, {
					originator: 'remote',
					message: this,
					request: request
				});

				transaction = this.ua.transactions.nist[request.via_branch];

				if (transaction && (transaction.state === JsSIP.Transactions.C.STATUS_TRYING || transaction.state === JsSIP.Transactions.C.STATUS_PROCEEDING)) {
					request.reply(200);
				}
			} else {
				request.reply(415, null, ['Accept: text/plain, text/html']);
			}
		};

		/**
		 * Accept the incoming Message
		 * Only valid for incoming Messages
		 */
		Message.prototype.accept = function (options) {
			options = options || {};

			var
				extraHeaders = options.extraHeaders || [],
				body = options.body;

			if (this.direction !== 'incoming') {
				throw new TypeError('Invalid method "accept" for an outgoing message');
			}

			this.request.reply(200, null, extraHeaders, body);
		};

		/**
		 * Reject the incoming Message
		 * Only valid for incoming Messages
		 *
		 * @param {Number} status_code
		 * @param {String} [reason_phrase]
		 */
		Message.prototype.reject = function (options) {
			options = options || {};

			var
				status_code = options.status_code || 480,
				reason_phrase = options.reason_phrase,
				extraHeaders = options.extraHeaders || [],
				body = options.body;

			if (this.direction !== 'incoming') {
				throw new TypeError('Invalid method "reject" for an outgoing message');
			}

			if (status_code < 300 || status_code >= 700) {
				throw new TypeError('Invalid status_code: ' + status_code);
			}

			this.request.reply(status_code, reason_phrase, extraHeaders, body);
		};

		JsSIP.Message = Message;
	}(JsSIP));


	/**
	 * @fileoverview SIP User Agent
	 */


	/**
	 * @augments JsSIP
	 * @class Class creating a SIP User Agent.
	 */
	(function (JsSIP) {
		var UA,
			LOG_PREFIX = JsSIP.name + ' | ' + 'UA' + ' | ',
			C = {
				// UA status codes
				STATUS_INIT: 0,
				STATUS_READY: 1,
				STATUS_USER_CLOSED: 2,
				STATUS_NOT_READY: 3,

				// UA error codes
				CONFIGURATION_ERROR: 1,
				NETWORK_ERROR: 2,

				/* UA events and corresponding SIP Methods.
				 * Dynamically added to 'Allow' header field if the
				 * corresponding event handler is set.
				 */
				EVENT_METHODS: {
					'newRTCSession': 'INVITE',
					'newMessage': 'MESSAGE'
				},

				ALLOWED_METHODS: [
					'ACK',
					'CANCEL',
					'BYE',
					'OPTIONS'
				],

				ACCEPTED_BODY_TYPES: [
					'application/sdp',
					'application/dtmf-relay'
				],

				SUPPORTED: 'path, outbound, gruu',

				MAX_FORWARDS: 69,
				TAG_LENGTH: 10
			};

		UA = function (configuration) {
			var events = [
				'connected',
				'disconnected',
				'registered',
				'unregistered',
				'registrationFailed',
				'newRTCSession',
				'newMessage',
				'mediaPermissionsRequest',
				'mediaPermissionsAccept',
				'mediaPermissionsRefuse'
			];

			// Set Accepted Body Types
			C.ACCEPTED_BODY_TYPES = C.ACCEPTED_BODY_TYPES.toString();

			this.cache = {
				credentials: {}
			};

			this.configuration = {};
			this.dialogs = {};
			this.registrator = null;

			//User actions outside any session/dialog (MESSAGE)
			this.applicants = {};

			this.sessions = {};
			this.transport = null;
			this.contact = null;
			this.status = C.STATUS_INIT;
			this.error = null;
			this.transactions = {
				nist: {},
				nict: {},
				ist: {},
				ict: {}
			};

			this.transportRecoverAttempts = 0;

			/**
			 * Load configuration
			 *
			 * @throws {JsSIP.Exceptions.ConfigurationError}
			 * @throws {TypeError}
			 */

			if (configuration === undefined) {
				throw new TypeError('Not enough arguments');
			}

			try {
				this.loadConfig(configuration);
				this.initEvents(events);
			} catch (e) {
				this.status = C.STATUS_NOT_READY;
				this.error = C.CONFIGURATION_ERROR;
				throw e;
			}
		};
		UA.prototype = new JsSIP.EventEmitter();

//=================
//  High Level API
//=================

		/**
		 * Register.
		 *
		 *
		 */
		UA.prototype.register = function (options) {
			this.configuration.register = true;
			this.registrator.register(options);
		};

		/**
		 * Unregister.
		 *
		 * @param {Boolean} [all] unregister all user bindings.
		 *
		 */
		UA.prototype.unregister = function (options) {
			this.configuration.register = false;
			this.registrator.unregister(options);
		};

		/**
		 * Registration state.
		 * @param {Boolean}
		 */
		UA.prototype.isRegistered = function () {
			if (this.registrator && this.registrator.registered) {
				return true;
			} else {
				return false;
			}
		};

		/**
		 * Connection state.
		 * @param {Boolean}
		 */
		UA.prototype.isConnected = function () {
			if (this.transport) {
				return this.transport.connected;
			} else {
				return false;
			}
		};

		/**
		 * Make an outgoing call.
		 *
		 * @param {String} target
		 * @param {Object} views
		 * @param {Object} [options]
		 *
		 * @throws {TypeError}
		 *
		 */
		UA.prototype.call = function (target, options) {
			var session;

			session = new JsSIP.RTCSession(this);
			session.connect(target, options);
		};

		/**
		 * Send a message.
		 *
		 * @param {String} target
		 * @param {String} body
		 * @param {Object} [options]
		 *
		 * @throws {TypeError}
		 *
		 */
		UA.prototype.sendMessage = function (target, body, options) {
			var message;

			message = new JsSIP.Message(this);
			message.send(target, body, options);
		};

		/**
		 * Gracefully close.
		 *
		 */
		UA.prototype.stop = function () {
			var session, applicant,
				ua = this;

			console.log(LOG_PREFIX + 'user requested closure...');

			if (this.status === C.STATUS_USER_CLOSED) {
				console.warn('UA already closed');
				return;
			}

			// Close registrator
			if (this.registrator) {
				console.log(LOG_PREFIX + 'closing registrator');
				this.registrator.close();
			}

			// Run  _terminate_ on every Session
			for (session in this.sessions) {
				console.log(LOG_PREFIX + 'closing session ' + session);
				this.sessions[session].terminate();
			}

			// Run  _close_ on every applicant
			for (applicant in this.applicants) {
				this.applicants[applicant].close();
			}

			this.status = C.STATUS_USER_CLOSED;
			this.shutdownGraceTimer = window.setTimeout(
				function () {
					ua.transport.disconnect();
				},
				'5000'
			);
		};

		/**
		 * Connect to the WS server if status = STATUS_INIT.
		 * Resume UA after being closed.
		 *
		 */
		UA.prototype.start = function () {
			var server;

			console.log(LOG_PREFIX + 'user requested startup...');

			if (this.status === C.STATUS_INIT) {
				server = this.getNextWsServer();
				new JsSIP.Transport(this, server);
			} else if (this.status === C.STATUS_USER_CLOSED) {
				console.log(LOG_PREFIX + 'resuming');
				this.status = C.STATUS_READY;
				this.transport.connect();
			} else if (this.status === C.STATUS_READY) {
				console.log(LOG_PREFIX + 'UA is in READY status, not resuming');
			} else {
				console.error('Connection is down. Auto-Recovery system is trying to connect');
			}
		};


//===============================
//  Private (For internal use)
//===============================

		UA.prototype.saveCredentials = function (credentials) {
			this.cache.credentials[credentials.realm] = this.cache.credentials[credentials.realm] || {};
			this.cache.credentials[credentials.realm][credentials.uri] = credentials;
		};

		UA.prototype.getCredentials = function (request) {
			var realm, credentials;

			realm = request.ruri.host;

			if (this.cache.credentials[realm] && this.cache.credentials[realm][request.ruri]) {
				credentials = this.cache.credentials[realm][request.ruri];
				credentials.method = request.method;
			}

			return credentials;
		};


//==========================
// Event Handlers
//==========================

		/**
		 * Transport Close event.
		 * @private
		 * @event
		 * @param {JsSIP.Transport} transport.
		 */
		UA.prototype.onTransportClosed = function (transport) {
			// Run _onTransportError_ callback on every client transaction using _transport_
			var type, idx,
				client_transactions = ['nict', 'ict', 'nist', 'ist'];

			transport.server.status = JsSIP.Transport.C.STATUS_DISCONNECTED;
			console.log(LOG_PREFIX + 'connection state set to ' + JsSIP.Transport.C.STATUS_DISCONNECTED);

			for (type in client_transactions) {
				for (idx in this.transactions[client_transactions[type]]) {
					this.transactions[client_transactions[type]][idx].onTransportError();
				}
			}

			// Close sessions if GRUU is not being used
			if (!this.contact.pub_gruu) {
				this.closeSessionsOnTransportError();
			}

		};

		/**
		 * Unrecoverable transport event.
		 * Connection reattempt logic has been done and didn't success.
		 * @private
		 * @event
		 * @param {JsSIP.Transport} transport.
		 */
		UA.prototype.onTransportError = function (transport) {
			var server;

			console.log(LOG_PREFIX + 'transport ' + transport.server.ws_uri + ' failed | connection state set to ' + JsSIP.Transport.C.STATUS_ERROR);

			// Close sessions.
			//Mark this transport as 'down' and try the next one
			transport.server.status = JsSIP.Transport.C.STATUS_ERROR;

			this.emit('disconnected', this, {
				transport: transport,
				code: transport.lastTransportError.code,
				reason: transport.lastTransportError.reason
			});

			server = this.getNextWsServer();

			if (server) {
				new JsSIP.Transport(this, server);
			} else {
				this.closeSessionsOnTransportError();
				if (!this.error || this.error !== C.NETWORK_ERROR) {
					this.status = C.STATUS_NOT_READY;
					this.error = C.NETWORK_ERROR;
				}
				// Transport Recovery process
				this.recoverTransport();
			}
		};

		/**
		 * Transport connection event.
		 * @private
		 * @event
		 * @param {JsSIP.Transport} transport.
		 */
		UA.prototype.onTransportConnected = function (transport) {
			this.transport = transport;

			// Reset transport recovery counter
			this.transportRecoverAttempts = 0;

			transport.server.status = JsSIP.Transport.C.STATUS_READY;
			console.log(LOG_PREFIX + 'connection state set to ' + JsSIP.Transport.C.STATUS_READY);

			if (this.status === C.STATUS_USER_CLOSED) {
				return;
			}

			this.status = C.STATUS_READY;
			this.error = null;
			this.emit('connected', this, {
				transport: transport
			});

			if (this.configuration.register) {
				if (this.registrator) {
					this.registrator.onTransportConnected();
				} else {
					this.registrator = new JsSIP.Registrator(this, transport);
					this.register();
				}
			} else if (!this.registrator) {
				this.registrator = new JsSIP.Registrator(this, transport);
			}
		};

//=========================
// receiveRequest
//=========================

		/**
		 * Request reception
		 * @private
		 * @param {JsSIP.IncomingRequest} request.
		 */
		UA.prototype.receiveRequest = function (request) {
			var dialog, session, message,
				method = request.method;

			// Check that Ruri points to us
			if (request.ruri.user !== this.configuration.uri.user && request.ruri.user !== this.contact.uri.user) {
				console.warn(LOG_PREFIX + 'Request-URI does not point to us');
				if (request.method !== JsSIP.C.ACK) {
					request.reply_sl(404);
				}
				return;
			}

			// Check transaction
			if (JsSIP.Transactions.checkTransaction(this, request)) {
				return;
			}

			// Create the server transaction
			if (method === JsSIP.C.INVITE) {
				new JsSIP.Transactions.InviteServerTransaction(request, this);
			} else if (method !== JsSIP.C.ACK) {
				new JsSIP.Transactions.NonInviteServerTransaction(request, this);
			}

			/* RFC3261 12.2.2
			 * Requests that do not change in any way the state of a dialog may be
			 * received within a dialog (for example, an OPTIONS request).
			 * They are processed as if they had been received outside the dialog.
			 */
			if (method === JsSIP.C.OPTIONS) {
				request.reply(200, null, [
					'Allow: ' + JsSIP.Utils.getAllowedMethods(this),
					'Accept: ' + C.ACCEPTED_BODY_TYPES
				]);
			} else if (method === JsSIP.C.MESSAGE) {
				if (!this.checkEvent('newMessage') || this.listeners('newMessage').length === 0) {
					request.reply(405, null, ['Allow: ' + JsSIP.Utils.getAllowedMethods(this)]);
					return;
				}
				message = new JsSIP.Message(this);
				message.init_incoming(request);
			}

			// Initial Request
			if (!request.to_tag) {
				if (!this.isRegistered()) {
					// High user does not want to be contacted
					request.reply(410);
					return;
				}

				switch (method) {
					case JsSIP.C.INVITE:
						if (JsSIP.WebRTC.isSupported) {
							session = new JsSIP.RTCSession(this);
							session.init_incoming(request);
						} else {
							console.warn(LOG_PREFIX + 'INVITE received but WebRTC is not supported');
							request.reply(488);
						}
						break;
					case JsSIP.C.BYE:
						// Out of dialog BYE received
						request.reply(481);
						break;
					case JsSIP.C.CANCEL:
						session = this.findSession(request);
						if (session) {
							session.receiveRequest(request);
						} else {
							console.warn(LOG_PREFIX + 'received CANCEL request for a non existent session');
						}
						break;
					case JsSIP.C.ACK:
						/* Absorb it.
						 * ACK request without a corresponding Invite Transaction
						 * and without To tag.
						 */
						break;
					default:
						request.reply(405);
						break;
				}
			}
			// In-dialog request
			else {
				dialog = this.findDialog(request);

				if (dialog) {
					dialog.receiveRequest(request);
				} else if (method === JsSIP.C.NOTIFY) {
					session = this.findSession(request);
					if (session) {
						session.receiveRequest(request);
					} else {
						console.warn(LOG_PREFIX + 'received NOTIFY request for a non existent session');
						request.reply(481, 'Subscription does not exist');
					}
				}
				/* RFC3261 12.2.2
				 * Request with to tag, but no matching dialog found.
				 * Exception: ACK for an Invite request for which a dialog has not
				 * been created.
				 */
				else {
					if (method !== JsSIP.C.ACK) {
						request.reply(481);
					}
				}
			}
		};

//=================
// Utils
//=================

		/**
		 * Get the session to which the request belongs to, if any.
		 * @private
		 * @param {JsSIP.IncomingRequest} request.
		 * @returns {JsSIP.OutgoingSession|JsSIP.IncomingSession|null}
		 */
		UA.prototype.findSession = function (request) {
			var
				sessionIDa = request.call_id + request.from_tag,
				sessionA = this.sessions[sessionIDa],
				sessionIDb = request.call_id + request.to_tag,
				sessionB = this.sessions[sessionIDb];

			if (sessionA) {
				return sessionA;
			} else if (sessionB) {
				return sessionB;
			} else {
				return null;
			}
		};

		/**
		 * Get the dialog to which the request belongs to, if any.
		 * @private
		 * @param {JsSIP.IncomingRequest}
		 * @returns {JsSIP.Dialog|null}
		 */
		UA.prototype.findDialog = function (request) {
			var
				id = request.call_id + request.from_tag + request.to_tag,
				dialog = this.dialogs[id];

			if (dialog) {
				return dialog;
			} else {
				id = request.call_id + request.to_tag + request.from_tag;
				dialog = this.dialogs[id];
				if (dialog) {
					return dialog;
				} else {
					return null;
				}
			}
		};

		/**
		 * Retrieve the next server to which connect.
		 * @private
		 * @returns {Object} ws_server
		 */
		UA.prototype.getNextWsServer = function () {
			// Order servers by weight
			var idx, ws_server,
				candidates = [];

			for (idx in this.configuration.ws_servers) {
				ws_server = this.configuration.ws_servers[idx];

				if (ws_server.status === JsSIP.Transport.C.STATUS_ERROR) {
					continue;
				} else if (candidates.length === 0) {
					candidates.push(ws_server);
				} else if (ws_server.weight > candidates[0].weight) {
					candidates = [ws_server];
				} else if (ws_server.weight === candidates[0].weight) {
					candidates.push(ws_server);
				}
			}

			idx = Math.floor((Math.random() * candidates.length));

			return candidates[idx];
		};

		/**
		 * Close all sessions on transport error.
		 * @private
		 */
		UA.prototype.closeSessionsOnTransportError = function () {
			var idx;

			// Run _transportError_ for every Session
			for (idx in this.sessions) {
				this.sessions[idx].onTransportError();
			}
			// Call registrator _onTransportClosed_
			if (this.registrator) {
				this.registrator.onTransportClosed();
			}
		};

		UA.prototype.recoverTransport = function (ua) {
			var idx, k, nextRetry, count, server;

			ua = ua || this;
			count = ua.transportRecoverAttempts;

			for (idx in ua.configuration.ws_servers) {
				ua.configuration.ws_servers[idx].status = 0;
			}

			server = ua.getNextWsServer();

			k = Math.floor((Math.random() * Math.pow(2, count)) + 1);
			nextRetry = k * ua.configuration.connection_recovery_min_interval;

			if (nextRetry > ua.configuration.connection_recovery_max_interval) {
				console.log(LOG_PREFIX + 'time for next connection attempt exceeds connection_recovery_max_interval, resetting counter');
				nextRetry = ua.configuration.connection_recovery_min_interval;
				count = 0;
			}

			console.log(LOG_PREFIX + 'next connection attempt in ' + nextRetry + ' seconds');

			window.setTimeout(
				function () {
					ua.transportRecoverAttempts = count + 1;
					new JsSIP.Transport(ua, server);
				}, nextRetry * 1000);
		};

		/**
		 * Configuration load.
		 * @private
		 * returns {Boolean}
		 */
		UA.prototype.loadConfig = function (configuration) {
			// Settings and default values
			var parameter, value, checked_value, hostport_params, registrar_server,
				settings = {
					/* Host address
					 * Value to be set in Via sent_by and host part of Contact FQDN
					 */
					via_host: JsSIP.Utils.createRandomToken(12) + '.invalid',

					// Password
					password: null,

					// Registration parameters
					register_expires: 600,
					register_min_expires: 120,
					register: true,
					registrar_server: null,

					// Transport related parameters
					ws_server_max_reconnection: 3,
					ws_server_reconnection_timeout: 4,

					connection_recovery_min_interval: 2,
					connection_recovery_max_interval: 30,

					use_preloaded_route: false,

					// Session parameters
					no_answer_timeout: 60,
					stun_servers: ['stun:stun.l.google.com:19302'],
					turn_servers: [],

					// Logging parameters
					trace_sip: false,

					// Hacks
					hack_via_tcp: false,
					hack_ip_in_contact: false
				};

			// Pre-Configuration

			// Check Mandatory parameters
			for (parameter in UA.configuration_check.mandatory) {
				if (!configuration.hasOwnProperty(parameter)) {
					throw new JsSIP.Exceptions.ConfigurationError(parameter);
				} else {
					value = configuration[parameter];
					checked_value = UA.configuration_check.mandatory[parameter](value);
					if (checked_value !== undefined) {
						settings[parameter] = checked_value;
					} else {
						throw new JsSIP.Exceptions.ConfigurationError(parameter, value);
					}
				}
			}

			// Check Optional parameters
			for (parameter in UA.configuration_check.optional) {
				if (configuration.hasOwnProperty(parameter)) {
					value = configuration[parameter];

					// If the parameter value is null, empty string or undefined then apply its default value.
					if (value === null || value === "" || value === undefined) {
						continue;
					}
					// If it's a number with NaN value then also apply its default value.
					// NOTE: JS does not allow "value === NaN", the following does the work:
					else if (typeof(value) === 'number' && window.isNaN(value)) {
						continue;
					}

					checked_value = UA.configuration_check.optional[parameter](value);
					if (checked_value !== undefined) {
						settings[parameter] = checked_value;
					} else {
						throw new JsSIP.Exceptions.ConfigurationError(parameter, value);
					}
				}
			}

			// Sanity Checks

			// Connection recovery intervals
			if (settings.connection_recovery_max_interval < settings.connection_recovery_min_interval) {
				throw new JsSIP.Exceptions.ConfigurationError('connection_recovery_max_interval', settings.connection_recovery_max_interval);
			}

			// Post Configuration Process

			// Allow passing 0 number as display_name.
			if (settings.display_name === 0) {
				settings.display_name = '0';
			}

			// Instance-id for GRUU
			settings.instance_id = JsSIP.Utils.newUUID();

			// jssip_id instance parameter. Static random tag of length 5
			settings.jssip_id = JsSIP.Utils.createRandomToken(5);

			// String containing settings.uri without scheme and user.
			hostport_params = settings.uri.clone();
			hostport_params.user = null;
			settings.hostport_params = hostport_params.toString().replace(/^sip:/i, '');

			/* Check whether authorization_user is explicitly defined.
			 * Take 'settings.uri.user' value if not.
			 */
			if (!settings.authorization_user) {
				settings.authorization_user = settings.uri.user;
			}

			/* If no 'registrar_server' is set use the 'uri' value without user portion. */
			if (!settings.registrar_server) {
				registrar_server = settings.uri.clone();
				registrar_server.user = null;
				settings.registrar_server = registrar_server;
			}

			// User no_answer_timeout
			settings.no_answer_timeout = settings.no_answer_timeout * 1000;

			// Via Host
			if (settings.hack_ip_in_contact) {
				settings.via_host = JsSIP.Utils.getRandomTestNetIP();
			}

			this.predefinedStream = settings.predefinedStream;

			this.contact = {
				pub_gruu: null,
				temp_gruu: null,
				uri: new JsSIP.URI('sip', settings.uri.user, settings.via_host, null, {transport: 'ws'}),
				toString: function (options) {
					options = options || {};

					var
						anonymous = options.anonymous || null,
						outbound = options.outbound || null,
						contact = '<';

					if (anonymous) {
						contact += this.temp_gruu || 'sip:anonymous@anonymous.invalid;transport=ws';
					} else {
						contact += this.pub_gruu || this.uri.toString();
					}

					if (outbound) {
						contact += ';ob';
					}

					contact += '>';

					return contact;
				}
			};

			// Fill the value of the configuration_skeleton
			console.log(LOG_PREFIX + 'configuration parameters after validation:');
			for (parameter in settings) {
				switch (parameter) {
					case 'uri':
					case 'registrar_server':
						console.log('· ' + parameter + ': ' + settings[parameter]);
						break;
					case 'password':
						console.log('· ' + parameter + ': ' + 'NOT SHOWN');
						break;
					default:
						console.log('· ' + parameter + ': ' + window.JSON.stringify(settings[parameter]));
				}
				UA.configuration_skeleton[parameter].value = settings[parameter];
			}

			Object.defineProperties(this.configuration, UA.configuration_skeleton);

			// Clean UA.configuration_skeleton
			for (parameter in settings) {
				UA.configuration_skeleton[parameter].value = '';
			}

			return;
		};


		/**
		 * Configuration Object skeleton.
		 * @private
		 */
		UA.configuration_skeleton = (function () {
			var idx, parameter,
				skeleton = {},
				parameters = [
					// Internal parameters
					"instance_id",
					"jssip_id",
					"register_min_expires",
					"ws_server_max_reconnection",
					"ws_server_reconnection_timeout",
					"hostport_params",

					// Mandatory user configurable parameters
					"uri",
					"ws_servers",

					// Optional user configurable parameters
					"authorization_user",
					"connection_recovery_max_interval",
					"connection_recovery_min_interval",
					"display_name",
					"hack_via_tcp", // false.
					"hack_ip_in_contact", //false
					"no_answer_timeout", // 30 seconds.
					"password",
					"register_expires", // 600 seconds.
					"registrar_server",
					"stun_servers",
					"trace_sip",
					"turn_servers",
					"use_preloaded_route",

					// Post-configuration generated parameters
					"via_core_value",
					"via_host"
				];

			for (idx in parameters) {
				parameter = parameters[idx];
				skeleton[parameter] = {
					value: '',
					writable: false,
					configurable: false
				};
			}

			skeleton['register'] = {
				value: '',
				writable: true,
				configurable: false
			};

			return skeleton;
		}());

		/**
		 * Configuration checker.
		 * @private
		 * @return {Boolean}
		 */
		UA.configuration_check = {
			mandatory: {

				uri: function (uri) {
					var parsed;

					if (!/^sip:/i.test(uri)) {
						uri = JsSIP.C.SIP + ':' + uri;
					}
					parsed = JsSIP.URI.parse(uri);

					if (!parsed) {
						return;
					} else if (!parsed.user) {
						return;
					} else {
						return parsed;
					}
				},

				ws_servers: function (ws_servers) {
					var idx, url;

					/* Allow defining ws_servers parameter as:
					 *  String: "host"
					 *  Array of Strings: ["host1", "host2"]
					 *  Array of Objects: [{ws_uri:"host1", weight:1}, {ws_uri:"host2", weight:0}]
					 *  Array of Objects and Strings: [{ws_uri:"host1"}, "host2"]
					 */
					if (typeof ws_servers === 'string') {
						ws_servers = [
							{ws_uri: ws_servers}
						];
					} else if (ws_servers instanceof Array) {
						for (idx in ws_servers) {
							if (typeof ws_servers[idx] === 'string') {
								ws_servers[idx] = {ws_uri: ws_servers[idx]};
							}
						}
					} else {
						return;
					}

					if (ws_servers.length === 0) {
						return false;
					}

					for (idx in ws_servers) {
						if (!ws_servers[idx].ws_uri) {
							console.error(LOG_PREFIX + 'missing "ws_uri" attribute in ws_servers parameter');
							return;
						}
						if (ws_servers[idx].weight && !Number(ws_servers[idx].weight)) {
							console.error(LOG_PREFIX + '"weight" attribute in ws_servers parameter must be a Number');
							return;
						}

						url = JsSIP.Grammar.parse(ws_servers[idx].ws_uri, 'absoluteURI');

						if (url === -1) {
							console.error(LOG_PREFIX + 'invalid "ws_uri" attribute in ws_servers parameter: ' + ws_servers[idx].ws_uri);
							return;
						} else if (url.scheme !== 'wss' && url.scheme !== 'ws') {
							console.error(LOG_PREFIX + 'invalid URI scheme in ws_servers parameter: ' + url.scheme);
							return;
						} else {
							ws_servers[idx].sip_uri = '<sip:' + url.host + (url.port ? ':' + url.port : '') + ';transport=ws;lr>';

							if (!ws_servers[idx].weight) {
								ws_servers[idx].weight = 0;
							}

							ws_servers[idx].status = 0;
							ws_servers[idx].scheme = url.scheme.toUpperCase();
						}
					}
					return ws_servers;
				}
			},

			optional: {

				authorization_user: function (authorization_user) {
					if (JsSIP.Grammar.parse('"' + authorization_user + '"', 'quoted_string') === -1) {
						return;
					} else {
						return authorization_user;
					}
				},

				connection_recovery_max_interval: function (connection_recovery_max_interval) {
					var value;
					if (JsSIP.Utils.isDecimal(connection_recovery_max_interval)) {
						value = window.Number(connection_recovery_max_interval);
						if (value > 0) {
							return value;
						}
					}
				},

				connection_recovery_min_interval: function (connection_recovery_min_interval) {
					var value;
					if (JsSIP.Utils.isDecimal(connection_recovery_min_interval)) {
						value = window.Number(connection_recovery_min_interval);
						if (value > 0) {
							return value;
						}
					}
				},

				display_name: function (display_name) {
					if (JsSIP.Grammar.parse('"' + display_name + '"', 'display_name') === -1) {
						return;
					} else {
						return display_name;
					}
				},

				hack_via_tcp: function (hack_via_tcp) {
					if (typeof hack_via_tcp === 'boolean') {
						return hack_via_tcp;
					}
				},

				hack_ip_in_contact: function (hack_ip_in_contact) {
					if (typeof hack_ip_in_contact === 'boolean') {
						return hack_ip_in_contact;
					}
				},

				no_answer_timeout: function (no_answer_timeout) {
					var value;
					if (JsSIP.Utils.isDecimal(no_answer_timeout)) {
						value = window.Number(no_answer_timeout);
						if (value > 0) {
							return value;
						}
					}
				},

				password: function (password) {
					return String(password);
				},

				register: function (register) {
					if (typeof register === 'boolean') {
						return register;
					}
				},

				register_expires: function (register_expires) {
					var value;
					if (JsSIP.Utils.isDecimal(register_expires)) {
						value = window.Number(register_expires);
						if (value > 0) {
							return value;
						}
					}
				},

				registrar_server: function (registrar_server) {
					var parsed;

					if (!/^sip:/i.test(registrar_server)) {
						registrar_server = JsSIP.C.SIP + ':' + registrar_server;
					}
					parsed = JsSIP.URI.parse(registrar_server);

					if (!parsed) {
						return;
					} else if (parsed.user) {
						return;
					} else {
						return parsed;
					}
				},

				stun_servers: function (stun_servers) {
					var idx, stun_server;

					if (typeof stun_servers === 'string') {
						stun_servers = [stun_servers];
					} else if (!(stun_servers instanceof Array)) {
						return;
					}

					for (idx in stun_servers) {
						stun_server = stun_servers[idx];
						if (!(/^stuns?:/.test(stun_server))) {
							stun_server = 'stun:' + stun_server;
						}

						if (JsSIP.Grammar.parse(stun_server, 'stun_URI') === -1) {
							return;
						} else {
							stun_servers[idx] = stun_server;
						}
					}
					return stun_servers;
				},

				trace_sip: function (trace_sip) {
					if (typeof trace_sip === 'boolean') {
						return trace_sip;
					}
				},

				turn_servers: function (turn_servers) {
					var idx, turn_server;

					if (turn_servers instanceof Array) {
						// Do nothing
					} else {
						turn_servers = [turn_servers];
					}

					for (idx in turn_servers) {
						turn_server = turn_servers[idx];
						if (!turn_server.server || !turn_server.username || !turn_server.password) {
							return;
						} else if (!(/^turns?:/.test(turn_server.server))) {
							turn_server.server = 'turn:' + turn_server.server;
						}

						if (JsSIP.Grammar.parse(turn_server.server, 'turn_URI') === -1) {
							return;
						} else if (JsSIP.Grammar.parse(turn_server.username, 'user') === -1) {
							return;
						} else if (JsSIP.Grammar.parse(turn_server.password, 'password') === -1) {
							return;
						}
					}
					return turn_servers;
				},

				use_preloaded_route: function (use_preloaded_route) {
					if (typeof use_preloaded_route === 'boolean') {
						return use_preloaded_route;
					}
				}
			}
		};

		UA.C = C;
		JsSIP.UA = UA;
	}(JsSIP));


	/**
	 * @fileoverview Utils
	 */

	(function (JsSIP) {
		var Utils;

		Utils = {

			str_utf8_length: function (string) {
				return window.unescape(encodeURIComponent(string)).length;
			},

			isFunction: function (fn) {
				if (fn !== undefined) {
					return (Object.prototype.toString.call(fn) === '[object Function]') ? true : false;
				} else {
					return false;
				}
			},

			isDecimal: function (num) {
				return !isNaN(num) && (parseFloat(num) === parseInt(num, 10));
			},

			createRandomToken: function (size, base) {
				var i, r,
					token = '';

				base = base || 32;

				for (i = 0; i < size; i++) {
					r = Math.random() * base | 0;
					token += r.toString(base);
				}

				return token;
			},

			newTag: function () {
				return JsSIP.Utils.createRandomToken(JsSIP.UA.C.TAG_LENGTH);
			},

			// http://stackoverflow.com/users/109538/broofa
			newUUID: function () {
				var UUID = 'xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx'.replace(/[xy]/g, function (c) {
					var r = Math.random() * 16 | 0, v = c === 'x' ? r : (r & 0x3 | 0x8);
					return v.toString(16);
				});

				return UUID;
			},

			hostType: function (host) {
				if (!host) {
					return;
				} else {
					host = JsSIP.Grammar.parse(host, 'host');
					if (host !== -1) {
						return host.host_type;
					}
				}
			},

			/**
			 * Normalize SIP URI.
			 * NOTE: It does not allow a SIP URI without username.
			 * Accepts 'sip', 'sips' and 'tel' URIs and convert them into 'sip'.
			 * Detects the domain part (if given) and properly hex-escapes the user portion.
			 * If the user portion has only 'tel' number symbols the user portion is clean of 'tel' visual separators.
			 * @private
			 * @param {String} target
			 * @param {String} [domain]
			 */
			normalizeURI: function (target, domain) {
				var uri, target_array, target_user, target_domain,
					original_target = target;

				// If no target is given then raise an error.
				if (!target) {
					throw new JsSIP.Exceptions.InvalidTargetError(original_target);

					// If a JsSIP.URI instance is given then return it.
				} else if (target instanceof JsSIP.URI) {
					return target;

					// If a string is given split it by '@':
					// - Last fragment is the desired domain.
					// - Otherwise append the given domain argument.
				} else if (typeof target === 'string') {
					target_array = target.split('@');

					switch (target_array.length) {
						case 1:
							if (!domain) {
								throw new JsSIP.Exceptions.InvalidTargetError(original_target);
							}
							target_user = target;
							target_domain = domain;
							break;
						case 2:
							target_user = target_array[0];
							target_domain = target_array[1];
							break;
						default:
							target_user = target_array.slice(0, target_array.length - 1).join('@');
							target_domain = target_array[target_array.length - 1];
					}

					// Remove the URI scheme (if present).
					target_user = target_user.replace(/^(sips?|tel):/i, '');

					// Remove 'tel' visual separators if the user portion just contains 'tel' number symbols.
					if (/^[\-\.\(\)]*\+?[0-9\-\.\(\)]+$/.test(target_user)) {
						target_user = target_user.replace(/[\-\.\(\)]/g, '');
					}

					// Build the complete SIP URI.
					target = JsSIP.C.SIP + ':' + JsSIP.Utils.escapeUser(target_user) + '@' + target_domain;

					// Finally parse the resulting URI.
					if (uri = JsSIP.URI.parse(target)) {
						return uri;
					} else {
						throw new JsSIP.Exceptions.InvalidTargetError(original_target);
					}
				}

				// Otherwise raise an error.
				else {
					throw new JsSIP.Exceptions.InvalidTargetError(original_target);
				}
			},

			/**
			 * Hex-escape a SIP URI user.
			 * @private
			 * @param {String} user
			 */
			escapeUser: function (user) {
				// Don't hex-escape ':' (%3A), '+' (%2B), '?' (%3F"), '/' (%2F).
				return window.encodeURIComponent(window.decodeURIComponent(user)).replace(/%3A/ig, ':').replace(/%2B/ig, '+').replace(/%3F/ig, '?').replace(/%2F/ig, '/');
			},

			headerize: function (string) {
				var exceptions = {
						'Call-Id': 'Call-ID',
						'Cseq': 'CSeq',
						'Www-Authenticate': 'WWW-Authenticate'
					},
					name = string.toLowerCase().replace(/_/g, '-').split('-'),
					hname = '', part;

				for (part in name) {
					if (part !== '0') {
						hname += '-';
					}
					hname += name[part].charAt(0).toUpperCase() + name[part].substring(1);
				}
				if (exceptions[hname]) {
					hname = exceptions[hname];
				}
				return hname;
			},

			sipErrorCause: function (status_code) {
				var cause;

				for (cause in JsSIP.C.SIP_ERROR_CAUSES) {
					if (JsSIP.C.SIP_ERROR_CAUSES[cause].indexOf(status_code) !== -1) {
						return JsSIP.C.causes[cause];
					}
				}

				return JsSIP.C.causes.SIP_FAILURE_CODE;
			},

			/**
			 * Generate a random Test-Net IP (http://tools.ietf.org/html/rfc5735)
			 * @private
			 */
			getRandomTestNetIP: function () {
				function getOctet(from, to) {
					return window.Math.floor(window.Math.random() * (to - from + 1) + from);
				}

				return '192.0.2.' + getOctet(1, 254);
			},

			getAllowedMethods: function (ua) {
				var event,
					allowed = JsSIP.UA.C.ALLOWED_METHODS.toString();

				for (event in JsSIP.UA.C.EVENT_METHODS) {
					if (ua.checkEvent(event) && ua.listeners(event).length > 0) {
						allowed += ',' + JsSIP.UA.C.EVENT_METHODS[event];
					}
				}

				return allowed;
			},

			// MD5 (Message-Digest Algorithm) http://www.webtoolkit.info
			calculateMD5: function (string) {
				function RotateLeft(lValue, iShiftBits) {
					return (lValue << iShiftBits) | (lValue >>> (32 - iShiftBits));
				}

				function AddUnsigned(lX, lY) {
					var lX4, lY4, lX8, lY8, lResult;
					lX8 = (lX & 0x80000000);
					lY8 = (lY & 0x80000000);
					lX4 = (lX & 0x40000000);
					lY4 = (lY & 0x40000000);
					lResult = (lX & 0x3FFFFFFF) + (lY & 0x3FFFFFFF);
					if (lX4 & lY4) {
						return (lResult ^ 0x80000000 ^ lX8 ^ lY8);
					}
					if (lX4 | lY4) {
						if (lResult & 0x40000000) {
							return (lResult ^ 0xC0000000 ^ lX8 ^ lY8);
						} else {
							return (lResult ^ 0x40000000 ^ lX8 ^ lY8);
						}
					} else {
						return (lResult ^ lX8 ^ lY8);
					}
				}

				function F(x, y, z) {
					return (x & y) | ((~x) & z);
				}

				function G(x, y, z) {
					return (x & z) | (y & (~z));
				}

				function H(x, y, z) {
					return (x ^ y ^ z);
				}

				function I(x, y, z) {
					return (y ^ (x | (~z)));
				}

				function FF(a, b, c, d, x, s, ac) {
					a = AddUnsigned(a, AddUnsigned(AddUnsigned(F(b, c, d), x), ac));
					return AddUnsigned(RotateLeft(a, s), b);
				}

				function GG(a, b, c, d, x, s, ac) {
					a = AddUnsigned(a, AddUnsigned(AddUnsigned(G(b, c, d), x), ac));
					return AddUnsigned(RotateLeft(a, s), b);
				}

				function HH(a, b, c, d, x, s, ac) {
					a = AddUnsigned(a, AddUnsigned(AddUnsigned(H(b, c, d), x), ac));
					return AddUnsigned(RotateLeft(a, s), b);
				}

				function II(a, b, c, d, x, s, ac) {
					a = AddUnsigned(a, AddUnsigned(AddUnsigned(I(b, c, d), x), ac));
					return AddUnsigned(RotateLeft(a, s), b);
				}

				function ConvertToWordArray(string) {
					var lWordCount;
					var lMessageLength = string.length;
					var lNumberOfWords_temp1 = lMessageLength + 8;
					var lNumberOfWords_temp2 = (lNumberOfWords_temp1 - (lNumberOfWords_temp1 % 64)) / 64;
					var lNumberOfWords = (lNumberOfWords_temp2 + 1) * 16;
					var lWordArray = Array(lNumberOfWords - 1);
					var lBytePosition = 0;
					var lByteCount = 0;
					while (lByteCount < lMessageLength) {
						lWordCount = (lByteCount - (lByteCount % 4)) / 4;
						lBytePosition = (lByteCount % 4) * 8;
						lWordArray[lWordCount] = (lWordArray[lWordCount] | (string.charCodeAt(lByteCount) << lBytePosition));
						lByteCount++;
					}
					lWordCount = (lByteCount - (lByteCount % 4)) / 4;
					lBytePosition = (lByteCount % 4) * 8;
					lWordArray[lWordCount] = lWordArray[lWordCount] | (0x80 << lBytePosition);
					lWordArray[lNumberOfWords - 2] = lMessageLength << 3;
					lWordArray[lNumberOfWords - 1] = lMessageLength >>> 29;
					return lWordArray;
				}

				function WordToHex(lValue) {
					var WordToHexValue = "", WordToHexValue_temp = "", lByte, lCount;
					for (lCount = 0; lCount <= 3; lCount++) {
						lByte = (lValue >>> (lCount * 8)) & 255;
						WordToHexValue_temp = "0" + lByte.toString(16);
						WordToHexValue = WordToHexValue + WordToHexValue_temp.substr(WordToHexValue_temp.length - 2, 2);
					}
					return WordToHexValue;
				}

				function Utf8Encode(string) {
					string = string.replace(/\r\n/g, "\n");
					var utftext = "";

					for (var n = 0; n < string.length; n++) {
						var c = string.charCodeAt(n);

						if (c < 128) {
							utftext += String.fromCharCode(c);
						}
						else if ((c > 127) && (c < 2048)) {
							utftext += String.fromCharCode((c >> 6) | 192);
							utftext += String.fromCharCode((c & 63) | 128);
						}
						else {
							utftext += String.fromCharCode((c >> 12) | 224);
							utftext += String.fromCharCode(((c >> 6) & 63) | 128);
							utftext += String.fromCharCode((c & 63) | 128);
						}
					}
					return utftext;
				}

				var x = [];
				var k, AA, BB, CC, DD, a, b, c, d;
				var S11 = 7, S12 = 12, S13 = 17, S14 = 22;
				var S21 = 5, S22 = 9 , S23 = 14, S24 = 20;
				var S31 = 4, S32 = 11, S33 = 16, S34 = 23;
				var S41 = 6, S42 = 10, S43 = 15, S44 = 21;

				string = Utf8Encode(string);

				x = ConvertToWordArray(string);

				a = 0x67452301;
				b = 0xEFCDAB89;
				c = 0x98BADCFE;
				d = 0x10325476;

				for (k = 0; k < x.length; k += 16) {
					AA = a;
					BB = b;
					CC = c;
					DD = d;
					a = FF(a, b, c, d, x[k + 0], S11, 0xD76AA478);
					d = FF(d, a, b, c, x[k + 1], S12, 0xE8C7B756);
					c = FF(c, d, a, b, x[k + 2], S13, 0x242070DB);
					b = FF(b, c, d, a, x[k + 3], S14, 0xC1BDCEEE);
					a = FF(a, b, c, d, x[k + 4], S11, 0xF57C0FAF);
					d = FF(d, a, b, c, x[k + 5], S12, 0x4787C62A);
					c = FF(c, d, a, b, x[k + 6], S13, 0xA8304613);
					b = FF(b, c, d, a, x[k + 7], S14, 0xFD469501);
					a = FF(a, b, c, d, x[k + 8], S11, 0x698098D8);
					d = FF(d, a, b, c, x[k + 9], S12, 0x8B44F7AF);
					c = FF(c, d, a, b, x[k + 10], S13, 0xFFFF5BB1);
					b = FF(b, c, d, a, x[k + 11], S14, 0x895CD7BE);
					a = FF(a, b, c, d, x[k + 12], S11, 0x6B901122);
					d = FF(d, a, b, c, x[k + 13], S12, 0xFD987193);
					c = FF(c, d, a, b, x[k + 14], S13, 0xA679438E);
					b = FF(b, c, d, a, x[k + 15], S14, 0x49B40821);
					a = GG(a, b, c, d, x[k + 1], S21, 0xF61E2562);
					d = GG(d, a, b, c, x[k + 6], S22, 0xC040B340);
					c = GG(c, d, a, b, x[k + 11], S23, 0x265E5A51);
					b = GG(b, c, d, a, x[k + 0], S24, 0xE9B6C7AA);
					a = GG(a, b, c, d, x[k + 5], S21, 0xD62F105D);
					d = GG(d, a, b, c, x[k + 10], S22, 0x2441453);
					c = GG(c, d, a, b, x[k + 15], S23, 0xD8A1E681);
					b = GG(b, c, d, a, x[k + 4], S24, 0xE7D3FBC8);
					a = GG(a, b, c, d, x[k + 9], S21, 0x21E1CDE6);
					d = GG(d, a, b, c, x[k + 14], S22, 0xC33707D6);
					c = GG(c, d, a, b, x[k + 3], S23, 0xF4D50D87);
					b = GG(b, c, d, a, x[k + 8], S24, 0x455A14ED);
					a = GG(a, b, c, d, x[k + 13], S21, 0xA9E3E905);
					d = GG(d, a, b, c, x[k + 2], S22, 0xFCEFA3F8);
					c = GG(c, d, a, b, x[k + 7], S23, 0x676F02D9);
					b = GG(b, c, d, a, x[k + 12], S24, 0x8D2A4C8A);
					a = HH(a, b, c, d, x[k + 5], S31, 0xFFFA3942);
					d = HH(d, a, b, c, x[k + 8], S32, 0x8771F681);
					c = HH(c, d, a, b, x[k + 11], S33, 0x6D9D6122);
					b = HH(b, c, d, a, x[k + 14], S34, 0xFDE5380C);
					a = HH(a, b, c, d, x[k + 1], S31, 0xA4BEEA44);
					d = HH(d, a, b, c, x[k + 4], S32, 0x4BDECFA9);
					c = HH(c, d, a, b, x[k + 7], S33, 0xF6BB4B60);
					b = HH(b, c, d, a, x[k + 10], S34, 0xBEBFBC70);
					a = HH(a, b, c, d, x[k + 13], S31, 0x289B7EC6);
					d = HH(d, a, b, c, x[k + 0], S32, 0xEAA127FA);
					c = HH(c, d, a, b, x[k + 3], S33, 0xD4EF3085);
					b = HH(b, c, d, a, x[k + 6], S34, 0x4881D05);
					a = HH(a, b, c, d, x[k + 9], S31, 0xD9D4D039);
					d = HH(d, a, b, c, x[k + 12], S32, 0xE6DB99E5);
					c = HH(c, d, a, b, x[k + 15], S33, 0x1FA27CF8);
					b = HH(b, c, d, a, x[k + 2], S34, 0xC4AC5665);
					a = II(a, b, c, d, x[k + 0], S41, 0xF4292244);
					d = II(d, a, b, c, x[k + 7], S42, 0x432AFF97);
					c = II(c, d, a, b, x[k + 14], S43, 0xAB9423A7);
					b = II(b, c, d, a, x[k + 5], S44, 0xFC93A039);
					a = II(a, b, c, d, x[k + 12], S41, 0x655B59C3);
					d = II(d, a, b, c, x[k + 3], S42, 0x8F0CCC92);
					c = II(c, d, a, b, x[k + 10], S43, 0xFFEFF47D);
					b = II(b, c, d, a, x[k + 1], S44, 0x85845DD1);
					a = II(a, b, c, d, x[k + 8], S41, 0x6FA87E4F);
					d = II(d, a, b, c, x[k + 15], S42, 0xFE2CE6E0);
					c = II(c, d, a, b, x[k + 6], S43, 0xA3014314);
					b = II(b, c, d, a, x[k + 13], S44, 0x4E0811A1);
					a = II(a, b, c, d, x[k + 4], S41, 0xF7537E82);
					d = II(d, a, b, c, x[k + 11], S42, 0xBD3AF235);
					c = II(c, d, a, b, x[k + 2], S43, 0x2AD7D2BB);
					b = II(b, c, d, a, x[k + 9], S44, 0xEB86D391);
					a = AddUnsigned(a, AA);
					b = AddUnsigned(b, BB);
					c = AddUnsigned(c, CC);
					d = AddUnsigned(d, DD);
				}

				var temp = WordToHex(a) + WordToHex(b) + WordToHex(c) + WordToHex(d);

				return temp.toLowerCase();
			}
		};

		JsSIP.Utils = Utils;
	}(JsSIP));


	/**
	 * @fileoverview Incoming SIP Message Sanity Check
	 */

	/**
	 * SIP message sanity check.
	 * @augments JsSIP
	 * @function
	 * @param {JsSIP.IncomingMessage} message
	 * @param {JsSIP.UA} ua
	 * @param {JsSIP.Transport} transport
	 * @returns {Boolean}
	 */
	(function (JsSIP) {
		var sanityCheck,
			LOG_PREFIX = JsSIP.name + ' | ' + 'SANITY CHECK' + ' | ',

			message, ua, transport,
			requests = [],
			responses = [],
			all = [];

		/*
		 * Sanity Check for incoming Messages
		 *
		 * Requests:
		 *  - _rfc3261_8_2_2_1_ Receive a Request with a non supported URI scheme
		 *  - _rfc3261_16_3_4_ Receive a Request already sent by us
		 *   Does not look at via sent-by but at jssip_id, which is inserted as
		 *   a prefix in all initial requests generated by the ua
		 *  - _rfc3261_18_3_request_ Body Content-Length
		 *  - _rfc3261_8_2_2_2_ Merged Requests
		 *
		 * Responses:
		 *  - _rfc3261_8_1_3_3_ Multiple Via headers
		 *  - _rfc3261_18_1_2_ sent-by mismatch
		 *  - _rfc3261_18_3_response_ Body Content-Length
		 *
		 * All:
		 *  - Minimum headers in a SIP message
		 */

// Sanity Check functions for requests
		function rfc3261_8_2_2_1() {
			if (message.s('to').uri.scheme !== 'sip') {
				reply(416);
				return false;
			}
		}

		function rfc3261_16_3_4() {
			if (!message.to_tag) {
				if (message.call_id.substr(0, 5) === ua.configuration.jssip_id) {
					reply(482);
					return false;
				}
			}
		}

		function rfc3261_18_3_request() {
			var len = JsSIP.Utils.str_utf8_length(message.body),
				contentLength = message.getHeader('content-length');

			if (len < contentLength) {
				reply(400);
				return false;
			}
		}

		function rfc3261_8_2_2_2() {
			var tr, idx,
				fromTag = message.from_tag,
				call_id = message.call_id,
				cseq = message.cseq;

			if (!message.to_tag) {
				if (message.method === JsSIP.C.INVITE) {
					tr = ua.transactions.ist[message.via_branch];
					if (!tr) {
						return;
					} else {
						for (idx in ua.transactions.ist) {
							tr = ua.transactions.ist[idx];
							if (tr.request.from_tag === fromTag && tr.request.call_id === call_id && tr.request.cseq === cseq) {
								reply(482);
								return false;
							}
						}
					}
				} else {
					tr = ua.transactions.nist[message.via_branch];
					if (!tr) {
						return;
					} else {
						for (idx in ua.transactions.nist) {
							tr = ua.transactions.nist[idx];
							if (tr.request.from_tag === fromTag && tr.request.call_id === call_id && tr.request.cseq === cseq) {
								reply(482);
								return false;
							}
						}
					}
				}
			}
		}

// Sanity Check functions for responses
		function rfc3261_8_1_3_3() {
			if (message.countHeader('via') > 1) {
				console.warn(LOG_PREFIX + 'More than one Via header field present in the response. Dropping the response');
				return false;
			}
		}

		function rfc3261_18_1_2() {
			var via_host = ua.configuration.via_host;
			if (message.via.host !== via_host) {
				console.warn(LOG_PREFIX + 'Via host in the response does not match UA Via host value. Dropping the response');
				return false;
			}
		}

		function rfc3261_18_3_response() {
			var
				len = JsSIP.Utils.str_utf8_length(message.body),
				contentLength = message.getHeader('content-length');

			if (len < contentLength) {
				console.warn(LOG_PREFIX + 'Message body length is lower than the value in Content-Length header field. Dropping the response');
				return false;
			}
		}

// Sanity Check functions for requests and responses
		function minimumHeaders() {
			var
				mandatoryHeaders = ['from', 'to', 'call_id', 'cseq', 'via'],
				idx = mandatoryHeaders.length;

			while (idx--) {
				if (!message.hasHeader(mandatoryHeaders[idx])) {
					console.warn(LOG_PREFIX + 'Missing mandatory header field : ' + mandatoryHeaders[idx] + '. Dropping the response');
					return false;
				}
			}
		}

// Reply
		function reply(status_code) {
			var to,
				response = "SIP/2.0 " + status_code + " " + JsSIP.C.REASON_PHRASE[status_code] + "\r\n",
				via_length = message.countHeader('via'),
				idx = 0;

			for (idx; idx < via_length; idx++) {
				response += "Via: " + message.getHeader('via', idx) + "\r\n";
			}

			to = message.getHeader('To');

			if (!message.to_tag) {
				to += ';tag=' + JsSIP.Utils.newTag();
			}

			response += "To: " + to + "\r\n";
			response += "From: " + message.getHeader('From') + "\r\n";
			response += "Call-ID: " + message.call_id + "\r\n";
			response += "CSeq: " + message.cseq + " " + message.method + "\r\n";
			response += "\r\n";

			transport.send(response);
		}

		requests.push(rfc3261_8_2_2_1);
		requests.push(rfc3261_16_3_4);
		requests.push(rfc3261_18_3_request);
		requests.push(rfc3261_8_2_2_2);

		responses.push(rfc3261_8_1_3_3);
		responses.push(rfc3261_18_1_2);
		responses.push(rfc3261_18_3_response);

		all.push(minimumHeaders);

		sanityCheck = function (m, u, t) {
			var len, pass;

			message = m;
			ua = u;
			transport = t;

			len = all.length;
			while (len--) {
				pass = all[len](message);
				if (pass === false) {
					return false;
				}
			}

			if (message instanceof JsSIP.IncomingRequest) {
				len = requests.length;
				while (len--) {
					pass = requests[len](message);
					if (pass === false) {
						return false;
					}
				}
			}

			else if (message instanceof JsSIP.IncomingResponse) {
				len = responses.length;
				while (len--) {
					pass = responses[len](message);
					if (pass === false) {
						return false;
					}
				}
			}

			//Everything is OK
			return true;
		};

		JsSIP.sanityCheck = sanityCheck;
	}(JsSIP));


	/**
	 * @fileoverview SIP Digest Authentication
	 */

	/**
	 * SIP Digest Authentication.
	 * @augments JsSIP.
	 * @function Digest Authentication
	 * @param {JsSIP.UA} ua
	 */
	(function (JsSIP) {
		var DigestAuthentication,
			LOG_PREFIX = JsSIP.name + ' | ' + 'DIGEST AUTHENTICATION' + ' | ';

		DigestAuthentication = function (ua) {
			this.username = ua.configuration.authorization_user;
			this.password = ua.configuration.password;
			this.cnonce = null;
			this.nc = 0;
			this.ncHex = '00000000';
			this.response = null;
		};


		/**
		 * Performs Digest authentication given a SIP request and the challenge
		 * received in a response to that request.
		 * Returns true if credentials were successfully generated, false otherwise.
		 *
		 * @param {JsSIP.OutgoingRequest} request
		 * @param {Object} challenge
		 */
		DigestAuthentication.prototype.authenticate = function (request, challenge) {
			// Inspect and validate the challenge.

			this.algorithm = challenge.algorithm;
			this.realm = challenge.realm;
			this.nonce = challenge.nonce;
			this.opaque = challenge.opaque;
			this.stale = challenge.stale;

			if (this.algorithm) {
				if (this.algorithm !== 'MD5') {
					console.warn(LOG_PREFIX + 'challenge with Digest algorithm different than "MD5", authentication aborted');
					return false;
				}
			} else {
				this.algorithm = 'MD5';
			}

			if (!this.realm) {
				console.warn(LOG_PREFIX + 'challenge without Digest realm, authentication aborted');
				return false;
			}

			if (!this.nonce) {
				console.warn(LOG_PREFIX + 'challenge without Digest nonce, authentication aborted');
				return false;
			}

			// 'qop' can contain a list of values (Array). Let's choose just one.
			if (challenge.qop) {
				if (challenge.qop.indexOf('auth') > -1) {
					this.qop = 'auth';
				} else if (challenge.qop.indexOf('auth-int') > -1) {
					this.qop = 'auth-int';
				} else {
					// Otherwise 'qop' is present but does not contain 'auth' or 'auth-int', so abort here.
					console.warn(LOG_PREFIX + 'challenge without Digest qop different than "auth" or "auth-int", authentication aborted');
					return false;
				}
			} else {
				this.qop = null;
			}

			// Fill other attributes.

			this.method = request.method;
			this.uri = request.ruri;
			this.cnonce = JsSIP.Utils.createRandomToken(12);
			this.nc += 1;
			this.updateNcHex();

			// nc-value = 8LHEX. Max value = 'FFFFFFFF'.
			if (this.nc === 4294967296) {
				this.nc = 1;
				this.ncHex = '00000001';
			}

			// Calculate the Digest "response" value.
			this.calculateResponse();

			return true;
		};


		/**
		 * Generate Digest 'response' value.
		 * @private
		 */
		DigestAuthentication.prototype.calculateResponse = function () {
			var ha1, ha2;

			// HA1 = MD5(A1) = MD5(username:realm:password)
			ha1 = JsSIP.Utils.calculateMD5(this.username + ":" + this.realm + ":" + this.password);

			if (this.qop === 'auth') {
				// HA2 = MD5(A2) = MD5(method:digestURI)
				ha2 = JsSIP.Utils.calculateMD5(this.method + ":" + this.uri);
				// response = MD5(HA1:nonce:nonceCount:credentialsNonce:qop:HA2)
				this.response = JsSIP.Utils.calculateMD5(ha1 + ":" + this.nonce + ":" + this.ncHex + ":" + this.cnonce + ":auth:" + ha2);

			} else if (this.qop === 'auth-int') {
				// HA2 = MD5(A2) = MD5(method:digestURI:MD5(entityBody))
				ha2 = JsSIP.Utils.calculateMD5(this.method + ":" + this.uri + ":" + JsSIP.Utils.calculateMD5(this.body ? this.body : ""));
				// response = MD5(HA1:nonce:nonceCount:credentialsNonce:qop:HA2)
				this.response = JsSIP.Utils.calculateMD5(ha1 + ":" + this.nonce + ":" + this.ncHex + ":" + this.cnonce + ":auth-int:" + ha2);

			} else if (this.qop === null) {
				// HA2 = MD5(A2) = MD5(method:digestURI)
				ha2 = JsSIP.Utils.calculateMD5(this.method + ":" + this.uri);
				// response = MD5(HA1:nonce:HA2)
				this.response = JsSIP.Utils.calculateMD5(ha1 + ":" + this.nonce + ":" + ha2);
			}
		};


		/**
		 * Return the Proxy-Authorization or WWW-Authorization header value.
		 */
		DigestAuthentication.prototype.toString = function () {
			var auth_params = [];

			if (!this.response) {
				throw new Error('response field does not exist, cannot generate Authorization header');
			}

			auth_params.push('algorithm=' + this.algorithm);
			auth_params.push('username="' + this.username + '"');
			auth_params.push('realm="' + this.realm + '"');
			auth_params.push('nonce="' + this.nonce + '"');
			auth_params.push('uri="' + this.uri + '"');
			auth_params.push('response="' + this.response + '"');
			if (this.opaque) {
				auth_params.push('opaque="' + this.opaque + '"');
			}
			if (this.qop) {
				auth_params.push('qop=' + this.qop);
				auth_params.push('cnonce="' + this.cnonce + '"');
				auth_params.push('nc=' + this.ncHex);
			}

			return 'Digest ' + auth_params.join(', ');
		};


		/**
		 * Generate the 'nc' value as required by Digest in this.ncHex by reading this.nc.
		 * @private
		 */
		DigestAuthentication.prototype.updateNcHex = function () {
			var hex = Number(this.nc).toString(16);
			this.ncHex = '00000000'.substr(0, 8 - hex.length) + hex;
		};

		JsSIP.DigestAuthentication = DigestAuthentication;
	}(JsSIP));


	/**
	 * @fileoverview WebRTC
	 */

	(function (JsSIP) {
		var WebRTC;

		WebRTC = {};

// getUserMedia
		if (window.navigator.webkitGetUserMedia) {
			WebRTC.getUserMedia = window.navigator.webkitGetUserMedia.bind(navigator);
		}
		else if (window.navigator.mozGetUserMedia) {
			WebRTC.getUserMedia = window.navigator.mozGetUserMedia.bind(navigator);
		}
		else if (window.navigator.getUserMedia) {
			WebRTC.getUserMedia = window.navigator.getUserMedia.bind(navigator);
		}

// RTCPeerConnection
		if (window.webkitRTCPeerConnection) {
			WebRTC.RTCPeerConnection = window.webkitRTCPeerConnection;
		}
		else if (window.mozRTCPeerConnection) {
			WebRTC.RTCPeerConnection = window.mozRTCPeerConnection;
		}
		else if (window.RTCPeerConnection) {
			WebRTC.RTCPeerConnection = window.RTCPeerConnection;
		}

// RTCSessionDescription
		if (window.webkitRTCSessionDescription) {
			WebRTC.RTCSessionDescription = window.webkitRTCSessionDescription;
		}
		else if (window.mozRTCSessionDescription) {
			WebRTC.RTCSessionDescription = window.mozRTCSessionDescription;
		}
		else if (window.RTCSessionDescription) {
			WebRTC.RTCSessionDescription = window.RTCSessionDescription;
		}

// New syntax for getting streams in Chrome M26.
		if (WebRTC.RTCPeerConnection && WebRTC.RTCPeerConnection.prototype) {
			if (!WebRTC.RTCPeerConnection.prototype.getLocalStreams) {
				WebRTC.RTCPeerConnection.prototype.getLocalStreams = function () {
					return this.localStreams;
				};
				WebRTC.RTCPeerConnection.prototype.getRemoteStreams = function () {
					return this.remoteStreams;
				};
			}
		}

// isSupported attribute.
		if (WebRTC.getUserMedia && WebRTC.RTCPeerConnection && WebRTC.RTCSessionDescription) {
			WebRTC.isSupported = true;
		}
		else {
			WebRTC.isSupported = false;
		}

		JsSIP.WebRTC = WebRTC;
	}(JsSIP));


	window.JsSIP = JsSIP;
}(window));


JsSIP.Grammar = (function () {
	/*
	 * Generated by PEG.js 0.7.0.
	 *
	 * http://pegjs.majda.cz/
	 */

	function quote(s) {
		/*
		 * ECMA-262, 5th ed., 7.8.4: All characters may appear literally in a
		 * string literal except for the closing quote character, backslash,
		 * carriage return, line separator, paragraph separator, and line feed.
		 * Any character may appear in the form of an escape sequence.
		 *
		 * For portability, we also escape escape all control and non-ASCII
		 * characters. Note that "\0" and "\v" escape sequences are not used
		 * because JSHint does not like the first and IE the second.
		 */
		return '"' + s
			.replace(/\\/g, '\\\\')  // backslash
			.replace(/"/g, '\\"')    // closing quote character
			.replace(/\x08/g, '\\b') // backspace
			.replace(/\t/g, '\\t')   // horizontal tab
			.replace(/\n/g, '\\n')   // line feed
			.replace(/\f/g, '\\f')   // form feed
			.replace(/\r/g, '\\r')   // carriage return
			.replace(/[\x00-\x07\x0B\x0E-\x1F\x80-\uFFFF]/g, escape)
			+ '"';
	}

	var result = {
		/*
		 * Parses the input with a generated parser. If the parsing is successfull,
		 * returns a value explicitly or implicitly specified by the grammar from
		 * which the parser was generated (see |PEG.buildParser|). If the parsing is
		 * unsuccessful, throws |PEG.parser.SyntaxError| describing the error.
		 */
		parse: function (input, startRule) {
			var parseFunctions = {
				"CRLF": parse_CRLF,
				"DIGIT": parse_DIGIT,
				"ALPHA": parse_ALPHA,
				"HEXDIG": parse_HEXDIG,
				"WSP": parse_WSP,
				"OCTET": parse_OCTET,
				"DQUOTE": parse_DQUOTE,
				"SP": parse_SP,
				"HTAB": parse_HTAB,
				"alphanum": parse_alphanum,
				"reserved": parse_reserved,
				"unreserved": parse_unreserved,
				"mark": parse_mark,
				"escaped": parse_escaped,
				"LWS": parse_LWS,
				"SWS": parse_SWS,
				"HCOLON": parse_HCOLON,
				"TEXT_UTF8_TRIM": parse_TEXT_UTF8_TRIM,
				"TEXT_UTF8char": parse_TEXT_UTF8char,
				"UTF8_NONASCII": parse_UTF8_NONASCII,
				"UTF8_CONT": parse_UTF8_CONT,
				"LHEX": parse_LHEX,
				"token": parse_token,
				"token_nodot": parse_token_nodot,
				"separators": parse_separators,
				"word": parse_word,
				"STAR": parse_STAR,
				"SLASH": parse_SLASH,
				"EQUAL": parse_EQUAL,
				"LPAREN": parse_LPAREN,
				"RPAREN": parse_RPAREN,
				"RAQUOT": parse_RAQUOT,
				"LAQUOT": parse_LAQUOT,
				"COMMA": parse_COMMA,
				"SEMI": parse_SEMI,
				"COLON": parse_COLON,
				"LDQUOT": parse_LDQUOT,
				"RDQUOT": parse_RDQUOT,
				"comment": parse_comment,
				"ctext": parse_ctext,
				"quoted_string": parse_quoted_string,
				"quoted_string_clean": parse_quoted_string_clean,
				"qdtext": parse_qdtext,
				"quoted_pair": parse_quoted_pair,
				"SIP_URI_noparams": parse_SIP_URI_noparams,
				"SIP_URI": parse_SIP_URI,
				"uri_scheme": parse_uri_scheme,
				"userinfo": parse_userinfo,
				"user": parse_user,
				"user_unreserved": parse_user_unreserved,
				"password": parse_password,
				"hostport": parse_hostport,
				"host": parse_host,
				"hostname": parse_hostname,
				"domainlabel": parse_domainlabel,
				"toplabel": parse_toplabel,
				"IPv6reference": parse_IPv6reference,
				"IPv6address": parse_IPv6address,
				"h16": parse_h16,
				"ls32": parse_ls32,
				"IPv4address": parse_IPv4address,
				"dec_octet": parse_dec_octet,
				"port": parse_port,
				"uri_parameters": parse_uri_parameters,
				"uri_parameter": parse_uri_parameter,
				"transport_param": parse_transport_param,
				"user_param": parse_user_param,
				"method_param": parse_method_param,
				"ttl_param": parse_ttl_param,
				"maddr_param": parse_maddr_param,
				"lr_param": parse_lr_param,
				"other_param": parse_other_param,
				"pname": parse_pname,
				"pvalue": parse_pvalue,
				"paramchar": parse_paramchar,
				"param_unreserved": parse_param_unreserved,
				"headers": parse_headers,
				"header": parse_header,
				"hname": parse_hname,
				"hvalue": parse_hvalue,
				"hnv_unreserved": parse_hnv_unreserved,
				"Request_Response": parse_Request_Response,
				"Request_Line": parse_Request_Line,
				"Request_URI": parse_Request_URI,
				"absoluteURI": parse_absoluteURI,
				"hier_part": parse_hier_part,
				"net_path": parse_net_path,
				"abs_path": parse_abs_path,
				"opaque_part": parse_opaque_part,
				"uric": parse_uric,
				"uric_no_slash": parse_uric_no_slash,
				"path_segments": parse_path_segments,
				"segment": parse_segment,
				"param": parse_param,
				"pchar": parse_pchar,
				"scheme": parse_scheme,
				"authority": parse_authority,
				"srvr": parse_srvr,
				"reg_name": parse_reg_name,
				"query": parse_query,
				"SIP_Version": parse_SIP_Version,
				"INVITEm": parse_INVITEm,
				"ACKm": parse_ACKm,
				"OPTIONSm": parse_OPTIONSm,
				"BYEm": parse_BYEm,
				"CANCELm": parse_CANCELm,
				"REGISTERm": parse_REGISTERm,
				"SUBSCRIBEm": parse_SUBSCRIBEm,
				"NOTIFYm": parse_NOTIFYm,
				"Method": parse_Method,
				"Status_Line": parse_Status_Line,
				"Status_Code": parse_Status_Code,
				"extension_code": parse_extension_code,
				"Reason_Phrase": parse_Reason_Phrase,
				"Allow_Events": parse_Allow_Events,
				"Call_ID": parse_Call_ID,
				"Contact": parse_Contact,
				"contact_param": parse_contact_param,
				"name_addr": parse_name_addr,
				"display_name": parse_display_name,
				"contact_params": parse_contact_params,
				"c_p_q": parse_c_p_q,
				"c_p_expires": parse_c_p_expires,
				"delta_seconds": parse_delta_seconds,
				"qvalue": parse_qvalue,
				"generic_param": parse_generic_param,
				"gen_value": parse_gen_value,
				"Content_Disposition": parse_Content_Disposition,
				"disp_type": parse_disp_type,
				"disp_param": parse_disp_param,
				"handling_param": parse_handling_param,
				"Content_Encoding": parse_Content_Encoding,
				"Content_Length": parse_Content_Length,
				"Content_Type": parse_Content_Type,
				"media_type": parse_media_type,
				"m_type": parse_m_type,
				"discrete_type": parse_discrete_type,
				"composite_type": parse_composite_type,
				"extension_token": parse_extension_token,
				"x_token": parse_x_token,
				"m_subtype": parse_m_subtype,
				"m_parameter": parse_m_parameter,
				"m_value": parse_m_value,
				"CSeq": parse_CSeq,
				"CSeq_value": parse_CSeq_value,
				"Expires": parse_Expires,
				"Event": parse_Event,
				"event_type": parse_event_type,
				"From": parse_From,
				"from_param": parse_from_param,
				"tag_param": parse_tag_param,
				"Max_Forwards": parse_Max_Forwards,
				"Min_Expires": parse_Min_Expires,
				"Name_Addr_Header": parse_Name_Addr_Header,
				"Proxy_Authenticate": parse_Proxy_Authenticate,
				"challenge": parse_challenge,
				"other_challenge": parse_other_challenge,
				"auth_param": parse_auth_param,
				"digest_cln": parse_digest_cln,
				"realm": parse_realm,
				"realm_value": parse_realm_value,
				"domain": parse_domain,
				"URI": parse_URI,
				"nonce": parse_nonce,
				"nonce_value": parse_nonce_value,
				"opaque": parse_opaque,
				"stale": parse_stale,
				"algorithm": parse_algorithm,
				"qop_options": parse_qop_options,
				"qop_value": parse_qop_value,
				"Proxy_Require": parse_Proxy_Require,
				"Record_Route": parse_Record_Route,
				"rec_route": parse_rec_route,
				"Require": parse_Require,
				"Route": parse_Route,
				"route_param": parse_route_param,
				"Subscription_State": parse_Subscription_State,
				"substate_value": parse_substate_value,
				"subexp_params": parse_subexp_params,
				"event_reason_value": parse_event_reason_value,
				"Subject": parse_Subject,
				"Supported": parse_Supported,
				"To": parse_To,
				"to_param": parse_to_param,
				"Via": parse_Via,
				"via_parm": parse_via_parm,
				"via_params": parse_via_params,
				"via_ttl": parse_via_ttl,
				"via_maddr": parse_via_maddr,
				"via_received": parse_via_received,
				"via_branch": parse_via_branch,
				"response_port": parse_response_port,
				"sent_protocol": parse_sent_protocol,
				"protocol_name": parse_protocol_name,
				"transport": parse_transport,
				"sent_by": parse_sent_by,
				"via_host": parse_via_host,
				"via_port": parse_via_port,
				"ttl": parse_ttl,
				"WWW_Authenticate": parse_WWW_Authenticate,
				"extension_header": parse_extension_header,
				"header_value": parse_header_value,
				"message_body": parse_message_body,
				"stun_URI": parse_stun_URI,
				"stun_scheme": parse_stun_scheme,
				"stun_host_port": parse_stun_host_port,
				"stun_host": parse_stun_host,
				"reg_name": parse_reg_name,
				"stun_unreserved": parse_stun_unreserved,
				"sub_delims": parse_sub_delims,
				"turn_URI": parse_turn_URI,
				"turn_scheme": parse_turn_scheme,
				"turn_transport": parse_turn_transport
			};

			if (startRule !== undefined) {
				if (parseFunctions[startRule] === undefined) {
					throw new Error("Invalid rule name: " + quote(startRule) + ".");
				}
			} else {
				startRule = "CRLF";
			}

			var pos = 0;
			var reportFailures = 0;
			var rightmostFailuresPos = 0;
			var rightmostFailuresExpected = [];

			function padLeft(input, padding, length) {
				var result = input;

				var padLength = length - input.length;
				for (var i = 0; i < padLength; i++) {
					result = padding + result;
				}

				return result;
			}

			function escape(ch) {
				var charCode = ch.charCodeAt(0);
				var escapeChar;
				var length;

				if (charCode <= 0xFF) {
					escapeChar = 'x';
					length = 2;
				} else {
					escapeChar = 'u';
					length = 4;
				}

				return '\\' + escapeChar + padLeft(charCode.toString(16).toUpperCase(), '0', length);
			}

			function matchFailed(failure) {
				if (pos < rightmostFailuresPos) {
					return;
				}

				if (pos > rightmostFailuresPos) {
					rightmostFailuresPos = pos;
					rightmostFailuresExpected = [];
				}

				rightmostFailuresExpected.push(failure);
			}

			function parse_CRLF() {
				var result0;

				if (input.substr(pos, 2) === "\r\n") {
					result0 = "\r\n";
					pos += 2;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"\\r\\n\"");
					}
				}
				return result0;
			}

			function parse_DIGIT() {
				var result0;

				if (/^[0-9]/.test(input.charAt(pos))) {
					result0 = input.charAt(pos);
					pos++;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("[0-9]");
					}
				}
				return result0;
			}

			function parse_ALPHA() {
				var result0;

				if (/^[a-zA-Z]/.test(input.charAt(pos))) {
					result0 = input.charAt(pos);
					pos++;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("[a-zA-Z]");
					}
				}
				return result0;
			}

			function parse_HEXDIG() {
				var result0;

				if (/^[0-9a-fA-F]/.test(input.charAt(pos))) {
					result0 = input.charAt(pos);
					pos++;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("[0-9a-fA-F]");
					}
				}
				return result0;
			}

			function parse_WSP() {
				var result0;

				result0 = parse_SP();
				if (result0 === null) {
					result0 = parse_HTAB();
				}
				return result0;
			}

			function parse_OCTET() {
				var result0;

				if (/^[\0-\xFF]/.test(input.charAt(pos))) {
					result0 = input.charAt(pos);
					pos++;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("[\\0-\\xFF]");
					}
				}
				return result0;
			}

			function parse_DQUOTE() {
				var result0;

				if (/^["]/.test(input.charAt(pos))) {
					result0 = input.charAt(pos);
					pos++;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("[\"]");
					}
				}
				return result0;
			}

			function parse_SP() {
				var result0;

				if (input.charCodeAt(pos) === 32) {
					result0 = " ";
					pos++;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\" \"");
					}
				}
				return result0;
			}

			function parse_HTAB() {
				var result0;

				if (input.charCodeAt(pos) === 9) {
					result0 = "\t";
					pos++;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"\\t\"");
					}
				}
				return result0;
			}

			function parse_alphanum() {
				var result0;

				if (/^[a-zA-Z0-9]/.test(input.charAt(pos))) {
					result0 = input.charAt(pos);
					pos++;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("[a-zA-Z0-9]");
					}
				}
				return result0;
			}

			function parse_reserved() {
				var result0;

				if (input.charCodeAt(pos) === 59) {
					result0 = ";";
					pos++;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\";\"");
					}
				}
				if (result0 === null) {
					if (input.charCodeAt(pos) === 47) {
						result0 = "/";
						pos++;
					} else {
						result0 = null;
						if (reportFailures === 0) {
							matchFailed("\"/\"");
						}
					}
					if (result0 === null) {
						if (input.charCodeAt(pos) === 63) {
							result0 = "?";
							pos++;
						} else {
							result0 = null;
							if (reportFailures === 0) {
								matchFailed("\"?\"");
							}
						}
						if (result0 === null) {
							if (input.charCodeAt(pos) === 58) {
								result0 = ":";
								pos++;
							} else {
								result0 = null;
								if (reportFailures === 0) {
									matchFailed("\":\"");
								}
							}
							if (result0 === null) {
								if (input.charCodeAt(pos) === 64) {
									result0 = "@";
									pos++;
								} else {
									result0 = null;
									if (reportFailures === 0) {
										matchFailed("\"@\"");
									}
								}
								if (result0 === null) {
									if (input.charCodeAt(pos) === 38) {
										result0 = "&";
										pos++;
									} else {
										result0 = null;
										if (reportFailures === 0) {
											matchFailed("\"&\"");
										}
									}
									if (result0 === null) {
										if (input.charCodeAt(pos) === 61) {
											result0 = "=";
											pos++;
										} else {
											result0 = null;
											if (reportFailures === 0) {
												matchFailed("\"=\"");
											}
										}
										if (result0 === null) {
											if (input.charCodeAt(pos) === 43) {
												result0 = "+";
												pos++;
											} else {
												result0 = null;
												if (reportFailures === 0) {
													matchFailed("\"+\"");
												}
											}
											if (result0 === null) {
												if (input.charCodeAt(pos) === 36) {
													result0 = "$";
													pos++;
												} else {
													result0 = null;
													if (reportFailures === 0) {
														matchFailed("\"$\"");
													}
												}
												if (result0 === null) {
													if (input.charCodeAt(pos) === 44) {
														result0 = ",";
														pos++;
													} else {
														result0 = null;
														if (reportFailures === 0) {
															matchFailed("\",\"");
														}
													}
												}
											}
										}
									}
								}
							}
						}
					}
				}
				return result0;
			}

			function parse_unreserved() {
				var result0;

				result0 = parse_alphanum();
				if (result0 === null) {
					result0 = parse_mark(true); // with #
				}
				return result0;
			}

			function parse_mark(withHash) {
				var result0;

				if (input.charCodeAt(pos) === 45) {
					result0 = "-";
					pos++;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"-\"");
					}
				}
				if (result0 === null) {
					if (input.charCodeAt(pos) === 95) {
						result0 = "_";
						pos++;
					} else {
						result0 = null;
						if (reportFailures === 0) {
							matchFailed("\"_\"");
						}
					}
					if (result0 === null) {
						if (input.charCodeAt(pos) === 46) {
							result0 = ".";
							pos++;
						} else {
							result0 = null;
							if (reportFailures === 0) {
								matchFailed("\".\"");
							}
						}
						if (result0 === null) {
							if (input.charCodeAt(pos) === 33) {
								result0 = "!";
								pos++;
							} else {
								result0 = null;
								if (reportFailures === 0) {
									matchFailed("\"!\"");
								}
							}
							if (result0 === null) {
								if (input.charCodeAt(pos) === 126) {
									result0 = "~";
									pos++;
								} else {
									result0 = null;
									if (reportFailures === 0) {
										matchFailed("\"~\"");
									}
								}
								if (result0 === null) {
									if (input.charCodeAt(pos) === 42) {
										result0 = "*";
										pos++;
									} else {
										result0 = null;
										if (reportFailures === 0) {
											matchFailed("\"*\"");
										}
									}
									if (result0 === null) {
										if (input.charCodeAt(pos) === 39) {
											result0 = "'";
											pos++;
										} else {
											result0 = null;
											if (reportFailures === 0) {
												matchFailed("\"'\"");
											}
										}
										if (result0 === null) {
											if (input.charCodeAt(pos) === 40) {
												result0 = "(";
												pos++;
											} else {
												result0 = null;
												if (reportFailures === 0) {
													matchFailed("\"(\"");
												}
											}
											if (result0 === null) {
												if (input.charCodeAt(pos) === 41) {
													result0 = ")";
													pos++;
												} else {
													result0 = null;
													if (reportFailures === 0) {
														matchFailed("\")\"");
													}
												}
												if (withHash && result0 === null) {
													if (input.charCodeAt(pos) === 35) { // #
														result0 = "#";
														pos++;
													} else {
														result0 = null;
														if (reportFailures === 0) {
															matchFailed("\"#\"");
														}
													}
												}
											}
										}
									}
								}
							}
						}
					}
				}
				return result0;
			}

			function parse_escaped() {
				var result0, result1, result2;
				var pos0;

				pos0 = pos;
				if (input.charCodeAt(pos) === 37) {
					result0 = "%";
					pos++;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"%\"");
					}
				}
				if (result0 !== null) {
					result1 = parse_HEXDIG();
					if (result1 !== null) {
						result2 = parse_HEXDIG();
						if (result2 !== null) {
							result0 = [result0, result1, result2];
						} else {
							result0 = null;
							pos = pos0;
						}
					} else {
						result0 = null;
						pos = pos0;
					}
				} else {
					result0 = null;
					pos = pos0;
				}
				return result0;
			}

			function parse_LWS() {
				var result0, result1, result2;
				var pos0, pos1, pos2;

				pos0 = pos;
				pos1 = pos;
				pos2 = pos;
				result0 = [];
				result1 = parse_WSP();
				while (result1 !== null) {
					result0.push(result1);
					result1 = parse_WSP();
				}
				if (result0 !== null) {
					result1 = parse_CRLF();
					if (result1 !== null) {
						result0 = [result0, result1];
					} else {
						result0 = null;
						pos = pos2;
					}
				} else {
					result0 = null;
					pos = pos2;
				}
				result0 = result0 !== null ? result0 : "";
				if (result0 !== null) {
					result2 = parse_WSP();
					if (result2 !== null) {
						result1 = [];
						while (result2 !== null) {
							result1.push(result2);
							result2 = parse_WSP();
						}
					} else {
						result1 = null;
					}
					if (result1 !== null) {
						result0 = [result0, result1];
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset) {
						return " ";
					})(pos0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_SWS() {
				var result0;

				result0 = parse_LWS();
				result0 = result0 !== null ? result0 : "";
				return result0;
			}

			function parse_HCOLON() {
				var result0, result1, result2;
				var pos0, pos1;

				pos0 = pos;
				pos1 = pos;
				result0 = [];
				result1 = parse_SP();
				if (result1 === null) {
					result1 = parse_HTAB();
				}
				while (result1 !== null) {
					result0.push(result1);
					result1 = parse_SP();
					if (result1 === null) {
						result1 = parse_HTAB();
					}
				}
				if (result0 !== null) {
					if (input.charCodeAt(pos) === 58) {
						result1 = ":";
						pos++;
					} else {
						result1 = null;
						if (reportFailures === 0) {
							matchFailed("\":\"");
						}
					}
					if (result1 !== null) {
						result2 = parse_SWS();
						if (result2 !== null) {
							result0 = [result0, result1, result2];
						} else {
							result0 = null;
							pos = pos1;
						}
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset) {
						return ':';
					})(pos0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_TEXT_UTF8_TRIM() {
				var result0, result1, result2, result3;
				var pos0, pos1, pos2;

				pos0 = pos;
				pos1 = pos;
				result1 = parse_TEXT_UTF8char();
				if (result1 !== null) {
					result0 = [];
					while (result1 !== null) {
						result0.push(result1);
						result1 = parse_TEXT_UTF8char();
					}
				} else {
					result0 = null;
				}
				if (result0 !== null) {
					result1 = [];
					pos2 = pos;
					result2 = [];
					result3 = parse_LWS();
					while (result3 !== null) {
						result2.push(result3);
						result3 = parse_LWS();
					}
					if (result2 !== null) {
						result3 = parse_TEXT_UTF8char();
						if (result3 !== null) {
							result2 = [result2, result3];
						} else {
							result2 = null;
							pos = pos2;
						}
					} else {
						result2 = null;
						pos = pos2;
					}
					while (result2 !== null) {
						result1.push(result2);
						pos2 = pos;
						result2 = [];
						result3 = parse_LWS();
						while (result3 !== null) {
							result2.push(result3);
							result3 = parse_LWS();
						}
						if (result2 !== null) {
							result3 = parse_TEXT_UTF8char();
							if (result3 !== null) {
								result2 = [result2, result3];
							} else {
								result2 = null;
								pos = pos2;
							}
						} else {
							result2 = null;
							pos = pos2;
						}
					}
					if (result1 !== null) {
						result0 = [result0, result1];
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset) {
						return input.substring(pos, offset);
					})(pos0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_TEXT_UTF8char() {
				var result0;

				if (/^[!-~]/.test(input.charAt(pos))) {
					result0 = input.charAt(pos);
					pos++;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("[!-~]");
					}
				}
				if (result0 === null) {
					result0 = parse_UTF8_NONASCII();
				}
				return result0;
			}

			function parse_UTF8_NONASCII() {
				var result0;

				if (/^[\x80-\uFFFF]/.test(input.charAt(pos))) {
					result0 = input.charAt(pos);
					pos++;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("[\\x80-\\uFFFF]");
					}
				}
				return result0;
			}

			function parse_UTF8_CONT() {
				var result0;

				if (/^[\x80-\xBF]/.test(input.charAt(pos))) {
					result0 = input.charAt(pos);
					pos++;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("[\\x80-\\xBF]");
					}
				}
				return result0;
			}

			function parse_LHEX() {
				var result0;

				result0 = parse_DIGIT();
				if (result0 === null) {
					if (/^[a-f]/.test(input.charAt(pos))) {
						result0 = input.charAt(pos);
						pos++;
					} else {
						result0 = null;
						if (reportFailures === 0) {
							matchFailed("[a-f]");
						}
					}
				}
				return result0;
			}

			function parse_token() {
				var result0, result1;
				var pos0;

				pos0 = pos;
				result1 = parse_alphanum();
				if (result1 === null) {
					if (input.charCodeAt(pos) === 45) {
						result1 = "-";
						pos++;
					} else {
						result1 = null;
						if (reportFailures === 0) {
							matchFailed("\"-\"");
						}
					}
					if (result1 === null) {
						if (input.charCodeAt(pos) === 46) {
							result1 = ".";
							pos++;
						} else {
							result1 = null;
							if (reportFailures === 0) {
								matchFailed("\".\"");
							}
						}
						if (result1 === null) {
							if (input.charCodeAt(pos) === 33) {
								result1 = "!";
								pos++;
							} else {
								result1 = null;
								if (reportFailures === 0) {
									matchFailed("\"!\"");
								}
							}
							if (result1 === null) {
								if (input.charCodeAt(pos) === 37) {
									result1 = "%";
									pos++;
								} else {
									result1 = null;
									if (reportFailures === 0) {
										matchFailed("\"%\"");
									}
								}
								if (result1 === null) {
									if (input.charCodeAt(pos) === 42) {
										result1 = "*";
										pos++;
									} else {
										result1 = null;
										if (reportFailures === 0) {
											matchFailed("\"*\"");
										}
									}
									if (result1 === null) {
										if (input.charCodeAt(pos) === 95) {
											result1 = "_";
											pos++;
										} else {
											result1 = null;
											if (reportFailures === 0) {
												matchFailed("\"_\"");
											}
										}
										if (result1 === null) {
											if (input.charCodeAt(pos) === 43) {
												result1 = "+";
												pos++;
											} else {
												result1 = null;
												if (reportFailures === 0) {
													matchFailed("\"+\"");
												}
											}
											if (result1 === null) {
												if (input.charCodeAt(pos) === 96) {
													result1 = "`";
													pos++;
												} else {
													result1 = null;
													if (reportFailures === 0) {
														matchFailed("\"`\"");
													}
												}
												if (result1 === null) {
													if (input.charCodeAt(pos) === 39) {
														result1 = "'";
														pos++;
													} else {
														result1 = null;
														if (reportFailures === 0) {
															matchFailed("\"'\"");
														}
													}
													if (result1 === null) {
														if (input.charCodeAt(pos) === 126) {
															result1 = "~";
															pos++;
														} else {
															result1 = null;
															if (reportFailures === 0) {
																matchFailed("\"~\"");
															}
														}
													}
												}
											}
										}
									}
								}
							}
						}
					}
				}
				if (result1 !== null) {
					result0 = [];
					while (result1 !== null) {
						result0.push(result1);
						result1 = parse_alphanum();
						if (result1 === null) {
							if (input.charCodeAt(pos) === 45) {
								result1 = "-";
								pos++;
							} else {
								result1 = null;
								if (reportFailures === 0) {
									matchFailed("\"-\"");
								}
							}
							if (result1 === null) {
								if (input.charCodeAt(pos) === 46) {
									result1 = ".";
									pos++;
								} else {
									result1 = null;
									if (reportFailures === 0) {
										matchFailed("\".\"");
									}
								}
								if (result1 === null) {
									if (input.charCodeAt(pos) === 33) {
										result1 = "!";
										pos++;
									} else {
										result1 = null;
										if (reportFailures === 0) {
											matchFailed("\"!\"");
										}
									}
									if (result1 === null) {
										if (input.charCodeAt(pos) === 37) {
											result1 = "%";
											pos++;
										} else {
											result1 = null;
											if (reportFailures === 0) {
												matchFailed("\"%\"");
											}
										}
										if (result1 === null) {
											if (input.charCodeAt(pos) === 42) {
												result1 = "*";
												pos++;
											} else {
												result1 = null;
												if (reportFailures === 0) {
													matchFailed("\"*\"");
												}
											}
											if (result1 === null) {
												if (input.charCodeAt(pos) === 95) {
													result1 = "_";
													pos++;
												} else {
													result1 = null;
													if (reportFailures === 0) {
														matchFailed("\"_\"");
													}
												}
												if (result1 === null) {
													if (input.charCodeAt(pos) === 43) {
														result1 = "+";
														pos++;
													} else {
														result1 = null;
														if (reportFailures === 0) {
															matchFailed("\"+\"");
														}
													}
													if (result1 === null) {
														if (input.charCodeAt(pos) === 96) {
															result1 = "`";
															pos++;
														} else {
															result1 = null;
															if (reportFailures === 0) {
																matchFailed("\"`\"");
															}
														}
														if (result1 === null) {
															if (input.charCodeAt(pos) === 39) {
																result1 = "'";
																pos++;
															} else {
																result1 = null;
																if (reportFailures === 0) {
																	matchFailed("\"'\"");
																}
															}
															if (result1 === null) {
																if (input.charCodeAt(pos) === 126) {
																	result1 = "~";
																	pos++;
																} else {
																	result1 = null;
																	if (reportFailures === 0) {
																		matchFailed("\"~\"");
																	}
																}
															}
														}
													}
												}
											}
										}
									}
								}
							}
						}
					}
				} else {
					result0 = null;
				}
				if (result0 !== null) {
					result0 = (function (offset) {
						return input.substring(pos, offset);
					})(pos0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_token_nodot() {
				var result0, result1;
				var pos0;

				pos0 = pos;
				result1 = parse_alphanum();
				if (result1 === null) {
					if (input.charCodeAt(pos) === 45) {
						result1 = "-";
						pos++;
					} else {
						result1 = null;
						if (reportFailures === 0) {
							matchFailed("\"-\"");
						}
					}
					if (result1 === null) {
						if (input.charCodeAt(pos) === 33) {
							result1 = "!";
							pos++;
						} else {
							result1 = null;
							if (reportFailures === 0) {
								matchFailed("\"!\"");
							}
						}
						if (result1 === null) {
							if (input.charCodeAt(pos) === 37) {
								result1 = "%";
								pos++;
							} else {
								result1 = null;
								if (reportFailures === 0) {
									matchFailed("\"%\"");
								}
							}
							if (result1 === null) {
								if (input.charCodeAt(pos) === 42) {
									result1 = "*";
									pos++;
								} else {
									result1 = null;
									if (reportFailures === 0) {
										matchFailed("\"*\"");
									}
								}
								if (result1 === null) {
									if (input.charCodeAt(pos) === 95) {
										result1 = "_";
										pos++;
									} else {
										result1 = null;
										if (reportFailures === 0) {
											matchFailed("\"_\"");
										}
									}
									if (result1 === null) {
										if (input.charCodeAt(pos) === 43) {
											result1 = "+";
											pos++;
										} else {
											result1 = null;
											if (reportFailures === 0) {
												matchFailed("\"+\"");
											}
										}
										if (result1 === null) {
											if (input.charCodeAt(pos) === 96) {
												result1 = "`";
												pos++;
											} else {
												result1 = null;
												if (reportFailures === 0) {
													matchFailed("\"`\"");
												}
											}
											if (result1 === null) {
												if (input.charCodeAt(pos) === 39) {
													result1 = "'";
													pos++;
												} else {
													result1 = null;
													if (reportFailures === 0) {
														matchFailed("\"'\"");
													}
												}
												if (result1 === null) {
													if (input.charCodeAt(pos) === 126) {
														result1 = "~";
														pos++;
													} else {
														result1 = null;
														if (reportFailures === 0) {
															matchFailed("\"~\"");
														}
													}
												}
											}
										}
									}
								}
							}
						}
					}
				}
				if (result1 !== null) {
					result0 = [];
					while (result1 !== null) {
						result0.push(result1);
						result1 = parse_alphanum();
						if (result1 === null) {
							if (input.charCodeAt(pos) === 45) {
								result1 = "-";
								pos++;
							} else {
								result1 = null;
								if (reportFailures === 0) {
									matchFailed("\"-\"");
								}
							}
							if (result1 === null) {
								if (input.charCodeAt(pos) === 33) {
									result1 = "!";
									pos++;
								} else {
									result1 = null;
									if (reportFailures === 0) {
										matchFailed("\"!\"");
									}
								}
								if (result1 === null) {
									if (input.charCodeAt(pos) === 37) {
										result1 = "%";
										pos++;
									} else {
										result1 = null;
										if (reportFailures === 0) {
											matchFailed("\"%\"");
										}
									}
									if (result1 === null) {
										if (input.charCodeAt(pos) === 42) {
											result1 = "*";
											pos++;
										} else {
											result1 = null;
											if (reportFailures === 0) {
												matchFailed("\"*\"");
											}
										}
										if (result1 === null) {
											if (input.charCodeAt(pos) === 95) {
												result1 = "_";
												pos++;
											} else {
												result1 = null;
												if (reportFailures === 0) {
													matchFailed("\"_\"");
												}
											}
											if (result1 === null) {
												if (input.charCodeAt(pos) === 43) {
													result1 = "+";
													pos++;
												} else {
													result1 = null;
													if (reportFailures === 0) {
														matchFailed("\"+\"");
													}
												}
												if (result1 === null) {
													if (input.charCodeAt(pos) === 96) {
														result1 = "`";
														pos++;
													} else {
														result1 = null;
														if (reportFailures === 0) {
															matchFailed("\"`\"");
														}
													}
													if (result1 === null) {
														if (input.charCodeAt(pos) === 39) {
															result1 = "'";
															pos++;
														} else {
															result1 = null;
															if (reportFailures === 0) {
																matchFailed("\"'\"");
															}
														}
														if (result1 === null) {
															if (input.charCodeAt(pos) === 126) {
																result1 = "~";
																pos++;
															} else {
																result1 = null;
																if (reportFailures === 0) {
																	matchFailed("\"~\"");
																}
															}
														}
													}
												}
											}
										}
									}
								}
							}
						}
					}
				} else {
					result0 = null;
				}
				if (result0 !== null) {
					result0 = (function (offset) {
						return input.substring(pos, offset);
					})(pos0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_separators() {
				var result0;

				if (input.charCodeAt(pos) === 40) {
					result0 = "(";
					pos++;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"(\"");
					}
				}
				if (result0 === null) {
					if (input.charCodeAt(pos) === 41) {
						result0 = ")";
						pos++;
					} else {
						result0 = null;
						if (reportFailures === 0) {
							matchFailed("\")\"");
						}
					}
					if (result0 === null) {
						if (input.charCodeAt(pos) === 60) {
							result0 = "<";
							pos++;
						} else {
							result0 = null;
							if (reportFailures === 0) {
								matchFailed("\"<\"");
							}
						}
						if (result0 === null) {
							if (input.charCodeAt(pos) === 62) {
								result0 = ">";
								pos++;
							} else {
								result0 = null;
								if (reportFailures === 0) {
									matchFailed("\">\"");
								}
							}
							if (result0 === null) {
								if (input.charCodeAt(pos) === 64) {
									result0 = "@";
									pos++;
								} else {
									result0 = null;
									if (reportFailures === 0) {
										matchFailed("\"@\"");
									}
								}
								if (result0 === null) {
									if (input.charCodeAt(pos) === 44) {
										result0 = ",";
										pos++;
									} else {
										result0 = null;
										if (reportFailures === 0) {
											matchFailed("\",\"");
										}
									}
									if (result0 === null) {
										if (input.charCodeAt(pos) === 59) {
											result0 = ";";
											pos++;
										} else {
											result0 = null;
											if (reportFailures === 0) {
												matchFailed("\";\"");
											}
										}
										if (result0 === null) {
											if (input.charCodeAt(pos) === 58) {
												result0 = ":";
												pos++;
											} else {
												result0 = null;
												if (reportFailures === 0) {
													matchFailed("\":\"");
												}
											}
											if (result0 === null) {
												if (input.charCodeAt(pos) === 92) {
													result0 = "\\";
													pos++;
												} else {
													result0 = null;
													if (reportFailures === 0) {
														matchFailed("\"\\\\\"");
													}
												}
												if (result0 === null) {
													result0 = parse_DQUOTE();
													if (result0 === null) {
														if (input.charCodeAt(pos) === 47) {
															result0 = "/";
															pos++;
														} else {
															result0 = null;
															if (reportFailures === 0) {
																matchFailed("\"/\"");
															}
														}
														if (result0 === null) {
															if (input.charCodeAt(pos) === 91) {
																result0 = "[";
																pos++;
															} else {
																result0 = null;
																if (reportFailures === 0) {
																	matchFailed("\"[\"");
																}
															}
															if (result0 === null) {
																if (input.charCodeAt(pos) === 93) {
																	result0 = "]";
																	pos++;
																} else {
																	result0 = null;
																	if (reportFailures === 0) {
																		matchFailed("\"]\"");
																	}
																}
																if (result0 === null) {
																	if (input.charCodeAt(pos) === 63) {
																		result0 = "?";
																		pos++;
																	} else {
																		result0 = null;
																		if (reportFailures === 0) {
																			matchFailed("\"?\"");
																		}
																	}
																	if (result0 === null) {
																		if (input.charCodeAt(pos) === 61) {
																			result0 = "=";
																			pos++;
																		} else {
																			result0 = null;
																			if (reportFailures === 0) {
																				matchFailed("\"=\"");
																			}
																		}
																		if (result0 === null) {
																			if (input.charCodeAt(pos) === 123) {
																				result0 = "{";
																				pos++;
																			} else {
																				result0 = null;
																				if (reportFailures === 0) {
																					matchFailed("\"{\"");
																				}
																			}
																			if (result0 === null) {
																				if (input.charCodeAt(pos) === 125) {
																					result0 = "}";
																					pos++;
																				} else {
																					result0 = null;
																					if (reportFailures === 0) {
																						matchFailed("\"}\"");
																					}
																				}
																				if (result0 === null) {
																					result0 = parse_SP();
																					if (result0 === null) {
																						result0 = parse_HTAB();
																					}
																				}
																			}
																		}
																	}
																}
															}
														}
													}
												}
											}
										}
									}
								}
							}
						}
					}
				}
				return result0;
			}

			function parse_word() {
				var result0, result1;
				var pos0;

				pos0 = pos;
				result1 = parse_alphanum();
				if (result1 === null) {
					if (input.charCodeAt(pos) === 45) {
						result1 = "-";
						pos++;
					} else {
						result1 = null;
						if (reportFailures === 0) {
							matchFailed("\"-\"");
						}
					}
					if (result1 === null) {
						if (input.charCodeAt(pos) === 46) {
							result1 = ".";
							pos++;
						} else {
							result1 = null;
							if (reportFailures === 0) {
								matchFailed("\".\"");
							}
						}
						if (result1 === null) {
							if (input.charCodeAt(pos) === 33) {
								result1 = "!";
								pos++;
							} else {
								result1 = null;
								if (reportFailures === 0) {
									matchFailed("\"!\"");
								}
							}
							if (result1 === null) {
								if (input.charCodeAt(pos) === 37) {
									result1 = "%";
									pos++;
								} else {
									result1 = null;
									if (reportFailures === 0) {
										matchFailed("\"%\"");
									}
								}
								if (result1 === null) {
									if (input.charCodeAt(pos) === 42) {
										result1 = "*";
										pos++;
									} else {
										result1 = null;
										if (reportFailures === 0) {
											matchFailed("\"*\"");
										}
									}
									if (result1 === null) {
										if (input.charCodeAt(pos) === 95) {
											result1 = "_";
											pos++;
										} else {
											result1 = null;
											if (reportFailures === 0) {
												matchFailed("\"_\"");
											}
										}
										if (result1 === null) {
											if (input.charCodeAt(pos) === 43) {
												result1 = "+";
												pos++;
											} else {
												result1 = null;
												if (reportFailures === 0) {
													matchFailed("\"+\"");
												}
											}
											if (result1 === null) {
												if (input.charCodeAt(pos) === 96) {
													result1 = "`";
													pos++;
												} else {
													result1 = null;
													if (reportFailures === 0) {
														matchFailed("\"`\"");
													}
												}
												if (result1 === null) {
													if (input.charCodeAt(pos) === 39) {
														result1 = "'";
														pos++;
													} else {
														result1 = null;
														if (reportFailures === 0) {
															matchFailed("\"'\"");
														}
													}
													if (result1 === null) {
														if (input.charCodeAt(pos) === 126) {
															result1 = "~";
															pos++;
														} else {
															result1 = null;
															if (reportFailures === 0) {
																matchFailed("\"~\"");
															}
														}
														if (result1 === null) {
															if (input.charCodeAt(pos) === 40) {
																result1 = "(";
																pos++;
															} else {
																result1 = null;
																if (reportFailures === 0) {
																	matchFailed("\"(\"");
																}
															}
															if (result1 === null) {
																if (input.charCodeAt(pos) === 41) {
																	result1 = ")";
																	pos++;
																} else {
																	result1 = null;
																	if (reportFailures === 0) {
																		matchFailed("\")\"");
																	}
																}
																if (result1 === null) {
																	if (input.charCodeAt(pos) === 60) {
																		result1 = "<";
																		pos++;
																	} else {
																		result1 = null;
																		if (reportFailures === 0) {
																			matchFailed("\"<\"");
																		}
																	}
																	if (result1 === null) {
																		if (input.charCodeAt(pos) === 62) {
																			result1 = ">";
																			pos++;
																		} else {
																			result1 = null;
																			if (reportFailures === 0) {
																				matchFailed("\">\"");
																			}
																		}
																		if (result1 === null) {
																			if (input.charCodeAt(pos) === 58) {
																				result1 = ":";
																				pos++;
																			} else {
																				result1 = null;
																				if (reportFailures === 0) {
																					matchFailed("\":\"");
																				}
																			}
																			if (result1 === null) {
																				if (input.charCodeAt(pos) === 92) {
																					result1 = "\\";
																					pos++;
																				} else {
																					result1 = null;
																					if (reportFailures === 0) {
																						matchFailed("\"\\\\\"");
																					}
																				}
																				if (result1 === null) {
																					result1 = parse_DQUOTE();
																					if (result1 === null) {
																						if (input.charCodeAt(pos) === 47) {
																							result1 = "/";
																							pos++;
																						} else {
																							result1 = null;
																							if (reportFailures === 0) {
																								matchFailed("\"/\"");
																							}
																						}
																						if (result1 === null) {
																							if (input.charCodeAt(pos) === 91) {
																								result1 = "[";
																								pos++;
																							} else {
																								result1 = null;
																								if (reportFailures === 0) {
																									matchFailed("\"[\"");
																								}
																							}
																							if (result1 === null) {
																								if (input.charCodeAt(pos) === 93) {
																									result1 = "]";
																									pos++;
																								} else {
																									result1 = null;
																									if (reportFailures === 0) {
																										matchFailed("\"]\"");
																									}
																								}
																								if (result1 === null) {
																									if (input.charCodeAt(pos) === 63) {
																										result1 = "?";
																										pos++;
																									} else {
																										result1 = null;
																										if (reportFailures === 0) {
																											matchFailed("\"?\"");
																										}
																									}
																									if (result1 === null) {
																										if (input.charCodeAt(pos) === 123) {
																											result1 = "{";
																											pos++;
																										} else {
																											result1 = null;
																											if (reportFailures === 0) {
																												matchFailed("\"{\"");
																											}
																										}
																										if (result1 === null) {
																											if (input.charCodeAt(pos) === 125) {
																												result1 = "}";
																												pos++;
																											} else {
																												result1 = null;
																												if (reportFailures === 0) {
																													matchFailed("\"}\"");
																												}
																											}
																										}
																									}
																								}
																							}
																						}
																					}
																				}
																			}
																		}
																	}
																}
															}
														}
													}
												}
											}
										}
									}
								}
							}
						}
					}
				}
				if (result1 !== null) {
					result0 = [];
					while (result1 !== null) {
						result0.push(result1);
						result1 = parse_alphanum();
						if (result1 === null) {
							if (input.charCodeAt(pos) === 45) {
								result1 = "-";
								pos++;
							} else {
								result1 = null;
								if (reportFailures === 0) {
									matchFailed("\"-\"");
								}
							}
							if (result1 === null) {
								if (input.charCodeAt(pos) === 46) {
									result1 = ".";
									pos++;
								} else {
									result1 = null;
									if (reportFailures === 0) {
										matchFailed("\".\"");
									}
								}
								if (result1 === null) {
									if (input.charCodeAt(pos) === 33) {
										result1 = "!";
										pos++;
									} else {
										result1 = null;
										if (reportFailures === 0) {
											matchFailed("\"!\"");
										}
									}
									if (result1 === null) {
										if (input.charCodeAt(pos) === 37) {
											result1 = "%";
											pos++;
										} else {
											result1 = null;
											if (reportFailures === 0) {
												matchFailed("\"%\"");
											}
										}
										if (result1 === null) {
											if (input.charCodeAt(pos) === 42) {
												result1 = "*";
												pos++;
											} else {
												result1 = null;
												if (reportFailures === 0) {
													matchFailed("\"*\"");
												}
											}
											if (result1 === null) {
												if (input.charCodeAt(pos) === 95) {
													result1 = "_";
													pos++;
												} else {
													result1 = null;
													if (reportFailures === 0) {
														matchFailed("\"_\"");
													}
												}
												if (result1 === null) {
													if (input.charCodeAt(pos) === 43) {
														result1 = "+";
														pos++;
													} else {
														result1 = null;
														if (reportFailures === 0) {
															matchFailed("\"+\"");
														}
													}
													if (result1 === null) {
														if (input.charCodeAt(pos) === 96) {
															result1 = "`";
															pos++;
														} else {
															result1 = null;
															if (reportFailures === 0) {
																matchFailed("\"`\"");
															}
														}
														if (result1 === null) {
															if (input.charCodeAt(pos) === 39) {
																result1 = "'";
																pos++;
															} else {
																result1 = null;
																if (reportFailures === 0) {
																	matchFailed("\"'\"");
																}
															}
															if (result1 === null) {
																if (input.charCodeAt(pos) === 126) {
																	result1 = "~";
																	pos++;
																} else {
																	result1 = null;
																	if (reportFailures === 0) {
																		matchFailed("\"~\"");
																	}
																}
																if (result1 === null) {
																	if (input.charCodeAt(pos) === 40) {
																		result1 = "(";
																		pos++;
																	} else {
																		result1 = null;
																		if (reportFailures === 0) {
																			matchFailed("\"(\"");
																		}
																	}
																	if (result1 === null) {
																		if (input.charCodeAt(pos) === 41) {
																			result1 = ")";
																			pos++;
																		} else {
																			result1 = null;
																			if (reportFailures === 0) {
																				matchFailed("\")\"");
																			}
																		}
																		if (result1 === null) {
																			if (input.charCodeAt(pos) === 60) {
																				result1 = "<";
																				pos++;
																			} else {
																				result1 = null;
																				if (reportFailures === 0) {
																					matchFailed("\"<\"");
																				}
																			}
																			if (result1 === null) {
																				if (input.charCodeAt(pos) === 62) {
																					result1 = ">";
																					pos++;
																				} else {
																					result1 = null;
																					if (reportFailures === 0) {
																						matchFailed("\">\"");
																					}
																				}
																				if (result1 === null) {
																					if (input.charCodeAt(pos) === 58) {
																						result1 = ":";
																						pos++;
																					} else {
																						result1 = null;
																						if (reportFailures === 0) {
																							matchFailed("\":\"");
																						}
																					}
																					if (result1 === null) {
																						if (input.charCodeAt(pos) === 92) {
																							result1 = "\\";
																							pos++;
																						} else {
																							result1 = null;
																							if (reportFailures === 0) {
																								matchFailed("\"\\\\\"");
																							}
																						}
																						if (result1 === null) {
																							result1 = parse_DQUOTE();
																							if (result1 === null) {
																								if (input.charCodeAt(pos) === 47) {
																									result1 = "/";
																									pos++;
																								} else {
																									result1 = null;
																									if (reportFailures === 0) {
																										matchFailed("\"/\"");
																									}
																								}
																								if (result1 === null) {
																									if (input.charCodeAt(pos) === 91) {
																										result1 = "[";
																										pos++;
																									} else {
																										result1 = null;
																										if (reportFailures === 0) {
																											matchFailed("\"[\"");
																										}
																									}
																									if (result1 === null) {
																										if (input.charCodeAt(pos) === 93) {
																											result1 = "]";
																											pos++;
																										} else {
																											result1 = null;
																											if (reportFailures === 0) {
																												matchFailed("\"]\"");
																											}
																										}
																										if (result1 === null) {
																											if (input.charCodeAt(pos) === 63) {
																												result1 = "?";
																												pos++;
																											} else {
																												result1 = null;
																												if (reportFailures === 0) {
																													matchFailed("\"?\"");
																												}
																											}
																											if (result1 === null) {
																												if (input.charCodeAt(pos) === 123) {
																													result1 = "{";
																													pos++;
																												} else {
																													result1 = null;
																													if (reportFailures === 0) {
																														matchFailed("\"{\"");
																													}
																												}
																												if (result1 === null) {
																													if (input.charCodeAt(pos) === 125) {
																														result1 = "}";
																														pos++;
																													} else {
																														result1 = null;
																														if (reportFailures === 0) {
																															matchFailed("\"}\"");
																														}
																													}
																												}
																											}
																										}
																									}
																								}
																							}
																						}
																					}
																				}
																			}
																		}
																	}
																}
															}
														}
													}
												}
											}
										}
									}
								}
							}
						}
					}
				} else {
					result0 = null;
				}
				if (result0 !== null) {
					result0 = (function (offset) {
						return input.substring(pos, offset);
					})(pos0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_STAR() {
				var result0, result1, result2;
				var pos0, pos1;

				pos0 = pos;
				pos1 = pos;
				result0 = parse_SWS();
				if (result0 !== null) {
					if (input.charCodeAt(pos) === 42) {
						result1 = "*";
						pos++;
					} else {
						result1 = null;
						if (reportFailures === 0) {
							matchFailed("\"*\"");
						}
					}
					if (result1 !== null) {
						result2 = parse_SWS();
						if (result2 !== null) {
							result0 = [result0, result1, result2];
						} else {
							result0 = null;
							pos = pos1;
						}
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset) {
						return "*";
					})(pos0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_SLASH() {
				var result0, result1, result2;
				var pos0, pos1;

				pos0 = pos;
				pos1 = pos;
				result0 = parse_SWS();
				if (result0 !== null) {
					if (input.charCodeAt(pos) === 47) {
						result1 = "/";
						pos++;
					} else {
						result1 = null;
						if (reportFailures === 0) {
							matchFailed("\"/\"");
						}
					}
					if (result1 !== null) {
						result2 = parse_SWS();
						if (result2 !== null) {
							result0 = [result0, result1, result2];
						} else {
							result0 = null;
							pos = pos1;
						}
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset) {
						return "/";
					})(pos0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_EQUAL() {
				var result0, result1, result2;
				var pos0, pos1;

				pos0 = pos;
				pos1 = pos;
				result0 = parse_SWS();
				if (result0 !== null) {
					if (input.charCodeAt(pos) === 61) {
						result1 = "=";
						pos++;
					} else {
						result1 = null;
						if (reportFailures === 0) {
							matchFailed("\"=\"");
						}
					}
					if (result1 !== null) {
						result2 = parse_SWS();
						if (result2 !== null) {
							result0 = [result0, result1, result2];
						} else {
							result0 = null;
							pos = pos1;
						}
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset) {
						return "=";
					})(pos0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_LPAREN() {
				var result0, result1, result2;
				var pos0, pos1;

				pos0 = pos;
				pos1 = pos;
				result0 = parse_SWS();
				if (result0 !== null) {
					if (input.charCodeAt(pos) === 40) {
						result1 = "(";
						pos++;
					} else {
						result1 = null;
						if (reportFailures === 0) {
							matchFailed("\"(\"");
						}
					}
					if (result1 !== null) {
						result2 = parse_SWS();
						if (result2 !== null) {
							result0 = [result0, result1, result2];
						} else {
							result0 = null;
							pos = pos1;
						}
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset) {
						return "(";
					})(pos0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_RPAREN() {
				var result0, result1, result2;
				var pos0, pos1;

				pos0 = pos;
				pos1 = pos;
				result0 = parse_SWS();
				if (result0 !== null) {
					if (input.charCodeAt(pos) === 41) {
						result1 = ")";
						pos++;
					} else {
						result1 = null;
						if (reportFailures === 0) {
							matchFailed("\")\"");
						}
					}
					if (result1 !== null) {
						result2 = parse_SWS();
						if (result2 !== null) {
							result0 = [result0, result1, result2];
						} else {
							result0 = null;
							pos = pos1;
						}
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset) {
						return ")";
					})(pos0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_RAQUOT() {
				var result0, result1;
				var pos0, pos1;

				pos0 = pos;
				pos1 = pos;
				if (input.charCodeAt(pos) === 62) {
					result0 = ">";
					pos++;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\">\"");
					}
				}
				if (result0 !== null) {
					result1 = parse_SWS();
					if (result1 !== null) {
						result0 = [result0, result1];
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset) {
						return ">";
					})(pos0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_LAQUOT() {
				var result0, result1;
				var pos0, pos1;

				pos0 = pos;
				pos1 = pos;
				result0 = parse_SWS();
				if (result0 !== null) {
					if (input.charCodeAt(pos) === 60) {
						result1 = "<";
						pos++;
					} else {
						result1 = null;
						if (reportFailures === 0) {
							matchFailed("\"<\"");
						}
					}
					if (result1 !== null) {
						result0 = [result0, result1];
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset) {
						return "<";
					})(pos0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_COMMA() {
				var result0, result1, result2;
				var pos0, pos1;

				pos0 = pos;
				pos1 = pos;
				result0 = parse_SWS();
				if (result0 !== null) {
					if (input.charCodeAt(pos) === 44) {
						result1 = ",";
						pos++;
					} else {
						result1 = null;
						if (reportFailures === 0) {
							matchFailed("\",\"");
						}
					}
					if (result1 !== null) {
						result2 = parse_SWS();
						if (result2 !== null) {
							result0 = [result0, result1, result2];
						} else {
							result0 = null;
							pos = pos1;
						}
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset) {
						return ",";
					})(pos0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_SEMI() {
				var result0, result1, result2;
				var pos0, pos1;

				pos0 = pos;
				pos1 = pos;
				result0 = parse_SWS();
				if (result0 !== null) {
					if (input.charCodeAt(pos) === 59) {
						result1 = ";";
						pos++;
					} else {
						result1 = null;
						if (reportFailures === 0) {
							matchFailed("\";\"");
						}
					}
					if (result1 !== null) {
						result2 = parse_SWS();
						if (result2 !== null) {
							result0 = [result0, result1, result2];
						} else {
							result0 = null;
							pos = pos1;
						}
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset) {
						return ";";
					})(pos0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_COLON() {
				var result0, result1, result2;
				var pos0, pos1;

				pos0 = pos;
				pos1 = pos;
				result0 = parse_SWS();
				if (result0 !== null) {
					if (input.charCodeAt(pos) === 58) {
						result1 = ":";
						pos++;
					} else {
						result1 = null;
						if (reportFailures === 0) {
							matchFailed("\":\"");
						}
					}
					if (result1 !== null) {
						result2 = parse_SWS();
						if (result2 !== null) {
							result0 = [result0, result1, result2];
						} else {
							result0 = null;
							pos = pos1;
						}
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset) {
						return ":";
					})(pos0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_LDQUOT() {
				var result0, result1;
				var pos0, pos1;

				pos0 = pos;
				pos1 = pos;
				result0 = parse_SWS();
				if (result0 !== null) {
					result1 = parse_DQUOTE();
					if (result1 !== null) {
						result0 = [result0, result1];
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset) {
						return "\"";
					})(pos0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_RDQUOT() {
				var result0, result1;
				var pos0, pos1;

				pos0 = pos;
				pos1 = pos;
				result0 = parse_DQUOTE();
				if (result0 !== null) {
					result1 = parse_SWS();
					if (result1 !== null) {
						result0 = [result0, result1];
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset) {
						return "\"";
					})(pos0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_comment() {
				var result0, result1, result2;
				var pos0;

				pos0 = pos;
				result0 = parse_LPAREN();
				if (result0 !== null) {
					result1 = [];
					result2 = parse_ctext();
					if (result2 === null) {
						result2 = parse_quoted_pair();
						if (result2 === null) {
							result2 = parse_comment();
						}
					}
					while (result2 !== null) {
						result1.push(result2);
						result2 = parse_ctext();
						if (result2 === null) {
							result2 = parse_quoted_pair();
							if (result2 === null) {
								result2 = parse_comment();
							}
						}
					}
					if (result1 !== null) {
						result2 = parse_RPAREN();
						if (result2 !== null) {
							result0 = [result0, result1, result2];
						} else {
							result0 = null;
							pos = pos0;
						}
					} else {
						result0 = null;
						pos = pos0;
					}
				} else {
					result0 = null;
					pos = pos0;
				}
				return result0;
			}

			function parse_ctext() {
				var result0;

				if (/^[!-']/.test(input.charAt(pos))) {
					result0 = input.charAt(pos);
					pos++;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("[!-']");
					}
				}
				if (result0 === null) {
					if (/^[*-[]/.test(input.charAt(pos))) {
						result0 = input.charAt(pos);
						pos++;
					} else {
						result0 = null;
						if (reportFailures === 0) {
							matchFailed("[*-[]");
						}
					}
					if (result0 === null) {
						if (/^[\]-~]/.test(input.charAt(pos))) {
							result0 = input.charAt(pos);
							pos++;
						} else {
							result0 = null;
							if (reportFailures === 0) {
								matchFailed("[\\]-~]");
							}
						}
						if (result0 === null) {
							result0 = parse_UTF8_NONASCII();
							if (result0 === null) {
								result0 = parse_LWS();
							}
						}
					}
				}
				return result0;
			}

			function parse_quoted_string() {
				var result0, result1, result2, result3;
				var pos0, pos1;

				pos0 = pos;
				pos1 = pos;
				result0 = parse_SWS();
				if (result0 !== null) {
					result1 = parse_DQUOTE();
					if (result1 !== null) {
						result2 = [];
						result3 = parse_qdtext();
						if (result3 === null) {
							result3 = parse_quoted_pair();
						}
						while (result3 !== null) {
							result2.push(result3);
							result3 = parse_qdtext();
							if (result3 === null) {
								result3 = parse_quoted_pair();
							}
						}
						if (result2 !== null) {
							result3 = parse_DQUOTE();
							if (result3 !== null) {
								result0 = [result0, result1, result2, result3];
							} else {
								result0 = null;
								pos = pos1;
							}
						} else {
							result0 = null;
							pos = pos1;
						}
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset) {
						return input.substring(pos, offset);
					})(pos0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_quoted_string_clean() {
				var result0, result1, result2, result3;
				var pos0, pos1;

				pos0 = pos;
				pos1 = pos;
				result0 = parse_SWS();
				if (result0 !== null) {
					result1 = parse_DQUOTE();
					if (result1 !== null) {
						result2 = [];
						result3 = parse_qdtext();
						if (result3 === null) {
							result3 = parse_quoted_pair();
						}
						while (result3 !== null) {
							result2.push(result3);
							result3 = parse_qdtext();
							if (result3 === null) {
								result3 = parse_quoted_pair();
							}
						}
						if (result2 !== null) {
							result3 = parse_DQUOTE();
							if (result3 !== null) {
								result0 = [result0, result1, result2, result3];
							} else {
								result0 = null;
								pos = pos1;
							}
						} else {
							result0 = null;
							pos = pos1;
						}
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset) {
						return input.substring(pos - 1, offset + 1);
					})(pos0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_qdtext() {
				var result0;

				result0 = parse_LWS();
				if (result0 === null) {
					if (input.charCodeAt(pos) === 33) {
						result0 = "!";
						pos++;
					} else {
						result0 = null;
						if (reportFailures === 0) {
							matchFailed("\"!\"");
						}
					}
					if (result0 === null) {
						if (/^[#-[]/.test(input.charAt(pos))) {
							result0 = input.charAt(pos);
							pos++;
						} else {
							result0 = null;
							if (reportFailures === 0) {
								matchFailed("[#-[]");
							}
						}
						if (result0 === null) {
							if (/^[\]-~]/.test(input.charAt(pos))) {
								result0 = input.charAt(pos);
								pos++;
							} else {
								result0 = null;
								if (reportFailures === 0) {
									matchFailed("[\\]-~]");
								}
							}
							if (result0 === null) {
								result0 = parse_UTF8_NONASCII();
							}
						}
					}
				}
				return result0;
			}

			function parse_quoted_pair() {
				var result0, result1;
				var pos0;

				pos0 = pos;
				if (input.charCodeAt(pos) === 92) {
					result0 = "\\";
					pos++;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"\\\\\"");
					}
				}
				if (result0 !== null) {
					if (/^[\0-\t]/.test(input.charAt(pos))) {
						result1 = input.charAt(pos);
						pos++;
					} else {
						result1 = null;
						if (reportFailures === 0) {
							matchFailed("[\\0-\\t]");
						}
					}
					if (result1 === null) {
						if (/^[\x0B-\f]/.test(input.charAt(pos))) {
							result1 = input.charAt(pos);
							pos++;
						} else {
							result1 = null;
							if (reportFailures === 0) {
								matchFailed("[\\x0B-\\f]");
							}
						}
						if (result1 === null) {
							if (/^[\x0E-]/.test(input.charAt(pos))) {
								result1 = input.charAt(pos);
								pos++;
							} else {
								result1 = null;
								if (reportFailures === 0) {
									matchFailed("[\\x0E-]");
								}
							}
						}
					}
					if (result1 !== null) {
						result0 = [result0, result1];
					} else {
						result0 = null;
						pos = pos0;
					}
				} else {
					result0 = null;
					pos = pos0;
				}
				return result0;
			}

			function parse_SIP_URI_noparams() {
				var result0, result1, result2, result3;
				var pos0, pos1;

				pos0 = pos;
				pos1 = pos;
				result0 = parse_uri_scheme();
				if (result0 !== null) {
					if (input.charCodeAt(pos) === 58) {
						result1 = ":";
						pos++;
					} else {
						result1 = null;
						if (reportFailures === 0) {
							matchFailed("\":\"");
						}
					}
					if (result1 !== null) {
						result2 = parse_userinfo();
						result2 = result2 !== null ? result2 : "";
						if (result2 !== null) {
							result3 = parse_hostport();
							if (result3 !== null) {
								result0 = [result0, result1, result2, result3];
							} else {
								result0 = null;
								pos = pos1;
							}
						} else {
							result0 = null;
							pos = pos1;
						}
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset) {
						try {
							data.uri = new JsSIP.URI(data.scheme, data.user, data.host, data.port);
							delete data.scheme;
							delete data.user;
							delete data.host;
							delete data.host_type;
							delete data.port;
						} catch (e) {
							data = -1;
						}
					})(pos0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_SIP_URI() {
				var result0, result1, result2, result3, result4, result5;
				var pos0, pos1;

				pos0 = pos;
				pos1 = pos;
				result0 = parse_uri_scheme();
				if (result0 !== null) {
					if (input.charCodeAt(pos) === 58) {
						result1 = ":";
						pos++;
					} else {
						result1 = null;
						if (reportFailures === 0) {
							matchFailed("\":\"");
						}
					}
					if (result1 !== null) {
						result2 = parse_userinfo();
						result2 = result2 !== null ? result2 : "";
						if (result2 !== null) {
							result3 = parse_hostport();
							if (result3 !== null) {
								result4 = parse_uri_parameters();
								if (result4 !== null) {
									result5 = parse_headers();
									result5 = result5 !== null ? result5 : "";
									if (result5 !== null) {
										result0 = [result0, result1, result2, result3, result4, result5];
									} else {
										result0 = null;
										pos = pos1;
									}
								} else {
									result0 = null;
									pos = pos1;
								}
							} else {
								result0 = null;
								pos = pos1;
							}
						} else {
							result0 = null;
							pos = pos1;
						}
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset) {
						var header;
						try {
							data.uri = new JsSIP.URI(data.scheme, data.user, data.host, data.port, data.uri_params, data.uri_headers);
							delete data.scheme;
							delete data.user;
							delete data.host;
							delete data.host_type;
							delete data.port;
							delete data.uri_params;

							if (startRule === 'SIP_URI') {
								data = data.uri;
							}
						} catch (e) {
							data = -1;
						}
					})(pos0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_uri_scheme() {
				var result0;
				var pos0;

				pos0 = pos;
				if (input.substr(pos, 3).toLowerCase() === "sip") {
					result0 = input.substr(pos, 3);
					pos += 3;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"sip\"");
					}
				}
				if (result0 !== null) {
					result0 = (function (offset, uri_scheme) {
						data.scheme = uri_scheme.toLowerCase();
					})(pos0, result0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_userinfo() {
				var result0, result1, result2;
				var pos0, pos1, pos2;

				pos0 = pos;
				pos1 = pos;
				result0 = parse_user();
				if (result0 !== null) {
					pos2 = pos;
					if (input.charCodeAt(pos) === 58) {
						result1 = ":";
						pos++;
					} else {
						result1 = null;
						if (reportFailures === 0) {
							matchFailed("\":\"");
						}
					}
					if (result1 !== null) {
						result2 = parse_password();
						if (result2 !== null) {
							result1 = [result1, result2];
						} else {
							result1 = null;
							pos = pos2;
						}
					} else {
						result1 = null;
						pos = pos2;
					}
					result1 = result1 !== null ? result1 : "";
					if (result1 !== null) {
						if (input.charCodeAt(pos) === 64) {
							result2 = "@";
							pos++;
						} else {
							result2 = null;
							if (reportFailures === 0) {
								matchFailed("\"@\"");
							}
						}
						if (result2 !== null) {
							result0 = [result0, result1, result2];
						} else {
							result0 = null;
							pos = pos1;
						}
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset) {
						data.user = window.decodeURIComponent(input.substring(pos - 1, offset));
					})(pos0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_user() {
				var result0, result1;

				result1 = parse_unreserved();
				if (result1 === null) {
					result1 = parse_escaped();
					if (result1 === null) {
						result1 = parse_user_unreserved();
					}
				}
				if (result1 !== null) {
					result0 = [];
					while (result1 !== null) {
						result0.push(result1);
						result1 = parse_unreserved();
						if (result1 === null) {
							result1 = parse_escaped();
							if (result1 === null) {
								result1 = parse_user_unreserved();
							}
						}
					}
				} else {
					result0 = null;
				}
				return result0;
			}

			function parse_user_unreserved() {
				var result0;

				if (input.charCodeAt(pos) === 38) {
					result0 = "&";
					pos++;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"&\"");
					}
				}
				if (result0 === null) {
					if (input.charCodeAt(pos) === 61) {
						result0 = "=";
						pos++;
					} else {
						result0 = null;
						if (reportFailures === 0) {
							matchFailed("\"=\"");
						}
					}
					if (result0 === null) {
						if (input.charCodeAt(pos) === 43) {
							result0 = "+";
							pos++;
						} else {
							result0 = null;
							if (reportFailures === 0) {
								matchFailed("\"+\"");
							}
						}
						if (result0 === null) {
							if (input.charCodeAt(pos) === 36) {
								result0 = "$";
								pos++;
							} else {
								result0 = null;
								if (reportFailures === 0) {
									matchFailed("\"$\"");
								}
							}
							if (result0 === null) {
								if (input.charCodeAt(pos) === 44) {
									result0 = ",";
									pos++;
								} else {
									result0 = null;
									if (reportFailures === 0) {
										matchFailed("\",\"");
									}
								}
								if (result0 === null) {
									if (input.charCodeAt(pos) === 59) {
										result0 = ";";
										pos++;
									} else {
										result0 = null;
										if (reportFailures === 0) {
											matchFailed("\";\"");
										}
									}
									if (result0 === null) {
										if (input.charCodeAt(pos) === 63) {
											result0 = "?";
											pos++;
										} else {
											result0 = null;
											if (reportFailures === 0) {
												matchFailed("\"?\"");
											}
										}
										if (result0 === null) {
											if (input.charCodeAt(pos) === 47) {
												result0 = "/";
												pos++;
											} else {
												result0 = null;
												if (reportFailures === 0) {
													matchFailed("\"/\"");
												}
											}
										}
									}
								}
							}
						}
					}
				}
				return result0;
			}

			function parse_password() {
				var result0, result1;
				var pos0;

				pos0 = pos;
				result0 = [];
				result1 = parse_unreserved();
				if (result1 === null) {
					result1 = parse_escaped();
					if (result1 === null) {
						if (input.charCodeAt(pos) === 38) {
							result1 = "&";
							pos++;
						} else {
							result1 = null;
							if (reportFailures === 0) {
								matchFailed("\"&\"");
							}
						}
						if (result1 === null) {
							if (input.charCodeAt(pos) === 61) {
								result1 = "=";
								pos++;
							} else {
								result1 = null;
								if (reportFailures === 0) {
									matchFailed("\"=\"");
								}
							}
							if (result1 === null) {
								if (input.charCodeAt(pos) === 43) {
									result1 = "+";
									pos++;
								} else {
									result1 = null;
									if (reportFailures === 0) {
										matchFailed("\"+\"");
									}
								}
								if (result1 === null) {
									if (input.charCodeAt(pos) === 36) {
										result1 = "$";
										pos++;
									} else {
										result1 = null;
										if (reportFailures === 0) {
											matchFailed("\"$\"");
										}
									}
									if (result1 === null) {
										if (input.charCodeAt(pos) === 44) {
											result1 = ",";
											pos++;
										} else {
											result1 = null;
											if (reportFailures === 0) {
												matchFailed("\",\"");
											}
										}
									}
								}
							}
						}
					}
				}
				while (result1 !== null) {
					result0.push(result1);
					result1 = parse_unreserved();
					if (result1 === null) {
						result1 = parse_escaped();
						if (result1 === null) {
							if (input.charCodeAt(pos) === 38) {
								result1 = "&";
								pos++;
							} else {
								result1 = null;
								if (reportFailures === 0) {
									matchFailed("\"&\"");
								}
							}
							if (result1 === null) {
								if (input.charCodeAt(pos) === 61) {
									result1 = "=";
									pos++;
								} else {
									result1 = null;
									if (reportFailures === 0) {
										matchFailed("\"=\"");
									}
								}
								if (result1 === null) {
									if (input.charCodeAt(pos) === 43) {
										result1 = "+";
										pos++;
									} else {
										result1 = null;
										if (reportFailures === 0) {
											matchFailed("\"+\"");
										}
									}
									if (result1 === null) {
										if (input.charCodeAt(pos) === 36) {
											result1 = "$";
											pos++;
										} else {
											result1 = null;
											if (reportFailures === 0) {
												matchFailed("\"$\"");
											}
										}
										if (result1 === null) {
											if (input.charCodeAt(pos) === 44) {
												result1 = ",";
												pos++;
											} else {
												result1 = null;
												if (reportFailures === 0) {
													matchFailed("\",\"");
												}
											}
										}
									}
								}
							}
						}
					}
				}
				if (result0 !== null) {
					result0 = (function (offset) {
						data.password = input.substring(pos, offset);
					})(pos0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_hostport() {
				var result0, result1, result2;
				var pos0, pos1;

				pos0 = pos;
				result0 = parse_host();
				if (result0 !== null) {
					pos1 = pos;
					if (input.charCodeAt(pos) === 58) {
						result1 = ":";
						pos++;
					} else {
						result1 = null;
						if (reportFailures === 0) {
							matchFailed("\":\"");
						}
					}
					if (result1 !== null) {
						result2 = parse_port();
						if (result2 !== null) {
							result1 = [result1, result2];
						} else {
							result1 = null;
							pos = pos1;
						}
					} else {
						result1 = null;
						pos = pos1;
					}
					result1 = result1 !== null ? result1 : "";
					if (result1 !== null) {
						result0 = [result0, result1];
					} else {
						result0 = null;
						pos = pos0;
					}
				} else {
					result0 = null;
					pos = pos0;
				}
				return result0;
			}

			function parse_host() {
				var result0;
				var pos0;

				pos0 = pos;
				result0 = parse_hostname();
				if (result0 === null) {
					result0 = parse_IPv4address();
					if (result0 === null) {
						result0 = parse_IPv6reference();
					}
				}
				if (result0 !== null) {
					result0 = (function (offset) {
						data.host = input.substring(pos, offset).toLowerCase();
						return data.host;
					})(pos0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_hostname() {
				var result0, result1, result2;
				var pos0, pos1, pos2;

				pos0 = pos;
				pos1 = pos;
				result0 = [];
				pos2 = pos;
				result1 = parse_domainlabel();
				if (result1 !== null) {
					if (input.charCodeAt(pos) === 46) {
						result2 = ".";
						pos++;
					} else {
						result2 = null;
						if (reportFailures === 0) {
							matchFailed("\".\"");
						}
					}
					if (result2 !== null) {
						result1 = [result1, result2];
					} else {
						result1 = null;
						pos = pos2;
					}
				} else {
					result1 = null;
					pos = pos2;
				}
				while (result1 !== null) {
					result0.push(result1);
					pos2 = pos;
					result1 = parse_domainlabel();
					if (result1 !== null) {
						if (input.charCodeAt(pos) === 46) {
							result2 = ".";
							pos++;
						} else {
							result2 = null;
							if (reportFailures === 0) {
								matchFailed("\".\"");
							}
						}
						if (result2 !== null) {
							result1 = [result1, result2];
						} else {
							result1 = null;
							pos = pos2;
						}
					} else {
						result1 = null;
						pos = pos2;
					}
				}
				if (result0 !== null) {
					result1 = parse_toplabel();
					if (result1 !== null) {
						if (input.charCodeAt(pos) === 46) {
							result2 = ".";
							pos++;
						} else {
							result2 = null;
							if (reportFailures === 0) {
								matchFailed("\".\"");
							}
						}
						result2 = result2 !== null ? result2 : "";
						if (result2 !== null) {
							result0 = [result0, result1, result2];
						} else {
							result0 = null;
							pos = pos1;
						}
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset) {
						data.host_type = 'domain';
						return input.substring(pos, offset);
					})(pos0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_domainlabel() {
				var result0, result1;

				if (/^[a-zA-Z0-9_\-]/.test(input.charAt(pos))) {
					result1 = input.charAt(pos);
					pos++;
				} else {
					result1 = null;
					if (reportFailures === 0) {
						matchFailed("[a-zA-Z0-9_\\-]");
					}
				}
				if (result1 !== null) {
					result0 = [];
					while (result1 !== null) {
						result0.push(result1);
						if (/^[a-zA-Z0-9_\-]/.test(input.charAt(pos))) {
							result1 = input.charAt(pos);
							pos++;
						} else {
							result1 = null;
							if (reportFailures === 0) {
								matchFailed("[a-zA-Z0-9_\\-]");
							}
						}
					}
				} else {
					result0 = null;
				}
				return result0;
			}

			function parse_toplabel() {
				var result0, result1;

				if (/^[a-zA-Z_\-]/.test(input.charAt(pos))) {
					result1 = input.charAt(pos);
					pos++;
				} else {
					result1 = null;
					if (reportFailures === 0) {
						matchFailed("[a-zA-Z_\\-]");
					}
				}
				if (result1 !== null) {
					result0 = [];
					while (result1 !== null) {
						result0.push(result1);
						if (/^[a-zA-Z_\-]/.test(input.charAt(pos))) {
							result1 = input.charAt(pos);
							pos++;
						} else {
							result1 = null;
							if (reportFailures === 0) {
								matchFailed("[a-zA-Z_\\-]");
							}
						}
					}
				} else {
					result0 = null;
				}
				return result0;
			}

			function parse_IPv6reference() {
				var result0, result1, result2;
				var pos0, pos1;

				pos0 = pos;
				pos1 = pos;
				if (input.charCodeAt(pos) === 91) {
					result0 = "[";
					pos++;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"[\"");
					}
				}
				if (result0 !== null) {
					result1 = parse_IPv6address();
					if (result1 !== null) {
						if (input.charCodeAt(pos) === 93) {
							result2 = "]";
							pos++;
						} else {
							result2 = null;
							if (reportFailures === 0) {
								matchFailed("\"]\"");
							}
						}
						if (result2 !== null) {
							result0 = [result0, result1, result2];
						} else {
							result0 = null;
							pos = pos1;
						}
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset) {
						data.host_type = 'IPv6';
						return input.substring(pos, offset);
					})(pos0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_IPv6address() {
				var result0, result1, result2, result3, result4, result5, result6, result7, result8, result9, result10, result11, result12;
				var pos0, pos1, pos2;

				pos0 = pos;
				pos1 = pos;
				result0 = parse_h16();
				if (result0 !== null) {
					if (input.charCodeAt(pos) === 58) {
						result1 = ":";
						pos++;
					} else {
						result1 = null;
						if (reportFailures === 0) {
							matchFailed("\":\"");
						}
					}
					if (result1 !== null) {
						result2 = parse_h16();
						if (result2 !== null) {
							if (input.charCodeAt(pos) === 58) {
								result3 = ":";
								pos++;
							} else {
								result3 = null;
								if (reportFailures === 0) {
									matchFailed("\":\"");
								}
							}
							if (result3 !== null) {
								result4 = parse_h16();
								if (result4 !== null) {
									if (input.charCodeAt(pos) === 58) {
										result5 = ":";
										pos++;
									} else {
										result5 = null;
										if (reportFailures === 0) {
											matchFailed("\":\"");
										}
									}
									if (result5 !== null) {
										result6 = parse_h16();
										if (result6 !== null) {
											if (input.charCodeAt(pos) === 58) {
												result7 = ":";
												pos++;
											} else {
												result7 = null;
												if (reportFailures === 0) {
													matchFailed("\":\"");
												}
											}
											if (result7 !== null) {
												result8 = parse_h16();
												if (result8 !== null) {
													if (input.charCodeAt(pos) === 58) {
														result9 = ":";
														pos++;
													} else {
														result9 = null;
														if (reportFailures === 0) {
															matchFailed("\":\"");
														}
													}
													if (result9 !== null) {
														result10 = parse_h16();
														if (result10 !== null) {
															if (input.charCodeAt(pos) === 58) {
																result11 = ":";
																pos++;
															} else {
																result11 = null;
																if (reportFailures === 0) {
																	matchFailed("\":\"");
																}
															}
															if (result11 !== null) {
																result12 = parse_ls32();
																if (result12 !== null) {
																	result0 = [result0, result1, result2, result3, result4, result5, result6, result7, result8, result9, result10, result11, result12];
																} else {
																	result0 = null;
																	pos = pos1;
																}
															} else {
																result0 = null;
																pos = pos1;
															}
														} else {
															result0 = null;
															pos = pos1;
														}
													} else {
														result0 = null;
														pos = pos1;
													}
												} else {
													result0 = null;
													pos = pos1;
												}
											} else {
												result0 = null;
												pos = pos1;
											}
										} else {
											result0 = null;
											pos = pos1;
										}
									} else {
										result0 = null;
										pos = pos1;
									}
								} else {
									result0 = null;
									pos = pos1;
								}
							} else {
								result0 = null;
								pos = pos1;
							}
						} else {
							result0 = null;
							pos = pos1;
						}
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 === null) {
					pos1 = pos;
					if (input.substr(pos, 2) === "::") {
						result0 = "::";
						pos += 2;
					} else {
						result0 = null;
						if (reportFailures === 0) {
							matchFailed("\"::\"");
						}
					}
					if (result0 !== null) {
						result1 = parse_h16();
						if (result1 !== null) {
							if (input.charCodeAt(pos) === 58) {
								result2 = ":";
								pos++;
							} else {
								result2 = null;
								if (reportFailures === 0) {
									matchFailed("\":\"");
								}
							}
							if (result2 !== null) {
								result3 = parse_h16();
								if (result3 !== null) {
									if (input.charCodeAt(pos) === 58) {
										result4 = ":";
										pos++;
									} else {
										result4 = null;
										if (reportFailures === 0) {
											matchFailed("\":\"");
										}
									}
									if (result4 !== null) {
										result5 = parse_h16();
										if (result5 !== null) {
											if (input.charCodeAt(pos) === 58) {
												result6 = ":";
												pos++;
											} else {
												result6 = null;
												if (reportFailures === 0) {
													matchFailed("\":\"");
												}
											}
											if (result6 !== null) {
												result7 = parse_h16();
												if (result7 !== null) {
													if (input.charCodeAt(pos) === 58) {
														result8 = ":";
														pos++;
													} else {
														result8 = null;
														if (reportFailures === 0) {
															matchFailed("\":\"");
														}
													}
													if (result8 !== null) {
														result9 = parse_h16();
														if (result9 !== null) {
															if (input.charCodeAt(pos) === 58) {
																result10 = ":";
																pos++;
															} else {
																result10 = null;
																if (reportFailures === 0) {
																	matchFailed("\":\"");
																}
															}
															if (result10 !== null) {
																result11 = parse_ls32();
																if (result11 !== null) {
																	result0 = [result0, result1, result2, result3, result4, result5, result6, result7, result8, result9, result10, result11];
																} else {
																	result0 = null;
																	pos = pos1;
																}
															} else {
																result0 = null;
																pos = pos1;
															}
														} else {
															result0 = null;
															pos = pos1;
														}
													} else {
														result0 = null;
														pos = pos1;
													}
												} else {
													result0 = null;
													pos = pos1;
												}
											} else {
												result0 = null;
												pos = pos1;
											}
										} else {
											result0 = null;
											pos = pos1;
										}
									} else {
										result0 = null;
										pos = pos1;
									}
								} else {
									result0 = null;
									pos = pos1;
								}
							} else {
								result0 = null;
								pos = pos1;
							}
						} else {
							result0 = null;
							pos = pos1;
						}
					} else {
						result0 = null;
						pos = pos1;
					}
					if (result0 === null) {
						pos1 = pos;
						if (input.substr(pos, 2) === "::") {
							result0 = "::";
							pos += 2;
						} else {
							result0 = null;
							if (reportFailures === 0) {
								matchFailed("\"::\"");
							}
						}
						if (result0 !== null) {
							result1 = parse_h16();
							if (result1 !== null) {
								if (input.charCodeAt(pos) === 58) {
									result2 = ":";
									pos++;
								} else {
									result2 = null;
									if (reportFailures === 0) {
										matchFailed("\":\"");
									}
								}
								if (result2 !== null) {
									result3 = parse_h16();
									if (result3 !== null) {
										if (input.charCodeAt(pos) === 58) {
											result4 = ":";
											pos++;
										} else {
											result4 = null;
											if (reportFailures === 0) {
												matchFailed("\":\"");
											}
										}
										if (result4 !== null) {
											result5 = parse_h16();
											if (result5 !== null) {
												if (input.charCodeAt(pos) === 58) {
													result6 = ":";
													pos++;
												} else {
													result6 = null;
													if (reportFailures === 0) {
														matchFailed("\":\"");
													}
												}
												if (result6 !== null) {
													result7 = parse_h16();
													if (result7 !== null) {
														if (input.charCodeAt(pos) === 58) {
															result8 = ":";
															pos++;
														} else {
															result8 = null;
															if (reportFailures === 0) {
																matchFailed("\":\"");
															}
														}
														if (result8 !== null) {
															result9 = parse_ls32();
															if (result9 !== null) {
																result0 = [result0, result1, result2, result3, result4, result5, result6, result7, result8, result9];
															} else {
																result0 = null;
																pos = pos1;
															}
														} else {
															result0 = null;
															pos = pos1;
														}
													} else {
														result0 = null;
														pos = pos1;
													}
												} else {
													result0 = null;
													pos = pos1;
												}
											} else {
												result0 = null;
												pos = pos1;
											}
										} else {
											result0 = null;
											pos = pos1;
										}
									} else {
										result0 = null;
										pos = pos1;
									}
								} else {
									result0 = null;
									pos = pos1;
								}
							} else {
								result0 = null;
								pos = pos1;
							}
						} else {
							result0 = null;
							pos = pos1;
						}
						if (result0 === null) {
							pos1 = pos;
							if (input.substr(pos, 2) === "::") {
								result0 = "::";
								pos += 2;
							} else {
								result0 = null;
								if (reportFailures === 0) {
									matchFailed("\"::\"");
								}
							}
							if (result0 !== null) {
								result1 = parse_h16();
								if (result1 !== null) {
									if (input.charCodeAt(pos) === 58) {
										result2 = ":";
										pos++;
									} else {
										result2 = null;
										if (reportFailures === 0) {
											matchFailed("\":\"");
										}
									}
									if (result2 !== null) {
										result3 = parse_h16();
										if (result3 !== null) {
											if (input.charCodeAt(pos) === 58) {
												result4 = ":";
												pos++;
											} else {
												result4 = null;
												if (reportFailures === 0) {
													matchFailed("\":\"");
												}
											}
											if (result4 !== null) {
												result5 = parse_h16();
												if (result5 !== null) {
													if (input.charCodeAt(pos) === 58) {
														result6 = ":";
														pos++;
													} else {
														result6 = null;
														if (reportFailures === 0) {
															matchFailed("\":\"");
														}
													}
													if (result6 !== null) {
														result7 = parse_ls32();
														if (result7 !== null) {
															result0 = [result0, result1, result2, result3, result4, result5, result6, result7];
														} else {
															result0 = null;
															pos = pos1;
														}
													} else {
														result0 = null;
														pos = pos1;
													}
												} else {
													result0 = null;
													pos = pos1;
												}
											} else {
												result0 = null;
												pos = pos1;
											}
										} else {
											result0 = null;
											pos = pos1;
										}
									} else {
										result0 = null;
										pos = pos1;
									}
								} else {
									result0 = null;
									pos = pos1;
								}
							} else {
								result0 = null;
								pos = pos1;
							}
							if (result0 === null) {
								pos1 = pos;
								if (input.substr(pos, 2) === "::") {
									result0 = "::";
									pos += 2;
								} else {
									result0 = null;
									if (reportFailures === 0) {
										matchFailed("\"::\"");
									}
								}
								if (result0 !== null) {
									result1 = parse_h16();
									if (result1 !== null) {
										if (input.charCodeAt(pos) === 58) {
											result2 = ":";
											pos++;
										} else {
											result2 = null;
											if (reportFailures === 0) {
												matchFailed("\":\"");
											}
										}
										if (result2 !== null) {
											result3 = parse_h16();
											if (result3 !== null) {
												if (input.charCodeAt(pos) === 58) {
													result4 = ":";
													pos++;
												} else {
													result4 = null;
													if (reportFailures === 0) {
														matchFailed("\":\"");
													}
												}
												if (result4 !== null) {
													result5 = parse_ls32();
													if (result5 !== null) {
														result0 = [result0, result1, result2, result3, result4, result5];
													} else {
														result0 = null;
														pos = pos1;
													}
												} else {
													result0 = null;
													pos = pos1;
												}
											} else {
												result0 = null;
												pos = pos1;
											}
										} else {
											result0 = null;
											pos = pos1;
										}
									} else {
										result0 = null;
										pos = pos1;
									}
								} else {
									result0 = null;
									pos = pos1;
								}
								if (result0 === null) {
									pos1 = pos;
									if (input.substr(pos, 2) === "::") {
										result0 = "::";
										pos += 2;
									} else {
										result0 = null;
										if (reportFailures === 0) {
											matchFailed("\"::\"");
										}
									}
									if (result0 !== null) {
										result1 = parse_h16();
										if (result1 !== null) {
											if (input.charCodeAt(pos) === 58) {
												result2 = ":";
												pos++;
											} else {
												result2 = null;
												if (reportFailures === 0) {
													matchFailed("\":\"");
												}
											}
											if (result2 !== null) {
												result3 = parse_ls32();
												if (result3 !== null) {
													result0 = [result0, result1, result2, result3];
												} else {
													result0 = null;
													pos = pos1;
												}
											} else {
												result0 = null;
												pos = pos1;
											}
										} else {
											result0 = null;
											pos = pos1;
										}
									} else {
										result0 = null;
										pos = pos1;
									}
									if (result0 === null) {
										pos1 = pos;
										if (input.substr(pos, 2) === "::") {
											result0 = "::";
											pos += 2;
										} else {
											result0 = null;
											if (reportFailures === 0) {
												matchFailed("\"::\"");
											}
										}
										if (result0 !== null) {
											result1 = parse_ls32();
											if (result1 !== null) {
												result0 = [result0, result1];
											} else {
												result0 = null;
												pos = pos1;
											}
										} else {
											result0 = null;
											pos = pos1;
										}
										if (result0 === null) {
											pos1 = pos;
											if (input.substr(pos, 2) === "::") {
												result0 = "::";
												pos += 2;
											} else {
												result0 = null;
												if (reportFailures === 0) {
													matchFailed("\"::\"");
												}
											}
											if (result0 !== null) {
												result1 = parse_h16();
												if (result1 !== null) {
													result0 = [result0, result1];
												} else {
													result0 = null;
													pos = pos1;
												}
											} else {
												result0 = null;
												pos = pos1;
											}
											if (result0 === null) {
												pos1 = pos;
												result0 = parse_h16();
												if (result0 !== null) {
													if (input.substr(pos, 2) === "::") {
														result1 = "::";
														pos += 2;
													} else {
														result1 = null;
														if (reportFailures === 0) {
															matchFailed("\"::\"");
														}
													}
													if (result1 !== null) {
														result2 = parse_h16();
														if (result2 !== null) {
															if (input.charCodeAt(pos) === 58) {
																result3 = ":";
																pos++;
															} else {
																result3 = null;
																if (reportFailures === 0) {
																	matchFailed("\":\"");
																}
															}
															if (result3 !== null) {
																result4 = parse_h16();
																if (result4 !== null) {
																	if (input.charCodeAt(pos) === 58) {
																		result5 = ":";
																		pos++;
																	} else {
																		result5 = null;
																		if (reportFailures === 0) {
																			matchFailed("\":\"");
																		}
																	}
																	if (result5 !== null) {
																		result6 = parse_h16();
																		if (result6 !== null) {
																			if (input.charCodeAt(pos) === 58) {
																				result7 = ":";
																				pos++;
																			} else {
																				result7 = null;
																				if (reportFailures === 0) {
																					matchFailed("\":\"");
																				}
																			}
																			if (result7 !== null) {
																				result8 = parse_h16();
																				if (result8 !== null) {
																					if (input.charCodeAt(pos) === 58) {
																						result9 = ":";
																						pos++;
																					} else {
																						result9 = null;
																						if (reportFailures === 0) {
																							matchFailed("\":\"");
																						}
																					}
																					if (result9 !== null) {
																						result10 = parse_ls32();
																						if (result10 !== null) {
																							result0 = [result0, result1, result2, result3, result4, result5, result6, result7, result8, result9, result10];
																						} else {
																							result0 = null;
																							pos = pos1;
																						}
																					} else {
																						result0 = null;
																						pos = pos1;
																					}
																				} else {
																					result0 = null;
																					pos = pos1;
																				}
																			} else {
																				result0 = null;
																				pos = pos1;
																			}
																		} else {
																			result0 = null;
																			pos = pos1;
																		}
																	} else {
																		result0 = null;
																		pos = pos1;
																	}
																} else {
																	result0 = null;
																	pos = pos1;
																}
															} else {
																result0 = null;
																pos = pos1;
															}
														} else {
															result0 = null;
															pos = pos1;
														}
													} else {
														result0 = null;
														pos = pos1;
													}
												} else {
													result0 = null;
													pos = pos1;
												}
												if (result0 === null) {
													pos1 = pos;
													result0 = parse_h16();
													if (result0 !== null) {
														pos2 = pos;
														if (input.charCodeAt(pos) === 58) {
															result1 = ":";
															pos++;
														} else {
															result1 = null;
															if (reportFailures === 0) {
																matchFailed("\":\"");
															}
														}
														if (result1 !== null) {
															result2 = parse_h16();
															if (result2 !== null) {
																result1 = [result1, result2];
															} else {
																result1 = null;
																pos = pos2;
															}
														} else {
															result1 = null;
															pos = pos2;
														}
														result1 = result1 !== null ? result1 : "";
														if (result1 !== null) {
															if (input.substr(pos, 2) === "::") {
																result2 = "::";
																pos += 2;
															} else {
																result2 = null;
																if (reportFailures === 0) {
																	matchFailed("\"::\"");
																}
															}
															if (result2 !== null) {
																result3 = parse_h16();
																if (result3 !== null) {
																	if (input.charCodeAt(pos) === 58) {
																		result4 = ":";
																		pos++;
																	} else {
																		result4 = null;
																		if (reportFailures === 0) {
																			matchFailed("\":\"");
																		}
																	}
																	if (result4 !== null) {
																		result5 = parse_h16();
																		if (result5 !== null) {
																			if (input.charCodeAt(pos) === 58) {
																				result6 = ":";
																				pos++;
																			} else {
																				result6 = null;
																				if (reportFailures === 0) {
																					matchFailed("\":\"");
																				}
																			}
																			if (result6 !== null) {
																				result7 = parse_h16();
																				if (result7 !== null) {
																					if (input.charCodeAt(pos) === 58) {
																						result8 = ":";
																						pos++;
																					} else {
																						result8 = null;
																						if (reportFailures === 0) {
																							matchFailed("\":\"");
																						}
																					}
																					if (result8 !== null) {
																						result9 = parse_ls32();
																						if (result9 !== null) {
																							result0 = [result0, result1, result2, result3, result4, result5, result6, result7, result8, result9];
																						} else {
																							result0 = null;
																							pos = pos1;
																						}
																					} else {
																						result0 = null;
																						pos = pos1;
																					}
																				} else {
																					result0 = null;
																					pos = pos1;
																				}
																			} else {
																				result0 = null;
																				pos = pos1;
																			}
																		} else {
																			result0 = null;
																			pos = pos1;
																		}
																	} else {
																		result0 = null;
																		pos = pos1;
																	}
																} else {
																	result0 = null;
																	pos = pos1;
																}
															} else {
																result0 = null;
																pos = pos1;
															}
														} else {
															result0 = null;
															pos = pos1;
														}
													} else {
														result0 = null;
														pos = pos1;
													}
													if (result0 === null) {
														pos1 = pos;
														result0 = parse_h16();
														if (result0 !== null) {
															pos2 = pos;
															if (input.charCodeAt(pos) === 58) {
																result1 = ":";
																pos++;
															} else {
																result1 = null;
																if (reportFailures === 0) {
																	matchFailed("\":\"");
																}
															}
															if (result1 !== null) {
																result2 = parse_h16();
																if (result2 !== null) {
																	result1 = [result1, result2];
																} else {
																	result1 = null;
																	pos = pos2;
																}
															} else {
																result1 = null;
																pos = pos2;
															}
															result1 = result1 !== null ? result1 : "";
															if (result1 !== null) {
																pos2 = pos;
																if (input.charCodeAt(pos) === 58) {
																	result2 = ":";
																	pos++;
																} else {
																	result2 = null;
																	if (reportFailures === 0) {
																		matchFailed("\":\"");
																	}
																}
																if (result2 !== null) {
																	result3 = parse_h16();
																	if (result3 !== null) {
																		result2 = [result2, result3];
																	} else {
																		result2 = null;
																		pos = pos2;
																	}
																} else {
																	result2 = null;
																	pos = pos2;
																}
																result2 = result2 !== null ? result2 : "";
																if (result2 !== null) {
																	if (input.substr(pos, 2) === "::") {
																		result3 = "::";
																		pos += 2;
																	} else {
																		result3 = null;
																		if (reportFailures === 0) {
																			matchFailed("\"::\"");
																		}
																	}
																	if (result3 !== null) {
																		result4 = parse_h16();
																		if (result4 !== null) {
																			if (input.charCodeAt(pos) === 58) {
																				result5 = ":";
																				pos++;
																			} else {
																				result5 = null;
																				if (reportFailures === 0) {
																					matchFailed("\":\"");
																				}
																			}
																			if (result5 !== null) {
																				result6 = parse_h16();
																				if (result6 !== null) {
																					if (input.charCodeAt(pos) === 58) {
																						result7 = ":";
																						pos++;
																					} else {
																						result7 = null;
																						if (reportFailures === 0) {
																							matchFailed("\":\"");
																						}
																					}
																					if (result7 !== null) {
																						result8 = parse_ls32();
																						if (result8 !== null) {
																							result0 = [result0, result1, result2, result3, result4, result5, result6, result7, result8];
																						} else {
																							result0 = null;
																							pos = pos1;
																						}
																					} else {
																						result0 = null;
																						pos = pos1;
																					}
																				} else {
																					result0 = null;
																					pos = pos1;
																				}
																			} else {
																				result0 = null;
																				pos = pos1;
																			}
																		} else {
																			result0 = null;
																			pos = pos1;
																		}
																	} else {
																		result0 = null;
																		pos = pos1;
																	}
																} else {
																	result0 = null;
																	pos = pos1;
																}
															} else {
																result0 = null;
																pos = pos1;
															}
														} else {
															result0 = null;
															pos = pos1;
														}
														if (result0 === null) {
															pos1 = pos;
															result0 = parse_h16();
															if (result0 !== null) {
																pos2 = pos;
																if (input.charCodeAt(pos) === 58) {
																	result1 = ":";
																	pos++;
																} else {
																	result1 = null;
																	if (reportFailures === 0) {
																		matchFailed("\":\"");
																	}
																}
																if (result1 !== null) {
																	result2 = parse_h16();
																	if (result2 !== null) {
																		result1 = [result1, result2];
																	} else {
																		result1 = null;
																		pos = pos2;
																	}
																} else {
																	result1 = null;
																	pos = pos2;
																}
																result1 = result1 !== null ? result1 : "";
																if (result1 !== null) {
																	pos2 = pos;
																	if (input.charCodeAt(pos) === 58) {
																		result2 = ":";
																		pos++;
																	} else {
																		result2 = null;
																		if (reportFailures === 0) {
																			matchFailed("\":\"");
																		}
																	}
																	if (result2 !== null) {
																		result3 = parse_h16();
																		if (result3 !== null) {
																			result2 = [result2, result3];
																		} else {
																			result2 = null;
																			pos = pos2;
																		}
																	} else {
																		result2 = null;
																		pos = pos2;
																	}
																	result2 = result2 !== null ? result2 : "";
																	if (result2 !== null) {
																		pos2 = pos;
																		if (input.charCodeAt(pos) === 58) {
																			result3 = ":";
																			pos++;
																		} else {
																			result3 = null;
																			if (reportFailures === 0) {
																				matchFailed("\":\"");
																			}
																		}
																		if (result3 !== null) {
																			result4 = parse_h16();
																			if (result4 !== null) {
																				result3 = [result3, result4];
																			} else {
																				result3 = null;
																				pos = pos2;
																			}
																		} else {
																			result3 = null;
																			pos = pos2;
																		}
																		result3 = result3 !== null ? result3 : "";
																		if (result3 !== null) {
																			if (input.substr(pos, 2) === "::") {
																				result4 = "::";
																				pos += 2;
																			} else {
																				result4 = null;
																				if (reportFailures === 0) {
																					matchFailed("\"::\"");
																				}
																			}
																			if (result4 !== null) {
																				result5 = parse_h16();
																				if (result5 !== null) {
																					if (input.charCodeAt(pos) === 58) {
																						result6 = ":";
																						pos++;
																					} else {
																						result6 = null;
																						if (reportFailures === 0) {
																							matchFailed("\":\"");
																						}
																					}
																					if (result6 !== null) {
																						result7 = parse_ls32();
																						if (result7 !== null) {
																							result0 = [result0, result1, result2, result3, result4, result5, result6, result7];
																						} else {
																							result0 = null;
																							pos = pos1;
																						}
																					} else {
																						result0 = null;
																						pos = pos1;
																					}
																				} else {
																					result0 = null;
																					pos = pos1;
																				}
																			} else {
																				result0 = null;
																				pos = pos1;
																			}
																		} else {
																			result0 = null;
																			pos = pos1;
																		}
																	} else {
																		result0 = null;
																		pos = pos1;
																	}
																} else {
																	result0 = null;
																	pos = pos1;
																}
															} else {
																result0 = null;
																pos = pos1;
															}
															if (result0 === null) {
																pos1 = pos;
																result0 = parse_h16();
																if (result0 !== null) {
																	pos2 = pos;
																	if (input.charCodeAt(pos) === 58) {
																		result1 = ":";
																		pos++;
																	} else {
																		result1 = null;
																		if (reportFailures === 0) {
																			matchFailed("\":\"");
																		}
																	}
																	if (result1 !== null) {
																		result2 = parse_h16();
																		if (result2 !== null) {
																			result1 = [result1, result2];
																		} else {
																			result1 = null;
																			pos = pos2;
																		}
																	} else {
																		result1 = null;
																		pos = pos2;
																	}
																	result1 = result1 !== null ? result1 : "";
																	if (result1 !== null) {
																		pos2 = pos;
																		if (input.charCodeAt(pos) === 58) {
																			result2 = ":";
																			pos++;
																		} else {
																			result2 = null;
																			if (reportFailures === 0) {
																				matchFailed("\":\"");
																			}
																		}
																		if (result2 !== null) {
																			result3 = parse_h16();
																			if (result3 !== null) {
																				result2 = [result2, result3];
																			} else {
																				result2 = null;
																				pos = pos2;
																			}
																		} else {
																			result2 = null;
																			pos = pos2;
																		}
																		result2 = result2 !== null ? result2 : "";
																		if (result2 !== null) {
																			pos2 = pos;
																			if (input.charCodeAt(pos) === 58) {
																				result3 = ":";
																				pos++;
																			} else {
																				result3 = null;
																				if (reportFailures === 0) {
																					matchFailed("\":\"");
																				}
																			}
																			if (result3 !== null) {
																				result4 = parse_h16();
																				if (result4 !== null) {
																					result3 = [result3, result4];
																				} else {
																					result3 = null;
																					pos = pos2;
																				}
																			} else {
																				result3 = null;
																				pos = pos2;
																			}
																			result3 = result3 !== null ? result3 : "";
																			if (result3 !== null) {
																				pos2 = pos;
																				if (input.charCodeAt(pos) === 58) {
																					result4 = ":";
																					pos++;
																				} else {
																					result4 = null;
																					if (reportFailures === 0) {
																						matchFailed("\":\"");
																					}
																				}
																				if (result4 !== null) {
																					result5 = parse_h16();
																					if (result5 !== null) {
																						result4 = [result4, result5];
																					} else {
																						result4 = null;
																						pos = pos2;
																					}
																				} else {
																					result4 = null;
																					pos = pos2;
																				}
																				result4 = result4 !== null ? result4 : "";
																				if (result4 !== null) {
																					if (input.substr(pos, 2) === "::") {
																						result5 = "::";
																						pos += 2;
																					} else {
																						result5 = null;
																						if (reportFailures === 0) {
																							matchFailed("\"::\"");
																						}
																					}
																					if (result5 !== null) {
																						result6 = parse_ls32();
																						if (result6 !== null) {
																							result0 = [result0, result1, result2, result3, result4, result5, result6];
																						} else {
																							result0 = null;
																							pos = pos1;
																						}
																					} else {
																						result0 = null;
																						pos = pos1;
																					}
																				} else {
																					result0 = null;
																					pos = pos1;
																				}
																			} else {
																				result0 = null;
																				pos = pos1;
																			}
																		} else {
																			result0 = null;
																			pos = pos1;
																		}
																	} else {
																		result0 = null;
																		pos = pos1;
																	}
																} else {
																	result0 = null;
																	pos = pos1;
																}
																if (result0 === null) {
																	pos1 = pos;
																	result0 = parse_h16();
																	if (result0 !== null) {
																		pos2 = pos;
																		if (input.charCodeAt(pos) === 58) {
																			result1 = ":";
																			pos++;
																		} else {
																			result1 = null;
																			if (reportFailures === 0) {
																				matchFailed("\":\"");
																			}
																		}
																		if (result1 !== null) {
																			result2 = parse_h16();
																			if (result2 !== null) {
																				result1 = [result1, result2];
																			} else {
																				result1 = null;
																				pos = pos2;
																			}
																		} else {
																			result1 = null;
																			pos = pos2;
																		}
																		result1 = result1 !== null ? result1 : "";
																		if (result1 !== null) {
																			pos2 = pos;
																			if (input.charCodeAt(pos) === 58) {
																				result2 = ":";
																				pos++;
																			} else {
																				result2 = null;
																				if (reportFailures === 0) {
																					matchFailed("\":\"");
																				}
																			}
																			if (result2 !== null) {
																				result3 = parse_h16();
																				if (result3 !== null) {
																					result2 = [result2, result3];
																				} else {
																					result2 = null;
																					pos = pos2;
																				}
																			} else {
																				result2 = null;
																				pos = pos2;
																			}
																			result2 = result2 !== null ? result2 : "";
																			if (result2 !== null) {
																				pos2 = pos;
																				if (input.charCodeAt(pos) === 58) {
																					result3 = ":";
																					pos++;
																				} else {
																					result3 = null;
																					if (reportFailures === 0) {
																						matchFailed("\":\"");
																					}
																				}
																				if (result3 !== null) {
																					result4 = parse_h16();
																					if (result4 !== null) {
																						result3 = [result3, result4];
																					} else {
																						result3 = null;
																						pos = pos2;
																					}
																				} else {
																					result3 = null;
																					pos = pos2;
																				}
																				result3 = result3 !== null ? result3 : "";
																				if (result3 !== null) {
																					pos2 = pos;
																					if (input.charCodeAt(pos) === 58) {
																						result4 = ":";
																						pos++;
																					} else {
																						result4 = null;
																						if (reportFailures === 0) {
																							matchFailed("\":\"");
																						}
																					}
																					if (result4 !== null) {
																						result5 = parse_h16();
																						if (result5 !== null) {
																							result4 = [result4, result5];
																						} else {
																							result4 = null;
																							pos = pos2;
																						}
																					} else {
																						result4 = null;
																						pos = pos2;
																					}
																					result4 = result4 !== null ? result4 : "";
																					if (result4 !== null) {
																						pos2 = pos;
																						if (input.charCodeAt(pos) === 58) {
																							result5 = ":";
																							pos++;
																						} else {
																							result5 = null;
																							if (reportFailures === 0) {
																								matchFailed("\":\"");
																							}
																						}
																						if (result5 !== null) {
																							result6 = parse_h16();
																							if (result6 !== null) {
																								result5 = [result5, result6];
																							} else {
																								result5 = null;
																								pos = pos2;
																							}
																						} else {
																							result5 = null;
																							pos = pos2;
																						}
																						result5 = result5 !== null ? result5 : "";
																						if (result5 !== null) {
																							if (input.substr(pos, 2) === "::") {
																								result6 = "::";
																								pos += 2;
																							} else {
																								result6 = null;
																								if (reportFailures === 0) {
																									matchFailed("\"::\"");
																								}
																							}
																							if (result6 !== null) {
																								result7 = parse_h16();
																								if (result7 !== null) {
																									result0 = [result0, result1, result2, result3, result4, result5, result6, result7];
																								} else {
																									result0 = null;
																									pos = pos1;
																								}
																							} else {
																								result0 = null;
																								pos = pos1;
																							}
																						} else {
																							result0 = null;
																							pos = pos1;
																						}
																					} else {
																						result0 = null;
																						pos = pos1;
																					}
																				} else {
																					result0 = null;
																					pos = pos1;
																				}
																			} else {
																				result0 = null;
																				pos = pos1;
																			}
																		} else {
																			result0 = null;
																			pos = pos1;
																		}
																	} else {
																		result0 = null;
																		pos = pos1;
																	}
																	if (result0 === null) {
																		pos1 = pos;
																		result0 = parse_h16();
																		if (result0 !== null) {
																			pos2 = pos;
																			if (input.charCodeAt(pos) === 58) {
																				result1 = ":";
																				pos++;
																			} else {
																				result1 = null;
																				if (reportFailures === 0) {
																					matchFailed("\":\"");
																				}
																			}
																			if (result1 !== null) {
																				result2 = parse_h16();
																				if (result2 !== null) {
																					result1 = [result1, result2];
																				} else {
																					result1 = null;
																					pos = pos2;
																				}
																			} else {
																				result1 = null;
																				pos = pos2;
																			}
																			result1 = result1 !== null ? result1 : "";
																			if (result1 !== null) {
																				pos2 = pos;
																				if (input.charCodeAt(pos) === 58) {
																					result2 = ":";
																					pos++;
																				} else {
																					result2 = null;
																					if (reportFailures === 0) {
																						matchFailed("\":\"");
																					}
																				}
																				if (result2 !== null) {
																					result3 = parse_h16();
																					if (result3 !== null) {
																						result2 = [result2, result3];
																					} else {
																						result2 = null;
																						pos = pos2;
																					}
																				} else {
																					result2 = null;
																					pos = pos2;
																				}
																				result2 = result2 !== null ? result2 : "";
																				if (result2 !== null) {
																					pos2 = pos;
																					if (input.charCodeAt(pos) === 58) {
																						result3 = ":";
																						pos++;
																					} else {
																						result3 = null;
																						if (reportFailures === 0) {
																							matchFailed("\":\"");
																						}
																					}
																					if (result3 !== null) {
																						result4 = parse_h16();
																						if (result4 !== null) {
																							result3 = [result3, result4];
																						} else {
																							result3 = null;
																							pos = pos2;
																						}
																					} else {
																						result3 = null;
																						pos = pos2;
																					}
																					result3 = result3 !== null ? result3 : "";
																					if (result3 !== null) {
																						pos2 = pos;
																						if (input.charCodeAt(pos) === 58) {
																							result4 = ":";
																							pos++;
																						} else {
																							result4 = null;
																							if (reportFailures === 0) {
																								matchFailed("\":\"");
																							}
																						}
																						if (result4 !== null) {
																							result5 = parse_h16();
																							if (result5 !== null) {
																								result4 = [result4, result5];
																							} else {
																								result4 = null;
																								pos = pos2;
																							}
																						} else {
																							result4 = null;
																							pos = pos2;
																						}
																						result4 = result4 !== null ? result4 : "";
																						if (result4 !== null) {
																							pos2 = pos;
																							if (input.charCodeAt(pos) === 58) {
																								result5 = ":";
																								pos++;
																							} else {
																								result5 = null;
																								if (reportFailures === 0) {
																									matchFailed("\":\"");
																								}
																							}
																							if (result5 !== null) {
																								result6 = parse_h16();
																								if (result6 !== null) {
																									result5 = [result5, result6];
																								} else {
																									result5 = null;
																									pos = pos2;
																								}
																							} else {
																								result5 = null;
																								pos = pos2;
																							}
																							result5 = result5 !== null ? result5 : "";
																							if (result5 !== null) {
																								pos2 = pos;
																								if (input.charCodeAt(pos) === 58) {
																									result6 = ":";
																									pos++;
																								} else {
																									result6 = null;
																									if (reportFailures === 0) {
																										matchFailed("\":\"");
																									}
																								}
																								if (result6 !== null) {
																									result7 = parse_h16();
																									if (result7 !== null) {
																										result6 = [result6, result7];
																									} else {
																										result6 = null;
																										pos = pos2;
																									}
																								} else {
																									result6 = null;
																									pos = pos2;
																								}
																								result6 = result6 !== null ? result6 : "";
																								if (result6 !== null) {
																									if (input.substr(pos, 2) === "::") {
																										result7 = "::";
																										pos += 2;
																									} else {
																										result7 = null;
																										if (reportFailures === 0) {
																											matchFailed("\"::\"");
																										}
																									}
																									if (result7 !== null) {
																										result0 = [result0, result1, result2, result3, result4, result5, result6, result7];
																									} else {
																										result0 = null;
																										pos = pos1;
																									}
																								} else {
																									result0 = null;
																									pos = pos1;
																								}
																							} else {
																								result0 = null;
																								pos = pos1;
																							}
																						} else {
																							result0 = null;
																							pos = pos1;
																						}
																					} else {
																						result0 = null;
																						pos = pos1;
																					}
																				} else {
																					result0 = null;
																					pos = pos1;
																				}
																			} else {
																				result0 = null;
																				pos = pos1;
																			}
																		} else {
																			result0 = null;
																			pos = pos1;
																		}
																	}
																}
															}
														}
													}
												}
											}
										}
									}
								}
							}
						}
					}
				}
				if (result0 !== null) {
					result0 = (function (offset) {
						data.host_type = 'IPv6';
						return input.substring(pos, offset);
					})(pos0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_h16() {
				var result0, result1, result2, result3;
				var pos0;

				pos0 = pos;
				result0 = parse_HEXDIG();
				if (result0 !== null) {
					result1 = parse_HEXDIG();
					result1 = result1 !== null ? result1 : "";
					if (result1 !== null) {
						result2 = parse_HEXDIG();
						result2 = result2 !== null ? result2 : "";
						if (result2 !== null) {
							result3 = parse_HEXDIG();
							result3 = result3 !== null ? result3 : "";
							if (result3 !== null) {
								result0 = [result0, result1, result2, result3];
							} else {
								result0 = null;
								pos = pos0;
							}
						} else {
							result0 = null;
							pos = pos0;
						}
					} else {
						result0 = null;
						pos = pos0;
					}
				} else {
					result0 = null;
					pos = pos0;
				}
				return result0;
			}

			function parse_ls32() {
				var result0, result1, result2;
				var pos0;

				pos0 = pos;
				result0 = parse_h16();
				if (result0 !== null) {
					if (input.charCodeAt(pos) === 58) {
						result1 = ":";
						pos++;
					} else {
						result1 = null;
						if (reportFailures === 0) {
							matchFailed("\":\"");
						}
					}
					if (result1 !== null) {
						result2 = parse_h16();
						if (result2 !== null) {
							result0 = [result0, result1, result2];
						} else {
							result0 = null;
							pos = pos0;
						}
					} else {
						result0 = null;
						pos = pos0;
					}
				} else {
					result0 = null;
					pos = pos0;
				}
				if (result0 === null) {
					result0 = parse_IPv4address();
				}
				return result0;
			}

			function parse_IPv4address() {
				var result0, result1, result2, result3, result4, result5, result6;
				var pos0, pos1;

				pos0 = pos;
				pos1 = pos;
				result0 = parse_dec_octet();
				if (result0 !== null) {
					if (input.charCodeAt(pos) === 46) {
						result1 = ".";
						pos++;
					} else {
						result1 = null;
						if (reportFailures === 0) {
							matchFailed("\".\"");
						}
					}
					if (result1 !== null) {
						result2 = parse_dec_octet();
						if (result2 !== null) {
							if (input.charCodeAt(pos) === 46) {
								result3 = ".";
								pos++;
							} else {
								result3 = null;
								if (reportFailures === 0) {
									matchFailed("\".\"");
								}
							}
							if (result3 !== null) {
								result4 = parse_dec_octet();
								if (result4 !== null) {
									if (input.charCodeAt(pos) === 46) {
										result5 = ".";
										pos++;
									} else {
										result5 = null;
										if (reportFailures === 0) {
											matchFailed("\".\"");
										}
									}
									if (result5 !== null) {
										result6 = parse_dec_octet();
										if (result6 !== null) {
											result0 = [result0, result1, result2, result3, result4, result5, result6];
										} else {
											result0 = null;
											pos = pos1;
										}
									} else {
										result0 = null;
										pos = pos1;
									}
								} else {
									result0 = null;
									pos = pos1;
								}
							} else {
								result0 = null;
								pos = pos1;
							}
						} else {
							result0 = null;
							pos = pos1;
						}
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset) {
						data.host_type = 'IPv4';
						return input.substring(pos, offset);
					})(pos0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_dec_octet() {
				var result0, result1, result2;
				var pos0;

				pos0 = pos;
				if (input.substr(pos, 2) === "25") {
					result0 = "25";
					pos += 2;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"25\"");
					}
				}
				if (result0 !== null) {
					if (/^[0-5]/.test(input.charAt(pos))) {
						result1 = input.charAt(pos);
						pos++;
					} else {
						result1 = null;
						if (reportFailures === 0) {
							matchFailed("[0-5]");
						}
					}
					if (result1 !== null) {
						result0 = [result0, result1];
					} else {
						result0 = null;
						pos = pos0;
					}
				} else {
					result0 = null;
					pos = pos0;
				}
				if (result0 === null) {
					pos0 = pos;
					if (input.charCodeAt(pos) === 50) {
						result0 = "2";
						pos++;
					} else {
						result0 = null;
						if (reportFailures === 0) {
							matchFailed("\"2\"");
						}
					}
					if (result0 !== null) {
						if (/^[0-4]/.test(input.charAt(pos))) {
							result1 = input.charAt(pos);
							pos++;
						} else {
							result1 = null;
							if (reportFailures === 0) {
								matchFailed("[0-4]");
							}
						}
						if (result1 !== null) {
							result2 = parse_DIGIT();
							if (result2 !== null) {
								result0 = [result0, result1, result2];
							} else {
								result0 = null;
								pos = pos0;
							}
						} else {
							result0 = null;
							pos = pos0;
						}
					} else {
						result0 = null;
						pos = pos0;
					}
					if (result0 === null) {
						pos0 = pos;
						if (input.charCodeAt(pos) === 49) {
							result0 = "1";
							pos++;
						} else {
							result0 = null;
							if (reportFailures === 0) {
								matchFailed("\"1\"");
							}
						}
						if (result0 !== null) {
							result1 = parse_DIGIT();
							if (result1 !== null) {
								result2 = parse_DIGIT();
								if (result2 !== null) {
									result0 = [result0, result1, result2];
								} else {
									result0 = null;
									pos = pos0;
								}
							} else {
								result0 = null;
								pos = pos0;
							}
						} else {
							result0 = null;
							pos = pos0;
						}
						if (result0 === null) {
							pos0 = pos;
							if (/^[1-9]/.test(input.charAt(pos))) {
								result0 = input.charAt(pos);
								pos++;
							} else {
								result0 = null;
								if (reportFailures === 0) {
									matchFailed("[1-9]");
								}
							}
							if (result0 !== null) {
								result1 = parse_DIGIT();
								if (result1 !== null) {
									result0 = [result0, result1];
								} else {
									result0 = null;
									pos = pos0;
								}
							} else {
								result0 = null;
								pos = pos0;
							}
							if (result0 === null) {
								result0 = parse_DIGIT();
							}
						}
					}
				}
				return result0;
			}

			function parse_port() {
				var result0, result1, result2, result3, result4;
				var pos0, pos1;

				pos0 = pos;
				pos1 = pos;
				result0 = parse_DIGIT();
				result0 = result0 !== null ? result0 : "";
				if (result0 !== null) {
					result1 = parse_DIGIT();
					result1 = result1 !== null ? result1 : "";
					if (result1 !== null) {
						result2 = parse_DIGIT();
						result2 = result2 !== null ? result2 : "";
						if (result2 !== null) {
							result3 = parse_DIGIT();
							result3 = result3 !== null ? result3 : "";
							if (result3 !== null) {
								result4 = parse_DIGIT();
								result4 = result4 !== null ? result4 : "";
								if (result4 !== null) {
									result0 = [result0, result1, result2, result3, result4];
								} else {
									result0 = null;
									pos = pos1;
								}
							} else {
								result0 = null;
								pos = pos1;
							}
						} else {
							result0 = null;
							pos = pos1;
						}
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset, port) {
						port = parseInt(port.join(''));
						data.port = port;
						return port;
					})(pos0, result0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_uri_parameters() {
				var result0, result1, result2;
				var pos0;

				result0 = [];
				pos0 = pos;
				if (input.charCodeAt(pos) === 59) {
					result1 = ";";
					pos++;
				} else {
					result1 = null;
					if (reportFailures === 0) {
						matchFailed("\";\"");
					}
				}
				if (result1 !== null) {
					result2 = parse_uri_parameter();
					if (result2 !== null) {
						result1 = [result1, result2];
					} else {
						result1 = null;
						pos = pos0;
					}
				} else {
					result1 = null;
					pos = pos0;
				}
				while (result1 !== null) {
					result0.push(result1);
					pos0 = pos;
					if (input.charCodeAt(pos) === 59) {
						result1 = ";";
						pos++;
					} else {
						result1 = null;
						if (reportFailures === 0) {
							matchFailed("\";\"");
						}
					}
					if (result1 !== null) {
						result2 = parse_uri_parameter();
						if (result2 !== null) {
							result1 = [result1, result2];
						} else {
							result1 = null;
							pos = pos0;
						}
					} else {
						result1 = null;
						pos = pos0;
					}
				}
				return result0;
			}

			function parse_uri_parameter() {
				var result0;

				result0 = parse_transport_param();
				if (result0 === null) {
					result0 = parse_user_param();
					if (result0 === null) {
						result0 = parse_method_param();
						if (result0 === null) {
							result0 = parse_ttl_param();
							if (result0 === null) {
								result0 = parse_maddr_param();
								if (result0 === null) {
									result0 = parse_lr_param();
									if (result0 === null) {
										result0 = parse_other_param();
									}
								}
							}
						}
					}
				}
				return result0;
			}

			function parse_transport_param() {
				var result0, result1;
				var pos0, pos1;

				pos0 = pos;
				pos1 = pos;
				if (input.substr(pos, 10).toLowerCase() === "transport=") {
					result0 = input.substr(pos, 10);
					pos += 10;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"transport=\"");
					}
				}
				if (result0 !== null) {
					if (input.substr(pos, 3).toLowerCase() === "udp") {
						result1 = input.substr(pos, 3);
						pos += 3;
					} else {
						result1 = null;
						if (reportFailures === 0) {
							matchFailed("\"udp\"");
						}
					}
					if (result1 === null) {
						if (input.substr(pos, 3).toLowerCase() === "tcp") {
							result1 = input.substr(pos, 3);
							pos += 3;
						} else {
							result1 = null;
							if (reportFailures === 0) {
								matchFailed("\"tcp\"");
							}
						}
						if (result1 === null) {
							if (input.substr(pos, 4).toLowerCase() === "sctp") {
								result1 = input.substr(pos, 4);
								pos += 4;
							} else {
								result1 = null;
								if (reportFailures === 0) {
									matchFailed("\"sctp\"");
								}
							}
							if (result1 === null) {
								if (input.substr(pos, 3).toLowerCase() === "tls") {
									result1 = input.substr(pos, 3);
									pos += 3;
								} else {
									result1 = null;
									if (reportFailures === 0) {
										matchFailed("\"tls\"");
									}
								}
								if (result1 === null) {
									result1 = parse_token();
								}
							}
						}
					}
					if (result1 !== null) {
						result0 = [result0, result1];
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset, transport) {
						if (!data.uri_params) data.uri_params = {};
						data.uri_params['transport'] = transport.toLowerCase();
					})(pos0, result0[1]);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_user_param() {
				var result0, result1;
				var pos0, pos1;

				pos0 = pos;
				pos1 = pos;
				if (input.substr(pos, 5).toLowerCase() === "user=") {
					result0 = input.substr(pos, 5);
					pos += 5;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"user=\"");
					}
				}
				if (result0 !== null) {
					if (input.substr(pos, 5).toLowerCase() === "phone") {
						result1 = input.substr(pos, 5);
						pos += 5;
					} else {
						result1 = null;
						if (reportFailures === 0) {
							matchFailed("\"phone\"");
						}
					}
					if (result1 === null) {
						if (input.substr(pos, 2).toLowerCase() === "ip") {
							result1 = input.substr(pos, 2);
							pos += 2;
						} else {
							result1 = null;
							if (reportFailures === 0) {
								matchFailed("\"ip\"");
							}
						}
						if (result1 === null) {
							result1 = parse_token();
						}
					}
					if (result1 !== null) {
						result0 = [result0, result1];
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset, user) {
						if (!data.uri_params) data.uri_params = {};
						data.uri_params['user'] = user.toLowerCase();
					})(pos0, result0[1]);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_method_param() {
				var result0, result1;
				var pos0, pos1;

				pos0 = pos;
				pos1 = pos;
				if (input.substr(pos, 7).toLowerCase() === "method=") {
					result0 = input.substr(pos, 7);
					pos += 7;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"method=\"");
					}
				}
				if (result0 !== null) {
					result1 = parse_Method();
					if (result1 !== null) {
						result0 = [result0, result1];
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset, method) {
						if (!data.uri_params) data.uri_params = {};
						data.uri_params['method'] = method;
					})(pos0, result0[1]);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_ttl_param() {
				var result0, result1;
				var pos0, pos1;

				pos0 = pos;
				pos1 = pos;
				if (input.substr(pos, 4).toLowerCase() === "ttl=") {
					result0 = input.substr(pos, 4);
					pos += 4;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"ttl=\"");
					}
				}
				if (result0 !== null) {
					result1 = parse_ttl();
					if (result1 !== null) {
						result0 = [result0, result1];
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset, ttl) {
						if (!data.params) data.params = {};
						data.params['ttl'] = ttl;
					})(pos0, result0[1]);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_maddr_param() {
				var result0, result1;
				var pos0, pos1;

				pos0 = pos;
				pos1 = pos;
				if (input.substr(pos, 6).toLowerCase() === "maddr=") {
					result0 = input.substr(pos, 6);
					pos += 6;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"maddr=\"");
					}
				}
				if (result0 !== null) {
					result1 = parse_host();
					if (result1 !== null) {
						result0 = [result0, result1];
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset, maddr) {
						if (!data.uri_params) data.uri_params = {};
						data.uri_params['maddr'] = maddr;
					})(pos0, result0[1]);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_lr_param() {
				var result0, result1, result2;
				var pos0, pos1, pos2;

				pos0 = pos;
				pos1 = pos;
				if (input.substr(pos, 2).toLowerCase() === "lr") {
					result0 = input.substr(pos, 2);
					pos += 2;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"lr\"");
					}
				}
				if (result0 !== null) {
					pos2 = pos;
					if (input.charCodeAt(pos) === 61) {
						result1 = "=";
						pos++;
					} else {
						result1 = null;
						if (reportFailures === 0) {
							matchFailed("\"=\"");
						}
					}
					if (result1 !== null) {
						result2 = parse_token();
						if (result2 !== null) {
							result1 = [result1, result2];
						} else {
							result1 = null;
							pos = pos2;
						}
					} else {
						result1 = null;
						pos = pos2;
					}
					result1 = result1 !== null ? result1 : "";
					if (result1 !== null) {
						result0 = [result0, result1];
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset) {
						if (!data.uri_params) data.uri_params = {};
						data.uri_params['lr'] = undefined;
					})(pos0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_other_param() {
				var result0, result1, result2;
				var pos0, pos1, pos2;

				pos0 = pos;
				pos1 = pos;
				result0 = parse_pname();
				if (result0 !== null) {
					pos2 = pos;
					if (input.charCodeAt(pos) === 61) {
						result1 = "=";
						pos++;
					} else {
						result1 = null;
						if (reportFailures === 0) {
							matchFailed("\"=\"");
						}
					}
					if (result1 !== null) {
						result2 = parse_pvalue();
						if (result2 !== null) {
							result1 = [result1, result2];
						} else {
							result1 = null;
							pos = pos2;
						}
					} else {
						result1 = null;
						pos = pos2;
					}
					result1 = result1 !== null ? result1 : "";
					if (result1 !== null) {
						result0 = [result0, result1];
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset, param, value) {
						if (!data.uri_params) data.uri_params = {};
						if (typeof value === 'undefined') {
							value = undefined;
						}
						else {
							value = value[1];
						}
						data.uri_params[param.toLowerCase()] = value && value.toLowerCase();
					})(pos0, result0[0], result0[1]);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_pname() {
				var result0, result1;
				var pos0;

				pos0 = pos;
				result1 = parse_paramchar();
				if (result1 !== null) {
					result0 = [];
					while (result1 !== null) {
						result0.push(result1);
						result1 = parse_paramchar();
					}
				} else {
					result0 = null;
				}
				if (result0 !== null) {
					result0 = (function (offset, pname) {
						return pname.join('');
					})(pos0, result0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_pvalue() {
				var result0, result1;
				var pos0;

				pos0 = pos;
				result1 = parse_paramchar();
				if (result1 !== null) {
					result0 = [];
					while (result1 !== null) {
						result0.push(result1);
						result1 = parse_paramchar();
					}
				} else {
					result0 = null;
				}
				if (result0 !== null) {
					result0 = (function (offset, pvalue) {
						return pvalue.join('');
					})(pos0, result0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_paramchar() {
				var result0;

				result0 = parse_param_unreserved();
				if (result0 === null) {
					result0 = parse_unreserved();
					if (result0 === null) {
						result0 = parse_escaped();
					}
				}
				return result0;
			}

			function parse_param_unreserved() {
				var result0;

				if (input.charCodeAt(pos) === 91) {
					result0 = "[";
					pos++;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"[\"");
					}
				}
				if (result0 === null) {
					if (input.charCodeAt(pos) === 93) {
						result0 = "]";
						pos++;
					} else {
						result0 = null;
						if (reportFailures === 0) {
							matchFailed("\"]\"");
						}
					}
					if (result0 === null) {
						if (input.charCodeAt(pos) === 47) {
							result0 = "/";
							pos++;
						} else {
							result0 = null;
							if (reportFailures === 0) {
								matchFailed("\"/\"");
							}
						}
						if (result0 === null) {
							if (input.charCodeAt(pos) === 58) {
								result0 = ":";
								pos++;
							} else {
								result0 = null;
								if (reportFailures === 0) {
									matchFailed("\":\"");
								}
							}
							if (result0 === null) {
								if (input.charCodeAt(pos) === 38) {
									result0 = "&";
									pos++;
								} else {
									result0 = null;
									if (reportFailures === 0) {
										matchFailed("\"&\"");
									}
								}
								if (result0 === null) {
									if (input.charCodeAt(pos) === 43) {
										result0 = "+";
										pos++;
									} else {
										result0 = null;
										if (reportFailures === 0) {
											matchFailed("\"+\"");
										}
									}
									if (result0 === null) {
										if (input.charCodeAt(pos) === 36) {
											result0 = "$";
											pos++;
										} else {
											result0 = null;
											if (reportFailures === 0) {
												matchFailed("\"$\"");
											}
										}
									}
								}
							}
						}
					}
				}
				return result0;
			}

			function parse_headers() {
				var result0, result1, result2, result3, result4;
				var pos0, pos1;

				pos0 = pos;
				if (input.charCodeAt(pos) === 63) {
					result0 = "?";
					pos++;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"?\"");
					}
				}
				if (result0 !== null) {
					result1 = parse_header();
					if (result1 !== null) {
						result2 = [];
						pos1 = pos;
						if (input.charCodeAt(pos) === 38) {
							result3 = "&";
							pos++;
						} else {
							result3 = null;
							if (reportFailures === 0) {
								matchFailed("\"&\"");
							}
						}
						if (result3 !== null) {
							result4 = parse_header();
							if (result4 !== null) {
								result3 = [result3, result4];
							} else {
								result3 = null;
								pos = pos1;
							}
						} else {
							result3 = null;
							pos = pos1;
						}
						while (result3 !== null) {
							result2.push(result3);
							pos1 = pos;
							if (input.charCodeAt(pos) === 38) {
								result3 = "&";
								pos++;
							} else {
								result3 = null;
								if (reportFailures === 0) {
									matchFailed("\"&\"");
								}
							}
							if (result3 !== null) {
								result4 = parse_header();
								if (result4 !== null) {
									result3 = [result3, result4];
								} else {
									result3 = null;
									pos = pos1;
								}
							} else {
								result3 = null;
								pos = pos1;
							}
						}
						if (result2 !== null) {
							result0 = [result0, result1, result2];
						} else {
							result0 = null;
							pos = pos0;
						}
					} else {
						result0 = null;
						pos = pos0;
					}
				} else {
					result0 = null;
					pos = pos0;
				}
				return result0;
			}

			function parse_header() {
				var result0, result1, result2;
				var pos0, pos1;

				pos0 = pos;
				pos1 = pos;
				result0 = parse_hname();
				if (result0 !== null) {
					if (input.charCodeAt(pos) === 61) {
						result1 = "=";
						pos++;
					} else {
						result1 = null;
						if (reportFailures === 0) {
							matchFailed("\"=\"");
						}
					}
					if (result1 !== null) {
						result2 = parse_hvalue();
						if (result2 !== null) {
							result0 = [result0, result1, result2];
						} else {
							result0 = null;
							pos = pos1;
						}
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset, hname, hvalue) {
						hname = hname.join('').toLowerCase();
						hvalue = hvalue.join('');
						if (!data.uri_headers) data.uri_headers = {};
						if (!data.uri_headers[hname]) {
							data.uri_headers[hname] = [hvalue];
						} else {
							data.uri_headers[hname].push(hvalue);
						}
					})(pos0, result0[0], result0[2]);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_hname() {
				var result0, result1;

				result1 = parse_hnv_unreserved();
				if (result1 === null) {
					result1 = parse_unreserved();
					if (result1 === null) {
						result1 = parse_escaped();
					}
				}
				if (result1 !== null) {
					result0 = [];
					while (result1 !== null) {
						result0.push(result1);
						result1 = parse_hnv_unreserved();
						if (result1 === null) {
							result1 = parse_unreserved();
							if (result1 === null) {
								result1 = parse_escaped();
							}
						}
					}
				} else {
					result0 = null;
				}
				return result0;
			}

			function parse_hvalue() {
				var result0, result1;

				result0 = [];
				result1 = parse_hnv_unreserved();
				if (result1 === null) {
					result1 = parse_unreserved();
					if (result1 === null) {
						result1 = parse_escaped();
					}
				}
				while (result1 !== null) {
					result0.push(result1);
					result1 = parse_hnv_unreserved();
					if (result1 === null) {
						result1 = parse_unreserved();
						if (result1 === null) {
							result1 = parse_escaped();
						}
					}
				}
				return result0;
			}

			function parse_hnv_unreserved() {
				var result0;

				if (input.charCodeAt(pos) === 91) {
					result0 = "[";
					pos++;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"[\"");
					}
				}
				if (result0 === null) {
					if (input.charCodeAt(pos) === 93) {
						result0 = "]";
						pos++;
					} else {
						result0 = null;
						if (reportFailures === 0) {
							matchFailed("\"]\"");
						}
					}
					if (result0 === null) {
						if (input.charCodeAt(pos) === 47) {
							result0 = "/";
							pos++;
						} else {
							result0 = null;
							if (reportFailures === 0) {
								matchFailed("\"/\"");
							}
						}
						if (result0 === null) {
							if (input.charCodeAt(pos) === 63) {
								result0 = "?";
								pos++;
							} else {
								result0 = null;
								if (reportFailures === 0) {
									matchFailed("\"?\"");
								}
							}
							if (result0 === null) {
								if (input.charCodeAt(pos) === 58) {
									result0 = ":";
									pos++;
								} else {
									result0 = null;
									if (reportFailures === 0) {
										matchFailed("\":\"");
									}
								}
								if (result0 === null) {
									if (input.charCodeAt(pos) === 43) {
										result0 = "+";
										pos++;
									} else {
										result0 = null;
										if (reportFailures === 0) {
											matchFailed("\"+\"");
										}
									}
									if (result0 === null) {
										if (input.charCodeAt(pos) === 36) {
											result0 = "$";
											pos++;
										} else {
											result0 = null;
											if (reportFailures === 0) {
												matchFailed("\"$\"");
											}
										}
									}
								}
							}
						}
					}
				}
				return result0;
			}

			function parse_Request_Response() {
				var result0;

				result0 = parse_Status_Line();
				if (result0 === null) {
					result0 = parse_Request_Line();
				}
				return result0;
			}

			function parse_Request_Line() {
				var result0, result1, result2, result3, result4;
				var pos0;

				pos0 = pos;
				result0 = parse_Method();
				if (result0 !== null) {
					result1 = parse_SP();
					if (result1 !== null) {
						result2 = parse_Request_URI();
						if (result2 !== null) {
							result3 = parse_SP();
							if (result3 !== null) {
								result4 = parse_SIP_Version();
								if (result4 !== null) {
									result0 = [result0, result1, result2, result3, result4];
								} else {
									result0 = null;
									pos = pos0;
								}
							} else {
								result0 = null;
								pos = pos0;
							}
						} else {
							result0 = null;
							pos = pos0;
						}
					} else {
						result0 = null;
						pos = pos0;
					}
				} else {
					result0 = null;
					pos = pos0;
				}
				return result0;
			}

			function parse_Request_URI() {
				var result0;

				result0 = parse_SIP_URI();
				if (result0 === null) {
					result0 = parse_absoluteURI();
				}
				return result0;
			}

			function parse_absoluteURI() {
				var result0, result1, result2;
				var pos0;

				pos0 = pos;
				result0 = parse_scheme();
				if (result0 !== null) {
					if (input.charCodeAt(pos) === 58) {
						result1 = ":";
						pos++;
					} else {
						result1 = null;
						if (reportFailures === 0) {
							matchFailed("\":\"");
						}
					}
					if (result1 !== null) {
						result2 = parse_hier_part();
						if (result2 === null) {
							result2 = parse_opaque_part();
						}
						if (result2 !== null) {
							result0 = [result0, result1, result2];
						} else {
							result0 = null;
							pos = pos0;
						}
					} else {
						result0 = null;
						pos = pos0;
					}
				} else {
					result0 = null;
					pos = pos0;
				}
				return result0;
			}

			function parse_hier_part() {
				var result0, result1, result2;
				var pos0, pos1;

				pos0 = pos;
				result0 = parse_net_path();
				if (result0 === null) {
					result0 = parse_abs_path();
				}
				if (result0 !== null) {
					pos1 = pos;
					if (input.charCodeAt(pos) === 63) {
						result1 = "?";
						pos++;
					} else {
						result1 = null;
						if (reportFailures === 0) {
							matchFailed("\"?\"");
						}
					}
					if (result1 !== null) {
						result2 = parse_query();
						if (result2 !== null) {
							result1 = [result1, result2];
						} else {
							result1 = null;
							pos = pos1;
						}
					} else {
						result1 = null;
						pos = pos1;
					}
					result1 = result1 !== null ? result1 : "";
					if (result1 !== null) {
						result0 = [result0, result1];
					} else {
						result0 = null;
						pos = pos0;
					}
				} else {
					result0 = null;
					pos = pos0;
				}
				return result0;
			}

			function parse_net_path() {
				var result0, result1, result2;
				var pos0;

				pos0 = pos;
				if (input.substr(pos, 2) === "//") {
					result0 = "//";
					pos += 2;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"//\"");
					}
				}
				if (result0 !== null) {
					result1 = parse_authority();
					if (result1 !== null) {
						result2 = parse_abs_path();
						result2 = result2 !== null ? result2 : "";
						if (result2 !== null) {
							result0 = [result0, result1, result2];
						} else {
							result0 = null;
							pos = pos0;
						}
					} else {
						result0 = null;
						pos = pos0;
					}
				} else {
					result0 = null;
					pos = pos0;
				}
				return result0;
			}

			function parse_abs_path() {
				var result0, result1;
				var pos0;

				pos0 = pos;
				if (input.charCodeAt(pos) === 47) {
					result0 = "/";
					pos++;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"/\"");
					}
				}
				if (result0 !== null) {
					result1 = parse_path_segments();
					if (result1 !== null) {
						result0 = [result0, result1];
					} else {
						result0 = null;
						pos = pos0;
					}
				} else {
					result0 = null;
					pos = pos0;
				}
				return result0;
			}

			function parse_opaque_part() {
				var result0, result1, result2;
				var pos0;

				pos0 = pos;
				result0 = parse_uric_no_slash();
				if (result0 !== null) {
					result1 = [];
					result2 = parse_uric();
					while (result2 !== null) {
						result1.push(result2);
						result2 = parse_uric();
					}
					if (result1 !== null) {
						result0 = [result0, result1];
					} else {
						result0 = null;
						pos = pos0;
					}
				} else {
					result0 = null;
					pos = pos0;
				}
				return result0;
			}

			function parse_uric() {
				var result0;

				result0 = parse_reserved();
				if (result0 === null) {
					result0 = parse_unreserved();
					if (result0 === null) {
						result0 = parse_escaped();
					}
				}
				return result0;
			}

			function parse_uric_no_slash() {
				var result0;

				result0 = parse_unreserved();
				if (result0 === null) {
					result0 = parse_escaped();
					if (result0 === null) {
						if (input.charCodeAt(pos) === 59) {
							result0 = ";";
							pos++;
						} else {
							result0 = null;
							if (reportFailures === 0) {
								matchFailed("\";\"");
							}
						}
						if (result0 === null) {
							if (input.charCodeAt(pos) === 63) {
								result0 = "?";
								pos++;
							} else {
								result0 = null;
								if (reportFailures === 0) {
									matchFailed("\"?\"");
								}
							}
							if (result0 === null) {
								if (input.charCodeAt(pos) === 58) {
									result0 = ":";
									pos++;
								} else {
									result0 = null;
									if (reportFailures === 0) {
										matchFailed("\":\"");
									}
								}
								if (result0 === null) {
									if (input.charCodeAt(pos) === 64) {
										result0 = "@";
										pos++;
									} else {
										result0 = null;
										if (reportFailures === 0) {
											matchFailed("\"@\"");
										}
									}
									if (result0 === null) {
										if (input.charCodeAt(pos) === 38) {
											result0 = "&";
											pos++;
										} else {
											result0 = null;
											if (reportFailures === 0) {
												matchFailed("\"&\"");
											}
										}
										if (result0 === null) {
											if (input.charCodeAt(pos) === 61) {
												result0 = "=";
												pos++;
											} else {
												result0 = null;
												if (reportFailures === 0) {
													matchFailed("\"=\"");
												}
											}
											if (result0 === null) {
												if (input.charCodeAt(pos) === 43) {
													result0 = "+";
													pos++;
												} else {
													result0 = null;
													if (reportFailures === 0) {
														matchFailed("\"+\"");
													}
												}
												if (result0 === null) {
													if (input.charCodeAt(pos) === 36) {
														result0 = "$";
														pos++;
													} else {
														result0 = null;
														if (reportFailures === 0) {
															matchFailed("\"$\"");
														}
													}
													if (result0 === null) {
														if (input.charCodeAt(pos) === 44) {
															result0 = ",";
															pos++;
														} else {
															result0 = null;
															if (reportFailures === 0) {
																matchFailed("\",\"");
															}
														}
													}
												}
											}
										}
									}
								}
							}
						}
					}
				}
				return result0;
			}

			function parse_path_segments() {
				var result0, result1, result2, result3;
				var pos0, pos1;

				pos0 = pos;
				result0 = parse_segment();
				if (result0 !== null) {
					result1 = [];
					pos1 = pos;
					if (input.charCodeAt(pos) === 47) {
						result2 = "/";
						pos++;
					} else {
						result2 = null;
						if (reportFailures === 0) {
							matchFailed("\"/\"");
						}
					}
					if (result2 !== null) {
						result3 = parse_segment();
						if (result3 !== null) {
							result2 = [result2, result3];
						} else {
							result2 = null;
							pos = pos1;
						}
					} else {
						result2 = null;
						pos = pos1;
					}
					while (result2 !== null) {
						result1.push(result2);
						pos1 = pos;
						if (input.charCodeAt(pos) === 47) {
							result2 = "/";
							pos++;
						} else {
							result2 = null;
							if (reportFailures === 0) {
								matchFailed("\"/\"");
							}
						}
						if (result2 !== null) {
							result3 = parse_segment();
							if (result3 !== null) {
								result2 = [result2, result3];
							} else {
								result2 = null;
								pos = pos1;
							}
						} else {
							result2 = null;
							pos = pos1;
						}
					}
					if (result1 !== null) {
						result0 = [result0, result1];
					} else {
						result0 = null;
						pos = pos0;
					}
				} else {
					result0 = null;
					pos = pos0;
				}
				return result0;
			}

			function parse_segment() {
				var result0, result1, result2, result3;
				var pos0, pos1;

				pos0 = pos;
				result0 = [];
				result1 = parse_pchar();
				while (result1 !== null) {
					result0.push(result1);
					result1 = parse_pchar();
				}
				if (result0 !== null) {
					result1 = [];
					pos1 = pos;
					if (input.charCodeAt(pos) === 59) {
						result2 = ";";
						pos++;
					} else {
						result2 = null;
						if (reportFailures === 0) {
							matchFailed("\";\"");
						}
					}
					if (result2 !== null) {
						result3 = parse_param();
						if (result3 !== null) {
							result2 = [result2, result3];
						} else {
							result2 = null;
							pos = pos1;
						}
					} else {
						result2 = null;
						pos = pos1;
					}
					while (result2 !== null) {
						result1.push(result2);
						pos1 = pos;
						if (input.charCodeAt(pos) === 59) {
							result2 = ";";
							pos++;
						} else {
							result2 = null;
							if (reportFailures === 0) {
								matchFailed("\";\"");
							}
						}
						if (result2 !== null) {
							result3 = parse_param();
							if (result3 !== null) {
								result2 = [result2, result3];
							} else {
								result2 = null;
								pos = pos1;
							}
						} else {
							result2 = null;
							pos = pos1;
						}
					}
					if (result1 !== null) {
						result0 = [result0, result1];
					} else {
						result0 = null;
						pos = pos0;
					}
				} else {
					result0 = null;
					pos = pos0;
				}
				return result0;
			}

			function parse_param() {
				var result0, result1;

				result0 = [];
				result1 = parse_pchar();
				while (result1 !== null) {
					result0.push(result1);
					result1 = parse_pchar();
				}
				return result0;
			}

			function parse_pchar() {
				var result0;

				result0 = parse_unreserved();
				if (result0 === null) {
					result0 = parse_escaped();
					if (result0 === null) {
						if (input.charCodeAt(pos) === 58) {
							result0 = ":";
							pos++;
						} else {
							result0 = null;
							if (reportFailures === 0) {
								matchFailed("\":\"");
							}
						}
						if (result0 === null) {
							if (input.charCodeAt(pos) === 64) {
								result0 = "@";
								pos++;
							} else {
								result0 = null;
								if (reportFailures === 0) {
									matchFailed("\"@\"");
								}
							}
							if (result0 === null) {
								if (input.charCodeAt(pos) === 38) {
									result0 = "&";
									pos++;
								} else {
									result0 = null;
									if (reportFailures === 0) {
										matchFailed("\"&\"");
									}
								}
								if (result0 === null) {
									if (input.charCodeAt(pos) === 61) {
										result0 = "=";
										pos++;
									} else {
										result0 = null;
										if (reportFailures === 0) {
											matchFailed("\"=\"");
										}
									}
									if (result0 === null) {
										if (input.charCodeAt(pos) === 43) {
											result0 = "+";
											pos++;
										} else {
											result0 = null;
											if (reportFailures === 0) {
												matchFailed("\"+\"");
											}
										}
										if (result0 === null) {
											if (input.charCodeAt(pos) === 36) {
												result0 = "$";
												pos++;
											} else {
												result0 = null;
												if (reportFailures === 0) {
													matchFailed("\"$\"");
												}
											}
											if (result0 === null) {
												if (input.charCodeAt(pos) === 44) {
													result0 = ",";
													pos++;
												} else {
													result0 = null;
													if (reportFailures === 0) {
														matchFailed("\",\"");
													}
												}
											}
										}
									}
								}
							}
						}
					}
				}
				return result0;
			}

			function parse_scheme() {
				var result0, result1, result2;
				var pos0, pos1;

				pos0 = pos;
				pos1 = pos;
				result0 = parse_ALPHA();
				if (result0 !== null) {
					result1 = [];
					result2 = parse_ALPHA();
					if (result2 === null) {
						result2 = parse_DIGIT();
						if (result2 === null) {
							if (input.charCodeAt(pos) === 43) {
								result2 = "+";
								pos++;
							} else {
								result2 = null;
								if (reportFailures === 0) {
									matchFailed("\"+\"");
								}
							}
							if (result2 === null) {
								if (input.charCodeAt(pos) === 45) {
									result2 = "-";
									pos++;
								} else {
									result2 = null;
									if (reportFailures === 0) {
										matchFailed("\"-\"");
									}
								}
								if (result2 === null) {
									if (input.charCodeAt(pos) === 46) {
										result2 = ".";
										pos++;
									} else {
										result2 = null;
										if (reportFailures === 0) {
											matchFailed("\".\"");
										}
									}
								}
							}
						}
					}
					while (result2 !== null) {
						result1.push(result2);
						result2 = parse_ALPHA();
						if (result2 === null) {
							result2 = parse_DIGIT();
							if (result2 === null) {
								if (input.charCodeAt(pos) === 43) {
									result2 = "+";
									pos++;
								} else {
									result2 = null;
									if (reportFailures === 0) {
										matchFailed("\"+\"");
									}
								}
								if (result2 === null) {
									if (input.charCodeAt(pos) === 45) {
										result2 = "-";
										pos++;
									} else {
										result2 = null;
										if (reportFailures === 0) {
											matchFailed("\"-\"");
										}
									}
									if (result2 === null) {
										if (input.charCodeAt(pos) === 46) {
											result2 = ".";
											pos++;
										} else {
											result2 = null;
											if (reportFailures === 0) {
												matchFailed("\".\"");
											}
										}
									}
								}
							}
						}
					}
					if (result1 !== null) {
						result0 = [result0, result1];
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset) {
						data.scheme = input.substring(pos, offset);
					})(pos0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_authority() {
				var result0;

				result0 = parse_srvr();
				if (result0 === null) {
					result0 = parse_reg_name();
				}
				return result0;
			}

			function parse_srvr() {
				var result0, result1;
				var pos0, pos1;

				pos0 = pos;
				pos1 = pos;
				result0 = parse_userinfo();
				if (result0 !== null) {
					if (input.charCodeAt(pos) === 64) {
						result1 = "@";
						pos++;
					} else {
						result1 = null;
						if (reportFailures === 0) {
							matchFailed("\"@\"");
						}
					}
					if (result1 !== null) {
						result0 = [result0, result1];
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				result0 = result0 !== null ? result0 : "";
				if (result0 !== null) {
					result1 = parse_hostport();
					if (result1 !== null) {
						result0 = [result0, result1];
					} else {
						result0 = null;
						pos = pos0;
					}
				} else {
					result0 = null;
					pos = pos0;
				}
				result0 = result0 !== null ? result0 : "";
				return result0;
			}

			function parse_reg_name() {
				var result0, result1;

				result1 = parse_unreserved();
				if (result1 === null) {
					result1 = parse_escaped();
					if (result1 === null) {
						if (input.charCodeAt(pos) === 36) {
							result1 = "$";
							pos++;
						} else {
							result1 = null;
							if (reportFailures === 0) {
								matchFailed("\"$\"");
							}
						}
						if (result1 === null) {
							if (input.charCodeAt(pos) === 44) {
								result1 = ",";
								pos++;
							} else {
								result1 = null;
								if (reportFailures === 0) {
									matchFailed("\",\"");
								}
							}
							if (result1 === null) {
								if (input.charCodeAt(pos) === 59) {
									result1 = ";";
									pos++;
								} else {
									result1 = null;
									if (reportFailures === 0) {
										matchFailed("\";\"");
									}
								}
								if (result1 === null) {
									if (input.charCodeAt(pos) === 58) {
										result1 = ":";
										pos++;
									} else {
										result1 = null;
										if (reportFailures === 0) {
											matchFailed("\":\"");
										}
									}
									if (result1 === null) {
										if (input.charCodeAt(pos) === 64) {
											result1 = "@";
											pos++;
										} else {
											result1 = null;
											if (reportFailures === 0) {
												matchFailed("\"@\"");
											}
										}
										if (result1 === null) {
											if (input.charCodeAt(pos) === 38) {
												result1 = "&";
												pos++;
											} else {
												result1 = null;
												if (reportFailures === 0) {
													matchFailed("\"&\"");
												}
											}
											if (result1 === null) {
												if (input.charCodeAt(pos) === 61) {
													result1 = "=";
													pos++;
												} else {
													result1 = null;
													if (reportFailures === 0) {
														matchFailed("\"=\"");
													}
												}
												if (result1 === null) {
													if (input.charCodeAt(pos) === 43) {
														result1 = "+";
														pos++;
													} else {
														result1 = null;
														if (reportFailures === 0) {
															matchFailed("\"+\"");
														}
													}
												}
											}
										}
									}
								}
							}
						}
					}
				}
				if (result1 !== null) {
					result0 = [];
					while (result1 !== null) {
						result0.push(result1);
						result1 = parse_unreserved();
						if (result1 === null) {
							result1 = parse_escaped();
							if (result1 === null) {
								if (input.charCodeAt(pos) === 36) {
									result1 = "$";
									pos++;
								} else {
									result1 = null;
									if (reportFailures === 0) {
										matchFailed("\"$\"");
									}
								}
								if (result1 === null) {
									if (input.charCodeAt(pos) === 44) {
										result1 = ",";
										pos++;
									} else {
										result1 = null;
										if (reportFailures === 0) {
											matchFailed("\",\"");
										}
									}
									if (result1 === null) {
										if (input.charCodeAt(pos) === 59) {
											result1 = ";";
											pos++;
										} else {
											result1 = null;
											if (reportFailures === 0) {
												matchFailed("\";\"");
											}
										}
										if (result1 === null) {
											if (input.charCodeAt(pos) === 58) {
												result1 = ":";
												pos++;
											} else {
												result1 = null;
												if (reportFailures === 0) {
													matchFailed("\":\"");
												}
											}
											if (result1 === null) {
												if (input.charCodeAt(pos) === 64) {
													result1 = "@";
													pos++;
												} else {
													result1 = null;
													if (reportFailures === 0) {
														matchFailed("\"@\"");
													}
												}
												if (result1 === null) {
													if (input.charCodeAt(pos) === 38) {
														result1 = "&";
														pos++;
													} else {
														result1 = null;
														if (reportFailures === 0) {
															matchFailed("\"&\"");
														}
													}
													if (result1 === null) {
														if (input.charCodeAt(pos) === 61) {
															result1 = "=";
															pos++;
														} else {
															result1 = null;
															if (reportFailures === 0) {
																matchFailed("\"=\"");
															}
														}
														if (result1 === null) {
															if (input.charCodeAt(pos) === 43) {
																result1 = "+";
																pos++;
															} else {
																result1 = null;
																if (reportFailures === 0) {
																	matchFailed("\"+\"");
																}
															}
														}
													}
												}
											}
										}
									}
								}
							}
						}
					}
				} else {
					result0 = null;
				}
				return result0;
			}

			function parse_query() {
				var result0, result1;

				result0 = [];
				result1 = parse_uric();
				while (result1 !== null) {
					result0.push(result1);
					result1 = parse_uric();
				}
				return result0;
			}

			function parse_SIP_Version() {
				var result0, result1, result2, result3, result4, result5;
				var pos0, pos1;

				pos0 = pos;
				pos1 = pos;
				if (input.substr(pos, 3).toLowerCase() === "sip") {
					result0 = input.substr(pos, 3);
					pos += 3;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"SIP\"");
					}
				}
				if (result0 !== null) {
					if (input.charCodeAt(pos) === 47) {
						result1 = "/";
						pos++;
					} else {
						result1 = null;
						if (reportFailures === 0) {
							matchFailed("\"/\"");
						}
					}
					if (result1 !== null) {
						result3 = parse_DIGIT();
						if (result3 !== null) {
							result2 = [];
							while (result3 !== null) {
								result2.push(result3);
								result3 = parse_DIGIT();
							}
						} else {
							result2 = null;
						}
						if (result2 !== null) {
							if (input.charCodeAt(pos) === 46) {
								result3 = ".";
								pos++;
							} else {
								result3 = null;
								if (reportFailures === 0) {
									matchFailed("\".\"");
								}
							}
							if (result3 !== null) {
								result5 = parse_DIGIT();
								if (result5 !== null) {
									result4 = [];
									while (result5 !== null) {
										result4.push(result5);
										result5 = parse_DIGIT();
									}
								} else {
									result4 = null;
								}
								if (result4 !== null) {
									result0 = [result0, result1, result2, result3, result4];
								} else {
									result0 = null;
									pos = pos1;
								}
							} else {
								result0 = null;
								pos = pos1;
							}
						} else {
							result0 = null;
							pos = pos1;
						}
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset) {
						data.sip_version = input.substring(pos, offset);
					})(pos0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_INVITEm() {
				var result0;

				if (input.substr(pos, 6) === "INVITE") {
					result0 = "INVITE";
					pos += 6;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"INVITE\"");
					}
				}
				return result0;
			}

			function parse_ACKm() {
				var result0;

				if (input.substr(pos, 3) === "ACK") {
					result0 = "ACK";
					pos += 3;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"ACK\"");
					}
				}
				return result0;
			}

			function parse_OPTIONSm() {
				var result0;

				if (input.substr(pos, 7) === "OPTIONS") {
					result0 = "OPTIONS";
					pos += 7;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"OPTIONS\"");
					}
				}
				return result0;
			}

			function parse_BYEm() {
				var result0;

				if (input.substr(pos, 3) === "BYE") {
					result0 = "BYE";
					pos += 3;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"BYE\"");
					}
				}
				return result0;
			}

			function parse_CANCELm() {
				var result0;

				if (input.substr(pos, 6) === "CANCEL") {
					result0 = "CANCEL";
					pos += 6;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"CANCEL\"");
					}
				}
				return result0;
			}

			function parse_REGISTERm() {
				var result0;

				if (input.substr(pos, 8) === "REGISTER") {
					result0 = "REGISTER";
					pos += 8;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"REGISTER\"");
					}
				}
				return result0;
			}

			function parse_SUBSCRIBEm() {
				var result0;

				if (input.substr(pos, 9) === "SUBSCRIBE") {
					result0 = "SUBSCRIBE";
					pos += 9;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"SUBSCRIBE\"");
					}
				}
				return result0;
			}

			function parse_NOTIFYm() {
				var result0;

				if (input.substr(pos, 6) === "NOTIFY") {
					result0 = "NOTIFY";
					pos += 6;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"NOTIFY\"");
					}
				}
				return result0;
			}

			function parse_Method() {
				var result0;
				var pos0;

				pos0 = pos;
				result0 = parse_INVITEm();
				if (result0 === null) {
					result0 = parse_ACKm();
					if (result0 === null) {
						result0 = parse_OPTIONSm();
						if (result0 === null) {
							result0 = parse_BYEm();
							if (result0 === null) {
								result0 = parse_CANCELm();
								if (result0 === null) {
									result0 = parse_REGISTERm();
									if (result0 === null) {
										result0 = parse_SUBSCRIBEm();
										if (result0 === null) {
											result0 = parse_NOTIFYm();
											if (result0 === null) {
												result0 = parse_token();
											}
										}
									}
								}
							}
						}
					}
				}
				if (result0 !== null) {
					result0 = (function (offset) {
						data.method = input.substring(pos, offset);
						return data.method;
					})(pos0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_Status_Line() {
				var result0, result1, result2, result3, result4;
				var pos0;

				pos0 = pos;
				result0 = parse_SIP_Version();
				if (result0 !== null) {
					result1 = parse_SP();
					if (result1 !== null) {
						result2 = parse_Status_Code();
						if (result2 !== null) {
							result3 = parse_SP();
							if (result3 !== null) {
								result4 = parse_Reason_Phrase();
								if (result4 !== null) {
									result0 = [result0, result1, result2, result3, result4];
								} else {
									result0 = null;
									pos = pos0;
								}
							} else {
								result0 = null;
								pos = pos0;
							}
						} else {
							result0 = null;
							pos = pos0;
						}
					} else {
						result0 = null;
						pos = pos0;
					}
				} else {
					result0 = null;
					pos = pos0;
				}
				return result0;
			}

			function parse_Status_Code() {
				var result0;
				var pos0;

				pos0 = pos;
				result0 = parse_extension_code();
				if (result0 !== null) {
					result0 = (function (offset, status_code) {
						data.status_code = parseInt(status_code.join(''));
					})(pos0, result0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_extension_code() {
				var result0, result1, result2;
				var pos0;

				pos0 = pos;
				result0 = parse_DIGIT();
				if (result0 !== null) {
					result1 = parse_DIGIT();
					if (result1 !== null) {
						result2 = parse_DIGIT();
						if (result2 !== null) {
							result0 = [result0, result1, result2];
						} else {
							result0 = null;
							pos = pos0;
						}
					} else {
						result0 = null;
						pos = pos0;
					}
				} else {
					result0 = null;
					pos = pos0;
				}
				return result0;
			}

			function parse_Reason_Phrase() {
				var result0, result1;
				var pos0;

				pos0 = pos;
				result0 = [];
				result1 = parse_reserved();
				if (result1 === null) {
					result1 = parse_unreserved();
					if (result1 === null) {
						result1 = parse_escaped();
						if (result1 === null) {
							result1 = parse_UTF8_NONASCII();
							if (result1 === null) {
								result1 = parse_UTF8_CONT();
								if (result1 === null) {
									result1 = parse_SP();
									if (result1 === null) {
										result1 = parse_HTAB();
									}
								}
							}
						}
					}
				}
				while (result1 !== null) {
					result0.push(result1);
					result1 = parse_reserved();
					if (result1 === null) {
						result1 = parse_unreserved();
						if (result1 === null) {
							result1 = parse_escaped();
							if (result1 === null) {
								result1 = parse_UTF8_NONASCII();
								if (result1 === null) {
									result1 = parse_UTF8_CONT();
									if (result1 === null) {
										result1 = parse_SP();
										if (result1 === null) {
											result1 = parse_HTAB();
										}
									}
								}
							}
						}
					}
				}
				if (result0 !== null) {
					result0 = (function (offset) {
						data.reason_phrase = input.substring(pos, offset);
					})(pos0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_Allow_Events() {
				var result0, result1, result2, result3;
				var pos0, pos1;

				pos0 = pos;
				result0 = parse_event_type();
				if (result0 !== null) {
					result1 = [];
					pos1 = pos;
					result2 = parse_COMMA();
					if (result2 !== null) {
						result3 = parse_event_type();
						if (result3 !== null) {
							result2 = [result2, result3];
						} else {
							result2 = null;
							pos = pos1;
						}
					} else {
						result2 = null;
						pos = pos1;
					}
					while (result2 !== null) {
						result1.push(result2);
						pos1 = pos;
						result2 = parse_COMMA();
						if (result2 !== null) {
							result3 = parse_event_type();
							if (result3 !== null) {
								result2 = [result2, result3];
							} else {
								result2 = null;
								pos = pos1;
							}
						} else {
							result2 = null;
							pos = pos1;
						}
					}
					if (result1 !== null) {
						result0 = [result0, result1];
					} else {
						result0 = null;
						pos = pos0;
					}
				} else {
					result0 = null;
					pos = pos0;
				}
				return result0;
			}

			function parse_Call_ID() {
				var result0, result1, result2;
				var pos0, pos1, pos2;

				pos0 = pos;
				pos1 = pos;
				result0 = parse_word();
				if (result0 !== null) {
					pos2 = pos;
					if (input.charCodeAt(pos) === 64) {
						result1 = "@";
						pos++;
					} else {
						result1 = null;
						if (reportFailures === 0) {
							matchFailed("\"@\"");
						}
					}
					if (result1 !== null) {
						result2 = parse_word();
						if (result2 !== null) {
							result1 = [result1, result2];
						} else {
							result1 = null;
							pos = pos2;
						}
					} else {
						result1 = null;
						pos = pos2;
					}
					result1 = result1 !== null ? result1 : "";
					if (result1 !== null) {
						result0 = [result0, result1];
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset) {
						data = input.substring(pos, offset);
					})(pos0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_Contact() {
				var result0, result1, result2, result3;
				var pos0, pos1, pos2;

				pos0 = pos;
				result0 = parse_STAR();
				if (result0 === null) {
					pos1 = pos;
					result0 = parse_contact_param();
					if (result0 !== null) {
						result1 = [];
						pos2 = pos;
						result2 = parse_COMMA();
						if (result2 !== null) {
							result3 = parse_contact_param();
							if (result3 !== null) {
								result2 = [result2, result3];
							} else {
								result2 = null;
								pos = pos2;
							}
						} else {
							result2 = null;
							pos = pos2;
						}
						while (result2 !== null) {
							result1.push(result2);
							pos2 = pos;
							result2 = parse_COMMA();
							if (result2 !== null) {
								result3 = parse_contact_param();
								if (result3 !== null) {
									result2 = [result2, result3];
								} else {
									result2 = null;
									pos = pos2;
								}
							} else {
								result2 = null;
								pos = pos2;
							}
						}
						if (result1 !== null) {
							result0 = [result0, result1];
						} else {
							result0 = null;
							pos = pos1;
						}
					} else {
						result0 = null;
						pos = pos1;
					}
				}
				if (result0 !== null) {
					result0 = (function (offset) {
						var idx;
						for (idx in data.multi_header) {
							if (data.multi_header[idx].parsed === null) {
								data = null;
								break;
							}
						}
						if (data !== null) {
							data = data.multi_header;
						} else {
							data = -1;
						}
					})(pos0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_contact_param() {
				var result0, result1, result2, result3;
				var pos0, pos1, pos2;

				pos0 = pos;
				pos1 = pos;
				result0 = parse_SIP_URI_noparams();
				if (result0 === null) {
					result0 = parse_name_addr();
				}
				if (result0 !== null) {
					result1 = [];
					pos2 = pos;
					result2 = parse_SEMI();
					if (result2 !== null) {
						result3 = parse_contact_params();
						if (result3 !== null) {
							result2 = [result2, result3];
						} else {
							result2 = null;
							pos = pos2;
						}
					} else {
						result2 = null;
						pos = pos2;
					}
					while (result2 !== null) {
						result1.push(result2);
						pos2 = pos;
						result2 = parse_SEMI();
						if (result2 !== null) {
							result3 = parse_contact_params();
							if (result3 !== null) {
								result2 = [result2, result3];
							} else {
								result2 = null;
								pos = pos2;
							}
						} else {
							result2 = null;
							pos = pos2;
						}
					}
					if (result1 !== null) {
						result0 = [result0, result1];
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset) {
						var header;
						if (!data.multi_header) data.multi_header = [];
						try {
							header = new JsSIP.NameAddrHeader(data.uri, data.display_name, data.params);
							delete data.uri;
							delete data.display_name;
							delete data.params;
						} catch (e) {
							header = null;
						}
						data.multi_header.push({ 'possition': pos,
							'offset': offset,
							'parsed': header
						});
					})(pos0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_name_addr() {
				var result0, result1, result2, result3;
				var pos0;

				pos0 = pos;
				result0 = parse_display_name();
				result0 = result0 !== null ? result0 : "";
				if (result0 !== null) {
					result1 = parse_LAQUOT();
					if (result1 !== null) {
						result2 = parse_SIP_URI();
						if (result2 !== null) {
							result3 = parse_RAQUOT();
							if (result3 !== null) {
								result0 = [result0, result1, result2, result3];
							} else {
								result0 = null;
								pos = pos0;
							}
						} else {
							result0 = null;
							pos = pos0;
						}
					} else {
						result0 = null;
						pos = pos0;
					}
				} else {
					result0 = null;
					pos = pos0;
				}
				return result0;
			}

			function parse_display_name() {
				var result0, result1, result2, result3;
				var pos0, pos1, pos2;

				pos0 = pos;
				pos1 = pos;
				result0 = parse_token();
				if (result0 !== null) {
					result1 = [];
					pos2 = pos;
					result2 = parse_LWS();
					if (result2 !== null) {
						result3 = parse_token();
						if (result3 !== null) {
							result2 = [result2, result3];
						} else {
							result2 = null;
							pos = pos2;
						}
					} else {
						result2 = null;
						pos = pos2;
					}
					while (result2 !== null) {
						result1.push(result2);
						pos2 = pos;
						result2 = parse_LWS();
						if (result2 !== null) {
							result3 = parse_token();
							if (result3 !== null) {
								result2 = [result2, result3];
							} else {
								result2 = null;
								pos = pos2;
							}
						} else {
							result2 = null;
							pos = pos2;
						}
					}
					if (result1 !== null) {
						result0 = [result0, result1];
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 === null) {
					result0 = parse_quoted_string();
				}
				if (result0 !== null) {
					result0 = (function (offset, display_name) {
						display_name = input.substring(pos, offset).trim();
						if (display_name[0] === '\"') {
							display_name = display_name.substring(1, display_name.length - 1);
						}
						data.display_name = display_name;
					})(pos0, result0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_contact_params() {
				var result0;

				result0 = parse_c_p_q();
				if (result0 === null) {
					result0 = parse_c_p_expires();
					if (result0 === null) {
						result0 = parse_generic_param();
					}
				}
				return result0;
			}

			function parse_c_p_q() {
				var result0, result1, result2;
				var pos0, pos1;

				pos0 = pos;
				pos1 = pos;
				if (input.substr(pos, 1).toLowerCase() === "q") {
					result0 = input.substr(pos, 1);
					pos++;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"q\"");
					}
				}
				if (result0 !== null) {
					result1 = parse_EQUAL();
					if (result1 !== null) {
						result2 = parse_qvalue();
						if (result2 !== null) {
							result0 = [result0, result1, result2];
						} else {
							result0 = null;
							pos = pos1;
						}
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset, q) {
						if (!data.params) data.params = {};
						data.params['q'] = q;
					})(pos0, result0[2]);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_c_p_expires() {
				var result0, result1, result2;
				var pos0, pos1;

				pos0 = pos;
				pos1 = pos;
				if (input.substr(pos, 7).toLowerCase() === "expires") {
					result0 = input.substr(pos, 7);
					pos += 7;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"expires\"");
					}
				}
				if (result0 !== null) {
					result1 = parse_EQUAL();
					if (result1 !== null) {
						result2 = parse_delta_seconds();
						if (result2 !== null) {
							result0 = [result0, result1, result2];
						} else {
							result0 = null;
							pos = pos1;
						}
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset, expires) {
						if (!data.params) data.params = {};
						data.params['expires'] = expires;
					})(pos0, result0[2]);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_delta_seconds() {
				var result0, result1;
				var pos0;

				pos0 = pos;
				result1 = parse_DIGIT();
				if (result1 !== null) {
					result0 = [];
					while (result1 !== null) {
						result0.push(result1);
						result1 = parse_DIGIT();
					}
				} else {
					result0 = null;
				}
				if (result0 !== null) {
					result0 = (function (offset, delta_seconds) {
						return parseInt(delta_seconds.join(''));
					})(pos0, result0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_qvalue() {
				var result0, result1, result2, result3, result4;
				var pos0, pos1, pos2;

				pos0 = pos;
				pos1 = pos;
				if (input.charCodeAt(pos) === 48) {
					result0 = "0";
					pos++;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"0\"");
					}
				}
				if (result0 !== null) {
					pos2 = pos;
					if (input.charCodeAt(pos) === 46) {
						result1 = ".";
						pos++;
					} else {
						result1 = null;
						if (reportFailures === 0) {
							matchFailed("\".\"");
						}
					}
					if (result1 !== null) {
						result2 = parse_DIGIT();
						result2 = result2 !== null ? result2 : "";
						if (result2 !== null) {
							result3 = parse_DIGIT();
							result3 = result3 !== null ? result3 : "";
							if (result3 !== null) {
								result4 = parse_DIGIT();
								result4 = result4 !== null ? result4 : "";
								if (result4 !== null) {
									result1 = [result1, result2, result3, result4];
								} else {
									result1 = null;
									pos = pos2;
								}
							} else {
								result1 = null;
								pos = pos2;
							}
						} else {
							result1 = null;
							pos = pos2;
						}
					} else {
						result1 = null;
						pos = pos2;
					}
					result1 = result1 !== null ? result1 : "";
					if (result1 !== null) {
						result0 = [result0, result1];
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset) {
						return parseFloat(input.substring(pos, offset));
					})(pos0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_generic_param() {
				var result0, result1, result2;
				var pos0, pos1, pos2;

				pos0 = pos;
				pos1 = pos;
				result0 = parse_token();
				if (result0 !== null) {
					pos2 = pos;
					result1 = parse_EQUAL();
					if (result1 !== null) {
						result2 = parse_gen_value();
						if (result2 !== null) {
							result1 = [result1, result2];
						} else {
							result1 = null;
							pos = pos2;
						}
					} else {
						result1 = null;
						pos = pos2;
					}
					result1 = result1 !== null ? result1 : "";
					if (result1 !== null) {
						result0 = [result0, result1];
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset, param, value) {
						if (!data.params) data.params = {};
						if (typeof value === 'undefined') {
							value = undefined;
						}
						else {
							value = value[1];
						}
						data.params[param.toLowerCase()] = value;
					})(pos0, result0[0], result0[1]);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_gen_value() {
				var result0;

				result0 = parse_token();
				if (result0 === null) {
					result0 = parse_host();
					if (result0 === null) {
						result0 = parse_quoted_string();
					}
				}
				return result0;
			}

			function parse_Content_Disposition() {
				var result0, result1, result2, result3;
				var pos0, pos1;

				pos0 = pos;
				result0 = parse_disp_type();
				if (result0 !== null) {
					result1 = [];
					pos1 = pos;
					result2 = parse_SEMI();
					if (result2 !== null) {
						result3 = parse_disp_param();
						if (result3 !== null) {
							result2 = [result2, result3];
						} else {
							result2 = null;
							pos = pos1;
						}
					} else {
						result2 = null;
						pos = pos1;
					}
					while (result2 !== null) {
						result1.push(result2);
						pos1 = pos;
						result2 = parse_SEMI();
						if (result2 !== null) {
							result3 = parse_disp_param();
							if (result3 !== null) {
								result2 = [result2, result3];
							} else {
								result2 = null;
								pos = pos1;
							}
						} else {
							result2 = null;
							pos = pos1;
						}
					}
					if (result1 !== null) {
						result0 = [result0, result1];
					} else {
						result0 = null;
						pos = pos0;
					}
				} else {
					result0 = null;
					pos = pos0;
				}
				return result0;
			}

			function parse_disp_type() {
				var result0;

				if (input.substr(pos, 6).toLowerCase() === "render") {
					result0 = input.substr(pos, 6);
					pos += 6;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"render\"");
					}
				}
				if (result0 === null) {
					if (input.substr(pos, 7).toLowerCase() === "session") {
						result0 = input.substr(pos, 7);
						pos += 7;
					} else {
						result0 = null;
						if (reportFailures === 0) {
							matchFailed("\"session\"");
						}
					}
					if (result0 === null) {
						if (input.substr(pos, 4).toLowerCase() === "icon") {
							result0 = input.substr(pos, 4);
							pos += 4;
						} else {
							result0 = null;
							if (reportFailures === 0) {
								matchFailed("\"icon\"");
							}
						}
						if (result0 === null) {
							if (input.substr(pos, 5).toLowerCase() === "alert") {
								result0 = input.substr(pos, 5);
								pos += 5;
							} else {
								result0 = null;
								if (reportFailures === 0) {
									matchFailed("\"alert\"");
								}
							}
							if (result0 === null) {
								result0 = parse_token();
							}
						}
					}
				}
				return result0;
			}

			function parse_disp_param() {
				var result0;

				result0 = parse_handling_param();
				if (result0 === null) {
					result0 = parse_generic_param();
				}
				return result0;
			}

			function parse_handling_param() {
				var result0, result1, result2;
				var pos0;

				pos0 = pos;
				if (input.substr(pos, 8).toLowerCase() === "handling") {
					result0 = input.substr(pos, 8);
					pos += 8;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"handling\"");
					}
				}
				if (result0 !== null) {
					result1 = parse_EQUAL();
					if (result1 !== null) {
						if (input.substr(pos, 8).toLowerCase() === "optional") {
							result2 = input.substr(pos, 8);
							pos += 8;
						} else {
							result2 = null;
							if (reportFailures === 0) {
								matchFailed("\"optional\"");
							}
						}
						if (result2 === null) {
							if (input.substr(pos, 8).toLowerCase() === "required") {
								result2 = input.substr(pos, 8);
								pos += 8;
							} else {
								result2 = null;
								if (reportFailures === 0) {
									matchFailed("\"required\"");
								}
							}
							if (result2 === null) {
								result2 = parse_token();
							}
						}
						if (result2 !== null) {
							result0 = [result0, result1, result2];
						} else {
							result0 = null;
							pos = pos0;
						}
					} else {
						result0 = null;
						pos = pos0;
					}
				} else {
					result0 = null;
					pos = pos0;
				}
				return result0;
			}

			function parse_Content_Encoding() {
				var result0, result1, result2, result3;
				var pos0, pos1;

				pos0 = pos;
				result0 = parse_token();
				if (result0 !== null) {
					result1 = [];
					pos1 = pos;
					result2 = parse_COMMA();
					if (result2 !== null) {
						result3 = parse_token();
						if (result3 !== null) {
							result2 = [result2, result3];
						} else {
							result2 = null;
							pos = pos1;
						}
					} else {
						result2 = null;
						pos = pos1;
					}
					while (result2 !== null) {
						result1.push(result2);
						pos1 = pos;
						result2 = parse_COMMA();
						if (result2 !== null) {
							result3 = parse_token();
							if (result3 !== null) {
								result2 = [result2, result3];
							} else {
								result2 = null;
								pos = pos1;
							}
						} else {
							result2 = null;
							pos = pos1;
						}
					}
					if (result1 !== null) {
						result0 = [result0, result1];
					} else {
						result0 = null;
						pos = pos0;
					}
				} else {
					result0 = null;
					pos = pos0;
				}
				return result0;
			}

			function parse_Content_Length() {
				var result0, result1;
				var pos0;

				pos0 = pos;
				result1 = parse_DIGIT();
				if (result1 !== null) {
					result0 = [];
					while (result1 !== null) {
						result0.push(result1);
						result1 = parse_DIGIT();
					}
				} else {
					result0 = null;
				}
				if (result0 !== null) {
					result0 = (function (offset, length) {
						data = parseInt(length.join(''));
					})(pos0, result0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_Content_Type() {
				var result0;
				var pos0;

				pos0 = pos;
				result0 = parse_media_type();
				if (result0 !== null) {
					result0 = (function (offset) {
						data = input.substring(pos, offset);
					})(pos0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_media_type() {
				var result0, result1, result2, result3, result4, result5;
				var pos0, pos1;

				pos0 = pos;
				result0 = parse_m_type();
				if (result0 !== null) {
					result1 = parse_SLASH();
					if (result1 !== null) {
						result2 = parse_m_subtype();
						if (result2 !== null) {
							result3 = [];
							pos1 = pos;
							result4 = parse_SEMI();
							if (result4 !== null) {
								result5 = parse_m_parameter();
								if (result5 !== null) {
									result4 = [result4, result5];
								} else {
									result4 = null;
									pos = pos1;
								}
							} else {
								result4 = null;
								pos = pos1;
							}
							while (result4 !== null) {
								result3.push(result4);
								pos1 = pos;
								result4 = parse_SEMI();
								if (result4 !== null) {
									result5 = parse_m_parameter();
									if (result5 !== null) {
										result4 = [result4, result5];
									} else {
										result4 = null;
										pos = pos1;
									}
								} else {
									result4 = null;
									pos = pos1;
								}
							}
							if (result3 !== null) {
								result0 = [result0, result1, result2, result3];
							} else {
								result0 = null;
								pos = pos0;
							}
						} else {
							result0 = null;
							pos = pos0;
						}
					} else {
						result0 = null;
						pos = pos0;
					}
				} else {
					result0 = null;
					pos = pos0;
				}
				return result0;
			}

			function parse_m_type() {
				var result0;

				result0 = parse_discrete_type();
				if (result0 === null) {
					result0 = parse_composite_type();
				}
				return result0;
			}

			function parse_discrete_type() {
				var result0;

				if (input.substr(pos, 4).toLowerCase() === "text") {
					result0 = input.substr(pos, 4);
					pos += 4;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"text\"");
					}
				}
				if (result0 === null) {
					if (input.substr(pos, 5).toLowerCase() === "image") {
						result0 = input.substr(pos, 5);
						pos += 5;
					} else {
						result0 = null;
						if (reportFailures === 0) {
							matchFailed("\"image\"");
						}
					}
					if (result0 === null) {
						if (input.substr(pos, 5).toLowerCase() === "audio") {
							result0 = input.substr(pos, 5);
							pos += 5;
						} else {
							result0 = null;
							if (reportFailures === 0) {
								matchFailed("\"audio\"");
							}
						}
						if (result0 === null) {
							if (input.substr(pos, 5).toLowerCase() === "video") {
								result0 = input.substr(pos, 5);
								pos += 5;
							} else {
								result0 = null;
								if (reportFailures === 0) {
									matchFailed("\"video\"");
								}
							}
							if (result0 === null) {
								if (input.substr(pos, 11).toLowerCase() === "application") {
									result0 = input.substr(pos, 11);
									pos += 11;
								} else {
									result0 = null;
									if (reportFailures === 0) {
										matchFailed("\"application\"");
									}
								}
								if (result0 === null) {
									result0 = parse_extension_token();
								}
							}
						}
					}
				}
				return result0;
			}

			function parse_composite_type() {
				var result0;

				if (input.substr(pos, 7).toLowerCase() === "message") {
					result0 = input.substr(pos, 7);
					pos += 7;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"message\"");
					}
				}
				if (result0 === null) {
					if (input.substr(pos, 9).toLowerCase() === "multipart") {
						result0 = input.substr(pos, 9);
						pos += 9;
					} else {
						result0 = null;
						if (reportFailures === 0) {
							matchFailed("\"multipart\"");
						}
					}
					if (result0 === null) {
						result0 = parse_extension_token();
					}
				}
				return result0;
			}

			function parse_extension_token() {
				var result0;

				result0 = parse_token();
				if (result0 === null) {
					result0 = parse_x_token();
				}
				return result0;
			}

			function parse_x_token() {
				var result0, result1;
				var pos0;

				pos0 = pos;
				if (input.substr(pos, 2).toLowerCase() === "x-") {
					result0 = input.substr(pos, 2);
					pos += 2;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"x-\"");
					}
				}
				if (result0 !== null) {
					result1 = parse_token();
					if (result1 !== null) {
						result0 = [result0, result1];
					} else {
						result0 = null;
						pos = pos0;
					}
				} else {
					result0 = null;
					pos = pos0;
				}
				return result0;
			}

			function parse_m_subtype() {
				var result0;

				result0 = parse_extension_token();
				if (result0 === null) {
					result0 = parse_token();
				}
				return result0;
			}

			function parse_m_parameter() {
				var result0, result1, result2;
				var pos0;

				pos0 = pos;
				result0 = parse_token();
				if (result0 !== null) {
					result1 = parse_EQUAL();
					if (result1 !== null) {
						result2 = parse_m_value();
						if (result2 !== null) {
							result0 = [result0, result1, result2];
						} else {
							result0 = null;
							pos = pos0;
						}
					} else {
						result0 = null;
						pos = pos0;
					}
				} else {
					result0 = null;
					pos = pos0;
				}
				return result0;
			}

			function parse_m_value() {
				var result0;

				result0 = parse_token();
				if (result0 === null) {
					result0 = parse_quoted_string();
				}
				return result0;
			}

			function parse_CSeq() {
				var result0, result1, result2;
				var pos0;

				pos0 = pos;
				result0 = parse_CSeq_value();
				if (result0 !== null) {
					result1 = parse_LWS();
					if (result1 !== null) {
						result2 = parse_Method();
						if (result2 !== null) {
							result0 = [result0, result1, result2];
						} else {
							result0 = null;
							pos = pos0;
						}
					} else {
						result0 = null;
						pos = pos0;
					}
				} else {
					result0 = null;
					pos = pos0;
				}
				return result0;
			}

			function parse_CSeq_value() {
				var result0, result1;
				var pos0;

				pos0 = pos;
				result1 = parse_DIGIT();
				if (result1 !== null) {
					result0 = [];
					while (result1 !== null) {
						result0.push(result1);
						result1 = parse_DIGIT();
					}
				} else {
					result0 = null;
				}
				if (result0 !== null) {
					result0 = (function (offset, cseq_value) {
						data.value = parseInt(cseq_value.join(''));
					})(pos0, result0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_Expires() {
				var result0;
				var pos0;

				pos0 = pos;
				result0 = parse_delta_seconds();
				if (result0 !== null) {
					result0 = (function (offset, expires) {
						data = expires;
					})(pos0, result0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_Event() {
				var result0, result1, result2, result3;
				var pos0, pos1, pos2;

				pos0 = pos;
				pos1 = pos;
				result0 = parse_event_type();
				if (result0 !== null) {
					result1 = [];
					pos2 = pos;
					result2 = parse_SEMI();
					if (result2 !== null) {
						result3 = parse_generic_param();
						if (result3 !== null) {
							result2 = [result2, result3];
						} else {
							result2 = null;
							pos = pos2;
						}
					} else {
						result2 = null;
						pos = pos2;
					}
					while (result2 !== null) {
						result1.push(result2);
						pos2 = pos;
						result2 = parse_SEMI();
						if (result2 !== null) {
							result3 = parse_generic_param();
							if (result3 !== null) {
								result2 = [result2, result3];
							} else {
								result2 = null;
								pos = pos2;
							}
						} else {
							result2 = null;
							pos = pos2;
						}
					}
					if (result1 !== null) {
						result0 = [result0, result1];
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset, event_type) {
						data.event = event_type.join('').toLowerCase();
					})(pos0, result0[0]);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_event_type() {
				var result0, result1, result2, result3;
				var pos0, pos1;

				pos0 = pos;
				result0 = parse_token_nodot();
				if (result0 !== null) {
					result1 = [];
					pos1 = pos;
					if (input.charCodeAt(pos) === 46) {
						result2 = ".";
						pos++;
					} else {
						result2 = null;
						if (reportFailures === 0) {
							matchFailed("\".\"");
						}
					}
					if (result2 !== null) {
						result3 = parse_token_nodot();
						if (result3 !== null) {
							result2 = [result2, result3];
						} else {
							result2 = null;
							pos = pos1;
						}
					} else {
						result2 = null;
						pos = pos1;
					}
					while (result2 !== null) {
						result1.push(result2);
						pos1 = pos;
						if (input.charCodeAt(pos) === 46) {
							result2 = ".";
							pos++;
						} else {
							result2 = null;
							if (reportFailures === 0) {
								matchFailed("\".\"");
							}
						}
						if (result2 !== null) {
							result3 = parse_token_nodot();
							if (result3 !== null) {
								result2 = [result2, result3];
							} else {
								result2 = null;
								pos = pos1;
							}
						} else {
							result2 = null;
							pos = pos1;
						}
					}
					if (result1 !== null) {
						result0 = [result0, result1];
					} else {
						result0 = null;
						pos = pos0;
					}
				} else {
					result0 = null;
					pos = pos0;
				}
				return result0;
			}

			function parse_From() {
				var result0, result1, result2, result3;
				var pos0, pos1, pos2;

				pos0 = pos;
				pos1 = pos;
				result0 = parse_SIP_URI_noparams();
				if (result0 === null) {
					result0 = parse_name_addr();
				}
				if (result0 !== null) {
					result1 = [];
					pos2 = pos;
					result2 = parse_SEMI();
					if (result2 !== null) {
						result3 = parse_from_param();
						if (result3 !== null) {
							result2 = [result2, result3];
						} else {
							result2 = null;
							pos = pos2;
						}
					} else {
						result2 = null;
						pos = pos2;
					}
					while (result2 !== null) {
						result1.push(result2);
						pos2 = pos;
						result2 = parse_SEMI();
						if (result2 !== null) {
							result3 = parse_from_param();
							if (result3 !== null) {
								result2 = [result2, result3];
							} else {
								result2 = null;
								pos = pos2;
							}
						} else {
							result2 = null;
							pos = pos2;
						}
					}
					if (result1 !== null) {
						result0 = [result0, result1];
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset) {
						var tag = data.tag;
						try {
							data = new JsSIP.NameAddrHeader(data.uri, data.display_name, data.params);
							if (tag) {
								data.setParam('tag', tag)
							}
						} catch (e) {
							data = -1;
						}
					})(pos0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_from_param() {
				var result0;

				result0 = parse_tag_param();
				if (result0 === null) {
					result0 = parse_generic_param();
				}
				return result0;
			}

			function parse_tag_param() {
				var result0, result1, result2;
				var pos0, pos1;

				pos0 = pos;
				pos1 = pos;
				if (input.substr(pos, 3).toLowerCase() === "tag") {
					result0 = input.substr(pos, 3);
					pos += 3;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"tag\"");
					}
				}
				if (result0 !== null) {
					result1 = parse_EQUAL();
					if (result1 !== null) {
						result2 = parse_token();
						if (result2 !== null) {
							result0 = [result0, result1, result2];
						} else {
							result0 = null;
							pos = pos1;
						}
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset, tag) {
						data.tag = tag;
					})(pos0, result0[2]);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_Max_Forwards() {
				var result0, result1;
				var pos0;

				pos0 = pos;
				result1 = parse_DIGIT();
				if (result1 !== null) {
					result0 = [];
					while (result1 !== null) {
						result0.push(result1);
						result1 = parse_DIGIT();
					}
				} else {
					result0 = null;
				}
				if (result0 !== null) {
					result0 = (function (offset, forwards) {
						data = parseInt(forwards.join(''));
					})(pos0, result0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_Min_Expires() {
				var result0;
				var pos0;

				pos0 = pos;
				result0 = parse_delta_seconds();
				if (result0 !== null) {
					result0 = (function (offset, min_expires) {
						data = min_expires;
					})(pos0, result0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_Name_Addr_Header() {
				var result0, result1, result2, result3, result4, result5, result6;
				var pos0, pos1, pos2;

				pos0 = pos;
				pos1 = pos;
				result0 = [];
				result1 = parse_display_name();
				while (result1 !== null) {
					result0.push(result1);
					result1 = parse_display_name();
				}
				if (result0 !== null) {
					result1 = parse_LAQUOT();
					if (result1 !== null) {
						result2 = parse_SIP_URI();
						if (result2 !== null) {
							result3 = parse_RAQUOT();
							if (result3 !== null) {
								result4 = [];
								pos2 = pos;
								result5 = parse_SEMI();
								if (result5 !== null) {
									result6 = parse_generic_param();
									if (result6 !== null) {
										result5 = [result5, result6];
									} else {
										result5 = null;
										pos = pos2;
									}
								} else {
									result5 = null;
									pos = pos2;
								}
								while (result5 !== null) {
									result4.push(result5);
									pos2 = pos;
									result5 = parse_SEMI();
									if (result5 !== null) {
										result6 = parse_generic_param();
										if (result6 !== null) {
											result5 = [result5, result6];
										} else {
											result5 = null;
											pos = pos2;
										}
									} else {
										result5 = null;
										pos = pos2;
									}
								}
								if (result4 !== null) {
									result0 = [result0, result1, result2, result3, result4];
								} else {
									result0 = null;
									pos = pos1;
								}
							} else {
								result0 = null;
								pos = pos1;
							}
						} else {
							result0 = null;
							pos = pos1;
						}
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset) {
						try {
							data = new JsSIP.NameAddrHeader(data.uri, data.display_name, data.params);
						} catch (e) {
							data = -1;
						}
					})(pos0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_Proxy_Authenticate() {
				var result0;

				result0 = parse_challenge();
				return result0;
			}

			function parse_challenge() {
				var result0, result1, result2, result3, result4, result5;
				var pos0, pos1;

				pos0 = pos;
				if (input.substr(pos, 6).toLowerCase() === "digest") {
					result0 = input.substr(pos, 6);
					pos += 6;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"Digest\"");
					}
				}
				if (result0 !== null) {
					result1 = parse_LWS();
					if (result1 !== null) {
						result2 = parse_digest_cln();
						if (result2 !== null) {
							result3 = [];
							pos1 = pos;
							result4 = parse_COMMA();
							if (result4 !== null) {
								result5 = parse_digest_cln();
								if (result5 !== null) {
									result4 = [result4, result5];
								} else {
									result4 = null;
									pos = pos1;
								}
							} else {
								result4 = null;
								pos = pos1;
							}
							while (result4 !== null) {
								result3.push(result4);
								pos1 = pos;
								result4 = parse_COMMA();
								if (result4 !== null) {
									result5 = parse_digest_cln();
									if (result5 !== null) {
										result4 = [result4, result5];
									} else {
										result4 = null;
										pos = pos1;
									}
								} else {
									result4 = null;
									pos = pos1;
								}
							}
							if (result3 !== null) {
								result0 = [result0, result1, result2, result3];
							} else {
								result0 = null;
								pos = pos0;
							}
						} else {
							result0 = null;
							pos = pos0;
						}
					} else {
						result0 = null;
						pos = pos0;
					}
				} else {
					result0 = null;
					pos = pos0;
				}
				if (result0 === null) {
					result0 = parse_other_challenge();
				}
				return result0;
			}

			function parse_other_challenge() {
				var result0, result1, result2, result3, result4, result5;
				var pos0, pos1;

				pos0 = pos;
				result0 = parse_token();
				if (result0 !== null) {
					result1 = parse_LWS();
					if (result1 !== null) {
						result2 = parse_auth_param();
						if (result2 !== null) {
							result3 = [];
							pos1 = pos;
							result4 = parse_COMMA();
							if (result4 !== null) {
								result5 = parse_auth_param();
								if (result5 !== null) {
									result4 = [result4, result5];
								} else {
									result4 = null;
									pos = pos1;
								}
							} else {
								result4 = null;
								pos = pos1;
							}
							while (result4 !== null) {
								result3.push(result4);
								pos1 = pos;
								result4 = parse_COMMA();
								if (result4 !== null) {
									result5 = parse_auth_param();
									if (result5 !== null) {
										result4 = [result4, result5];
									} else {
										result4 = null;
										pos = pos1;
									}
								} else {
									result4 = null;
									pos = pos1;
								}
							}
							if (result3 !== null) {
								result0 = [result0, result1, result2, result3];
							} else {
								result0 = null;
								pos = pos0;
							}
						} else {
							result0 = null;
							pos = pos0;
						}
					} else {
						result0 = null;
						pos = pos0;
					}
				} else {
					result0 = null;
					pos = pos0;
				}
				return result0;
			}

			function parse_auth_param() {
				var result0, result1, result2;
				var pos0;

				pos0 = pos;
				result0 = parse_token();
				if (result0 !== null) {
					result1 = parse_EQUAL();
					if (result1 !== null) {
						result2 = parse_token();
						if (result2 === null) {
							result2 = parse_quoted_string();
						}
						if (result2 !== null) {
							result0 = [result0, result1, result2];
						} else {
							result0 = null;
							pos = pos0;
						}
					} else {
						result0 = null;
						pos = pos0;
					}
				} else {
					result0 = null;
					pos = pos0;
				}
				return result0;
			}

			function parse_digest_cln() {
				var result0;

				result0 = parse_realm();
				if (result0 === null) {
					result0 = parse_domain();
					if (result0 === null) {
						result0 = parse_nonce();
						if (result0 === null) {
							result0 = parse_opaque();
							if (result0 === null) {
								result0 = parse_stale();
								if (result0 === null) {
									result0 = parse_algorithm();
									if (result0 === null) {
										result0 = parse_qop_options();
										if (result0 === null) {
											result0 = parse_auth_param();
										}
									}
								}
							}
						}
					}
				}
				return result0;
			}

			function parse_realm() {
				var result0, result1, result2;
				var pos0;

				pos0 = pos;
				if (input.substr(pos, 5).toLowerCase() === "realm") {
					result0 = input.substr(pos, 5);
					pos += 5;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"realm\"");
					}
				}
				if (result0 !== null) {
					result1 = parse_EQUAL();
					if (result1 !== null) {
						result2 = parse_realm_value();
						if (result2 !== null) {
							result0 = [result0, result1, result2];
						} else {
							result0 = null;
							pos = pos0;
						}
					} else {
						result0 = null;
						pos = pos0;
					}
				} else {
					result0 = null;
					pos = pos0;
				}
				return result0;
			}

			function parse_realm_value() {
				var result0;
				var pos0;

				pos0 = pos;
				result0 = parse_quoted_string_clean();
				if (result0 !== null) {
					result0 = (function (offset, realm) {
						data.realm = realm;
					})(pos0, result0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_domain() {
				var result0, result1, result2, result3, result4, result5, result6;
				var pos0, pos1;

				pos0 = pos;
				if (input.substr(pos, 6).toLowerCase() === "domain") {
					result0 = input.substr(pos, 6);
					pos += 6;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"domain\"");
					}
				}
				if (result0 !== null) {
					result1 = parse_EQUAL();
					if (result1 !== null) {
						result2 = parse_LDQUOT();
						if (result2 !== null) {
							result3 = parse_URI();
							if (result3 !== null) {
								result4 = [];
								pos1 = pos;
								result6 = parse_SP();
								if (result6 !== null) {
									result5 = [];
									while (result6 !== null) {
										result5.push(result6);
										result6 = parse_SP();
									}
								} else {
									result5 = null;
								}
								if (result5 !== null) {
									result6 = parse_URI();
									if (result6 !== null) {
										result5 = [result5, result6];
									} else {
										result5 = null;
										pos = pos1;
									}
								} else {
									result5 = null;
									pos = pos1;
								}
								while (result5 !== null) {
									result4.push(result5);
									pos1 = pos;
									result6 = parse_SP();
									if (result6 !== null) {
										result5 = [];
										while (result6 !== null) {
											result5.push(result6);
											result6 = parse_SP();
										}
									} else {
										result5 = null;
									}
									if (result5 !== null) {
										result6 = parse_URI();
										if (result6 !== null) {
											result5 = [result5, result6];
										} else {
											result5 = null;
											pos = pos1;
										}
									} else {
										result5 = null;
										pos = pos1;
									}
								}
								if (result4 !== null) {
									result5 = parse_RDQUOT();
									if (result5 !== null) {
										result0 = [result0, result1, result2, result3, result4, result5];
									} else {
										result0 = null;
										pos = pos0;
									}
								} else {
									result0 = null;
									pos = pos0;
								}
							} else {
								result0 = null;
								pos = pos0;
							}
						} else {
							result0 = null;
							pos = pos0;
						}
					} else {
						result0 = null;
						pos = pos0;
					}
				} else {
					result0 = null;
					pos = pos0;
				}
				return result0;
			}

			function parse_URI() {
				var result0;

				result0 = parse_absoluteURI();
				if (result0 === null) {
					result0 = parse_abs_path();
				}
				return result0;
			}

			function parse_nonce() {
				var result0, result1, result2;
				var pos0;

				pos0 = pos;
				if (input.substr(pos, 5).toLowerCase() === "nonce") {
					result0 = input.substr(pos, 5);
					pos += 5;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"nonce\"");
					}
				}
				if (result0 !== null) {
					result1 = parse_EQUAL();
					if (result1 !== null) {
						result2 = parse_nonce_value();
						if (result2 !== null) {
							result0 = [result0, result1, result2];
						} else {
							result0 = null;
							pos = pos0;
						}
					} else {
						result0 = null;
						pos = pos0;
					}
				} else {
					result0 = null;
					pos = pos0;
				}
				return result0;
			}

			function parse_nonce_value() {
				var result0;
				var pos0;

				pos0 = pos;
				result0 = parse_quoted_string_clean();
				if (result0 !== null) {
					result0 = (function (offset, nonce) {
						data.nonce = nonce;
					})(pos0, result0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_opaque() {
				var result0, result1, result2;
				var pos0, pos1;

				pos0 = pos;
				pos1 = pos;
				if (input.substr(pos, 6).toLowerCase() === "opaque") {
					result0 = input.substr(pos, 6);
					pos += 6;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"opaque\"");
					}
				}
				if (result0 !== null) {
					result1 = parse_EQUAL();
					if (result1 !== null) {
						result2 = parse_quoted_string_clean();
						if (result2 !== null) {
							result0 = [result0, result1, result2];
						} else {
							result0 = null;
							pos = pos1;
						}
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset, opaque) {
						data.opaque = opaque;
					})(pos0, result0[2]);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_stale() {
				var result0, result1, result2;
				var pos0, pos1;

				pos0 = pos;
				if (input.substr(pos, 5).toLowerCase() === "stale") {
					result0 = input.substr(pos, 5);
					pos += 5;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"stale\"");
					}
				}
				if (result0 !== null) {
					result1 = parse_EQUAL();
					if (result1 !== null) {
						pos1 = pos;
						if (input.substr(pos, 4).toLowerCase() === "true") {
							result2 = input.substr(pos, 4);
							pos += 4;
						} else {
							result2 = null;
							if (reportFailures === 0) {
								matchFailed("\"true\"");
							}
						}
						if (result2 !== null) {
							result2 = (function (offset) {
								data.stale = true;
							})(pos1);
						}
						if (result2 === null) {
							pos = pos1;
						}
						if (result2 === null) {
							pos1 = pos;
							if (input.substr(pos, 5).toLowerCase() === "false") {
								result2 = input.substr(pos, 5);
								pos += 5;
							} else {
								result2 = null;
								if (reportFailures === 0) {
									matchFailed("\"false\"");
								}
							}
							if (result2 !== null) {
								result2 = (function (offset) {
									data.stale = false;
								})(pos1);
							}
							if (result2 === null) {
								pos = pos1;
							}
						}
						if (result2 !== null) {
							result0 = [result0, result1, result2];
						} else {
							result0 = null;
							pos = pos0;
						}
					} else {
						result0 = null;
						pos = pos0;
					}
				} else {
					result0 = null;
					pos = pos0;
				}
				return result0;
			}

			function parse_algorithm() {
				var result0, result1, result2;
				var pos0, pos1;

				pos0 = pos;
				pos1 = pos;
				if (input.substr(pos, 9).toLowerCase() === "algorithm") {
					result0 = input.substr(pos, 9);
					pos += 9;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"algorithm\"");
					}
				}
				if (result0 !== null) {
					result1 = parse_EQUAL();
					if (result1 !== null) {
						if (input.substr(pos, 3).toLowerCase() === "md5") {
							result2 = input.substr(pos, 3);
							pos += 3;
						} else {
							result2 = null;
							if (reportFailures === 0) {
								matchFailed("\"MD5\"");
							}
						}
						if (result2 === null) {
							if (input.substr(pos, 8).toLowerCase() === "md5-sess") {
								result2 = input.substr(pos, 8);
								pos += 8;
							} else {
								result2 = null;
								if (reportFailures === 0) {
									matchFailed("\"MD5-sess\"");
								}
							}
							if (result2 === null) {
								result2 = parse_token();
							}
						}
						if (result2 !== null) {
							result0 = [result0, result1, result2];
						} else {
							result0 = null;
							pos = pos1;
						}
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset, algorithm) {
						data.algorithm = algorithm.toUpperCase();
					})(pos0, result0[2]);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_qop_options() {
				var result0, result1, result2, result3, result4, result5, result6;
				var pos0, pos1, pos2;

				pos0 = pos;
				if (input.substr(pos, 3).toLowerCase() === "qop") {
					result0 = input.substr(pos, 3);
					pos += 3;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"qop\"");
					}
				}
				if (result0 !== null) {
					result1 = parse_EQUAL();
					if (result1 !== null) {
						result2 = parse_LDQUOT();
						if (result2 !== null) {
							pos1 = pos;
							result3 = parse_qop_value();
							if (result3 !== null) {
								result4 = [];
								pos2 = pos;
								if (input.charCodeAt(pos) === 44) {
									result5 = ",";
									pos++;
								} else {
									result5 = null;
									if (reportFailures === 0) {
										matchFailed("\",\"");
									}
								}
								if (result5 !== null) {
									result6 = parse_qop_value();
									if (result6 !== null) {
										result5 = [result5, result6];
									} else {
										result5 = null;
										pos = pos2;
									}
								} else {
									result5 = null;
									pos = pos2;
								}
								while (result5 !== null) {
									result4.push(result5);
									pos2 = pos;
									if (input.charCodeAt(pos) === 44) {
										result5 = ",";
										pos++;
									} else {
										result5 = null;
										if (reportFailures === 0) {
											matchFailed("\",\"");
										}
									}
									if (result5 !== null) {
										result6 = parse_qop_value();
										if (result6 !== null) {
											result5 = [result5, result6];
										} else {
											result5 = null;
											pos = pos2;
										}
									} else {
										result5 = null;
										pos = pos2;
									}
								}
								if (result4 !== null) {
									result3 = [result3, result4];
								} else {
									result3 = null;
									pos = pos1;
								}
							} else {
								result3 = null;
								pos = pos1;
							}
							if (result3 !== null) {
								result4 = parse_RDQUOT();
								if (result4 !== null) {
									result0 = [result0, result1, result2, result3, result4];
								} else {
									result0 = null;
									pos = pos0;
								}
							} else {
								result0 = null;
								pos = pos0;
							}
						} else {
							result0 = null;
							pos = pos0;
						}
					} else {
						result0 = null;
						pos = pos0;
					}
				} else {
					result0 = null;
					pos = pos0;
				}
				return result0;
			}

			function parse_qop_value() {
				var result0;
				var pos0;

				pos0 = pos;
				if (input.substr(pos, 8).toLowerCase() === "auth-int") {
					result0 = input.substr(pos, 8);
					pos += 8;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"auth-int\"");
					}
				}
				if (result0 === null) {
					if (input.substr(pos, 4).toLowerCase() === "auth") {
						result0 = input.substr(pos, 4);
						pos += 4;
					} else {
						result0 = null;
						if (reportFailures === 0) {
							matchFailed("\"auth\"");
						}
					}
					if (result0 === null) {
						result0 = parse_token();
					}
				}
				if (result0 !== null) {
					result0 = (function (offset, qop_value) {
						data.qop || (data.qop = []);
						data.qop.push(qop_value.toLowerCase());
					})(pos0, result0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_Proxy_Require() {
				var result0, result1, result2, result3;
				var pos0, pos1;

				pos0 = pos;
				result0 = parse_token();
				if (result0 !== null) {
					result1 = [];
					pos1 = pos;
					result2 = parse_COMMA();
					if (result2 !== null) {
						result3 = parse_token();
						if (result3 !== null) {
							result2 = [result2, result3];
						} else {
							result2 = null;
							pos = pos1;
						}
					} else {
						result2 = null;
						pos = pos1;
					}
					while (result2 !== null) {
						result1.push(result2);
						pos1 = pos;
						result2 = parse_COMMA();
						if (result2 !== null) {
							result3 = parse_token();
							if (result3 !== null) {
								result2 = [result2, result3];
							} else {
								result2 = null;
								pos = pos1;
							}
						} else {
							result2 = null;
							pos = pos1;
						}
					}
					if (result1 !== null) {
						result0 = [result0, result1];
					} else {
						result0 = null;
						pos = pos0;
					}
				} else {
					result0 = null;
					pos = pos0;
				}
				return result0;
			}

			function parse_Record_Route() {
				var result0, result1, result2, result3;
				var pos0, pos1, pos2;

				pos0 = pos;
				pos1 = pos;
				result0 = parse_rec_route();
				if (result0 !== null) {
					result1 = [];
					pos2 = pos;
					result2 = parse_COMMA();
					if (result2 !== null) {
						result3 = parse_rec_route();
						if (result3 !== null) {
							result2 = [result2, result3];
						} else {
							result2 = null;
							pos = pos2;
						}
					} else {
						result2 = null;
						pos = pos2;
					}
					while (result2 !== null) {
						result1.push(result2);
						pos2 = pos;
						result2 = parse_COMMA();
						if (result2 !== null) {
							result3 = parse_rec_route();
							if (result3 !== null) {
								result2 = [result2, result3];
							} else {
								result2 = null;
								pos = pos2;
							}
						} else {
							result2 = null;
							pos = pos2;
						}
					}
					if (result1 !== null) {
						result0 = [result0, result1];
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset) {
						var idx;
						for (idx in data.multi_header) {
							if (data.multi_header[idx].parsed === null) {
								data = null;
								break;
							}
						}
						if (data !== null) {
							data = data.multi_header;
						} else {
							data = -1;
						}
					})(pos0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_rec_route() {
				var result0, result1, result2, result3;
				var pos0, pos1, pos2;

				pos0 = pos;
				pos1 = pos;
				result0 = parse_name_addr();
				if (result0 !== null) {
					result1 = [];
					pos2 = pos;
					result2 = parse_SEMI();
					if (result2 !== null) {
						result3 = parse_generic_param();
						if (result3 !== null) {
							result2 = [result2, result3];
						} else {
							result2 = null;
							pos = pos2;
						}
					} else {
						result2 = null;
						pos = pos2;
					}
					while (result2 !== null) {
						result1.push(result2);
						pos2 = pos;
						result2 = parse_SEMI();
						if (result2 !== null) {
							result3 = parse_generic_param();
							if (result3 !== null) {
								result2 = [result2, result3];
							} else {
								result2 = null;
								pos = pos2;
							}
						} else {
							result2 = null;
							pos = pos2;
						}
					}
					if (result1 !== null) {
						result0 = [result0, result1];
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset) {
						var header;
						if (!data.multi_header) data.multi_header = [];
						try {
							header = new JsSIP.NameAddrHeader(data.uri, data.display_name, data.params);
							delete data.uri;
							delete data.display_name;
							delete data.params;
						} catch (e) {
							header = null;
						}
						data.multi_header.push({ 'possition': pos,
							'offset': offset,
							'parsed': header
						});
					})(pos0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_Require() {
				var result0, result1, result2, result3;
				var pos0, pos1;

				pos0 = pos;
				result0 = parse_token();
				if (result0 !== null) {
					result1 = [];
					pos1 = pos;
					result2 = parse_COMMA();
					if (result2 !== null) {
						result3 = parse_token();
						if (result3 !== null) {
							result2 = [result2, result3];
						} else {
							result2 = null;
							pos = pos1;
						}
					} else {
						result2 = null;
						pos = pos1;
					}
					while (result2 !== null) {
						result1.push(result2);
						pos1 = pos;
						result2 = parse_COMMA();
						if (result2 !== null) {
							result3 = parse_token();
							if (result3 !== null) {
								result2 = [result2, result3];
							} else {
								result2 = null;
								pos = pos1;
							}
						} else {
							result2 = null;
							pos = pos1;
						}
					}
					if (result1 !== null) {
						result0 = [result0, result1];
					} else {
						result0 = null;
						pos = pos0;
					}
				} else {
					result0 = null;
					pos = pos0;
				}
				return result0;
			}

			function parse_Route() {
				var result0, result1, result2, result3;
				var pos0, pos1;

				pos0 = pos;
				result0 = parse_route_param();
				if (result0 !== null) {
					result1 = [];
					pos1 = pos;
					result2 = parse_COMMA();
					if (result2 !== null) {
						result3 = parse_route_param();
						if (result3 !== null) {
							result2 = [result2, result3];
						} else {
							result2 = null;
							pos = pos1;
						}
					} else {
						result2 = null;
						pos = pos1;
					}
					while (result2 !== null) {
						result1.push(result2);
						pos1 = pos;
						result2 = parse_COMMA();
						if (result2 !== null) {
							result3 = parse_route_param();
							if (result3 !== null) {
								result2 = [result2, result3];
							} else {
								result2 = null;
								pos = pos1;
							}
						} else {
							result2 = null;
							pos = pos1;
						}
					}
					if (result1 !== null) {
						result0 = [result0, result1];
					} else {
						result0 = null;
						pos = pos0;
					}
				} else {
					result0 = null;
					pos = pos0;
				}
				return result0;
			}

			function parse_route_param() {
				var result0, result1, result2, result3;
				var pos0, pos1;

				pos0 = pos;
				result0 = parse_name_addr();
				if (result0 !== null) {
					result1 = [];
					pos1 = pos;
					result2 = parse_SEMI();
					if (result2 !== null) {
						result3 = parse_generic_param();
						if (result3 !== null) {
							result2 = [result2, result3];
						} else {
							result2 = null;
							pos = pos1;
						}
					} else {
						result2 = null;
						pos = pos1;
					}
					while (result2 !== null) {
						result1.push(result2);
						pos1 = pos;
						result2 = parse_SEMI();
						if (result2 !== null) {
							result3 = parse_generic_param();
							if (result3 !== null) {
								result2 = [result2, result3];
							} else {
								result2 = null;
								pos = pos1;
							}
						} else {
							result2 = null;
							pos = pos1;
						}
					}
					if (result1 !== null) {
						result0 = [result0, result1];
					} else {
						result0 = null;
						pos = pos0;
					}
				} else {
					result0 = null;
					pos = pos0;
				}
				return result0;
			}

			function parse_Subscription_State() {
				var result0, result1, result2, result3;
				var pos0, pos1;

				pos0 = pos;
				result0 = parse_substate_value();
				if (result0 !== null) {
					result1 = [];
					pos1 = pos;
					result2 = parse_SEMI();
					if (result2 !== null) {
						result3 = parse_subexp_params();
						if (result3 !== null) {
							result2 = [result2, result3];
						} else {
							result2 = null;
							pos = pos1;
						}
					} else {
						result2 = null;
						pos = pos1;
					}
					while (result2 !== null) {
						result1.push(result2);
						pos1 = pos;
						result2 = parse_SEMI();
						if (result2 !== null) {
							result3 = parse_subexp_params();
							if (result3 !== null) {
								result2 = [result2, result3];
							} else {
								result2 = null;
								pos = pos1;
							}
						} else {
							result2 = null;
							pos = pos1;
						}
					}
					if (result1 !== null) {
						result0 = [result0, result1];
					} else {
						result0 = null;
						pos = pos0;
					}
				} else {
					result0 = null;
					pos = pos0;
				}
				return result0;
			}

			function parse_substate_value() {
				var result0;
				var pos0;

				pos0 = pos;
				if (input.substr(pos, 6).toLowerCase() === "active") {
					result0 = input.substr(pos, 6);
					pos += 6;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"active\"");
					}
				}
				if (result0 === null) {
					if (input.substr(pos, 7).toLowerCase() === "pending") {
						result0 = input.substr(pos, 7);
						pos += 7;
					} else {
						result0 = null;
						if (reportFailures === 0) {
							matchFailed("\"pending\"");
						}
					}
					if (result0 === null) {
						if (input.substr(pos, 10).toLowerCase() === "terminated") {
							result0 = input.substr(pos, 10);
							pos += 10;
						} else {
							result0 = null;
							if (reportFailures === 0) {
								matchFailed("\"terminated\"");
							}
						}
						if (result0 === null) {
							result0 = parse_token();
						}
					}
				}
				if (result0 !== null) {
					result0 = (function (offset) {
						data.state = input.substring(pos, offset);
					})(pos0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_subexp_params() {
				var result0, result1, result2;
				var pos0, pos1;

				pos0 = pos;
				pos1 = pos;
				if (input.substr(pos, 6).toLowerCase() === "reason") {
					result0 = input.substr(pos, 6);
					pos += 6;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"reason\"");
					}
				}
				if (result0 !== null) {
					result1 = parse_EQUAL();
					if (result1 !== null) {
						result2 = parse_event_reason_value();
						if (result2 !== null) {
							result0 = [result0, result1, result2];
						} else {
							result0 = null;
							pos = pos1;
						}
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset, reason) {
						if (typeof reason !== 'undefined') data.reason = reason;
					})(pos0, result0[2]);
				}
				if (result0 === null) {
					pos = pos0;
				}
				if (result0 === null) {
					pos0 = pos;
					pos1 = pos;
					if (input.substr(pos, 7).toLowerCase() === "expires") {
						result0 = input.substr(pos, 7);
						pos += 7;
					} else {
						result0 = null;
						if (reportFailures === 0) {
							matchFailed("\"expires\"");
						}
					}
					if (result0 !== null) {
						result1 = parse_EQUAL();
						if (result1 !== null) {
							result2 = parse_delta_seconds();
							if (result2 !== null) {
								result0 = [result0, result1, result2];
							} else {
								result0 = null;
								pos = pos1;
							}
						} else {
							result0 = null;
							pos = pos1;
						}
					} else {
						result0 = null;
						pos = pos1;
					}
					if (result0 !== null) {
						result0 = (function (offset, expires) {
							if (typeof expires !== 'undefined') data.expires = expires;
						})(pos0, result0[2]);
					}
					if (result0 === null) {
						pos = pos0;
					}
					if (result0 === null) {
						pos0 = pos;
						pos1 = pos;
						if (input.substr(pos, 11).toLowerCase() === "retry_after") {
							result0 = input.substr(pos, 11);
							pos += 11;
						} else {
							result0 = null;
							if (reportFailures === 0) {
								matchFailed("\"retry_after\"");
							}
						}
						if (result0 !== null) {
							result1 = parse_EQUAL();
							if (result1 !== null) {
								result2 = parse_delta_seconds();
								if (result2 !== null) {
									result0 = [result0, result1, result2];
								} else {
									result0 = null;
									pos = pos1;
								}
							} else {
								result0 = null;
								pos = pos1;
							}
						} else {
							result0 = null;
							pos = pos1;
						}
						if (result0 !== null) {
							result0 = (function (offset, retry_after) {
								if (typeof retry_after !== 'undefined') data.retry_after = retry_after;
							})(pos0, result0[2]);
						}
						if (result0 === null) {
							pos = pos0;
						}
						if (result0 === null) {
							result0 = parse_generic_param();
						}
					}
				}
				return result0;
			}

			function parse_event_reason_value() {
				var result0;

				if (input.substr(pos, 11).toLowerCase() === "deactivated") {
					result0 = input.substr(pos, 11);
					pos += 11;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"deactivated\"");
					}
				}
				if (result0 === null) {
					if (input.substr(pos, 9).toLowerCase() === "probation") {
						result0 = input.substr(pos, 9);
						pos += 9;
					} else {
						result0 = null;
						if (reportFailures === 0) {
							matchFailed("\"probation\"");
						}
					}
					if (result0 === null) {
						if (input.substr(pos, 8).toLowerCase() === "rejected") {
							result0 = input.substr(pos, 8);
							pos += 8;
						} else {
							result0 = null;
							if (reportFailures === 0) {
								matchFailed("\"rejected\"");
							}
						}
						if (result0 === null) {
							if (input.substr(pos, 7).toLowerCase() === "timeout") {
								result0 = input.substr(pos, 7);
								pos += 7;
							} else {
								result0 = null;
								if (reportFailures === 0) {
									matchFailed("\"timeout\"");
								}
							}
							if (result0 === null) {
								if (input.substr(pos, 6).toLowerCase() === "giveup") {
									result0 = input.substr(pos, 6);
									pos += 6;
								} else {
									result0 = null;
									if (reportFailures === 0) {
										matchFailed("\"giveup\"");
									}
								}
								if (result0 === null) {
									if (input.substr(pos, 10).toLowerCase() === "noresource") {
										result0 = input.substr(pos, 10);
										pos += 10;
									} else {
										result0 = null;
										if (reportFailures === 0) {
											matchFailed("\"noresource\"");
										}
									}
									if (result0 === null) {
										if (input.substr(pos, 9).toLowerCase() === "invariant") {
											result0 = input.substr(pos, 9);
											pos += 9;
										} else {
											result0 = null;
											if (reportFailures === 0) {
												matchFailed("\"invariant\"");
											}
										}
										if (result0 === null) {
											result0 = parse_token();
										}
									}
								}
							}
						}
					}
				}
				return result0;
			}

			function parse_Subject() {
				var result0;

				result0 = parse_TEXT_UTF8_TRIM();
				result0 = result0 !== null ? result0 : "";
				return result0;
			}

			function parse_Supported() {
				var result0, result1, result2, result3;
				var pos0, pos1;

				pos0 = pos;
				result0 = parse_token();
				if (result0 !== null) {
					result1 = [];
					pos1 = pos;
					result2 = parse_COMMA();
					if (result2 !== null) {
						result3 = parse_token();
						if (result3 !== null) {
							result2 = [result2, result3];
						} else {
							result2 = null;
							pos = pos1;
						}
					} else {
						result2 = null;
						pos = pos1;
					}
					while (result2 !== null) {
						result1.push(result2);
						pos1 = pos;
						result2 = parse_COMMA();
						if (result2 !== null) {
							result3 = parse_token();
							if (result3 !== null) {
								result2 = [result2, result3];
							} else {
								result2 = null;
								pos = pos1;
							}
						} else {
							result2 = null;
							pos = pos1;
						}
					}
					if (result1 !== null) {
						result0 = [result0, result1];
					} else {
						result0 = null;
						pos = pos0;
					}
				} else {
					result0 = null;
					pos = pos0;
				}
				result0 = result0 !== null ? result0 : "";
				return result0;
			}

			function parse_To() {
				var result0, result1, result2, result3;
				var pos0, pos1, pos2;

				pos0 = pos;
				pos1 = pos;
				result0 = parse_SIP_URI_noparams();
				if (result0 === null) {
					result0 = parse_name_addr();
				}
				if (result0 !== null) {
					result1 = [];
					pos2 = pos;
					result2 = parse_SEMI();
					if (result2 !== null) {
						result3 = parse_to_param();
						if (result3 !== null) {
							result2 = [result2, result3];
						} else {
							result2 = null;
							pos = pos2;
						}
					} else {
						result2 = null;
						pos = pos2;
					}
					while (result2 !== null) {
						result1.push(result2);
						pos2 = pos;
						result2 = parse_SEMI();
						if (result2 !== null) {
							result3 = parse_to_param();
							if (result3 !== null) {
								result2 = [result2, result3];
							} else {
								result2 = null;
								pos = pos2;
							}
						} else {
							result2 = null;
							pos = pos2;
						}
					}
					if (result1 !== null) {
						result0 = [result0, result1];
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset) {
						var tag = data.tag;
						try {
							data = new JsSIP.NameAddrHeader(data.uri, data.display_name, data.params);
							if (tag) {
								data.setParam('tag', tag)
							}
						} catch (e) {
							data = -1;
						}
					})(pos0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_to_param() {
				var result0;

				result0 = parse_tag_param();
				if (result0 === null) {
					result0 = parse_generic_param();
				}
				return result0;
			}

			function parse_Via() {
				var result0, result1, result2, result3;
				var pos0, pos1;

				pos0 = pos;
				result0 = parse_via_parm();
				if (result0 !== null) {
					result1 = [];
					pos1 = pos;
					result2 = parse_COMMA();
					if (result2 !== null) {
						result3 = parse_via_parm();
						if (result3 !== null) {
							result2 = [result2, result3];
						} else {
							result2 = null;
							pos = pos1;
						}
					} else {
						result2 = null;
						pos = pos1;
					}
					while (result2 !== null) {
						result1.push(result2);
						pos1 = pos;
						result2 = parse_COMMA();
						if (result2 !== null) {
							result3 = parse_via_parm();
							if (result3 !== null) {
								result2 = [result2, result3];
							} else {
								result2 = null;
								pos = pos1;
							}
						} else {
							result2 = null;
							pos = pos1;
						}
					}
					if (result1 !== null) {
						result0 = [result0, result1];
					} else {
						result0 = null;
						pos = pos0;
					}
				} else {
					result0 = null;
					pos = pos0;
				}
				return result0;
			}

			function parse_via_parm() {
				var result0, result1, result2, result3, result4, result5;
				var pos0, pos1;

				pos0 = pos;
				result0 = parse_sent_protocol();
				if (result0 !== null) {
					result1 = parse_LWS();
					if (result1 !== null) {
						result2 = parse_sent_by();
						if (result2 !== null) {
							result3 = [];
							pos1 = pos;
							result4 = parse_SEMI();
							if (result4 !== null) {
								result5 = parse_via_params();
								if (result5 !== null) {
									result4 = [result4, result5];
								} else {
									result4 = null;
									pos = pos1;
								}
							} else {
								result4 = null;
								pos = pos1;
							}
							while (result4 !== null) {
								result3.push(result4);
								pos1 = pos;
								result4 = parse_SEMI();
								if (result4 !== null) {
									result5 = parse_via_params();
									if (result5 !== null) {
										result4 = [result4, result5];
									} else {
										result4 = null;
										pos = pos1;
									}
								} else {
									result4 = null;
									pos = pos1;
								}
							}
							if (result3 !== null) {
								result0 = [result0, result1, result2, result3];
							} else {
								result0 = null;
								pos = pos0;
							}
						} else {
							result0 = null;
							pos = pos0;
						}
					} else {
						result0 = null;
						pos = pos0;
					}
				} else {
					result0 = null;
					pos = pos0;
				}
				return result0;
			}

			function parse_via_params() {
				var result0;

				result0 = parse_via_ttl();
				if (result0 === null) {
					result0 = parse_via_maddr();
					if (result0 === null) {
						result0 = parse_via_received();
						if (result0 === null) {
							result0 = parse_via_branch();
							if (result0 === null) {
								result0 = parse_response_port();
								if (result0 === null) {
									result0 = parse_generic_param();
								}
							}
						}
					}
				}
				return result0;
			}

			function parse_via_ttl() {
				var result0, result1, result2;
				var pos0, pos1;

				pos0 = pos;
				pos1 = pos;
				if (input.substr(pos, 3).toLowerCase() === "ttl") {
					result0 = input.substr(pos, 3);
					pos += 3;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"ttl\"");
					}
				}
				if (result0 !== null) {
					result1 = parse_EQUAL();
					if (result1 !== null) {
						result2 = parse_ttl();
						if (result2 !== null) {
							result0 = [result0, result1, result2];
						} else {
							result0 = null;
							pos = pos1;
						}
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset, via_ttl_value) {
						data.ttl = via_ttl_value;
					})(pos0, result0[2]);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_via_maddr() {
				var result0, result1, result2;
				var pos0, pos1;

				pos0 = pos;
				pos1 = pos;
				if (input.substr(pos, 5).toLowerCase() === "maddr") {
					result0 = input.substr(pos, 5);
					pos += 5;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"maddr\"");
					}
				}
				if (result0 !== null) {
					result1 = parse_EQUAL();
					if (result1 !== null) {
						result2 = parse_host();
						if (result2 !== null) {
							result0 = [result0, result1, result2];
						} else {
							result0 = null;
							pos = pos1;
						}
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset, via_maddr) {
						data.maddr = via_maddr;
					})(pos0, result0[2]);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_via_received() {
				var result0, result1, result2;
				var pos0, pos1;

				pos0 = pos;
				pos1 = pos;
				if (input.substr(pos, 8).toLowerCase() === "received") {
					result0 = input.substr(pos, 8);
					pos += 8;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"received\"");
					}
				}
				if (result0 !== null) {
					result1 = parse_EQUAL();
					if (result1 !== null) {
						result2 = parse_IPv4address();
						if (result2 === null) {
							result2 = parse_IPv6address();
						}
						if (result2 !== null) {
							result0 = [result0, result1, result2];
						} else {
							result0 = null;
							pos = pos1;
						}
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset, via_received) {
						data.received = via_received;
					})(pos0, result0[2]);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_via_branch() {
				var result0, result1, result2;
				var pos0, pos1;

				pos0 = pos;
				pos1 = pos;
				if (input.substr(pos, 6).toLowerCase() === "branch") {
					result0 = input.substr(pos, 6);
					pos += 6;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"branch\"");
					}
				}
				if (result0 !== null) {
					result1 = parse_EQUAL();
					if (result1 !== null) {
						result2 = parse_token();
						if (result2 !== null) {
							result0 = [result0, result1, result2];
						} else {
							result0 = null;
							pos = pos1;
						}
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset, via_branch) {
						data.branch = via_branch;
					})(pos0, result0[2]);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_response_port() {
				var result0, result1, result2, result3;
				var pos0, pos1, pos2;

				pos0 = pos;
				pos1 = pos;
				if (input.substr(pos, 5).toLowerCase() === "rport") {
					result0 = input.substr(pos, 5);
					pos += 5;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"rport\"");
					}
				}
				if (result0 !== null) {
					pos2 = pos;
					result1 = parse_EQUAL();
					if (result1 !== null) {
						result2 = [];
						result3 = parse_DIGIT();
						while (result3 !== null) {
							result2.push(result3);
							result3 = parse_DIGIT();
						}
						if (result2 !== null) {
							result1 = [result1, result2];
						} else {
							result1 = null;
							pos = pos2;
						}
					} else {
						result1 = null;
						pos = pos2;
					}
					result1 = result1 !== null ? result1 : "";
					if (result1 !== null) {
						result0 = [result0, result1];
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset) {
						if (typeof response_port !== 'undefined')
							data.rport = response_port.join('');
					})(pos0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_sent_protocol() {
				var result0, result1, result2, result3, result4;
				var pos0;

				pos0 = pos;
				result0 = parse_protocol_name();
				if (result0 !== null) {
					result1 = parse_SLASH();
					if (result1 !== null) {
						result2 = parse_token();
						if (result2 !== null) {
							result3 = parse_SLASH();
							if (result3 !== null) {
								result4 = parse_transport();
								if (result4 !== null) {
									result0 = [result0, result1, result2, result3, result4];
								} else {
									result0 = null;
									pos = pos0;
								}
							} else {
								result0 = null;
								pos = pos0;
							}
						} else {
							result0 = null;
							pos = pos0;
						}
					} else {
						result0 = null;
						pos = pos0;
					}
				} else {
					result0 = null;
					pos = pos0;
				}
				return result0;
			}

			function parse_protocol_name() {
				var result0;
				var pos0;

				pos0 = pos;
				if (input.substr(pos, 3).toLowerCase() === "sip") {
					result0 = input.substr(pos, 3);
					pos += 3;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"SIP\"");
					}
				}
				if (result0 === null) {
					result0 = parse_token();
				}
				if (result0 !== null) {
					result0 = (function (offset, via_protocol) {
						data.protocol = via_protocol;
					})(pos0, result0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_transport() {
				var result0;
				var pos0;

				pos0 = pos;
				if (input.substr(pos, 3).toLowerCase() === "udp") {
					result0 = input.substr(pos, 3);
					pos += 3;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"UDP\"");
					}
				}
				if (result0 === null) {
					if (input.substr(pos, 3).toLowerCase() === "tcp") {
						result0 = input.substr(pos, 3);
						pos += 3;
					} else {
						result0 = null;
						if (reportFailures === 0) {
							matchFailed("\"TCP\"");
						}
					}
					if (result0 === null) {
						if (input.substr(pos, 3).toLowerCase() === "tls") {
							result0 = input.substr(pos, 3);
							pos += 3;
						} else {
							result0 = null;
							if (reportFailures === 0) {
								matchFailed("\"TLS\"");
							}
						}
						if (result0 === null) {
							if (input.substr(pos, 4).toLowerCase() === "sctp") {
								result0 = input.substr(pos, 4);
								pos += 4;
							} else {
								result0 = null;
								if (reportFailures === 0) {
									matchFailed("\"SCTP\"");
								}
							}
							if (result0 === null) {
								result0 = parse_token();
							}
						}
					}
				}
				if (result0 !== null) {
					result0 = (function (offset, via_transport) {
						data.transport = via_transport;
					})(pos0, result0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_sent_by() {
				var result0, result1, result2;
				var pos0, pos1;

				pos0 = pos;
				result0 = parse_via_host();
				if (result0 !== null) {
					pos1 = pos;
					result1 = parse_COLON();
					if (result1 !== null) {
						result2 = parse_via_port();
						if (result2 !== null) {
							result1 = [result1, result2];
						} else {
							result1 = null;
							pos = pos1;
						}
					} else {
						result1 = null;
						pos = pos1;
					}
					result1 = result1 !== null ? result1 : "";
					if (result1 !== null) {
						result0 = [result0, result1];
					} else {
						result0 = null;
						pos = pos0;
					}
				} else {
					result0 = null;
					pos = pos0;
				}
				return result0;
			}

			function parse_via_host() {
				var result0;
				var pos0;

				pos0 = pos;
				result0 = parse_hostname();
				if (result0 === null) {
					result0 = parse_IPv4address();
					if (result0 === null) {
						result0 = parse_IPv6reference();
					}
				}
				if (result0 !== null) {
					result0 = (function (offset) {
						data.host = input.substring(pos, offset);
					})(pos0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_via_port() {
				var result0, result1, result2, result3, result4;
				var pos0, pos1;

				pos0 = pos;
				pos1 = pos;
				result0 = parse_DIGIT();
				result0 = result0 !== null ? result0 : "";
				if (result0 !== null) {
					result1 = parse_DIGIT();
					result1 = result1 !== null ? result1 : "";
					if (result1 !== null) {
						result2 = parse_DIGIT();
						result2 = result2 !== null ? result2 : "";
						if (result2 !== null) {
							result3 = parse_DIGIT();
							result3 = result3 !== null ? result3 : "";
							if (result3 !== null) {
								result4 = parse_DIGIT();
								result4 = result4 !== null ? result4 : "";
								if (result4 !== null) {
									result0 = [result0, result1, result2, result3, result4];
								} else {
									result0 = null;
									pos = pos1;
								}
							} else {
								result0 = null;
								pos = pos1;
							}
						} else {
							result0 = null;
							pos = pos1;
						}
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset, via_sent_by_port) {
						data.port = parseInt(via_sent_by_port.join(''));
					})(pos0, result0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_ttl() {
				var result0, result1, result2;
				var pos0, pos1;

				pos0 = pos;
				pos1 = pos;
				result0 = parse_DIGIT();
				if (result0 !== null) {
					result1 = parse_DIGIT();
					result1 = result1 !== null ? result1 : "";
					if (result1 !== null) {
						result2 = parse_DIGIT();
						result2 = result2 !== null ? result2 : "";
						if (result2 !== null) {
							result0 = [result0, result1, result2];
						} else {
							result0 = null;
							pos = pos1;
						}
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset, ttl) {
						return parseInt(ttl.join(''));
					})(pos0, result0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_WWW_Authenticate() {
				var result0;

				result0 = parse_challenge();
				return result0;
			}

			function parse_extension_header() {
				var result0, result1, result2;
				var pos0;

				pos0 = pos;
				result0 = parse_token();
				if (result0 !== null) {
					result1 = parse_HCOLON();
					if (result1 !== null) {
						result2 = parse_header_value();
						if (result2 !== null) {
							result0 = [result0, result1, result2];
						} else {
							result0 = null;
							pos = pos0;
						}
					} else {
						result0 = null;
						pos = pos0;
					}
				} else {
					result0 = null;
					pos = pos0;
				}
				return result0;
			}

			function parse_header_value() {
				var result0, result1;

				result0 = [];
				result1 = parse_TEXT_UTF8char();
				if (result1 === null) {
					result1 = parse_UTF8_CONT();
					if (result1 === null) {
						result1 = parse_LWS();
					}
				}
				while (result1 !== null) {
					result0.push(result1);
					result1 = parse_TEXT_UTF8char();
					if (result1 === null) {
						result1 = parse_UTF8_CONT();
						if (result1 === null) {
							result1 = parse_LWS();
						}
					}
				}
				return result0;
			}

			function parse_message_body() {
				var result0, result1;

				result0 = [];
				result1 = parse_OCTET();
				while (result1 !== null) {
					result0.push(result1);
					result1 = parse_OCTET();
				}
				return result0;
			}

			function parse_stun_URI() {
				var result0, result1, result2;
				var pos0;

				pos0 = pos;
				result0 = parse_stun_scheme();
				if (result0 !== null) {
					if (input.charCodeAt(pos) === 58) {
						result1 = ":";
						pos++;
					} else {
						result1 = null;
						if (reportFailures === 0) {
							matchFailed("\":\"");
						}
					}
					if (result1 !== null) {
						result2 = parse_stun_host_port();
						if (result2 !== null) {
							result0 = [result0, result1, result2];
						} else {
							result0 = null;
							pos = pos0;
						}
					} else {
						result0 = null;
						pos = pos0;
					}
				} else {
					result0 = null;
					pos = pos0;
				}
				return result0;
			}

			function parse_stun_scheme() {
				var result0;
				var pos0;

				pos0 = pos;
				if (input.substr(pos, 5).toLowerCase() === "stuns") {
					result0 = input.substr(pos, 5);
					pos += 5;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"stuns\"");
					}
				}
				if (result0 === null) {
					if (input.substr(pos, 4).toLowerCase() === "stun") {
						result0 = input.substr(pos, 4);
						pos += 4;
					} else {
						result0 = null;
						if (reportFailures === 0) {
							matchFailed("\"stun\"");
						}
					}
				}
				if (result0 !== null) {
					result0 = (function (offset, scheme) {
						data.scheme = scheme;
					})(pos0, result0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_stun_host_port() {
				var result0, result1, result2;
				var pos0, pos1;

				pos0 = pos;
				result0 = parse_stun_host();
				if (result0 !== null) {
					pos1 = pos;
					if (input.charCodeAt(pos) === 58) {
						result1 = ":";
						pos++;
					} else {
						result1 = null;
						if (reportFailures === 0) {
							matchFailed("\":\"");
						}
					}
					if (result1 !== null) {
						result2 = parse_port();
						if (result2 !== null) {
							result1 = [result1, result2];
						} else {
							result1 = null;
							pos = pos1;
						}
					} else {
						result1 = null;
						pos = pos1;
					}
					result1 = result1 !== null ? result1 : "";
					if (result1 !== null) {
						result0 = [result0, result1];
					} else {
						result0 = null;
						pos = pos0;
					}
				} else {
					result0 = null;
					pos = pos0;
				}
				return result0;
			}

			function parse_stun_host() {
				var result0;
				var pos0;

				pos0 = pos;
				result0 = parse_IPv4address();
				if (result0 === null) {
					result0 = parse_IPv6reference();
					if (result0 === null) {
						result0 = parse_reg_name();
					}
				}
				if (result0 !== null) {
					result0 = (function (offset, host) {
						data.host = host;
					})(pos0, result0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_reg_name() {
				var result0, result1;
				var pos0;

				pos0 = pos;
				result0 = [];
				result1 = parse_stun_unreserved();
				if (result1 === null) {
					result1 = parse_escaped();
					if (result1 === null) {
						result1 = parse_sub_delims();
					}
				}
				while (result1 !== null) {
					result0.push(result1);
					result1 = parse_stun_unreserved();
					if (result1 === null) {
						result1 = parse_escaped();
						if (result1 === null) {
							result1 = parse_sub_delims();
						}
					}
				}
				if (result0 !== null) {
					result0 = (function (offset) {
						return input.substring(pos, offset);
					})(pos0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_stun_unreserved() {
				var result0;

				result0 = parse_ALPHA();
				if (result0 === null) {
					result0 = parse_DIGIT();
					if (result0 === null) {
						if (input.charCodeAt(pos) === 45) {
							result0 = "-";
							pos++;
						} else {
							result0 = null;
							if (reportFailures === 0) {
								matchFailed("\"-\"");
							}
						}
						if (result0 === null) {
							if (input.charCodeAt(pos) === 46) {
								result0 = ".";
								pos++;
							} else {
								result0 = null;
								if (reportFailures === 0) {
									matchFailed("\".\"");
								}
							}
							if (result0 === null) {
								if (input.charCodeAt(pos) === 95) {
									result0 = "_";
									pos++;
								} else {
									result0 = null;
									if (reportFailures === 0) {
										matchFailed("\"_\"");
									}
								}
								if (result0 === null) {
									if (input.charCodeAt(pos) === 126) {
										result0 = "~";
										pos++;
									} else {
										result0 = null;
										if (reportFailures === 0) {
											matchFailed("\"~\"");
										}
									}
								}
							}
						}
					}
				}
				return result0;
			}

			function parse_sub_delims() {
				var result0;

				if (input.charCodeAt(pos) === 33) {
					result0 = "!";
					pos++;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"!\"");
					}
				}
				if (result0 === null) {
					if (input.charCodeAt(pos) === 36) {
						result0 = "$";
						pos++;
					} else {
						result0 = null;
						if (reportFailures === 0) {
							matchFailed("\"$\"");
						}
					}
					if (result0 === null) {
						if (input.charCodeAt(pos) === 38) {
							result0 = "&";
							pos++;
						} else {
							result0 = null;
							if (reportFailures === 0) {
								matchFailed("\"&\"");
							}
						}
						if (result0 === null) {
							if (input.charCodeAt(pos) === 39) {
								result0 = "'";
								pos++;
							} else {
								result0 = null;
								if (reportFailures === 0) {
									matchFailed("\"'\"");
								}
							}
							if (result0 === null) {
								if (input.charCodeAt(pos) === 40) {
									result0 = "(";
									pos++;
								} else {
									result0 = null;
									if (reportFailures === 0) {
										matchFailed("\"(\"");
									}
								}
								if (result0 === null) {
									if (input.charCodeAt(pos) === 41) {
										result0 = ")";
										pos++;
									} else {
										result0 = null;
										if (reportFailures === 0) {
											matchFailed("\")\"");
										}
									}
									if (result0 === null) {
										if (input.charCodeAt(pos) === 42) {
											result0 = "*";
											pos++;
										} else {
											result0 = null;
											if (reportFailures === 0) {
												matchFailed("\"*\"");
											}
										}
										if (result0 === null) {
											if (input.charCodeAt(pos) === 43) {
												result0 = "+";
												pos++;
											} else {
												result0 = null;
												if (reportFailures === 0) {
													matchFailed("\"+\"");
												}
											}
											if (result0 === null) {
												if (input.charCodeAt(pos) === 44) {
													result0 = ",";
													pos++;
												} else {
													result0 = null;
													if (reportFailures === 0) {
														matchFailed("\",\"");
													}
												}
												if (result0 === null) {
													if (input.charCodeAt(pos) === 59) {
														result0 = ";";
														pos++;
													} else {
														result0 = null;
														if (reportFailures === 0) {
															matchFailed("\";\"");
														}
													}
													if (result0 === null) {
														if (input.charCodeAt(pos) === 61) {
															result0 = "=";
															pos++;
														} else {
															result0 = null;
															if (reportFailures === 0) {
																matchFailed("\"=\"");
															}
														}
													}
												}
											}
										}
									}
								}
							}
						}
					}
				}
				return result0;
			}

			function parse_turn_URI() {
				var result0, result1, result2, result3, result4;
				var pos0, pos1;

				pos0 = pos;
				result0 = parse_turn_scheme();
				if (result0 !== null) {
					if (input.charCodeAt(pos) === 58) {
						result1 = ":";
						pos++;
					} else {
						result1 = null;
						if (reportFailures === 0) {
							matchFailed("\":\"");
						}
					}
					if (result1 !== null) {
						result2 = parse_stun_host_port();
						if (result2 !== null) {
							pos1 = pos;
							if (input.substr(pos, 11) === "?transport=") {
								result3 = "?transport=";
								pos += 11;
							} else {
								result3 = null;
								if (reportFailures === 0) {
									matchFailed("\"?transport=\"");
								}
							}
							if (result3 !== null) {
								result4 = parse_transport();
								if (result4 !== null) {
									result3 = [result3, result4];
								} else {
									result3 = null;
									pos = pos1;
								}
							} else {
								result3 = null;
								pos = pos1;
							}
							result3 = result3 !== null ? result3 : "";
							if (result3 !== null) {
								result0 = [result0, result1, result2, result3];
							} else {
								result0 = null;
								pos = pos0;
							}
						} else {
							result0 = null;
							pos = pos0;
						}
					} else {
						result0 = null;
						pos = pos0;
					}
				} else {
					result0 = null;
					pos = pos0;
				}
				return result0;
			}

			function parse_turn_scheme() {
				var result0;
				var pos0;

				pos0 = pos;
				if (input.substr(pos, 5).toLowerCase() === "turns") {
					result0 = input.substr(pos, 5);
					pos += 5;
				} else {
					result0 = null;
					if (reportFailures === 0) {
						matchFailed("\"turns\"");
					}
				}
				if (result0 === null) {
					if (input.substr(pos, 4).toLowerCase() === "turn") {
						result0 = input.substr(pos, 4);
						pos += 4;
					} else {
						result0 = null;
						if (reportFailures === 0) {
							matchFailed("\"turn\"");
						}
					}
				}
				if (result0 !== null) {
					result0 = (function (offset, scheme) {
						data.scheme = scheme;
					})(pos0, result0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}

			function parse_turn_transport() {
				var result0, result1, result2;
				var pos0, pos1;

				pos0 = pos;
				pos1 = pos;
				result0 = parse_transport();
				if (result0 !== null) {
					if (input.substr(pos, 3).toLowerCase() === "udp") {
						result1 = input.substr(pos, 3);
						pos += 3;
					} else {
						result1 = null;
						if (reportFailures === 0) {
							matchFailed("\"udp\"");
						}
					}
					if (result1 === null) {
						if (input.substr(pos, 3).toLowerCase() === "tcp") {
							result1 = input.substr(pos, 3);
							pos += 3;
						} else {
							result1 = null;
							if (reportFailures === 0) {
								matchFailed("\"tcp\"");
							}
						}
						if (result1 === null) {
							result1 = [];
							result2 = parse_unreserved();
							while (result2 !== null) {
								result1.push(result2);
								result2 = parse_unreserved();
							}
						}
					}
					if (result1 !== null) {
						result0 = [result0, result1];
					} else {
						result0 = null;
						pos = pos1;
					}
				} else {
					result0 = null;
					pos = pos1;
				}
				if (result0 !== null) {
					result0 = (function (offset) {
						data.transport = transport;
					})(pos0);
				}
				if (result0 === null) {
					pos = pos0;
				}
				return result0;
			}


			function cleanupExpected(expected) {
				expected.sort();

				var lastExpected = null;
				var cleanExpected = [];
				for (var i = 0; i < expected.length; i++) {
					if (expected[i] !== lastExpected) {
						cleanExpected.push(expected[i]);
						lastExpected = expected[i];
					}
				}
				return cleanExpected;
			}

			function computeErrorPosition() {
				/*
				 * The first idea was to use |String.split| to break the input up to the
				 * error position along newlines and derive the line and column from
				 * there. However IE's |split| implementation is so broken that it was
				 * enough to prevent it.
				 */

				var line = 1;
				var column = 1;
				var seenCR = false;

				for (var i = 0; i < Math.max(pos, rightmostFailuresPos); i++) {
					var ch = input.charAt(i);
					if (ch === "\n") {
						if (!seenCR) {
							line++;
						}
						column = 1;
						seenCR = false;
					} else if (ch === "\r" || ch === "\u2028" || ch === "\u2029") {
						line++;
						column = 1;
						seenCR = true;
					} else {
						column++;
						seenCR = false;
					}
				}

				return { line: line, column: column };
			}

			var data = {};

			var result = parseFunctions[startRule]();

			/*
			 * The parser is now in one of the following three states:
			 *
			 * 1. The parser successfully parsed the whole input.
			 *
			 *    - |result !== null|
			 *    - |pos === input.length|
			 *    - |rightmostFailuresExpected| may or may not contain something
			 *
			 * 2. The parser successfully parsed only a part of the input.
			 *
			 *    - |result !== null|
			 *    - |pos < input.length|
			 *    - |rightmostFailuresExpected| may or may not contain something
			 *
			 * 3. The parser did not successfully parse any part of the input.
			 *
			 *   - |result === null|
			 *   - |pos === 0|
			 *   - |rightmostFailuresExpected| contains at least one failure
			 *
			 * All code following this comment (including called functions) must
			 * handle these states.
			 */
			if (result === null || pos !== input.length) {
				var offset = Math.max(pos, rightmostFailuresPos);
				var found = offset < input.length ? input.charAt(offset) : null;
				var errorPosition = computeErrorPosition();

				new this.SyntaxError(
					cleanupExpected(rightmostFailuresExpected),
					found,
					offset,
					errorPosition.line,
					errorPosition.column
				);
				return -1;
			}

			return data;
		},

		/* Returns the parser source code. */
		toSource: function () {
			return this._source;
		}
	};

	/* Thrown when a parser encounters a syntax error. */

	result.SyntaxError = function (expected, found, offset, line, column) {
		function buildMessage(expected, found) {
			var expectedHumanized, foundHumanized;

			switch (expected.length) {
				case 0:
					expectedHumanized = "end of input";
					break;
				case 1:
					expectedHumanized = expected[0];
					break;
				default:
					expectedHumanized = expected.slice(0, expected.length - 1).join(", ")
						+ " or "
						+ expected[expected.length - 1];
			}

			foundHumanized = found ? quote(found) : "end of input";

			return "Expected " + expectedHumanized + " but " + foundHumanized + " found.";
		}

		this.name = "SyntaxError";
		this.expected = expected;
		this.found = found;
		this.message = buildMessage(expected, found);
		this.offset = offset;
		this.line = line;
		this.column = column;
	};

	result.SyntaxError.prototype = Error.prototype;

	return result;
})();

// Generated by CoffeeScript 1.6.2
var oktellVoice,
  __slice = [].slice,
  __hasProp = {}.hasOwnProperty,
  __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

oktellVoice = (function() {
  var Account, JsSIPAccount, SIPml5Account, currentAcc, debugMode, eventSplitter, events, extend, key, log, logErr, logStr, manager, okVoice, userMedia, _i, _len, _ref,
    _this = this;

  debugMode = false;
  logStr = '';
  log = function() {
    var args, d, dd, e, fnName, i, t, val, _i, _len;

    args = 1 <= arguments.length ? __slice.call(arguments, 0) : [];
    if (!debugMode) {
      return;
    }
    d = new Date();
    dd = d.getFullYear() + '-' + (d.getMonth() < 10 ? '0' : '') + d.getMonth() + '-' + (d.getDate() < 10 ? '0' : '') + d.getDate();
    t = (d.getHours() < 10 ? '0' : '') + d.getHours() + ':' + (d.getMinutes() < 10 ? '0' : '') + d.getMinutes() + ':' + (d.getSeconds() < 10 ? '0' : '') + d.getSeconds() + ':' + (d.getMilliseconds() + 1000).toString().substr(1);
    logStr += dd + ' ' + t + ' | ';
    fnName = 'log';
    if (args[0].toString().toLowerCase() === 'error') {
      fnName = 'error';
    }
    for (i = _i = 0, _len = args.length; _i < _len; i = ++_i) {
      val = args[i];
      if (typeof val === 'object') {
        try {
          logStr += JSON.stringify(val);
        } catch (_error) {
          e = _error;
          logStr += val.toString();
        }
      } else {
        logStr += val;
      }
      logStr += ' | ';
    }
    logStr += "\n\n";
    args.unshift('Oktell-Voice.js ' + t + ' |');
    try {
      return console[fnName].apply(console, args || []);
    } catch (_error) {
      e = _error;
    }
  };
  logErr = function() {
    var args;

    args = 1 <= arguments.length ? __slice.call(arguments, 0) : [];
    return log.apply(this, ['error'].concat(args));
  };
  eventSplitter = /\s+/;
  events = {
    on: function(eventNames, callback, context) {
      var callbacks, event, eventCallbacks, _i, _len;

      if (!eventNames || typeof callback !== 'function') {
        return false;
      }
      eventNames = eventNames.split(eventSplitter);
      callbacks = this.__eventCallbacks || (this.__eventCallbacks = {});
      for (_i = 0, _len = eventNames.length; _i < _len; _i++) {
        event = eventNames[_i];
        eventCallbacks = callbacks[event] || (callbacks[event] = []);
        eventCallbacks.push({
          fn: callback,
          context: context
        });
      }
      return true;
    },
    off: function(eventNames, callback) {
      var callbacks, event, eventCallback, eventCallbacks, i, _i, _j, _k, _len, _len1, _len2;

      if (eventNames == null) {
        this.__eventCallbacks = {};
      } else {
        callbacks = this.__eventCallbacks || (this.__eventCallbacks = {});
        eventNames = eventNames.split(eventSplitter);
        if (callback == null) {
          for (_i = 0, _len = eventNames.length; _i < _len; _i++) {
            event = eventNames[_i];
            delete callbacks[event];
          }
        } else {
          for (_j = 0, _len1 = eventNames.length; _j < _len1; _j++) {
            event = eventNames[_j];
            eventCallbacks = callbacks[event] || (callbacks[event] = []);
            for (i = _k = 0, _len2 = eventCallbacks.length; _k < _len2; i = ++_k) {
              eventCallback = eventCallbacks[i];
              if (eventCallback.fn === callback) {
                eventCallbacks[i] = false;
              }
            }
          }
        }
      }
      return true;
    },
    trigger: function() {
      var args, callbacks, event, eventCallbacks, eventInfo, eventNames, _i, _j, _len, _len1, _results;

      eventNames = arguments[0], args = 2 <= arguments.length ? __slice.call(arguments, 1) : [];
      if (!eventNames) {
        return false;
      }
      eventNames = eventNames.split(eventSplitter);
      callbacks = this.__eventCallbacks || (this.__eventCallbacks = {});
      _results = [];
      for (_i = 0, _len = eventNames.length; _i < _len; _i++) {
        event = eventNames[_i];
        eventCallbacks = callbacks[event] || (callbacks[event] = []);
        for (_j = 0, _len1 = eventCallbacks.length; _j < _len1; _j++) {
          eventInfo = eventCallbacks[_j];
          if (eventInfo.fn != null) {
            eventInfo.fn.apply(eventInfo.context || window, args);
          }
        }
        args.unshift(event);
        _results.push((function() {
          var _k, _len2, _ref, _results1;

          _ref = callbacks['all'] || [];
          _results1 = [];
          for (_k = 0, _len2 = _ref.length; _k < _len2; _k++) {
            eventInfo = _ref[_k];
            if (eventInfo.fn != null) {
              _results1.push(eventInfo.fn.apply(eventInfo.context || window, args));
            } else {
              _results1.push(void 0);
            }
          }
          return _results1;
        })());
      }
      return _results;
    }
  };
  extend = function() {
    var args, i, key, target, val, _i, _ref, _ref1;

    target = arguments[0], args = 2 <= arguments.length ? __slice.call(arguments, 1) : [];
    for (i = _i = _ref = args.length - 1; _ref <= 0 ? _i <= 0 : _i >= 0; i = _ref <= 0 ? ++_i : --_i) {
      if (typeof args[i] === 'object') {
        _ref1 = args[i];
        for (key in _ref1) {
          if (!__hasProp.call(_ref1, key)) continue;
          val = _ref1[key];
          target[key] = val;
        }
      }
    }
    return target;
  };
  okVoice = {
    isOktellVoice: true
  };
  extend(okVoice, events);
  Account = (function() {
    Account.prototype.id = '';

    Account.prototype.connected = false;

    function Account(sipObject, login, pass, server) {
      var _this = this;

      this.sip = sipObject;
      this.login = login;
      this.pass = pass || '';
      this.server = server != null ? server.split(':')[0] : void 0;
      this.port = (server != null ? server.split(':')[1] : void 0) || '5060';
      if (this.sip && this.login && this.server && this.port) {
        this.constructed = true;
      }
      this.name = 'Common account';
      this.on('all', function() {
        var args, event;

        event = arguments[0], args = 2 <= arguments.length ? __slice.call(arguments, 1) : [];
        return log('EVENT ' + event + ' on ' + _this.getName(), args);
      });
    }

    Account.prototype.getName = function() {
      return this.name + ' #' + this.id;
    };

    Account.prototype.connect = function() {
      if (!this.constructed) {
        logErr('error while consctruct ' + this.getName());
        return false;
      } else {
        log(this.getName() + ' connect', arguments);
        return true;
      }
    };

    Account.prototype.call = function(number) {
      if (!number) {
        return false;
      }
      log(this.getName() + ' call', arguments);
      return true;
    };

    Account.prototype.answer = function() {
      return log(this.getName() + ' answer', arguments);
    };

    Account.prototype.transfer = function(to) {
      if (!to) {
        return false;
      }
      log(this.getName() + ' transfer', arguments);
      return true;
    };

    Account.prototype.hangup = function() {
      return log(this.getName() + ' hangup', arguments);
    };

    Account.prototype.dtmf = function() {
      return log(this.getName() + ' dtmf', arguments);
    };

    Account.prototype.hold = function() {
      return log(this.getName() + ' hold', arguments);
    };

    Account.prototype.resume = function() {
      return log(this.getName() + ' resume', arguments);
    };

    Account.prototype.reject = function() {
      return log(this.getName() + ' reject', arguments);
    };

    Account.prototype.disconnect = function() {
      return log(this.getName() + ' disconnect', arguments);
    };

    Account.prototype.isConnected = function() {
      return this.connected;
    };

    return Account;

  })();
  extend(Account.prototype, events);
  SIPml5Account = (function(_super) {
    __extends(SIPml5Account, _super);

    function SIPml5Account() {
      SIPml5Account.__super__.constructor.apply(this, arguments);
      this.name = 'SIPml5 account';
    }

    SIPml5Account.prototype.createFantomAbonent = function(newSession) {
      var abonents, caller;

      caller = typeof newSession === 'string' || typeof newSession === 'number' ? newSession : newSession.getRemoteFriendlyName();
      abonents = [
        {
          phone: caller.toString(),
          name: caller.toString()
        }
      ];
      return abonents;
    };

    SIPml5Account.prototype.sipStack = false;

    SIPml5Account.prototype.goLogin = function() {
      var _this = this;

      this.registerSession = this.sipStack.newSession('register', {
        events_listener: {
          events: '*',
          listener: function(e) {
            log('registerSession event = ' + e.type);
            if (e.session === _this.registerSession) {
              if (e.type === 'connected') {
                _this.connected = true;
                return _this.trigger('connect');
              } else if (e.type === 'terminated') {
                _this.connected = false;
                return _this.trigger('disconnect');
              }
            }
          }
        }
      });
      return this.registerSession.register();
    };

    SIPml5Account.prototype.createAudioElement = function() {
      this.el = document.createElement('audio');
      this.elId = 'oktellVoice_sipml5_' + Date.now();
      return this.el.setAttribute('id', this.elId);
    };

    SIPml5Account.prototype.connect = function() {
      var _this = this;

      if (!SIPml5Account.__super__.connect.apply(this, arguments)) {
        return false;
      }
      if (!this.el) {
        this.createAudioElement();
      }
      this.sip.debugMode = debugMode;
      return this.sip.init(function(e) {
        _this.sipStack = new _this.sip.Stack({
          realm: _this.server,
          impi: _this.login,
          impu: 'sip:' + _this.login + '@' + _this.server,
          password: _this.pass,
          display_name: _this.login,
          ice_servers: [
            {
              "url": "stun:stun.l.google.com:19302"
            }
          ],
          websocket_proxy_url: 'ws://' + _this.server + ':' + _this.port,
          outbound_proxy_url: 'udp://' + _this.server + ':' + _this.port,
          enable_rtcweb_breaker: false,
          events_listener: {
            events: '*',
            listener: function(e) {
              var abonents, session;

              log('sipStack event = ' + e.type);
              switch (e.type) {
                case 'started':
                  return _this.goLogin();
                case 'i_new_call':
                  abonents = _this.createFantomAbonent(e.newSession);
                  _this.currentSession = e.newSession;
                  session = _this.currentSession;
                  session.setConfiguration({
                    audio_remote: _this.el,
                    events_listener: {
                      events: '*',
                      listener: function(e) {
                        log('INCOMING session event!!! ' + e.type);
                        if (e.type === 'connected') {
                          abonents = _this.createFantomAbonent(session);
                          session.eventTalkStart = true;
                          return _this.trigger('talkStart', session.getRemoteFriendlyName());
                        } else if (e.type === 'terminated') {
                          if (session.eventRingStart && !session.eventRingStop) {
                            session.eventRingStop = true;
                            _this.trigger('ringStop', session.getRemoteFriendlyName());
                          }
                          if (session.eventTalkStart) {
                            session.eventTalkStop = true;
                            _this.trigger('talkStop', session.getRemoteFriendlyName());
                          }
                          _this.currentSession = false;
                          return _this.trigger('sessionClose');
                        }
                      }
                    }
                  });
                  session.eventRingStart = true;
                  return _this.trigger('ringStart', session.getRemoteFriendlyName());
                case 'm_permission_requested':
                  if (!okVoice.getUserMediaStream()) {
                    return okVoice.trigger('mediaPermissionsRequest');
                  }
                  break;
                case 'm_permission_accepted':
                  if (!okVoice.getUserMediaStream()) {
                    return okVoice.trigger('mediaPermissionsAccept');
                  }
                  break;
                case 'm_permission_refused':
                  if (!okVoice.getUserMediaStream()) {
                    return okVoice.trigger('mediaPermissionsRefuse');
                  }
              }
            }
          },
          sip_headers: [
            {
              name: 'User-Agent',
              value: 'Oktell WebRTC'
            }, {
              name: 'Organization',
              value: 'Oktell'
            }
          ]
        });
        return _this.sipStack.start();
      }, function(e) {
        return logErr('Failed to initialize the engine: ' + e.message);
      });
    };

    SIPml5Account.prototype.call = function(number) {
      var abonents, session,
        _this = this;

      if (!SIPml5Account.__super__.call.apply(this, arguments)) {
        return false;
      }
      number = number.toString();
      session = this.sipStack.newSession('call-audio', {
        audio_remote: this.el,
        events_listener: {
          events: '*',
          listener: function(e) {
            var abonents;

            if (_this.currentSession === e.session) {
              log('!! callSession event = ' + e.type);
              if (e.type === 'terminated') {
                if (session.eventTalkStart) {
                  session.eventTalkStop = true;
                  _this.trigger('talkStop', session.getRemoteFriendlyName());
                }
                _this.currentSession = false;
                return _this.trigger('sessionClose');
              } else if (e.type === 'connected') {
                abonents = _this.createFantomAbonent(e.session);
                if (session.eventCallStart && !session.eventCallStop) {
                  session.eventCallStop = true;
                  _this.trigger('callStop', session.getRemoteFriendlyName());
                }
                session.eventTalkStart = true;
                return _this.trigger('talkStart', session.getRemoteFriendlyName());
              }
            }
          }
        }
      });
      this.currentSession = session;
      abonents = this.createFantomAbonent(number);
      session.eventCallStart = true;
      this.trigger('callStart', number);
      return this.currentSession.call(number);
    };

    SIPml5Account.prototype.answer = function() {
      var _ref;

      SIPml5Account.__super__.answer.apply(this, arguments);
      return (_ref = this.currentSession) != null ? typeof _ref.accept === "function" ? _ref.accept() : void 0 : void 0;
    };

    SIPml5Account.prototype.hangup = function() {
      var _ref;

      SIPml5Account.__super__.hangup.apply(this, arguments);
      return (_ref = this.currentSession) != null ? typeof _ref.hangup === "function" ? _ref.hangup() : void 0 : void 0;
    };

    SIPml5Account.prototype.reject = function() {
      var _ref;

      SIPml5Account.__super__.reject.apply(this, arguments);
      return (_ref = this.currentSession) != null ? typeof _ref.reject === "function" ? _ref.reject() : void 0 : void 0;
    };

    SIPml5Account.prototype.hold = function() {
      var _ref;

      SIPml5Account.__super__.hold.apply(this, arguments);
      return (_ref = this.currentSession) != null ? typeof _ref.hold === "function" ? _ref.hold() : void 0 : void 0;
    };

    SIPml5Account.prototype.resume = function() {
      var _ref;

      SIPml5Account.__super__.resume.apply(this, arguments);
      return (_ref = this.currentSession) != null ? typeof _ref.resume === "function" ? _ref.resume() : void 0 : void 0;
    };

    SIPml5Account.prototype.dtmf = function(digit) {
      var _ref;

      SIPml5Account.__super__.dtmf.apply(this, arguments);
      return (_ref = this.currentSession) != null ? typeof _ref.dtmf === "function" ? _ref.dtmf(digit) : void 0 : void 0;
    };

    SIPml5Account.prototype.transfer = function(to) {
      var _ref;

      if (!SIPml5Account.__super__.transfer.apply(this, arguments)) {
        return false;
      }
      return (_ref = this.currentSession) != null ? typeof _ref.transfer === "function" ? _ref.transfer(to.toString()) : void 0 : void 0;
    };

    SIPml5Account.prototype.disconnect = function() {
      this.sipStack.stop();
      return setTimeout(function() {
        return location.reload();
      }, 500);
    };

    return SIPml5Account;

  })(Account);
  JsSIPAccount = (function(_super) {
    __extends(JsSIPAccount, _super);

    function JsSIPAccount() {
      JsSIPAccount.__super__.constructor.apply(this, arguments);
      this.name = 'JsSIP account';
    }

    JsSIPAccount.prototype.createFantomAbonent = function(newSession) {
      var abonents, caller;

      caller = typeof newSession === 'string' || typeof newSession === 'number' ? newSession : newSession.getRemoteFriendlyName();
      abonents = [
        {
          phone: caller.toString(),
          name: caller.toString()
        }
      ];
      return abonents;
    };

    JsSIPAccount.prototype.currentSession = false;

    JsSIPAccount.prototype.connectedFired = false;

    JsSIPAccount.prototype.createAudioElements = function() {
      this.elLocal = document.createElement('audio');
      this.elRemote = document.createElement('audio');
      this.elLocalId = 'oktellVoice_jssip_local_' + Date.now();
      this.elRemoteId = 'oktellVoice_jssip_remote_' + Date.now();
      this.elLocal.setAttribute('id', this.elLocalId);
      this.elRemote.setAttribute('id', this.elRemoteId);
      document.body.appendChild(this.elLocal);
      return document.body.appendChild(this.elRemote);
    };

    JsSIPAccount.prototype.connect = function() {
      var config,
        _this = this;

      if (!JsSIPAccount.__super__.connect.apply(this, arguments)) {
        return false;
      }
      if (!this.elLocal) {
        this.createAudioElements();
      }
      config = {
        ws_servers: 'ws://' + this.server + ':' + this.port,
        uri: 'sip:' + this.login + '@' + this.server,
        password: this.pass,
        trace_sip: debugMode,
        via_host: this.server
      };
      this.UA = new this.sip.UA(config);
      window.sipua = this.UA;
      this.UA.on('connected', function(e) {
        return log('connected', e);
      });
      this.UA.on('connected', function(e) {
        _this.connectedFired = false;
        return log('disconnected', e);
      });
      this.UA.on('registered', function(e) {
        log('registered', e);
        _this.connected = true;
        if (!_this.connectedFired) {
          _this.connectedFired = true;
          return _this.trigger('connect');
        }
      });
      this.UA.on('unregistered', function(e) {
        log('unregistered', e);
        _this.connected = false;
        return _this.trigger('disconnect');
      });
      this.UA.on('registrationFailed', function(e) {
        log('registration failed', e);
        _this.connected = false;
        return _this.trigger('disconnect');
      });
      this.UA.on('mediaPermissionsRequest', function(e) {
        log('media permissions request', e);
        return _this.trigger('mediaPermissionsRequest');
      });
      this.UA.on('mediaPermissionsAccept', function(e) {
        log('media permissions accept', e);
        return _this.trigger('mediaPermissionsAccept');
      });
      this.UA.on('mediaPermissionsRefuse', function(e) {
        log('media permissions refuse', e);
        return _this.trigger('mediaPermissionsRefuse');
      });
      this.UA.on('newRTCSession', function(e) {
        log('new RTC session', e);
        _this.currentSession = e.data.session;
        _this.currentSession.on('progress', function(e) {
          return log('currentSession progress', e);
        });
        _this.currentSession.on('failed', function(e) {
          return log('currentSession failed', e);
        });
        _this.currentSession.on('started', function(e) {
          var rtcSession;

          log('currentSession started', e);
          rtcSession = e.sender;
          if (rtcSession.getLocalStreams().length > 0) {
            log('currentSession local stream > 0');
            _this.elLocal.src = window.URL.createObjectURL(rtcSession.getLocalStreams()[0]);
          } else {
            log('currentSession local stream == 0');
          }
          if (rtcSession.getRemoteStreams().length > 0) {
            log('currentSession remote stream > 0', rtcSession.getRemoteStreams()[0].getAudioTracks());
            _this.elRemote.src = window.URL.createObjectURL(rtcSession.getRemoteStreams()[0]);
            return _this.elRemote.play();
          } else {
            return log('currentSession remote stream == 0');
          }
        });
        return _this.currentSession.on('ended', function(e) {
          return log('currentSession ended');
        });
      });
      return this.UA.start();
    };

    JsSIPAccount.prototype.call = function(number) {
      var options;

      if (!JsSIPAccount.__super__.call.apply(this, arguments)) {
        return false;
      }
      if (!this.connected) {
        return false;
      }
      number = number.toString();
      options = {
        mediaConstraints: {
          'audio': true,
          'video': false
        }
      };
      return this.UA.call(number, options);
    };

    JsSIPAccount.prototype.answer = function() {
      var _ref;

      JsSIPAccount.__super__.answer.apply(this, arguments);
      return (_ref = this.currentSession) != null ? typeof _ref.answer === "function" ? _ref.answer({
        'audio': true,
        'video': false
      }) : void 0 : void 0;
    };

    JsSIPAccount.prototype.hangup = function() {
      var _ref;

      JsSIPAccount.__super__.hangup.apply(this, arguments);
      return (_ref = this.currentSession) != null ? typeof _ref.terminate === "function" ? _ref.terminate() : void 0 : void 0;
    };

    JsSIPAccount.prototype.reject = function() {
      var _ref;

      JsSIPAccount.__super__.reject.apply(this, arguments);
      return (_ref = this.currentSession) != null ? typeof _ref.terminate === "function" ? _ref.terminate() : void 0 : void 0;
    };

    JsSIPAccount.prototype.hold = function() {
      var _ref;

      JsSIPAccount.__super__.hold.apply(this, arguments);
      return (_ref = this.currentSession) != null ? typeof _ref.hold === "function" ? _ref.hold() : void 0 : void 0;
    };

    JsSIPAccount.prototype.resume = function() {
      var _ref;

      JsSIPAccount.__super__.resume.apply(this, arguments);
      return (_ref = this.currentSession) != null ? typeof _ref.resume === "function" ? _ref.resume() : void 0 : void 0;
    };

    JsSIPAccount.prototype.dtmf = function(digit) {
      var _ref;

      JsSIPAccount.__super__.dtmf.apply(this, arguments);
      return (_ref = this.currentSession) != null ? typeof _ref.sendDTMF === "function" ? _ref.sendDTMF(digit) : void 0 : void 0;
    };

    JsSIPAccount.prototype.transfer = function(to) {
      var _ref;

      if (!JsSIPAccount.__super__.transfer.apply(this, arguments)) {
        return false;
      }
      return (_ref = this.currentSession) != null ? typeof _ref.transfer === "function" ? _ref.transfer(to.toString()) : void 0 : void 0;
    };

    JsSIPAccount.prototype.disconnect = function() {
      return this.UA.stop();
    };

    return JsSIPAccount;

  })(Account);
  userMedia = false;
  okVoice.createUserMedia = function(onSuccess, onDeny, useVideo) {
    var getUserMedia, hasDecision;

    if (userMedia) {
      return typeof onSuccess === "function" ? onSuccess(userMedia) : void 0;
    }
    getUserMedia = navigator.getUserMedia || navigator.webkitGetUserMedia || navigator.mozGetUserMedia || navigator.msGetUserMedia;
    if (typeof getUserMedia !== 'function') {
      return false;
    }
    hasDecision = false;
    setTimeout(function() {
      if (!hasDecision) {
        return okVoice.trigger('mediaPermissionsRequest');
      }
    }, 500);
    return getUserMedia.call(navigator, {
      audio: true,
      video: useVideo
    }, function(st) {
      hasDecision = true;
      userMedia = st;
      okVoice.trigger('mediaPermissionsAccept');
      return typeof onSuccess === "function" ? onSuccess(userMedia) : void 0;
    }, function(st) {
      hasDecision = true;
      okVoice.trigger('mediaPermissionsRefuse');
      return typeof onDeny === "function" ? onDeny(st) : void 0;
    });
  };
  okVoice.getUserMediaStream = function() {
    return userMedia;
  };
  manager = {
    accounts: [],
    defaultAcc: null,
    defaultOptions: {
      typeName: 'jssip',
      debugMode: false
    },
    getSipObject: function(typeName) {
      switch (typeName) {
        case 'sipml5':
          return window.SIPmlCreate();
        case 'jssip':
          return window.JsSIP;
      }
    },
    getClassByTypeName: function(name) {
      switch (name) {
        case 'sipml5':
          return SIPml5Account;
        case 'jssip':
          return JsSIPAccount;
      }
    },
    exportKeys: ['call', 'answer', 'hangup', 'transfer', 'hold', 'resume', 'dtmf', 'reject', 'disconnect', 'isConnected'],
    createExportAccount: function(account) {
      var a, key, _i, _len, _ref,
        _this = this;

      if (account == null) {
        return false;
      }
      a = {};
      _ref = this.exportKeys;
      for (_i = 0, _len = _ref.length; _i < _len; _i++) {
        key = _ref[_i];
        if (account[key] != null) {
          (function() {
            var val;

            val = account[key];
            return a[key] = function() {
              return val.apply(account, arguments);
            };
          })();
        }
      }
      extend(a, events);
      account.on('all', function() {
        var args;

        args = 1 <= arguments.length ? __slice.call(arguments, 0) : [];
        return a.trigger.apply(a, args);
      });
      return a;
    },
    createAccount: function(opts) {
      var acc, accClass, sipObject, _ref;

      opts = extend({}, opts || {}, this.defaultOptions);
      sipObject = opts.type || this.getSipObject(opts.typeName);
      accClass = this.getClassByTypeName(opts.typeName);
      if (!sipObject || !accClass) {
        return false;
      }
      debugMode = Boolean(opts.debugMode);
      acc = new accClass(sipObject, opts.login, opts.password, opts.server);
      if ((_ref = this.defaultAcc) == null) {
        this.defaultAcc = acc;
      }
      acc.id = this.accounts.length + 1;
      this.accounts.push(acc);
      acc.connect();
      return acc;
    }
  };
  _ref = manager.exportKeys;
  for (_i = 0, _len = _ref.length; _i < _len; _i++) {
    key = _ref[_i];
    okVoice[key] = function() {
      return false;
    };
  }
  currentAcc = null;
  okVoice.connect = function() {
    var acc,
      _this = this;

    if (currentAcc) {
      if (!(currentAcc != null ? typeof currentAcc.isConnected === "function" ? currentAcc.isConnected() : void 0 : void 0)) {
        currentAcc.connect();
      }
      return currentAcc;
    } else {
      acc = manager.createAccount.apply(manager, arguments);
      currentAcc = manager.createExportAccount(acc);
      if (acc === manager.defaultAcc) {
        extend(okVoice, currentAcc);
        currentAcc.on('all', function() {
          var args;

          args = 1 <= arguments.length ? __slice.call(arguments, 0) : [];
          return okVoice.trigger.apply(okVoice, args);
        });
        okVoice.on('all', function() {
          var args, eventname;

          eventname = arguments[0], args = 2 <= arguments.length ? __slice.call(arguments, 1) : [];
          return console.log('oktellVoice!!!!!!!!!!!!!!!!!!!! EVENT ' + eventname, args);
        });
      }
      return currentAcc;
    }
  };
  okVoice.disconnect = function() {};
  okVoice.version = '0.1.0';
  return okVoice;
})();
